(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    244899,       8386]*)
(*NotebookOutlinePosition[    246075,       8424]*)
(*  CellTagsIndexPosition[    246031,       8420]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["EXAMPLE 4",
  FontSize->46,
  FontColor->RGBColor[1, 0, 0]]], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell["Mass-spring systems", "Subsection",
  FontSize->24,
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "We analyse the mass-spring systems for different values of ",
  StyleBox["spring constant",
    FontColor->RGBColor[0, 0, 1]],
  " k, with k>0, and the ",
  StyleBox["damping constant",
    FontColor->RGBColor[0, 0, 1]],
  " n, n>0. Then we solve the equation mx''[t]+ nx'[t]+kx[t]=f[t]. We study \
the unforced equation (f(t)= 0), and forced equation ",
  StyleBox["with ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "f(t)= F*Sin(w t), periodical force and we only analyse this case. We try \
to analyse different cases according different values of parameters m, n and \
k. Then we define the equation with input ",
  StyleBox["command",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  ".\nFirst we define the parameters of equation m x''[t]+ n x'[t]+k x[t]= F \
Sin[w t]"
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[m, n, k]\), "\n", 
    \(m = Input[m]; n = Input[n]; k = Input[k]; Print[{m, n, k}]\)}], "Input",\

  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \({1, 0, 4}\)], "Print"],

Cell[TextData[{
  "We give now the ",
  StyleBox["frequency ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "of forced term and we advise of the possible resonance."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[w]\), "\n", 
    \(w = Input[w]; Print[w]; 
    If[n == 0, Print["\<Possible resonance\>"]]\)}], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \("Possible resonance"\)], "Print"],

Cell[TextData[{
  "If the above answer is ",
  StyleBox["possible ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "resonance we try to see if the ",
  StyleBox["phenomenon ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "appears."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(If[w == \@\(k\/m\), Print["\<RESONANCE\>"], 
      Print["\<NO RESONANCE\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \("RESONANCE"\)], "Print"],

Cell[TextData[{
  "We define the equation. Previously we define the ",
  StyleBox["amplitude ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "of the wave."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[f]\), "\n", 
    \(f = Input[f]; Print[f];\)}], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    RowBox[{"ecua", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"m", " ", 
            RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
                MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"n", " ", 
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "+", \(k\ x[t]\)}], "\[Equal]", \(f*Sin[w\ t]\)}]}]], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(4\ x[t]\), "+", 
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], 
      "\[Equal]", \(5\ Sin[2\ t]\)}]], "Output"],

Cell["UNFORCED MOVEMENT", "Subsection",
  FontSize->24,
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "We observe the nature of the roots of the characteristic polynomial to \
analyse",
  StyleBox[" the natural response or free response ",
    FontColor->RGBColor[0, 0, 1]],
  "of the system.\nWe show the different possibilities."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Supercritical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m > 0, Print["\<Supercritical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(" Another case"\)], "Print"],

Cell["\<\
If the answer is Supercritical damping we find the roots and the general \
solution of the homogeneous equation in exponential form.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(caract = Solve[m\ a\^2 + n\ a + k == 0, a]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solgenh[t_, c1_, c2_] = 
      c1\ Exp[caract\[LeftDoubleBracket]1, 1, 2\[RightDoubleBracket]\ t] + 
        c2\ Exp[caract\[LeftDoubleBracket]2, 1, 
                2\[RightDoubleBracket]\ t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["We jump to the Forced damping.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Sub critical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m < 0, Print["\<Sub critical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \("Sub critical damping"\)], "Print"],

Cell[TextData[{
  "If the answer is ",
  StyleBox["Sub critical ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True,
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  " damping we use Root command to find the roots. After we obtain the \
general solution of the homogeneous equation."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(caract = Roots[m\ a\^2 + n\ a + k == 0, a]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(a \[Equal] 2\ \[ImaginaryI] || 
      a \[Equal] \(-2\)\ \[ImaginaryI]\)], "Output"],

Cell["In easier form", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(prim = caract\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(2\ \[ImaginaryI]\)], "Output"],

Cell[BoxData[
    \(seg = caract\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-2\)\ \[ImaginaryI]\)], "Output"],

Cell["\<\
Analysing again the resonance. ONLY will be possible with imaginary roots of \
the characteristic polynomial.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(If[Re[prim] == 0, Print["\<POSIBLE RESONANCE\>"], \ 
      Print["\<NO RESONANCE\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \("POSIBLE RESONANCE"\)], "Print"],

Cell["Analysing the real situation.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(If[Im[prim] == w, Print["\<RESONANCE DANGEREOUS CASE\>"], 
      Print["\<NO RESONANCE\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \("RESONANCE DANGEREOUS CASE"\)], "Print"],

Cell["The general solution.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solgenh[t_, c1_, c2_] = 
      c1\ Exp[Re[prim]\ t]\ Cos[Im[prim]\ t] + 
        c2\ Exp[Re[prim]\ t]\ Sin[Im[prim]\ t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(c1\ Cos[2\ t] + c2\ Sin[2\ t]\)], "Output"],

Cell["We jump to the Forced damping.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Critical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m == 0, Print["\<Critical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(" Another case"\)], "Print"],

Cell["\<\
If the answer is Critical damping we use Root command to find the roots. We \
will obtain the general solution of the homogeneous equation.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(caract = Roots[m\ a\^2 + n\ a + k == 0, a]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(prim = caract\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(seg = caract\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solgenh[t_, c1_, c2_] = 
      c1\ Exp[prim\ t] + c2\ t\ Exp[prim\ t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["FORCED DAMPING", "Subsection",
  FontSize->24,
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "We found a particular solution of non-homogeneous equation, ",
  StyleBox["forced response",
    FontColor->RGBColor[0, 0, 1]],
  ". We suppose null initial conditions (speed and ",
  StyleBox["displacement ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "0 at t=0). We apply the linearity principle to find the general solutions \
of the non homogeneous equation.\nFinally we plot graphs of some solutions \
for ",
  StyleBox["different ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "values of constants c1 y c2."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Supercritical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m > 0, Print["\<Supercritical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(" Another case"\)], "Print"],

Cell["\<\
If the answer is Supercritical damping we solve the equation with null \
initial conditions.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"solecua", "=", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"ecua", ",", \(x[0] == 0\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
            "}"}], ",", \(x[t]\), ",", "t"}], "]"}]}]], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Easier form.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solpar[t_] = 
      Simplify[x[t] /. solecua\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], 
  "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["The general solution of equation", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solfin[t_, c1_, c2_] = solgenh[t, c1, c2] + solpar[t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
We plot graphs of some solutions. In this case the solutions decay \
exponentially for every values of c1 and c2.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(grafic = 
      Table[solfin[t, c1, c2], {c1, \(-3\), 3, 3}, {c2, \(-3\), 3, 
          3}]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "We must be ",
  StyleBox["careful ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "with the values of the constants c1 and c2 and the ",
  StyleBox["chosen ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "interval for the independent variable. A bad election implies a bad ",
  StyleBox["understanding ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "of the graph. ",
  StyleBox["Please check each case with several values of constants and \
several intervals.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(Plot[Evaluate[grafic], {t, 0, 3}]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "Remark: Experiment with big values of t, time. Some times only one graph \
is appearing. Analyse the reason. All transient solutions, ",
  StyleBox["corresponding ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  "to natural response tend to 0. Only the steady-state response appears."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Sub critical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m < 0, Print["\<Sub critical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \("Sub critical damping"\)], "Print"],

Cell["\<\
If the answer is Sub critical damping we solve the equation with null initial \
conditions.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"solecua", "=", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"ecua", ",", \(x[0] == 0\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
            "}"}], ",", \(x[t]\), ",", "t"}], "]"}]}]], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(-\(5\/16\)\)\ \((4\ t\ Cos[2\ t] - Sin[2\ t] + 
                Cos[4\ t]\ Sin[2\ t] - Cos[2\ t]\ Sin[4\ t])\)}}\)], "Output"],

Cell["Easier form.", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solpar[t_] = 
      Simplify[x[t] /. 
          solecua\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-\(5\/4\)\)\ \((t\ Cos[2\ t] - Cos[t]\ Sin[t])\)\)], "Output"],

Cell["The general solution of equation", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solfin[t_, c1_, c2_] = solgenh[t, c1, c2] + solpar[t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(c1\ Cos[2\ t] - 5\/4\ \((t\ Cos[2\ t] - Cos[t]\ Sin[t])\) + 
      c2\ Sin[2\ t]\)], "Output"],

Cell[TextData[{
  "We plot graphs of some solutions. In this case for f(t)= F sin(wt) the \
solutions decay exponentially, for every values of c1 and c2 but with change \
of sign, due to the sine and cosine functions. In the resonance ",
  StyleBox["phenomenon ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  " the solutions are going to infinity, due to the solution tsin(wt) or t \
cos(wt) or both."
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(grafic = 
      Table[solfin[t, c1, c2], {c1, \(-3\), 3, 3}, {c2, \(-3\), 3, 
          3}]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["We have to be careful with the values of constants c1 and c2 and \
the ",
    Background->RGBColor[0, 1, 0]],
  StyleBox["chosen ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True,
    Background->RGBColor[0, 1, 0]],
  StyleBox[" interval for independent variable.\nA bad election implies a bad \
understanding of the graph. ",
    Background->RGBColor[0, 1, 0]],
  StyleBox["Please ",
    FontColor->RGBColor[1, 0, 0],
    Background->RGBColor[0, 1, 0]],
  StyleBox["check ",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True,
    FontColor->RGBColor[1, 0, 0],
    Background->RGBColor[0, 1, 0]],
  StyleBox[" in all the cases with several values of constants and several \
intervals, for small and big values of time.",
    FontColor->RGBColor[1, 0, 0],
    Background->RGBColor[0, 1, 0]]
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(Plot[Evaluate[grafic], {t, 0, 10}]; 
    Plot[Evaluate[grafic], {t, 100, 110}];\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.328991 0.0208354 [
[.21429 .31649 -3 -9 ]
[.21429 .31649 3 0 ]
[.40476 .31649 -3 -9 ]
[.40476 .31649 3 0 ]
[.59524 .31649 -3 -9 ]
[.59524 .31649 3 0 ]
[.78571 .31649 -3 -9 ]
[.78571 .31649 3 0 ]
[.97619 .31649 -6 -9 ]
[.97619 .31649 6 0 ]
[.01131 .01646 -18 -4.5 ]
[.01131 .01646 0 4.5 ]
[.01131 .12064 -18 -4.5 ]
[.01131 .12064 0 4.5 ]
[.01131 .22481 -12 -4.5 ]
[.01131 .22481 0 4.5 ]
[.01131 .43317 -6 -4.5 ]
[.01131 .43317 0 4.5 ]
[.01131 .53735 -12 -4.5 ]
[.01131 .53735 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .32899 m
.21429 .33524 L
s
[(2)] .21429 .31649 0 1 Mshowa
.40476 .32899 m
.40476 .33524 L
s
[(4)] .40476 .31649 0 1 Mshowa
.59524 .32899 m
.59524 .33524 L
s
[(6)] .59524 .31649 0 1 Mshowa
.78571 .32899 m
.78571 .33524 L
s
[(8)] .78571 .31649 0 1 Mshowa
.97619 .32899 m
.97619 .33524 L
s
[(10)] .97619 .31649 0 1 Mshowa
.125 Mabswid
.07143 .32899 m
.07143 .33274 L
s
.11905 .32899 m
.11905 .33274 L
s
.16667 .32899 m
.16667 .33274 L
s
.2619 .32899 m
.2619 .33274 L
s
.30952 .32899 m
.30952 .33274 L
s
.35714 .32899 m
.35714 .33274 L
s
.45238 .32899 m
.45238 .33274 L
s
.5 .32899 m
.5 .33274 L
s
.54762 .32899 m
.54762 .33274 L
s
.64286 .32899 m
.64286 .33274 L
s
.69048 .32899 m
.69048 .33274 L
s
.7381 .32899 m
.7381 .33274 L
s
.83333 .32899 m
.83333 .33274 L
s
.88095 .32899 m
.88095 .33274 L
s
.92857 .32899 m
.92857 .33274 L
s
.25 Mabswid
0 .32899 m
1 .32899 L
s
.02381 .01646 m
.03006 .01646 L
s
[(-15)] .01131 .01646 1 0 Mshowa
.02381 .12064 m
.03006 .12064 L
s
[(-10)] .01131 .12064 1 0 Mshowa
.02381 .22481 m
.03006 .22481 L
s
[(-5)] .01131 .22481 1 0 Mshowa
.02381 .43317 m
.03006 .43317 L
s
[(5)] .01131 .43317 1 0 Mshowa
.02381 .53735 m
.03006 .53735 L
s
[(10)] .01131 .53735 1 0 Mshowa
.125 Mabswid
.02381 .0373 m
.02756 .0373 L
s
.02381 .05813 m
.02756 .05813 L
s
.02381 .07897 m
.02756 .07897 L
s
.02381 .0998 m
.02756 .0998 L
s
.02381 .14147 m
.02756 .14147 L
s
.02381 .16231 m
.02756 .16231 L
s
.02381 .18314 m
.02756 .18314 L
s
.02381 .20398 m
.02756 .20398 L
s
.02381 .24565 m
.02756 .24565 L
s
.02381 .26649 m
.02756 .26649 L
s
.02381 .28732 m
.02756 .28732 L
s
.02381 .30816 m
.02756 .30816 L
s
.02381 .34983 m
.02756 .34983 L
s
.02381 .37066 m
.02756 .37066 L
s
.02381 .3915 m
.02756 .3915 L
s
.02381 .41233 m
.02756 .41233 L
s
.02381 .454 m
.02756 .454 L
s
.02381 .47484 m
.02756 .47484 L
s
.02381 .49567 m
.02756 .49567 L
s
.02381 .51651 m
.02756 .51651 L
s
.02381 .55818 m
.02756 .55818 L
s
.02381 .57902 m
.02756 .57902 L
s
.02381 .59985 m
.02756 .59985 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26648 m
.03279 .25591 L
.03793 .25106 L
.04262 .24751 L
.04758 .24472 L
.0503 .24363 L
.05156 .24323 L
.05288 .24289 L
.05402 .24266 L
.05527 .24248 L
.0564 .24237 L
.05747 .24232 L
.05872 .24234 L
.05987 .24241 L
.06119 .24257 L
.06244 .24279 L
.06381 .24312 L
.0651 .24351 L
.0675 .24444 L
.07009 .24575 L
.07289 .24751 L
.07794 .25159 L
.08259 .25634 L
.09328 .27072 L
.10458 .29047 L
.14255 .37485 L
.15341 .39825 L
.1637 .41764 L
.17293 .43177 L
.17771 .43762 L
.18298 .44277 L
.18541 .44466 L
.18803 .44634 L
.19051 .44758 L
.19278 .44841 L
.19403 .44875 L
.1952 .44897 L
.19648 .44914 L
.1972 .44918 L
.19785 .4492 L
.19916 .44916 L
.19991 .44909 L
.20059 .449 L
.20185 .44876 L
.20319 .44841 L
.2054 .44758 L
.20779 .44637 L
.21209 .44332 L
.21721 .43828 L
.22188 .43237 L
Mistroke
.23176 .41598 L
.24091 .39651 L
.26165 .34101 L
.28048 .28434 L
.30083 .22769 L
.31201 .20276 L
.31691 .19383 L
.32228 .18564 L
.32736 .17957 L
.3321 .17546 L
.33472 .17385 L
.33596 .17327 L
.3371 .17282 L
.33842 .17242 L
.33912 .17227 L
.33986 .17214 L
.3411 .17201 L
.3418 .17199 L
.34246 .172 L
.34364 .1721 L
.3449 .17233 L
.34609 .17265 L
.34717 .17303 L
.34982 .17433 L
.35232 .17604 L
.3573 .18081 L
.36268 .18801 L
.37232 .20594 L
.3812 .22773 L
.42066 .36404 L
.44049 .43592 L
.44916 .46318 L
.4586 .48825 L
.46379 .49958 L
.4686 .50832 L
.47319 .51498 L
.47808 .52017 L
.48055 .52201 L
.48193 .52282 L
.4832 .52341 L
.48432 .52381 L
.48555 .52412 L
.48682 .5243 L
.48801 .52434 L
.4887 .52431 L
.48944 .52422 L
.49014 .5241 L
.49079 .52394 L
.49202 .52354 L
.49332 .52297 L
Mistroke
.49602 .52129 L
.49899 .51869 L
.50419 .51223 L
.50913 .50389 L
.51841 .4827 L
.5284 .45251 L
.5393 .41226 L
.57996 .23182 L
.59877 .15872 L
.60937 .12758 L
.61441 .11605 L
.61911 .10738 L
.62408 .10056 L
.62671 .09796 L
.62818 .09681 L
.62953 .09595 L
.63095 .09526 L
.6317 .09498 L
.63249 .09475 L
.63318 .0946 L
.63382 .09451 L
.63453 .09445 L
.63529 .09446 L
.63593 .09451 L
.63662 .09461 L
.63735 .09478 L
.63803 .09498 L
.63924 .09547 L
.64054 .09617 L
.64315 .09811 L
.64598 .10104 L
.65111 .10852 L
.65611 .11842 L
.66071 .12977 L
.67042 .16021 L
.67949 .19586 L
.70014 .29585 L
.71873 .39579 L
.73898 .49666 L
.74998 .54122 L
.75533 .55919 L
.76017 .57305 L
.76485 .58412 L
.76991 .59335 L
.7727 .59717 L
.77525 .59987 L
.7777 .60171 L
.77893 .60237 L
.77963 .60265 L
.78028 .60287 L
Mistroke
.78154 .60314 L
.78219 .6032 L
.78289 .60321 L
.78414 .60308 L
.7853 .60277 L
.78601 .60251 L
.78668 .60221 L
.78793 .60148 L
.78929 .60048 L
.79077 .59913 L
.79325 .59624 L
.79591 .59232 L
.80068 .58312 L
.8057 .57056 L
.81042 .55609 L
.81926 .52268 L
.83933 .42139 L
.8578 .30948 L
.87821 .18556 L
.88818 .13177 L
.89727 .08954 L
.90668 .05455 L
.911 .04187 L
.91559 .03093 L
.91791 .02644 L
.92047 .02231 L
.9228 .01932 L
.92499 .0172 L
.92625 .01628 L
.92756 .01555 L
.92869 .01511 L
.92992 .01484 L
.93062 .01478 L
.93125 .01479 L
.93198 .01487 L
.93267 .01501 L
.9339 .01543 L
.93459 .01576 L
.93523 .01612 L
.93767 .01805 L
.9399 .02054 L
.94247 .02428 L
.94492 .02869 L
.94925 .03853 L
.95398 .05215 L
.96469 .09341 L
.97462 .14326 L
.97619 .15203 L
Mfstroke
.02381 .26649 m
.02499 .2665 L
.02605 .26655 L
.02729 .26665 L
.02846 .26679 L
.03053 .26712 L
.03279 .26762 L
.03527 .26835 L
.0379 .26931 L
.04262 .27156 L
.04749 .27458 L
.05205 .27803 L
.06244 .28812 L
.08274 .31558 L
.10458 .35249 L
.12429 .38637 L
.1347 .40227 L
.1458 .41633 L
.15137 .42194 L
.1566 .42622 L
.16131 .42916 L
.16396 .43041 L
.1664 .4313 L
.1675 .43162 L
.16869 .4319 L
.16981 .43211 L
.17083 .43226 L
.17202 .43236 L
.17333 .43241 L
.17455 .43238 L
.17569 .43229 L
.17686 .43213 L
.17796 .43193 L
.17916 .43165 L
.18045 .43126 L
.18309 .43024 L
.18551 .42901 L
.19025 .42582 L
.19532 .42124 L
.20444 .41007 L
.21528 .39221 L
.22514 .37223 L
.26512 .2721 L
.28344 .22937 L
.29385 .20993 L
.29894 .20217 L
.30359 .19622 L
.3085 .19119 L
.31317 .1877 L
.31572 .18634 L
Mistroke
.31694 .18582 L
.31809 .18543 L
.31875 .18524 L
.31946 .18506 L
.32069 .18483 L
.32139 .18475 L
.32214 .18469 L
.32277 .18467 L
.32346 .18467 L
.32414 .18471 L
.32488 .18478 L
.32557 .18487 L
.32621 .18499 L
.32743 .18529 L
.32872 .18571 L
.3314 .18692 L
.33435 .1888 L
.33959 .19351 L
.3445 .19951 L
.35436 .21602 L
.36473 .2393 L
.38324 .29299 L
.4214 .42187 L
.43152 .45203 L
.44105 .47623 L
.44633 .48744 L
.45204 .49756 L
.45724 .5048 L
.45974 .50759 L
.46202 .50971 L
.46426 .51141 L
.46671 .51282 L
.46805 .51338 L
.46929 .51378 L
.47048 .51404 L
.47174 .5142 L
.47281 .51423 L
.47396 .51415 L
.47505 .51398 L
.47605 .51374 L
.47716 .51338 L
.47837 .51286 L
.48082 .51146 L
.48353 .50933 L
.48599 .50687 L
.49151 .49955 L
.49663 .4906 L
.50147 .4803 L
.52146 .42079 L
.53991 .34808 L
Mistroke
.56024 .26075 L
.57928 .18576 L
.58863 .15532 L
.59752 .13198 L
.60242 .12179 L
.60776 .11305 L
.61012 .11003 L
.61262 .10737 L
.61499 .10542 L
.61713 .10412 L
.61834 .10359 L
.61946 .10322 L
.62069 .10296 L
.62201 .10285 L
.62268 .10286 L
.6234 .10291 L
.62471 .10316 L
.62599 .10356 L
.62717 .10407 L
.62929 .10536 L
.63164 .1073 L
.63409 .10992 L
.63639 .11292 L
.64162 .12167 L
.64642 .132 L
.65722 .1629 L
.67616 .23864 L
.69686 .34126 L
.71813 .44906 L
.73744 .53102 L
.74709 .56146 L
.75253 .57475 L
.75754 .58427 L
.76193 .59036 L
.76443 .59286 L
.76676 .59455 L
.76802 .59521 L
.76922 .59565 L
.77029 .59591 L
.77146 .59604 L
.77273 .596 L
.77344 .59589 L
.77408 .59574 L
.77533 .59532 L
.77651 .59474 L
.77768 .59401 L
.77893 .59305 L
.78119 .59085 L
.78387 .58746 L
.78631 .58364 L
Mistroke
.79162 .57296 L
.79664 .55995 L
.80551 .53046 L
.81513 .48993 L
.85599 .25946 L
.87629 .14583 L
.88623 .09964 L
.89532 .06539 L
.89979 .05182 L
.90466 .03968 L
.90689 .0351 L
.90927 .03091 L
.91149 .02763 L
.91354 .02519 L
.91609 .02294 L
.91742 .0221 L
.9181 .02176 L
.91884 .02147 L
.92007 .02115 L
.92121 .02103 L
.92191 .02104 L
.92258 .02112 L
.92382 .02142 L
.92495 .02188 L
.92614 .02255 L
.92829 .02425 L
.9306 .02677 L
.93315 .0304 L
.93806 .03985 L
.94323 .05322 L
.95249 .08547 L
.96244 .13104 L
.97334 .1917 L
.97619 .20909 L
Mfstroke
.02381 .26649 m
.06244 .33345 L
.08255 .37427 L
.0932 .39479 L
.10458 .41451 L
.11531 .42999 L
.12507 .44073 L
.12977 .4446 L
.13225 .44627 L
.13488 .44775 L
.13717 .44879 L
.13839 .44925 L
.1397 .44967 L
.1409 .44998 L
.142 .45021 L
.1431 .45038 L
.14415 .4505 L
.1454 .45056 L
.1461 .45057 L
.14674 .45055 L
.14793 .45047 L
.14918 .45031 L
.1503 .45011 L
.15135 .44986 L
.15374 .4491 L
.15632 .44797 L
.15867 .44666 L
.16396 .44274 L
.16848 .43832 L
.1734 .43242 L
.18234 .4189 L
.20212 .37781 L
.22313 .32252 L
.24282 .26777 L
.26088 .22264 L
.27012 .20366 L
.28022 .1873 L
.28549 .18089 L
.29038 .17635 L
.29309 .17445 L
.29556 .17312 L
.29692 .17254 L
.2984 .17205 L
.29908 .17187 L
.29979 .17171 L
.30108 .17151 L
.30229 .17141 L
.30361 .17142 L
.30486 .17153 L
.30601 .17173 L
Mistroke
.30716 .172 L
.30819 .17233 L
.31052 .17331 L
.31303 .17478 L
.31574 .17682 L
.32065 .18175 L
.3253 .18784 L
.3302 .19572 L
.33897 .21341 L
.35865 .26748 L
.37699 .33006 L
.39567 .39706 L
.41595 .46223 L
.42701 .49019 L
.43187 .50019 L
.43723 .50939 L
.44227 .51615 L
.447 .52076 L
.44961 .52254 L
.45084 .5232 L
.45199 .52371 L
.45324 .52413 L
.45391 .52431 L
.45461 .52445 L
.45535 .52456 L
.45606 .52462 L
.45737 .52463 L
.45852 .52451 L
.45977 .52427 L
.46094 .52392 L
.46201 .5235 L
.46463 .52208 L
.46711 .5202 L
.47205 .51495 L
.47742 .50698 L
.48701 .48709 L
.49588 .46269 L
.51453 .39606 L
.53512 .30761 L
.55607 .21709 L
.56524 .18166 L
.57529 .14816 L
.58504 .12239 L
.5897 .11277 L
.59411 .10544 L
.59652 .10219 L
.59913 .09928 L
.60151 .09721 L
.6037 .09578 L
.60492 .09518 L
Mistroke
.60606 .09476 L
.60732 .09445 L
.60803 .09434 L
.60867 .09429 L
.60997 .09431 L
.6107 .0944 L
.61138 .09452 L
.61262 .09488 L
.61331 .09514 L
.61394 .09543 L
.61627 .09682 L
.61882 .09898 L
.62149 .10193 L
.62398 .10532 L
.63321 .12321 L
.63847 .13699 L
.64326 .15169 L
.65403 .19146 L
.6939 .38831 L
.71213 .47903 L
.72251 .52334 L
.73225 .55754 L
.74177 .58257 L
.74438 .58781 L
.74713 .59253 L
.7497 .59619 L
.75203 .59887 L
.75455 .60107 L
.75593 .60196 L
.75724 .6026 L
.75844 .60301 L
.75956 .60324 L
.76078 .60332 L
.76207 .60321 L
.76338 .60291 L
.76411 .60265 L
.76477 .60235 L
.76607 .60163 L
.7673 .60076 L
.77005 .59817 L
.77305 .59433 L
.77838 .58489 L
.7834 .57304 L
.79277 .54357 L
.80287 .50213 L
.81377 .44795 L
.85484 .20474 L
.86473 .15022 L
.87532 .0993 L
.88531 .0606 L
Mistroke
.88972 .04691 L
.8944 .03489 L
.89672 .02993 L
.89927 .02525 L
.90162 .02169 L
.90377 .01906 L
.90631 .01675 L
.9077 .01585 L
.90834 .01552 L
.90903 .01523 L
.91025 .01487 L
.91138 .01472 L
.91208 .01472 L
.91273 .01477 L
.91395 .01503 L
.91503 .01542 L
.9162 .01604 L
.91743 .01688 L
.91858 .01786 L
.92063 .02005 L
.92283 .02304 L
.92786 .0323 L
.93244 .04367 L
.94235 .07731 L
.95152 .11857 L
.97228 .24015 L
.97619 .26615 L
Mfstroke
.02381 .32899 m
.04262 .3052 L
.0522 .29478 L
.06244 .28583 L
.0679 .2822 L
.07286 .27966 L
.07525 .27872 L
.07784 .2779 L
.07903 .2776 L
.08029 .27733 L
.08145 .27713 L
.08255 .27698 L
.0832 .27691 L
.08392 .27685 L
.08516 .27679 L
.08586 .27678 L
.08662 .27679 L
.08732 .27681 L
.08797 .27685 L
.08922 .27696 L
.08993 .27705 L
.09058 .27714 L
.09304 .27763 L
.09442 .278 L
.09571 .2784 L
.09865 .27952 L
.10458 .28266 L
.10959 .28618 L
.11503 .29085 L
.12493 .3014 L
.14349 .32638 L
.16287 .35523 L
.17317 .36959 L
.18427 .38292 L
.18942 .38807 L
.19484 .39263 L
.19946 .39576 L
.20211 .39721 L
.20452 .39831 L
.20697 .39921 L
.20929 .39984 L
.21056 .4001 L
.21173 .40028 L
.21301 .40042 L
.21366 .40046 L
.21437 .40049 L
.21557 .40049 L
.21666 .40045 L
.21791 .40033 L
.21911 .40016 L
Mistroke
.22021 .39996 L
.22123 .39972 L
.22354 .39903 L
.22619 .39797 L
.22863 .39674 L
.23413 .39309 L
.23898 .38888 L
.2441 .38348 L
.26272 .3566 L
.30074 .28369 L
.32029 .25087 L
.32592 .24351 L
.33124 .23766 L
.33603 .23342 L
.33853 .23162 L
.34122 .23 L
.34376 .22879 L
.34487 .22836 L
.34608 .22796 L
.34716 .22766 L
.34831 .22741 L
.34952 .22722 L
.35064 .22711 L
.35134 .22708 L
.35199 .22707 L
.3527 .22708 L
.35345 .22712 L
.35471 .22726 L
.35542 .22737 L
.35609 .22751 L
.35847 .22816 L
.35981 .22866 L
.36103 .2292 L
.3662 .23233 L
.36912 .23471 L
.37182 .2373 L
.38205 .25037 L
.39166 .26697 L
.40069 .28584 L
.42129 .33685 L
.43974 .38519 L
.4502 .41049 L
.45994 .43106 L
.46962 .44756 L
.47503 .45474 L
.47996 .45986 L
.48248 .46192 L
.48516 .46369 L
.48656 .46443 L
.4881 .46511 L
Mistroke
.48949 .4656 L
.4908 .46594 L
.49213 .46617 L
.49338 .46629 L
.49451 .4663 L
.49574 .46622 L
.49644 .46613 L
.49707 .46602 L
.4985 .46568 L
.49981 .46525 L
.50105 .46473 L
.50346 .46344 L
.50571 .46189 L
.51082 .45712 L
.51581 .45085 L
.52114 .44241 L
.53081 .42285 L
.53962 .40078 L
.57949 .27287 L
.59772 .21669 L
.6081 .19062 L
.61318 .18003 L
.61784 .17177 L
.62239 .16512 L
.62736 .15956 L
.62995 .15741 L
.63236 .15587 L
.6337 .15522 L
.63491 .15474 L
.63558 .15453 L
.63631 .15435 L
.63762 .15411 L
.63893 .15402 L
.64016 .15406 L
.64086 .15414 L
.6415 .15424 L
.64224 .15441 L
.64294 .1546 L
.64433 .15512 L
.64563 .15573 L
.64856 .15764 L
.65112 .15987 L
.65344 .16236 L
.65864 .16949 L
.66353 .17814 L
.6687 .18922 L
.67794 .21368 L
.69878 .28639 L
.73682 .4405 L
.74688 .47549 L
Mistroke
.75638 .50316 L
.76164 .51569 L
.76734 .52679 L
.76986 .53081 L
.77253 .53446 L
.77482 .53708 L
.77732 .53938 L
.77862 .54035 L
.77983 .54111 L
.78109 .54174 L
.78223 .54219 L
.78335 .5425 L
.7844 .54269 L
.78552 .54277 L
.78672 .54272 L
.78794 .54252 L
.78864 .54234 L
.78928 .54214 L
.79059 .54159 L
.79199 .54082 L
.79453 .53894 L
.79684 .53667 L
.80134 .53078 L
.80624 .52217 L
.81514 .50088 L
.82453 .47116 L
.8349 .43095 L
.85591 .33337 L
.87687 .23033 L
.88605 .18871 L
.8961 .14843 L
.90521 .11829 L
.91021 .10479 L
.91494 .09425 L
.91752 .08944 L
.92032 .08502 L
.92265 .08198 L
.92521 .07933 L
.92763 .07749 L
.92895 .07676 L
.93019 .07626 L
.93134 .07595 L
.9324 .07579 L
.93362 .07578 L
.93478 .07592 L
.93602 .07624 L
.93673 .0765 L
.93737 .07679 L
.93854 .07744 L
.93982 .07832 L
Mistroke
.94204 .08031 L
.94438 .08302 L
.94967 .09143 L
.95461 .10209 L
.96349 .12776 L
.97301 .16375 L
.97619 .17753 L
Mfstroke
.02381 .32899 m
.02499 .32899 L
.02605 .32899 L
.02729 .32899 L
.02846 .329 L
.02954 .329 L
.03053 .329 L
.03163 .32901 L
.03279 .32902 L
.03395 .32903 L
.0352 .32905 L
.03746 .32909 L
.03884 .32913 L
.04016 .32916 L
.04262 .32925 L
.045 .32937 L
.04753 .32951 L
.0521 .32987 L
.05752 .33046 L
.06244 .33116 L
.07287 .33325 L
.07874 .33481 L
.08414 .33648 L
.10458 .34467 L
.125 .35463 L
.13497 .35942 L
.14407 .36336 L
.14857 .36506 L
.15348 .36668 L
.15772 .36785 L
.16239 .36887 L
.16495 .36928 L
.16734 .36958 L
.16866 .3697 L
.16987 .36979 L
.17051 .36983 L
.1712 .36986 L
.17192 .36988 L
.1726 .3699 L
.17383 .3699 L
.17499 .36988 L
.17603 .36984 L
.17716 .36977 L
.17839 .36967 L
.1797 .36953 L
.18204 .36921 L
.18457 .36873 L
.18697 .36815 L
.19148 .36676 L
.19633 .36478 L
Mistroke
.20161 .36206 L
.21112 .35571 L
.21993 .34821 L
.25911 .30171 L
.27912 .27641 L
.28964 .26503 L
.29539 .25974 L
.30074 .25552 L
.30596 .25216 L
.31072 .24981 L
.31343 .24879 L
.316 .24804 L
.31741 .24773 L
.31871 .2475 L
.32014 .24732 L
.32086 .24725 L
.32165 .2472 L
.32287 .24717 L
.32414 .24719 L
.32523 .24726 L
.32643 .24738 L
.32771 .24757 L
.32909 .24785 L
.33157 .24851 L
.33407 .24942 L
.33644 .2505 L
.34086 .25308 L
.34551 .25658 L
.35061 .26135 L
.36091 .27381 L
.37938 .30435 L
.41977 .38884 L
.43838 .4229 L
.44348 .43043 L
.44891 .43735 L
.45359 .44234 L
.45865 .44659 L
.46136 .44837 L
.46384 .44968 L
.46622 .45063 L
.46742 .451 L
.46873 .45132 L
.46948 .45146 L
.47019 .45156 L
.47082 .45164 L
.47151 .45169 L
.47227 .45172 L
.47306 .45172 L
.47374 .45169 L
.47449 .45163 L
Mistroke
.47519 .45154 L
.47583 .45144 L
.47727 .45113 L
.4786 .45074 L
.47986 .45028 L
.48228 .44916 L
.48485 .44761 L
.48948 .44391 L
.49499 .43798 L
.49998 .43121 L
.51001 .41379 L
.51924 .39374 L
.54006 .33781 L
.5605 .27661 L
.57957 .22381 L
.58899 .20217 L
.59791 .18563 L
.60284 .17842 L
.60819 .17228 L
.61055 .17016 L
.61306 .16833 L
.6152 .16711 L
.61642 .16655 L
.61756 .16612 L
.6187 .16579 L
.61991 .16554 L
.62061 .16544 L
.62126 .16538 L
.62249 .16535 L
.62378 .16544 L
.62497 .16563 L
.62628 .16595 L
.62767 .16643 L
.62994 .16752 L
.63208 .16889 L
.63692 .17323 L
.64218 .17985 L
.64698 .1876 L
.65779 .21065 L
.67682 .26741 L
.69757 .34417 L
.71894 .42514 L
.73828 .48635 L
.748 .50903 L
.75347 .5188 L
.75849 .52569 L
.76062 .52798 L
.7629 .53 L
.76421 .53096 L
.7654 .5317 L
Mistroke
.76653 .53229 L
.76773 .5328 L
.76898 .53318 L
.77014 .53342 L
.77138 .53353 L
.77208 .53354 L
.77275 .5335 L
.77394 .53334 L
.77503 .53307 L
.77629 .53263 L
.77749 .53208 L
.78007 .53045 L
.78251 .52835 L
.78707 .52299 L
.79197 .51515 L
.79728 .50432 L
.80686 .47896 L
.81567 .44963 L
.85514 .27565 L
.87499 .18753 L
.88367 .15465 L
.8931 .12476 L
.8983 .11138 L
.90311 .10118 L
.90771 .09351 L
.91026 .09017 L
.9126 .08769 L
.91507 .08569 L
.91636 .0849 L
.91773 .08426 L
.91892 .08387 L
.92002 .08363 L
.92124 .08353 L
.92254 .0836 L
.92328 .08372 L
.92396 .08388 L
.9247 .08412 L
.9255 .08444 L
.92683 .08512 L
.92829 .0861 L
.93099 .08852 L
.93351 .09149 L
.93849 .09935 L
.94391 .11089 L
.95379 .13944 L
.96341 .17572 L
.97232 .2157 L
.97619 .2346 L
Mfstroke
.02381 .32899 m
.04262 .35331 L
.06244 .37649 L
.07216 .38619 L
.08255 .39495 L
.08852 .39911 L
.09396 .40229 L
.09911 .40473 L
.10194 .40583 L
.10458 .40669 L
.10705 .40735 L
.10932 .40783 L
.11052 .40804 L
.11183 .40822 L
.11255 .40831 L
.11322 .40838 L
.11454 .40848 L
.11574 .40853 L
.11687 .40856 L
.11788 .40855 L
.11898 .40851 L
.12019 .40844 L
.12145 .40832 L
.12254 .40819 L
.12373 .40801 L
.12644 .40747 L
.12891 .40682 L
.13447 .40479 L
.13963 .40222 L
.14451 .39918 L
.15416 .39147 L
.16442 .38093 L
.18284 .35677 L
.22059 .29531 L
.24156 .26248 L
.25075 .25026 L
.26079 .23916 L
.26551 .2349 L
.27056 .23111 L
.27531 .2283 L
.27964 .22643 L
.28219 .22564 L
.2834 .22535 L
.28454 .22513 L
.28576 .22494 L
.28642 .22486 L
.28711 .2248 L
.28785 .22475 L
.28854 .22473 L
.28985 .22473 L
Mistroke
.291 .22479 L
.29224 .22491 L
.2934 .22507 L
.29445 .22527 L
.29704 .22593 L
.29948 .2268 L
.30415 .22913 L
.30927 .23266 L
.31461 .23745 L
.3196 .24291 L
.33808 .27083 L
.35848 .3129 L
.37704 .35665 L
.39778 .40446 L
.40689 .42302 L
.41694 .44055 L
.42157 .44736 L
.42655 .45369 L
.43086 .45825 L
.43556 .46221 L
.438 .46382 L
.44059 .4652 L
.44203 .46581 L
.44333 .46627 L
.44466 .46665 L
.44588 .46691 L
.44701 .46707 L
.44821 .46717 L
.44942 .46719 L
.4501 .46717 L
.45074 .46712 L
.4519 .46698 L
.45295 .46679 L
.45417 .46649 L
.45532 .46612 L
.45768 .46515 L
.4599 .46394 L
.46496 .46016 L
.46989 .45509 L
.47521 .44813 L
.48481 .4318 L
.49362 .41291 L
.53321 .29771 L
.55315 .23659 L
.57129 .19079 L
.57612 .18113 L
.58136 .17213 L
.58589 .16568 L
.59088 .16011 L
.59361 .15776 L
Mistroke
.59616 .15603 L
.59755 .15528 L
.59886 .15469 L
.59959 .15443 L
.60038 .15417 L
.60109 .15399 L
.60177 .15384 L
.6024 .15374 L
.60309 .15366 L
.60429 .1536 L
.60497 .15362 L
.60569 .15367 L
.60698 .15386 L
.60817 .15414 L
.60929 .1545 L
.61182 .15565 L
.61442 .15734 L
.61683 .15934 L
.62228 .16544 L
.62708 .1726 L
.63218 .18197 L
.65075 .23003 L
.67023 .29865 L
.68852 .37108 L
.70701 .4418 L
.71748 .47672 L
.72722 .50385 L
.73692 .52448 L
.74235 .53287 L
.74728 .53837 L
.74999 .5405 L
.75128 .54129 L
.75249 .54189 L
.7538 .5424 L
.75449 .5426 L
.75523 .54278 L
.75601 .5429 L
.75675 .54297 L
.75742 .54299 L
.75814 .54297 L
.75883 .5429 L
.75949 .5428 L
.76071 .5425 L
.76203 .54203 L
.76346 .54133 L
.76602 .53962 L
.76838 .53751 L
.7731 .53177 L
.77815 .52341 L
.78726 .50279 L
Mistroke
.79809 .46969 L
.80794 .43262 L
.84786 .24756 L
.86613 .1679 L
.87652 .13083 L
.88161 .11565 L
.88626 .10369 L
.89083 .09389 L
.89581 .08548 L
.89854 .08194 L
.90108 .07934 L
.90351 .0775 L
.90486 .07674 L
.90609 .07622 L
.90741 .07584 L
.90807 .07572 L
.9088 .07565 L
.91009 .07566 L
.91129 .07583 L
.91202 .07601 L
.91271 .07623 L
.914 .0768 L
.9154 .07761 L
.91692 .07873 L
.91948 .08121 L
.92221 .08462 L
.92712 .09278 L
.932 .10342 L
.93648 .11532 L
.94658 .14918 L
.96485 .23128 L
.97619 .29166 L
Mfstroke
.02381 .3915 m
.06244 .32887 L
.08255 .29766 L
.09396 .28397 L
.09942 .2788 L
.10458 .27484 L
.10938 .272 L
.11209 .27076 L
.11459 .26986 L
.11669 .26928 L
.11789 .26902 L
.11901 .26883 L
.12019 .26867 L
.12127 .26858 L
.12252 .26852 L
.1237 .26852 L
.12499 .26858 L
.12615 .26869 L
.1268 .26876 L
.1275 .26887 L
.12877 .2691 L
.13122 .26971 L
.13348 .27045 L
.13867 .27283 L
.14415 .27628 L
.15363 .28431 L
.16379 .29533 L
.18212 .3191 L
.20193 .3455 L
.21238 .35765 L
.21811 .36338 L
.22348 .36803 L
.22862 .37175 L
.23332 .37447 L
.23582 .37564 L
.23855 .3767 L
.24129 .37752 L
.24279 .37786 L
.24418 .37811 L
.24538 .37827 L
.24668 .3784 L
.2479 .37847 L
.24903 .37848 L
.25005 .37846 L
.25117 .3784 L
.25234 .37829 L
.25344 .37815 L
.25472 .37793 L
.25593 .37767 L
.25821 .37706 L
Mistroke
.26066 .37621 L
.26333 .37507 L
.26866 .37213 L
.27367 .3686 L
.28304 .36022 L
.30403 .33518 L
.32244 .31042 L
.33289 .29725 L
.34263 .28656 L
.35228 .27814 L
.35769 .27456 L
.36261 .27211 L
.36531 .27111 L
.3678 .27041 L
.3691 .27013 L
.37054 .26989 L
.37126 .2698 L
.37203 .26972 L
.37277 .26967 L
.37344 .26963 L
.37468 .26962 L
.37583 .26965 L
.37709 .26974 L
.37779 .26982 L
.37843 .26991 L
.37973 .27012 L
.38114 .27043 L
.38369 .27117 L
.38605 .27207 L
.38859 .27327 L
.39318 .276 L
.39863 .2802 L
.4036 .28489 L
.42466 .31234 L
.44533 .34651 L
.46447 .37773 L
.47404 .39107 L
.48303 .40131 L
.48792 .40574 L
.49241 .40903 L
.49739 .41173 L
.50001 .41273 L
.50133 .41313 L
.50277 .41347 L
.50408 .4137 L
.5053 .41385 L
.50593 .4139 L
.50663 .41394 L
.50736 .41395 L
.50804 .41394 L
Mistroke
.5093 .41387 L
.51044 .41374 L
.51108 .41365 L
.51177 .41352 L
.51303 .41324 L
.51537 .41251 L
.51786 .41146 L
.52235 .40886 L
.52801 .40429 L
.53334 .3987 L
.5433 .38515 L
.56339 .3477 L
.58187 .30642 L
.6023 .26163 L
.61228 .24294 L
.62137 .22897 L
.62589 .22334 L
.63079 .21831 L
.63304 .21641 L
.63543 .21469 L
.63767 .21335 L
.63971 .21236 L
.64203 .21153 L
.64325 .21121 L
.64453 .21096 L
.64565 .21083 L
.6467 .21077 L
.64784 .21077 L
.64906 .21086 L
.64975 .21095 L
.65039 .21106 L
.65184 .21139 L
.65311 .21178 L
.65446 .2123 L
.6568 .21345 L
.65937 .21508 L
.66459 .21958 L
.66954 .2253 L
.67883 .23962 L
.68883 .25984 L
.69973 .28657 L
.7211 .34782 L
.74044 .40425 L
.75016 .42956 L
.76065 .45269 L
.76547 .46149 L
.77055 .46934 L
.77522 .47515 L
.77964 .47934 L
.78203 .48105 L
Mistroke
.78329 .48179 L
.78463 .48246 L
.78575 .48292 L
.78698 .48333 L
.78811 .4836 L
.78916 .48378 L
.79047 .48388 L
.79172 .48387 L
.79284 .48376 L
.79406 .48353 L
.79476 .48335 L
.79539 .48316 L
.7968 .48263 L
.79934 .4813 L
.8017 .47963 L
.80388 .47774 L
.80879 .47221 L
.81311 .46591 L
.81769 .45784 L
.82716 .43683 L
.83732 .40855 L
.85565 .34645 L
.87545 .27267 L
.8859 .2353 L
.897 .19964 L
.90683 .17326 L
.91205 .16172 L
.91768 .15148 L
.92283 .14425 L
.92509 .14176 L
.92756 .13952 L
.9299 .13788 L
.93207 .13677 L
.93328 .13634 L
.93437 .13605 L
.93564 .13586 L
.93683 .1358 L
.93798 .13587 L
.93922 .13607 L
.94039 .13639 L
.94146 .13679 L
.9427 .13738 L
.94407 .13818 L
.94655 .14008 L
.94913 .14263 L
.95188 .14601 L
.95683 .15373 L
.96652 .17479 L
.97528 .20011 L
.97619 .20304 L
Mistroke
Mfstroke
.02381 .3915 m
.02499 .39148 L
.02605 .39143 L
.02729 .39133 L
.02846 .3912 L
.03053 .39089 L
.03279 .39042 L
.03527 .38976 L
.0379 .38889 L
.04262 .38695 L
.05205 .3817 L
.06244 .3742 L
.08274 .35647 L
.10458 .33686 L
.11537 .3283 L
.12562 .32135 L
.13571 .31584 L
.14487 .31206 L
.1498 .31051 L
.15445 .30935 L
.15936 .30844 L
.16213 .30806 L
.16467 .30778 L
.16688 .30761 L
.16793 .30754 L
.16894 .30749 L
.17012 .30745 L
.17119 .30742 L
.17235 .3074 L
.17361 .3074 L
.17475 .3074 L
.17599 .30743 L
.1773 .30746 L
.17852 .30751 L
.18071 .30763 L
.18306 .3078 L
.18802 .30828 L
.19263 .30885 L
.2031 .31045 L
.21395 .31227 L
.2242 .31387 L
.23402 .31507 L
.23671 .31532 L
.23955 .31555 L
.24201 .31571 L
.24466 .31585 L
.24588 .3159 L
.24705 .31594 L
.24818 .31597 L
.24923 .31599 L
Mistroke
.25022 .31601 L
.25128 .31602 L
.25245 .31602 L
.25351 .31602 L
.25477 .316 L
.25592 .31598 L
.25719 .31595 L
.25853 .31591 L
.26078 .31582 L
.26325 .31569 L
.2685 .31531 L
.27348 .31484 L
.28279 .31373 L
.29295 .31235 L
.30372 .31096 L
.30829 .31047 L
.31321 .31005 L
.31603 .30987 L
.31726 .30981 L
.31861 .30976 L
.31989 .30972 L
.32108 .30969 L
.32233 .30968 L
.32303 .30968 L
.32367 .30968 L
.32482 .30969 L
.32604 .30972 L
.32708 .30975 L
.32823 .3098 L
.32946 .30986 L
.33078 .30995 L
.33316 .31016 L
.33556 .31042 L
.33784 .31074 L
.3421 .31148 L
.34668 .31254 L
.35174 .31401 L
.36199 .31802 L
.37148 .32297 L
.3804 .32864 L
.41906 .36041 L
.43868 .37606 L
.44406 .37961 L
.44981 .38291 L
.45519 .38544 L
.46016 .38725 L
.46265 .38794 L
.46528 .38852 L
.46655 .38874 L
.46792 .38893 L
Mistroke
.4687 .38902 L
.46942 .38908 L
.4701 .38913 L
.47083 .38917 L
.47211 .38921 L
.4733 .38921 L
.47402 .38919 L
.47471 .38916 L
.47599 .38906 L
.47722 .38893 L
.47835 .38877 L
.4809 .38828 L
.48316 .3877 L
.48527 .38702 L
.49007 .385 L
.49475 .3824 L
.49976 .37891 L
.50994 .36967 L
.52101 .35659 L
.54114 .32645 L
.56054 .29352 L
.58194 .25947 L
.59169 .24682 L
.59682 .24126 L
.60221 .23633 L
.60695 .23286 L
.60945 .23138 L
.61213 .23007 L
.6146 .22913 L
.61684 .22849 L
.61793 .22826 L
.6191 .22807 L
.6202 .22795 L
.62123 .22788 L
.62248 .22786 L
.62367 .2279 L
.62474 .228 L
.6259 .22816 L
.62717 .22841 L
.62851 .22875 L
.63093 .22957 L
.63338 .23068 L
.63569 .23198 L
.64 .23506 L
.64518 .23987 L
.64993 .24534 L
.66065 .26119 L
.67952 .29922 L
.70021 .35021 L
.72141 .40323 L
Mistroke
.7407 .44296 L
.75031 .4572 L
.75573 .46318 L
.75832 .46547 L
.76074 .46727 L
.76302 .46865 L
.76511 .46965 L
.76622 .47007 L
.76744 .47044 L
.76872 .47074 L
.76993 .47093 L
.77122 .47102 L
.77238 .47103 L
.77303 .47099 L
.77372 .47092 L
.77499 .47072 L
.77618 .47043 L
.77743 .47004 L
.77968 .46908 L
.78223 .4676 L
.78464 .46583 L
.78916 .46151 L
.79402 .45543 L
.79931 .44718 L
.81764 .40663 L
.83741 .34692 L
.85841 .2757 L
.8781 .21363 L
.88672 .19088 L
.89615 .17054 L
.90071 .16271 L
.90557 .1559 L
.90826 .15287 L
.91071 .15059 L
.91303 .14884 L
.91549 .14744 L
.91676 .1469 L
.91744 .14667 L
.91817 .14646 L
.91944 .14619 L
.92064 .14606 L
.92135 .14604 L
.92213 .14606 L
.92287 .14612 L
.92355 .14622 L
.92484 .14651 L
.92556 .14673 L
.92622 .14697 L
.92872 .14821 L
.93013 .14913 L
Mistroke
.93143 .15012 L
.93634 .15509 L
.94105 .16169 L
.9461 .17067 L
.9552 .19167 L
.97587 .25889 L
.97619 .26011 L
Mfstroke
.02381 .3915 m
.03279 .40213 L
.04262 .411 L
.04758 .41432 L
.0503 .4158 L
.05288 .41699 L
.05528 .4179 L
.05789 .41868 L
.05904 .41896 L
.06026 .41921 L
.0613 .41938 L
.06244 .41953 L
.06314 .4196 L
.06378 .41965 L
.06505 .41971 L
.0662 .41973 L
.06743 .4197 L
.06813 .41966 L
.06888 .4196 L
.06959 .41953 L
.07025 .41946 L
.07157 .41926 L
.0728 .41903 L
.07505 .41849 L
.07751 .41773 L
.0825 .41566 L
.08807 .41254 L
.09315 .409 L
.10458 .39887 L
.12366 .37663 L
.14443 .34796 L
.16381 .32038 L
.18521 .29266 L
.19495 .28185 L
.20546 .27187 L
.21531 .26432 L
.22447 .259 L
.2291 .25698 L
.23404 .25531 L
.23687 .25459 L
.23953 .25408 L
.24192 .25374 L
.24327 .25361 L
.24451 .25352 L
.24573 .25347 L
.24704 .25345 L
.24827 .25346 L
.24939 .25351 L
.25071 .25359 L
.25146 .25366 L
Mistroke
.25215 .25373 L
.25476 .25409 L
.25618 .25435 L
.25752 .25463 L
.26002 .25526 L
.26561 .25716 L
.27028 .25924 L
.2754 .26204 L
.28573 .26926 L
.30422 .28687 L
.34469 .33954 L
.36337 .36552 L
.38365 .39069 L
.39471 .40183 L
.39958 .40596 L
.40493 .40989 L
.40964 .41277 L
.4147 .41524 L
.41749 .4163 L
.42005 .41708 L
.4225 .41765 L
.42372 .41787 L
.42507 .41806 L
.42571 .41813 L
.42639 .4182 L
.42761 .41827 L
.42893 .41831 L
.42967 .41831 L
.43037 .41829 L
.43163 .41822 L
.43278 .41811 L
.43411 .41794 L
.43537 .41772 L
.43769 .41719 L
.43984 .41656 L
.44472 .41457 L
.44954 .41188 L
.45488 .40805 L
.46568 .39765 L
.47576 .38495 L
.485 .37102 L
.50585 .33355 L
.52635 .29279 L
.54544 .25683 L
.5549 .24143 L
.56384 .2291 L
.56879 .22339 L
.57415 .21821 L
.57902 .21446 L
.58352 .21188 L
Mistroke
.58596 .21085 L
.58818 .21013 L
.58941 .20983 L
.59006 .2097 L
.59075 .20958 L
.59202 .20942 L
.5932 .20934 L
.59437 .20932 L
.59565 .20937 L
.59685 .20949 L
.59795 .20966 L
.59895 .20986 L
.60005 .21013 L
.60226 .21086 L
.60495 .21206 L
.60741 .21346 L
.61293 .21764 L
.61805 .22278 L
.62289 .22876 L
.64281 .26374 L
.66124 .30789 L
.68151 .36302 L
.70053 .41336 L
.71871 .45293 L
.72369 .46146 L
.72893 .46914 L
.73375 .47492 L
.7383 .47918 L
.7407 .48094 L
.7433 .48246 L
.74445 .483 L
.74567 .48348 L
.74681 .48385 L
.74785 .48411 L
.74906 .48433 L
.75036 .48447 L
.75157 .4845 L
.75271 .48444 L
.75335 .48437 L
.75404 .48427 L
.75527 .48401 L
.75673 .48357 L
.75805 .48306 L
.76043 .48185 L
.76261 .48043 L
.76752 .47608 L
.77185 .47097 L
.77642 .46431 L
.78594 .44644 L
.79612 .42182 L
Mistroke
.81447 .36607 L
.83433 .29653 L
.8559 .22289 L
.86597 .19325 L
.87665 .16729 L
.88577 .15067 L
.89096 .14379 L
.89331 .14133 L
.89582 .13917 L
.89839 .13747 L
.89954 .13687 L
.90078 .13635 L
.90154 .13609 L
.90224 .13589 L
.90291 .13574 L
.90362 .13562 L
.90484 .13551 L
.90554 .1355 L
.90619 .13552 L
.90747 .13567 L
.90868 .13594 L
.90977 .13629 L
.91095 .13677 L
.9136 .13827 L
.91606 .14018 L
.92032 .14466 L
.92504 .15133 L
.93458 .17015 L
.94467 .19725 L
.95392 .22779 L
.97477 .31103 L
.97619 .31717 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{181.125, 111.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004?0000Yb000`400?l00000o`00003oo`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`007P3oool00`000000oooo0?oo
o`3^0?ooo`002P3oool7000000<0oooo100000060?ooo`030000003oool0oooo0>h0oooo000=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0>h0oooo000=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3^0?ooo`003@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo0P00003D0?ooo`@0000000@0oooo00000000000000004`3oool000030?oo
o`000000000000@000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0
403oool000d0oooo00<000000?ooo`3oool0103oool4000000H0oooo00<000000?ooo`3oool0d@3o
ool200000080oooo1@0000020?ooo`030000003oool0oooo00l0oooo000=0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3A0?ooo`050000003oool0
oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00h0oooo000;
0?ooo`<000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=40oooo00<00000
0?ooo`3oool00P0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool03P3oool0
00d0oooo00<000000?ooo`3oool0103oool5000000D0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`02000000@0oooo0P0000030?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool000000080
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0c`3oool010000000oooo
0?ooo`3oool2000000D0oooo0P0000020?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0<l0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`02000000H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`3>0?ooo`040000003oool0oooo0?ooo`8000001`3oool200000080oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0cP3oool01P000000oooo0?ooo`00
0000oooo000000L0oooo0P0000020?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool02`3oool001h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`02
000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`007P3oool00`00
0000oooo0?ooo`3=0?ooo`060000003oool0oooo0000003oool000002@3oool200000080oooo00<0
00000?ooo`3oool02`3oool001h0oooo00<000000?ooo`3oool0c@3oool01@000000oooo0?ooo`00
0000oooo00D0000000<0oooo000000000000100000020?ooo`030000003oool0oooo00/0oooo000N
0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool00`0000030?ooo`<000000`3oool0
1@000000oooo0000003oool0000000d0oooo000N0?ooo`030000003oool0oooo0<d0oooo00D00000
0?ooo`000000oooo000000030?ooo`D000000P3oool300000080oooo00<000000?ooo`3oool02P3o
ool001h0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0300000080oooo10000000
0`3oool000000?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`0:0?ooo`007P3oool00`00
0000oooo0?ooo`2:0?ooo`<000000`3oool3000003T0oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`8000000P3oool00`000000oooo000000020?ooo`<0000000<0oooo0000003oool02`3o
ool001h0oooo00<000000?ooo`3oool0R03oool3000000040?ooo`00000000000?ooo`80000000<0
oooo000000000000>03oool02P000000oooo000000000000oooo0000003oool000000?ooo`000002
0?ooo`050000003oool0oooo0000003oool00`0000000`3oool000000?ooo`0;0?ooo`007P3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000003oool0
oooo03D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000103oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000<0?ooo`002P3oool7000000<0oooo10000006
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool00P3oool5000000<0oooo00<00000
0?ooo`3oool0=@3oool010000000oooo0000003oool200000080oooo00<000000?ooo`3oool00`3o
ool01P000000oooo000000000000oooo00000080oooo00<000000?ooo`3oool02@3oool000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?ooo`00
0000oooo000000030?ooo`030000003oool0oooo03<0oooo00D000000?ooo`00000000000?ooo`02
00000080oooo00<000000?ooo`3oool00`3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000;0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0<`3oool00`000000oooo
000000020?ooo`80000000<0oooo0000003oool01P3oool2000000060?ooo`000000oooo0000003o
ool000002`3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool000000080oooo00@000000?ooo`3oool000001`3oool020000000oooo000000000000
oooo0000003oool000002`3oool000030?ooo`000000000000@000001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000008H0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`0b0?ooo`<0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`050?ooo`05
0000003oool000000000003oool00P0000000`3oool000000?ooo`090?ooo`003@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`250?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0300oooo00D000000?ooo`00000000000?ooo`02
000000030?ooo`000000oooo00P0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000:
0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`240?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<03o
ool01@000000oooo000000000000oooo0080000000<0oooo0000003oool0203oool00`000000oooo
000000020?ooo`030000003oool0000000X0oooo000;0?ooo`<000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Q03oool01`000000oooo0?oo
o`3oool000000?ooo`0000001`3oool00`000000oooo000000020?ooo`030000003oool0oooo0300
oooo00H000000?ooo`00000000000?ooo`0000020?ooo`<000001@3oool300000080oooo00D00000
0?ooo`000000oooo0000000:0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`@000001P3oool0
0`000000oooo0?ooo`240?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02l0oooo0`0000020?ooo`050000
003oool000000000003oool00`0000000`3oool00000000000020?ooo`80000000<0oooo0000003o
ool00P0000000`3oool000000?ooo`080?ooo`007P3oool00`000000oooo0?ooo`230?ooo`070000
003oool0oooo0?ooo`000000oooo000000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0;P3oool01@000000oooo000000000000oooo00@000001@3oool2000000@0oooo0`00
00001@3oool000000000003oool0000000T0oooo000N0?ooo`030000003oool0oooo08<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000T0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0]0?ooo`050000003oool000000000003oool00P0000000`3oool000000?ooo`020?oo
o`D000000`3oool300000080oooo00<000000?ooo`0000002@3oool001h0oooo00<000000?ooo`3o
ool0P`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`80000000@0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`03000000030?ooo`000000000000<0oooo10000000103oool000000?oo
o`0000090?ooo`007P3oool00`000000oooo0?ooo`220?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000040?ooo`@0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0/0?ooo`80
000000H0oooo00000000000000000?ooo`0000020?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000020?ooo`050000003oool000000000003oool00P00000:0?ooo`007P3oool00`000000
oooo0?ooo`220?ooo`040000003oool0oooo0?ooo`<000000`3oool2000000030?ooo`0000000000
00<0oooo0P0000001@3oool000000?ooo`3oool0000002h0oooo0`0000001`3oool000000000003o
ool000000?ooo`0000000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`040000003oool00000000000X0oooo000N0?ooo`030000003oool0oooo0840oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`040000003o
ool0000000000080oooo00<000000?ooo`3oool0;03oool00`000000oooo0000000200000080oooo
00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`00
0000oooo0000003oool2000000X0oooo000N0?ooo`030000003oool0oooo0840oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`D000000`3oool010000000oooo0000
000000020?ooo`030000003oool0oooo02/0oooo0P000000203oool00000000000000000oooo0000
003oool000000P3oool00`000000oooo0?ooo`030?ooo`060000003oool000000?ooo`000000oooo
1000000:0?ooo`007P3oool00`000000oooo0?ooo`0o0?ooo`@000001@3oool4000003D0oooo00<0
00000?ooo`3oool00P0000000`3oool000000?ooo`020?ooo`060000003oool000000?ooo`000000
oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool0:P3oool20000
000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000H0oooo00<000000?ooo`3o
ool00P0000001P3oool00000000000000000oooo000000T0oooo000N0?ooo`030000003oool0oooo
03d0oooo0P0000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000003<0oooo00P00000
0?ooo`3oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0:P3oool20000
00050?ooo`00000000000000003oool00P0000020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P0000001P3oool00000000000000000oooo000000T0oooo000N0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000050?ooo`800000
<@3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`0000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`00000/0?oo
o`030000003oool00000008000000P3oool2000000030?ooo`000000oooo00L0oooo00D000000?oo
o`3oool000000?ooo`04000000X0oooo000N0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool01P3oool4000000H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`020000
0080oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000002`0oooo00H000000?ooo`000000oooo0000003oool200000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo0000
00X0oooo000N0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool200000004
0?ooo`0000000000000000H0oooo00<000000?ooo`3oool0;P3oool01P000000oooo0000003oool0
00000?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0000003oool0
00000?ooo`0200000080oooo00<000000?ooo`3oool0:@3oool3000000030?ooo`000000oooo0080
00000P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0000003oool00`00000:0?oo
o`007P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`00
0000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0200000080oooo0P0000030?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`000000oooo000000020?ooo`040000003oool0oooo000002X0oooo10000000103oool000000?oo
o`0000030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool000000?ooo`03000000X0
oooo000N0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0200000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo008000000P3oool2000000030?ooo`000000oooo02T0oooo10000000103oool000000?ooo`00
00020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`000000oooo100000090?ooo`007P3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0oooo
00D000000?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`0200000080oooo0P0000000`3oool000000?ooo`0Y0?ooo`80000000D0oooo0000
00000000oooo000000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001@000009
0?ooo`007P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0:`3oool01@000000oooo0000003oool000000080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00800000:P3oool3000000040?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0300000003
0?ooo`000000oooo00P0oooo000D0?ooo`@000001P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000050?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0Z0?ooo`050000003oool000000?ooo`0000000P3oool5
000000T0oooo00<000000?ooo`3oool00P0000001P3oool000000?ooo`000000oooo000002T0oooo
0`000000103oool000000000000000020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00
0000oooo0`0000090?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02T0oooo00H00000
0?ooo`000000oooo0000003oool200000080oooo0`0000070?ooo`H000000P3oool010000000oooo
00000000000Y0?ooo`<0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000000<000002P3oool001P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0Y0?ooo`8000000P3oool2
000000050?ooo`000000oooo0?ooo`0000000P3oool2000000<0oooo0P0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`0000000000:03oool2000000030?ooo`000000000000<0
00000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000<000002P3oool001P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0:@3oool2000000040?ooo`00000000000?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P0000001@3oool000000?ooo`3o
ool0000002P0oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo00000003000000X0oooo000:0?ooo`H00000203oool00`000000oooo0?ooo`03
0?ooo`800000=`3oool00`000000oooo0?ooo`020?ooo`H000002@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0300000080
oooo00<000000?ooo`3oool09P3oool3000000040?ooo`000000000000000080oooo00<000000?oo
o`3oool03@3oool00`000000oooo00000002000000X0oooo000D0?ooo`@000001P3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool2000000P0
oooo1P0000030?ooo`030000003oool0oooo02L0oooo0P0000000`3oool00000000000020?ooo`04
0000003oool0oooo000000@0oooo1P0000030?ooo`050000003oool0oooo0000003oool00P000000
0`3oool000000000000W0?ooo`<0000000@0oooo00000000000000000P3oool00`000000oooo0?oo
o`0=0?ooo`060000003oool000000000003oool000002@3oool001@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool000000080000000<0oooo0000003oool0
0`3oool00`000000oooo000000050?ooo`80000000H0oooo0000003oool0oooo0000003oool20000
00030?ooo`000000oooo02P0oooo00H000000?ooo`000000oooo0000003oool200000080oooo00<0
00000?ooo`3oool00P0000001@3oool000000?ooo`000000oooo008000000P3oool00`000000oooo
0?ooo`02000000030?ooo`000000oooo008000009`3oool00`000000oooo00000004000000030?oo
o`000000oooo00l0oooo00<000000?ooo`0000000`0000090?ooo`00503oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo03D0oooo0P0000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool09P3oool01P000000oooo0000003oool000000?ooo`800000
0P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
00000?ooo`02000000050?ooo`000000oooo0?ooo`0000009`3oool00`000000oooo000000020000
00040?ooo`000000oooo00000100oooo00<000000?ooo`0000000P00000:0?ooo`00503oool50000
00D0oooo00<000000?ooo`3oool00`3oool4000002d0oooo0P0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`000000:03oool20000000:0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
00000?ooo`80000000D0oooo000000000000oooo0000000V0?ooo`80000000<0oooo000000000000
0P0000020?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000?ooo`090?ooo`007P3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool2000002/0oooo0P0000040?ooo`050000003o
ool0oooo0?ooo`0000001P3oool2000000D0oooo00@000000?ooo`3oool000000`3oool2000002L0
oooo0P0000020?ooo`040000003oool0000000000080oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool200000080oooo00H000000?ooo`00000000000?ooo`00
000V0?ooo`80000000<0oooo0000000000000P0000020?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`00000000002P3oool001h0oooo00<000000?ooo`3oool00P0000060?ooo`<00000:03o
ool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool800000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`8000009P3oool01P000000oooo0?ooo`3oool00000
0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`80000000<0oooo0000000000000P00000U0?ooo`030000003o
ool0000000@0000000<0oooo0000003oool04@3oool010000000oooo00000000000:0?ooo`007P3o
ool00`000000oooo0000000:0?ooo`030000003oool0oooo02<0oooo1`0000020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`00000000000P3oool00`000000oooo000000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P00000V0?ooo`040000003oool0oooo
0?ooo`80000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`0T0?ooo`03
0000003oool000000080000000@0oooo0000003oool000004P3oool00`000000oooo000000020000
00T0oooo000N0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool07`3oool3000000<0
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000009@3o
ool200000080oooo00@000000?ooo`000000oooo0`0000040?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool0oooo0P0000001P3oool000000000003oool000000?ooo`8000009@3oool0
0`000000oooo00000002000000040?ooo`000000oooo000001<0oooo0P0000000`3oool000000?oo
o`080?ooo`007P3oool2000000d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00009@3oool01P000000oooo0?ooo`3oool000000?ooo`<0000000<0oooo0000003oool00P3oool0
0`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000030?ooo`00
0000000002@0oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool04@3o
ool2000000030?ooo`000000oooo00P0oooo000N0?ooo`<00000303oool00`000000oooo0?ooo`0H
0?ooo`H00000103oool2000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<000007P3oool2000000<0oooo0P000000103oool00000
0000003oool5000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000200000004
0?ooo`000000oooo00000180oooo1000000=0?ooo`050000003oool0oooo0000003oool00P000000
0`3oool000000?ooo`0>0?ooo`T0000000<0oooo0000000000000P0000040?ooo`007P3oool50000
00/0oooo00@000000?ooo`3oool0oooo1`00000?0?ooo`060000003oool000000000003oool00000
0`3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo2@0000030?ooo`030000
003oool0oooo01d0oooo0P0000030?ooo`80000000<0oooo0000003oool00P0000020?ooo`030000
003oool0000000T0oooo00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`000000oooo
008000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`000000100000000`3oool000000?ooo`0A0?ooo`070000003oool000000?ooo`000000oooo0000
00040?ooo`030000003oool0oooo0040oooo000N0?ooo`8000000`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`05
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00<000000P3oool0
0`000000oooo0?ooo`0L0?ooo`<000000P3oool200000080oooo00@000000?ooo`00000000000P3o
ool00`000000oooo000000090?ooo`040000003oool0oooo0?ooo`<0000000@0oooo000000000000
oooo0P00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool200000008
0?ooo`00000000000000003oool000000?ooo`00000B0?ooo`030000003oool0oooo0080000000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`010?ooo`007P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo0080oooo200000090?ooo`800000303oool00`000000oooo00000005
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
000000030?ooo`000000oooo00L0oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`00
0000oooo0080oooo1P00000M0?ooo`<000000P3oool2000000040?ooo`000000oooo0?ooo`@00000
0P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`80000000<0oooo00000000
00000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool2000000080?ooo`00000000000000003oool000000?ooo`00000B0?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`010?ooo`007P3oool0
0`000000oooo000000040?ooo`80000000<0oooo0000003oool01@3oool3000000X0oooo0P000009
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`8000000`3oool200000080
oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0L0?ooo`<000000`3oool20000
00070?ooo`000000oooo0000003oool000000?ooo`03000000/0oooo00@000000?ooo`3oool0oooo
1@0000020?ooo`8000004@3oool4000000`0oooo0P0000000`3oool0000000000002000000030?oo
o`000000oooo0180oooo00D000000?ooo`3oool000000?ooo`02000000@0oooo00<000000?ooo`3o
ool00@3oool001h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`0000002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo000000080?ooo`8000000`3oool01@000000oooo0000
003oool0000000<0oooo1000000M0?ooo`<000000`3oool01`000000oooo000000000000oooo0000
003oool00P00000?0?ooo`030000003oool0oooo00D000000`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool2000000030?ooo`0000000000
0080000000<0oooo0000003oool04P3oool01@000000oooo0?ooo`000000oooo00800000103oool0
0`000000oooo0?ooo`010?ooo`007P3oool010000000oooo0?ooo`0000030?ooo`80000000<0oooo
0000003oool00`3oool01P000000oooo0?ooo`3oool000000?ooo`8000002P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo0000000L0?ooo`040000003oool0000000000080oooo0P0000001@3oool000000000003oool0
00000080oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`000000oooo0000003oool0
0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`8000000P3oool4000000030?ooo`000000oooo0180oooo00@000000?ooo`3oool0
oooo0`0000040?ooo`030000003oool0oooo0040oooo000N0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001@3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000000<0oooo00D000000?ooo`000000oooo000000030?ooo`@000006`3oool2000000040?ooo`00
0000oooo0?ooo`<0000000<0oooo0000000000000P3oool00`000000oooo0000000?0?ooo`030000
003oool0oooo0080000000<0oooo0000000000000P3oool2000000l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`80000000@0oooo000000000000oooo0P0000000`3oool0
00000?ooo`0@0?ooo`<000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo0040
oooo000N0?ooo`040000003oool0oooo0?ooo`8000001@3oool010000000oooo0?ooo`0000050?oo
o`040000003oool0oooo000000/0oooo00@000000?ooo`3oool00000103oool4000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0000003oool0000000<0oooo1000000J0?ooo`040000003oool00000000000<0oooo0P00
0000103oool000000?ooo`0000020?ooo`030000003oool0oooo00<00000303oool00`000000oooo
0?ooo`0500000080oooo0P00000@0?ooo`@000002`3oool2000000050?ooo`00000000000000003o
ool00P00000D0?ooo`050000003oool0oooo0?ooo`0000000P3oool4000000@0oooo000N0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000H0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`040000003o
ool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`05
0000003oool000000?ooo`0000006@3oool010000000oooo0000000000030?ooo`80000000H0oooo
0000003oool000000?ooo`00000C0?ooo`040000003oool000000?ooo`<000000P3oool2000001h0
oooo0`0000000`3oool0000000000002000000030?ooo`000000oooo01L0oooo00<000000?ooo`3o
ool0203oool001h0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000L0oooo2@0000030?ooo`050000003oool0
oooo0?ooo`0000001@3oool2000000<0oooo00D000000?ooo`3oool0oooo000000070?ooo`800000
1P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo0P0000020?ooo`03
0000003oool0oooo01D0oooo00D000000?ooo`000000oooo000000020?ooo`8000000P3oool20000
0080oooo00<000000?ooo`3oool04@3oool010000000oooo0000003oool3000000<0oooo0P00000M
0?ooo`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`0H0?ooo`030000003oool0
oooo00L0oooo000N0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool2
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0400000080oooo00<00000
0?ooo`000000103oool500000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo00H00000
0?ooo`3oool0oooo0000003oool>00000080oooo00@000000?ooo`3oool000000P3oool2000000<0
oooo0P0000030?ooo`030000003oool0oooo01@0oooo00D000000?ooo`000000oooo000000020?oo
o`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00D000000P3oool2000001d0oooo0`0000000`3oool000000?ooo`03000001X0oooo00<00000
0?ooo`3oool01`3oool001h0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool3000000H0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0B000000H0oooo00<000000?ooo`0000001@3o
ool300000080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool04P3oool01P000000oooo0?ooo`000000oooo00000080oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000001D0oooo00D000000?ooo`00000000000?ooo`0200000080oooo
0P00000M0?ooo`80000000@0oooo000000000000oooo0`00000J0?ooo`030000003oool0oooo00L0
oooo000N0?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`060000003oool000000000003oool000001P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000H0oooo0P0000000`3oool0
00000?ooo`020?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool04P3oool01@000000
oooo0000003oool000000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0C0?oo
o`050000003oool000000000003oool00P0000020?ooo`<000006`3oool3000000040?ooo`000000
oooo0?ooo`<00000903oool001h0oooo0P0000060?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo0`0000030?ooo`8000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0100oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`040000003oool0
oooo0?ooo`80000000<0oooo0000003oool05@3oool010000000oooo0000003oool300000080oooo
0`00000K0?ooo`<0000000L0oooo0000003oool0oooo0000003oool0000002@0oooo000H0?oooo@0
00000`3oool001h0oooo0P0000040?ooo`H00000103oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo00D0oooo00D000000?ooo`000000oooo000000050?ooo`030000003oool00000
00<0oooo0P0000030?ooo`030000003oool0000000<0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`080000003oool00000
0?ooo`000000oooo0000003oool2000000060?ooo`000000oooo0000003oool000000`3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05
00000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`00000000000?ooo`0200000080oooo0`0000040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo00000003000000040?oo
o`0000000000000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo000N0?ooo`8000001P3oool200000080oooo10000000103oool00000
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo0080
oooo0P0000020?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool30000
00060?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`0=0?ooo`080000003o
ool0oooo0?ooo`000000oooo0000003oool300000080oooo0P0000000`3oool000000?ooo`050?oo
o`030000003oool0oooo00l0oooo00D000000?ooo`00000000000?ooo`0200000080oooo0`00000@
0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool00000000000000000oooo00<000006`3o
ool00`000000oooo0?ooo`070?ooo`007P3oool00`000000oooo000000040?ooo`040000003oool0
oooo000000D0oooo0`0000050?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<00000
0?ooo`3oool0303oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool0
0P3oool2000000030?ooo`000000oooo01P0oooo0`0000020?ooo`030000003oool0oooo00<00000
6@3oool3000000040?ooo`000000oooo0?ooo`<000009@3oool001h0oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`0000060?ooo`<000001@3oool00`000000oooo0?ooo`020?oo
o`800000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`8000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool00000000000<0oooo0`00000J0?ooo`80000000<0oooo0000003oool00P0000001@3oool0
00000000003oool0000001L0oooo00<000000?ooo`0000000`0000020?ooo`8000009P3oool001h0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`000000oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo0P0000020?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool02P3oool01P000000oooo0?ooo`3oool00000
0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0000000K0?ooo`<0000000<0oooo
0000000000000P3oool3000001L0oooo00<000000?ooo`0000000`0000020?ooo`8000009P3oool0
01h0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo008000000P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`800000
0P3oool3000001`0oooo0`0000020?ooo`030000003oool0oooo00<000005`3oool2000000040?oo
o`000000000000000080oooo0P00000V0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`3oool300000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?ooo`03
0000003oool0oooo00h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo0P000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool01P000000oooo0?oo
o`3oool000000?ooo`80000000@0oooo0000003oool000000P3oool3000001`0oooo0`0000020?oo
o`80000000D0oooo000000000000oooo0000000F0?ooo`80000000D0oooo00000000000000000?oo
o`02000002L0oooo000N0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`800000
1P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool010000000oooo0?ooo`0000050?ooo`@0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool03`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool200000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?ooo`02000000<0oooo0P00000N0?ooo`040000003oool000000?ooo`80000000D0
oooo000000000000oooo0000000E0?ooo`040000003oool000000?ooo`<0000000<0oooo00000000
00009`3oool001h0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo0`0000070?oo
o`030000003oool0oooo0080oooo1P0000030?ooo`030000003oool0000000@0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000<0oooo0P00000C
0?ooo`040000003oool0oooo0?ooo`800000103oool200000080oooo0P0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000050?ooo`00
000000000?ooo`0000000`3oool2000001h0oooo0`0000000`3oool000000?ooo`02000000030?oo
o`000000000001D0oooo00<000000?ooo`0000000`0000020?ooo`8000009`3oool001h0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`X000000P3oool0
10000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0D0?ooo`060000003oool0oooo0000003oool000000`3oool01P000000oooo0000003oool00000
0?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P000000103oool000000?ooo`3oool2000001l0oooo0`0000001@3oool000000000
00000000oooo0080000000<0oooo0000003oool04`3oool00`000000oooo0000000300000080oooo
00<000000?ooo`3oool09P3oool001h0oooo00@000000?ooo`3oool00000103oool2000000@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`<000000P3oool2000000<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`04
0000003oool00000000000D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2
00000080oooo00D000000?ooo`000000oooo000000020?ooo`800000803oool2000000050?ooo`00
000000000000003oool00P0000000`3oool000000?ooo`0B0?ooo`040000003oool000000?ooo`<0
00000P3oool00`000000oooo0?ooo`0V0?ooo`007P3oool00`000000oooo000000040?ooo`<00000
103oool00`000000oooo0?ooo`060?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08000001T0
oooo00<000000?ooo`3oool00P0000040?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000002
0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0O0?ooo`8000000P3oool0
0`000000oooo00000002000000030?ooo`000000oooo0180oooo00@000000?ooo`000000oooo0`00
00020?ooo`030000003oool0oooo02H0oooo000N0?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`020?ooo`8000007P3oool00`000000oooo0?ooo`02000000<0oooo
00D000000?ooo`000000oooo000000030?ooo`<00000103oool00`000000oooo000000030?ooo`04
0000003oool0oooo00000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo
01l0oooo0`0000000`3oool0000000000002000000040?ooo`000000oooo00000180oooo00@00000
0?ooo`000000oooo0`0000000`3oool000000?ooo`0X0?ooo`007P3oool200000080oooo0P000005
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07P3oool010000000oooo0000000000030?ooo`030000003oool0oooo
008000000`3oool00`000000oooo0?ooo`03000000030?ooo`00000000000080oooo0P0000020?oo
o`040000003oool0oooo0?ooo`80000000@0oooo0000003oool0oooo0P00000R0?ooo`80000000<0
oooo0000000000000P000000103oool000000?ooo`00000A0?ooo`030000003oool0oooo00@00000
0P3oool00`000000oooo0?ooo`0W0?ooo`007P3oool4000000P0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000L0oooo
0P0000050?ooo`030000003oool0oooo0080oooo0P00000Q0?ooo`030000003oool0000000@0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0080oooo1P0000040?ooo`03
0000003oool0oooo008000000P3oool010000000oooo00000000000S0?ooo`80000000@0oooo0000
00000000oooo0`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`000000oooo0`00
00020?ooo`030000003oool0oooo02L0oooo000N0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P000009
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000002<0oooo0`000003
0?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo0000003oool08P3o
ool2000000030?ooo`000000oooo00@000000P3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0000003oool00`0000000`3oool000000000000Y0?ooo`007P3oool2000000d0oooo00D0
00000?ooo`000000oooo000000060?ooo`030000003oool0oooo00<00000203oool00`000000oooo
0000000300000080oooo0`0000000`3oool000000?ooo`0S0?ooo`8000000`3oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo0?ooo`80000000@0oooo000000000000oooo0P00000T0?ooo`030000003oool0
oooo0080000000H0oooo0000003oool000000?ooo`00000?0?ooo`050000003oool0oooo0000003o
ool00`0000000`3oool000000000000Y0?ooo`007P3oool00`000000oooo0000000=0?ooo`<00000
203oool2000000<0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool500000080
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo00000080oooo0P00000T0?ooo`80000000L0oooo000000000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050000
00030?ooo`000000000002T0oooo000N0?ooo`040000003oool0oooo000000d0oooo100000040?oo
o`<00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000000P3oool2
000000<0oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`0000020?ooo`8000000P3o
ool010000000oooo0?ooo`00000U0?ooo`80000000L0oooo000000000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool8000002T0oooo000N0?oo
o`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo000000020?ooo`@000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo02H0oooo0P0000020?ooo`030000003oool0oooo008000000`3o
ool2000000P0oooo0`0000020?ooo`030000003oool000000080000000<0oooo0000000000009P3o
ool010000000oooo0000003oool400000080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`02000000040?ooo`00000000000?ooo`800000:P3oool001h0oooo00<000000?ooo`3oool0
0P3oool2000000L0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000
oooo0?ooo`0V0?ooo`D000000`3oool2000000040?ooo`000000oooo000000T0oooo1P000000103o
ool000000?ooo`3oool2000002H0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0000000<0oooo00000000
0000:P3oool001@0oooo100000060?ooo`030000003oool0oooo00@0oooo1`0000060?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0
00000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0000003oool0000002H0oooo0P000000103oool000000000003oool300000080oooo00<0
00000?ooo`3oool02@3oool01P000000oooo0?ooo`3oool000000?ooo`@0000000<0oooo0000003o
ool0:@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo0P0000020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
00000`3oool010000000oooo00000000000W0?ooo`80000000<0oooo0000003oool0100000020?oo
o`030000003oool0oooo00T0oooo00H000000?ooo`3oool0oooo0000003oool6000002X0oooo000H
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`08
0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02T0oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo00000000000X
0?ooo`<0000000D0oooo000000000000oooo000000030?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo00000003000002X0oooo000H0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`L00000203o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool000000080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000030?ooo`050000
003oool000000?ooo`000000:03oool3000000040?ooo`00000000000?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000040?ooo`000000
0000000002X0oooo000H0?ooo`030000003oool0oooo00<0oooo0P00000E0?ooo`030000003oool0
oooo00T0oooo0P00000:0?ooo`030000003oool0oooo02/0oooo0P0000020?ooo`040000003oool0
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool0
00000`3oool010000000oooo00000000000Y0?ooo`030000003oool000000080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000P3oool3
000000030?ooo`000000oooo02X0oooo000D0?ooo`@000001P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000oooo02P0oooo
0`0000020?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080000000<0oooo0000000000001000000[0?ooo`00503oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01D0oooo0P0000080?ooo`040000003oool0oooo0?ooo`800000
1@3oool2000002h0oooo00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`000000oooo0000000Y0?ooo`80000000<0oooo0000003oool00P0000000`3oool00000
000000030?ooo`030000003oool0oooo00@0oooo00T000000?ooo`3oool000000?ooo`000000oooo
0000003oool01000000[0?ooo`00503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01L0oooo0P0000040?ooo`8000001@3oool3000000030?ooo`00000000000340oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo0000000000000P3oool0
10000000oooo0?ooo`0000030?ooo`80000000<0oooo0000003oool0:P3oool010000000oooo0000
003oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0200000080oooo00@000000?ooo`000000oooo0P00000[0?ooo`00503oool5000000D0oooo
00<000000?ooo`3oool0603oool5000000T0oooo0`00000b0?ooo`060000003oool0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`020?ooo`D000000`3oool00`000000oooo0?ooo`020000
0080oooo00<000000?ooo`3oool0:@3oool01P000000oooo000000000000oooo00000080oooo0P00
00030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`06
0000003oool000000000003oool00000:`3oool001h0oooo00<000000?ooo`3oool0F`3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0Y0?ooo`@0000000@0oooo0000003oool0oooo
0P0000030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`80000000<0oooo000000000000;03oool001h0oooo00<000000?ooo`3oool0G03oool010000000
oooo0?ooo`3oool200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool0:P3oool2000000040?ooo`00
0000000000000080oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`09
0000003oool0oooo0000003oool000000?ooo`000000oooo00800000;03oool001h0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool00P000004
0?ooo`80000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo02X0oooo0P000000
0`3oool0000000000002000000040?ooo`000000oooo0?ooo`80000000D0oooo0000003oool0oooo
000000020?ooo`030000003oool000000080oooo0`0000000`3oool000000000000/0?ooo`007P3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0080oooo1@0000080?ooo`<0000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`0Z0?ooo`80000000<0oooo0000003oool00P00
00020?ooo`030000003oool0oooo0080000000<0oooo0000000000000`0000020?ooo`030000003o
ool0oooo00@0000000<0oooo0000003oool0:`3oool001h0oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo02/0oooo0`0000000`3oool00000000000020?ooo`030000
003oool0oooo0080oooo100000040?ooo`050000003oool000000000003oool00`00000]0?ooo`00
7P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02`0oooo0P000000103o
ool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool3
00000080oooo0`00000]0?ooo`007P3oool00`000000oooo0?ooo`1N0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0;03oool2000000030?ooo`000000oooo00@000000`3oool010000000oooo0?oo
o`3oool200000080oooo100000001@3oool000000000003oool0000002d0oooo000N0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0/0?ooo`050000003oool00000
0000003oool00P0000000`3oool0000000000003000000D0oooo100000000`3oool000000?ooo`02
000000030?ooo`000000oooo02`0oooo000N0?ooo`030000003oool0oooo05l0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0/0?ooo`040000003oool0000000000080oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`02000000050?ooo`00000000000?ooo`000000;@3oool001h0
oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0
00000000003oool00P0000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0P3oool3000002h0oooo000N0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
;P3oool01@000000oooo000000000000oooo008000000P3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`000000;P3oool001h0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`0_0?ooo`080000003oool0oooo0000003oool000000?oo
o`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000001@3oool00000
0000003oool0000002h0oooo000N0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
;`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080000000D0oooo000000000000oooo0000000^0?ooo`007P3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0`0000040?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool00P0000001P3oool000000?ooo`000000
oooo000000H0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0;03oool001h0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`040?ooo`D00000
103oool00`000000oooo0?ooo`0a0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080oooo00<00000
0?ooo`000000;`3oool001h0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool01P000000oooo0?ooo`000000
oooo00000080oooo00<000000?ooo`000000103oool01P000000oooo0000003oool000000?ooo`80
000000<0oooo0000003oool0;P3oool001h0oooo00<000000?ooo`3oool0H`3oool2000000<0oooo
0P0000000`3oool00000000000020?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
0P0000001P3oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo02d0oooo000:0?ooo`L000000`3oool4000000H0
oooo00<000000?ooo`3oool0I03oool4000000@0oooo1000000f0?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool3
00000080oooo00<000000?ooo`3oool0;@3oool000d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0YP3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool6000000<0oooo0`0000020?ooo`030000003o
ool0oooo02d0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool00`000004
0?ooo`@00000103oool01@000000oooo0000003oool000000300oooo000=0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000Z03oool0
1@000000oooo0?ooo`000000oooo00800000103oool3000000<0oooo0`0000020?ooo`030000003o
ool0oooo02h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0:L0oooo00H000000?ooo`3oool0oooo0000
003oool500000080oooo1@0000001@3oool000000?ooo`3oool000000300oooo000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0:P0oooo00H000000?ooo`3oool000000?ooo`00000:0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0;P3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Z03oool01P000000
oooo0?ooo`000000oooo000000X0oooo00D000000?ooo`000000oooo0000000a0?ooo`002`3oool3
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool0;`3oool000d0oooo00<000000?ooo`3oool0103oool40000
00H0oooo00<000000?ooo`3oool0Z@3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0_0?ooo`007P3oool00`000000oooo0?ooo`2Y
0?ooo`060000003oool0oooo0000003oool000001`3oool00`000000oooo000000030?ooo`030000
003oool0oooo02l0oooo000N0?ooo`030000003oool0oooo0:X0oooo00H000000?ooo`3oool00000
0?ooo`0000060?ooo`030000003oool000000080oooo00<000000?ooo`3oool0<03oool001h0oooo
00<000000?ooo`3oool0ZP3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0`0?ooo`007P3oool00`000000oooo0?ooo`2Z0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool0<@3oool001h0oooo00<000000?ooo`3oool0Z`3oool01P000000oooo0?ooo`000000
oooo000000@0oooo0P0000030?ooo`030000003oool0oooo0340oooo000N0?ooo`030000003oool0
oooo0:/0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0b0?ooo`007P3oool00`000000oooo0?ooo`2/0?ooo`060000003o
ool0oooo0000003oool000000P3oool200000080oooo00<000000?ooo`3oool0<`3oool001h0oooo
00<000000?ooo`3oool0[03oool01P000000oooo0?ooo`3oool000000?ooo`80000000D0oooo0000
003oool0oooo0000000e0?ooo`007P3oool00`000000oooo0?ooo`2]0?ooo`040000003oool0oooo
0?ooo`@000000`3oool00`000000oooo0?ooo`0c0?ooo`007P3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo00<000000`3oool00`000000oooo0?ooo`0d0?ooo`007P3oool00`000000
oooo0?ooo`2^0?ooo`@000000P3oool3000003L0oooo000N0?ooo`030000003oool0oooo0>h0oooo
000N0?ooo`030000003oool0oooo0>h0oooo000N0?ooo`030000003oool0oooo0>h0oooo000N0?oo
o`030000003oool0oooo0>h0oooo003o0?oooa00oooo003o0?oooa00oooo003o0?oooa00oooo003o
0?oooa00oooo003o0?oooa00oooo003o0?oooa00oooo0000\
\>"],
  ImageRangeCache->{{{72.9375, 216.813}, {143, 54.5}} -> {-7.22852, 2.57497, \
0.0650096, 0.297157}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.0952381 0.311084 0.00210979 [
[.21429 .29858 -9 -9 ]
[.21429 .29858 9 0 ]
[.40476 .29858 -9 -9 ]
[.40476 .29858 9 0 ]
[.59524 .29858 -9 -9 ]
[.59524 .29858 9 0 ]
[.78571 .29858 -9 -9 ]
[.78571 .29858 9 0 ]
[.97619 .29858 -9 -9 ]
[.97619 .29858 9 0 ]
[.01131 .10011 -24 -4.5 ]
[.01131 .10011 0 4.5 ]
[.01131 .20559 -18 -4.5 ]
[.01131 .20559 0 4.5 ]
[.01131 .41657 -12 -4.5 ]
[.01131 .41657 0 4.5 ]
[.01131 .52206 -18 -4.5 ]
[.01131 .52206 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31108 m
.21429 .31733 L
s
[(102)] .21429 .29858 0 1 Mshowa
.40476 .31108 m
.40476 .31733 L
s
[(104)] .40476 .29858 0 1 Mshowa
.59524 .31108 m
.59524 .31733 L
s
[(106)] .59524 .29858 0 1 Mshowa
.78571 .31108 m
.78571 .31733 L
s
[(108)] .78571 .29858 0 1 Mshowa
.97619 .31108 m
.97619 .31733 L
s
[(110)] .97619 .29858 0 1 Mshowa
.125 Mabswid
.07143 .31108 m
.07143 .31483 L
s
.11905 .31108 m
.11905 .31483 L
s
.16667 .31108 m
.16667 .31483 L
s
.2619 .31108 m
.2619 .31483 L
s
.30952 .31108 m
.30952 .31483 L
s
.35714 .31108 m
.35714 .31483 L
s
.45238 .31108 m
.45238 .31483 L
s
.5 .31108 m
.5 .31483 L
s
.54762 .31108 m
.54762 .31483 L
s
.64286 .31108 m
.64286 .31483 L
s
.69048 .31108 m
.69048 .31483 L
s
.7381 .31108 m
.7381 .31483 L
s
.83333 .31108 m
.83333 .31483 L
s
.88095 .31108 m
.88095 .31483 L
s
.92857 .31108 m
.92857 .31483 L
s
.25 Mabswid
0 .31108 m
1 .31108 L
s
.02381 .10011 m
.03006 .10011 L
s
[(-100)] .01131 .10011 1 0 Mshowa
.02381 .20559 m
.03006 .20559 L
s
[(-50)] .01131 .20559 1 0 Mshowa
.02381 .41657 m
.03006 .41657 L
s
[(50)] .01131 .41657 1 0 Mshowa
.02381 .52206 m
.03006 .52206 L
s
[(100)] .01131 .52206 1 0 Mshowa
.125 Mabswid
.02381 .1212 m
.02756 .1212 L
s
.02381 .1423 m
.02756 .1423 L
s
.02381 .1634 m
.02756 .1634 L
s
.02381 .1845 m
.02756 .1845 L
s
.02381 .22669 m
.02756 .22669 L
s
.02381 .24779 m
.02756 .24779 L
s
.02381 .26889 m
.02756 .26889 L
s
.02381 .28999 m
.02756 .28999 L
s
.02381 .33218 m
.02756 .33218 L
s
.02381 .35328 m
.02756 .35328 L
s
.02381 .37438 m
.02756 .37438 L
s
.02381 .39548 m
.02756 .39548 L
s
.02381 .43767 m
.02756 .43767 L
s
.02381 .45877 m
.02756 .45877 L
s
.02381 .47987 m
.02756 .47987 L
s
.02381 .50097 m
.02756 .50097 L
s
.02381 .07901 m
.02756 .07901 L
s
.02381 .05791 m
.02756 .05791 L
s
.02381 .03681 m
.02756 .03681 L
s
.02381 .01571 m
.02756 .01571 L
s
.02381 .54316 m
.02756 .54316 L
s
.02381 .56426 m
.02756 .56426 L
s
.02381 .58536 m
.02756 .58536 L
s
.02381 .60646 m
.02756 .60646 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .18389 m
.03279 .14134 L
.04262 .10159 L
.04758 .0848 L
.05288 .06954 L
.05785 .05794 L
.06244 .04967 L
.06508 .04601 L
.06788 .04301 L
.06933 .04182 L
.07069 .04093 L
.07218 .04021 L
.07302 .03992 L
.07379 .03973 L
.07445 .03962 L
.07515 .03956 L
.07641 .03961 L
.07719 .03973 L
.07792 .03991 L
.07857 .04013 L
.07928 .04042 L
.08061 .04112 L
.082 .0421 L
.08451 .04442 L
.0869 .04732 L
.08946 .05117 L
.09408 .06001 L
.09957 .07361 L
.10458 .08878 L
.12366 .1675 L
.14443 .27886 L
.16381 .38916 L
.17411 .44383 L
.18521 .49589 L
.19577 .53629 L
.2004 .55063 L
.20546 .56373 L
.21026 .57353 L
.21472 .58027 L
.21719 .58299 L
.21944 .58483 L
.22068 .58558 L
.22133 .58591 L
.22203 .58619 L
.2233 .58656 L
.22447 .58673 L
.22568 .58673 L
.227 .58653 L
.22825 .58614 L
.2294 .58561 L
Mistroke
.23055 .58493 L
.23159 .58417 L
.23391 .58201 L
.23642 .57895 L
.23913 .57481 L
.24405 .56512 L
.25359 .53867 L
.26236 .50624 L
.28122 .41564 L
.3019 .29788 L
.32309 .17946 L
.34238 .09301 L
.35197 .06238 L
.35739 .04944 L
.35997 .04445 L
.3624 .04049 L
.36468 .03739 L
.36677 .0351 L
.36909 .03318 L
.37031 .03244 L
.37159 .03185 L
.37276 .0315 L
.374 .0313 L
.37518 .03129 L
.37625 .03143 L
.37751 .03178 L
.37821 .03206 L
.37887 .03237 L
.38014 .03313 L
.38134 .03403 L
.38379 .03641 L
.38603 .03922 L
.39106 .04773 L
.39541 .05747 L
.40014 .07047 L
.41086 .10854 L
.42079 .15305 L
.46003 .37456 L
.4797 .47992 L
.48831 .51815 L
.49775 .55228 L
.50229 .56545 L
.50715 .57697 L
.50984 .58217 L
.51229 .58615 L
.51461 .58925 L
.51707 .59182 L
.51834 .59286 L
.51974 .59377 L
.52102 .59439 L
Mistroke
.52221 .59478 L
.52293 .59493 L
.52361 .59501 L
.5249 .59501 L
.52562 .59492 L
.52628 .59477 L
.52701 .59455 L
.52779 .59425 L
.5291 .59355 L
.53052 .59256 L
.5331 .59013 L
.53561 .58697 L
.53792 .58339 L
.54262 .57411 L
.54766 .56131 L
.55676 .53122 L
.57742 .43502 L
.59725 .32046 L
.6188 .19425 L
.62885 .14188 L
.63952 .09443 L
.64862 .06234 L
.65381 .04804 L
.65867 .03744 L
.66337 .0299 L
.66603 .02683 L
.66851 .02478 L
.66986 .02399 L
.67114 .02345 L
.67228 .02314 L
.67352 .023 L
.67416 .023 L
.67487 .02306 L
.67561 .02319 L
.6763 .02338 L
.67754 .02387 L
.67887 .02461 L
.68124 .02648 L
.68383 .02934 L
.68854 .03666 L
.69313 .04638 L
.69738 .05758 L
.70798 .09416 L
.71796 .13845 L
.73658 .23988 L
.7752 .46633 L
.78555 .51593 L
.79519 .55359 L
.80046 .57009 L
.80525 .58236 L
Mistroke
.81058 .59279 L
.81351 .59703 L
.81484 .59861 L
.81628 .60005 L
.81752 .60109 L
.81866 .60187 L
.8198 .60248 L
.82089 .60291 L
.82215 .60322 L
.82332 .60332 L
.8246 .60323 L
.82532 .60308 L
.82597 .6029 L
.82661 .60266 L
.82729 .60235 L
.82851 .60164 L
.82982 .60067 L
.83126 .59936 L
.83383 .59634 L
.83624 .59276 L
.84089 .58381 L
.84514 .57337 L
.85468 .54241 L
.86459 .50041 L
.87376 .45415 L
.89451 .33253 L
.91476 .20941 L
.92467 .15425 L
.93377 .10949 L
.94244 .07356 L
.95192 .04321 L
.95686 .03153 L
.96146 .02335 L
.964 .01997 L
.96632 .01762 L
.9676 .01661 L
.96898 .01576 L
.9703 .01518 L
.9715 .01485 L
.97266 .01472 L
.97374 .01474 L
.97492 .01495 L
.97619 .01538 L
Mfstroke
.02381 .17837 m
.03279 .13649 L
.04262 .09768 L
.04758 .08143 L
.05288 .06678 L
.05785 .05579 L
.06244 .0481 L
.06508 .04478 L
.06788 .04215 L
.06933 .04115 L
.07069 .04044 L
.07147 .04014 L
.07218 .03992 L
.073 .03974 L
.07379 .03965 L
.07507 .03966 L
.07579 .03975 L
.07644 .03989 L
.07771 .0403 L
.07891 .04086 L
.08031 .04174 L
.0816 .04275 L
.08451 .04575 L
.08691 .04899 L
.08916 .05262 L
.09427 .063 L
.10458 .09253 L
.11503 .13294 L
.12493 .17924 L
.14349 .27981 L
.16171 .38359 L
.18182 .48582 L
.19133 .52456 L
.20159 .55683 L
.20724 .56986 L
.20972 .57443 L
.21243 .57862 L
.21482 .58161 L
.21738 .58404 L
.2188 .58505 L
.22009 .58576 L
.22138 .58627 L
.2226 .58657 L
.22375 .58668 L
.22499 .58662 L
.22616 .58639 L
.22723 .58604 L
.22848 .58545 L
.22984 .58459 L
.23232 .58246 L
Mistroke
.23491 .57945 L
.23766 .57537 L
.24261 .56582 L
.2523 .53927 L
.26107 .50703 L
.28035 .41445 L
.30118 .29573 L
.32077 .1859 L
.33114 .13498 L
.34224 .08964 L
.34774 .07144 L
.35295 .05715 L
.35762 .04688 L
.36004 .04256 L
.3627 .0386 L
.36519 .03568 L
.36751 .03361 L
.3688 .03275 L
.36997 .03215 L
.37126 .03168 L
.37191 .03152 L
.37262 .0314 L
.37382 .03135 L
.37492 .03146 L
.37618 .03176 L
.37737 .03223 L
.37847 .03282 L
.37949 .0335 L
.38178 .03549 L
.38423 .03832 L
.38647 .04154 L
.3915 .05095 L
.39616 .06227 L
.40058 .07521 L
.42124 .16053 L
.45953 .37786 L
.47889 .48114 L
.48918 .5258 L
.49459 .54541 L
.50028 .56283 L
.50532 .57526 L
.50798 .58065 L
.51083 .58549 L
.51346 .58908 L
.51584 .59161 L
.51699 .59258 L
.51824 .59344 L
.51942 .59408 L
.52051 .59452 L
.5216 .59481 L
Mistroke
.52278 .59496 L
.52389 .59493 L
.5249 .59478 L
.52609 .59443 L
.52738 .59386 L
.5286 .59312 L
.52974 .59227 L
.53222 .58986 L
.53447 .58701 L
.53952 .5784 L
.5444 .5672 L
.54955 .55245 L
.55878 .51908 L
.5796 .41729 L
.61759 .19516 L
.63712 .09993 L
.64274 .07837 L
.64806 .06092 L
.65281 .04799 L
.65804 .03673 L
.66044 .03267 L
.66302 .02908 L
.66547 .02645 L
.6677 .02469 L
.66894 .02399 L
.67009 .02352 L
.67135 .02319 L
.67206 .02309 L
.6727 .02306 L
.674 .02316 L
.67473 .0233 L
.67541 .0235 L
.67665 .02401 L
.67796 .02477 L
.68015 .02651 L
.6825 .02905 L
.68674 .03537 L
.69178 .04573 L
.69639 .0578 L
.70627 .09156 L
.71543 .13136 L
.73617 .24361 L
.77537 .47248 L
.78569 .52095 L
.79112 .54265 L
.79684 .5623 L
.80186 .57659 L
.80736 .58886 L
.80978 .59309 L
.81236 .59682 L
Mistroke
.8148 .59957 L
.81703 .60141 L
.81821 .60213 L
.81932 .60265 L
.82054 .60303 L
.82185 .60323 L
.82251 .60325 L
.82322 .6032 L
.82453 .60295 L
.8258 .6025 L
.82697 .60189 L
.82818 .60109 L
.82931 .60016 L
.83142 .59799 L
.8337 .59502 L
.83616 .59108 L
.84142 .58016 L
.84698 .56504 L
.85694 .52944 L
.87657 .43303 L
.8949 .32381 L
.91353 .21061 L
.9338 .1048 L
.94482 .06157 L
.94967 .04664 L
.95503 .03332 L
.95745 .02844 L
.96006 .024 L
.96231 .02085 L
.96478 .01815 L
.96615 .01699 L
.96742 .01613 L
.96876 .01545 L
.96951 .01517 L
.97019 .01498 L
.97141 .0148 L
.9721 .01478 L
.97274 .01481 L
.97391 .01502 L
.97515 .01543 L
.97619 .01594 L
Mfstroke
.02381 .17284 m
.03279 .13163 L
.04262 .09376 L
.04758 .07805 L
.05288 .06402 L
.05789 .05358 L
.06244 .04653 L
.06507 .04357 L
.0665 .04229 L
.06785 .04131 L
.06899 .04065 L
.07022 .04011 L
.07092 .03989 L
.07158 .03973 L
.07283 .03957 L
.07354 .03956 L
.07418 .03961 L
.07493 .03972 L
.07563 .03989 L
.07687 .04033 L
.07757 .04067 L
.07822 .04102 L
.08108 .04321 L
.08252 .04467 L
.0841 .04656 L
.08922 .05466 L
.09469 .06662 L
.10458 .09628 L
.11475 .13649 L
.12582 .18928 L
.14594 .30014 L
.16533 .40943 L
.17562 .46218 L
.18672 .51121 L
.19187 .53045 L
.19729 .54796 L
.20231 .56145 L
.20698 .57153 L
.21137 .57874 L
.21382 .58178 L
.21606 .58393 L
.21725 .58483 L
.21851 .58559 L
.21917 .58591 L
.21989 .58621 L
.22117 .58657 L
.22237 .58674 L
.22366 .58672 L
.22488 .58651 L
.22599 .58617 L
Mistroke
.22728 .58558 L
.2285 .58484 L
.23077 .58298 L
.23322 .58028 L
.23586 .57657 L
.24063 .56781 L
.24501 .55748 L
.2551 .52591 L
.26575 .48213 L
.30377 .27438 L
.32496 .15909 L
.33499 .11348 L
.34425 .07898 L
.35385 .05244 L
.3589 .04259 L
.36146 .03876 L
.36427 .03544 L
.36547 .03432 L
.36673 .03333 L
.36782 .03263 L
.36898 .03204 L
.37023 .03159 L
.3714 .03135 L
.37211 .03128 L
.37279 .03128 L
.37405 .03142 L
.37516 .03171 L
.37634 .03218 L
.37734 .03272 L
.37845 .03345 L
.38091 .03563 L
.38321 .03833 L
.38821 .04637 L
.39365 .05844 L
.40354 .08875 L
.41317 .12751 L
.42209 .17018 L
.46132 .39422 L
.48099 .49585 L
.48961 .53155 L
.49449 .54868 L
.49904 .5624 L
.50397 .57469 L
.50845 .58344 L
.51075 .58699 L
.51324 .59012 L
.51461 .59152 L
.51587 .5926 L
.51707 .59345 L
.51836 .59416 L
Mistroke
.51966 .59466 L
.52085 .59494 L
.52205 .59504 L
.52318 .59496 L
.5245 .59468 L
.52572 .59422 L
.52642 .59388 L
.52706 .59351 L
.52849 .5925 L
.53114 .58995 L
.53401 .58622 L
.53921 .57692 L
.54413 .56518 L
.54873 .55178 L
.55916 .51316 L
.58023 .40788 L
.61916 .18086 L
.62935 .12946 L
.64042 .08293 L
.64549 .06556 L
.65087 .05014 L
.65547 .0396 L
.65789 .03505 L
.66054 .0309 L
.66309 .02771 L
.66547 .02548 L
.66678 .02455 L
.66797 .02389 L
.66863 .0236 L
.66935 .02335 L
.67065 .02307 L
.67176 .02299 L
.67299 .02309 L
.67427 .0234 L
.67546 .02388 L
.67658 .02449 L
.67761 .02518 L
.67991 .02723 L
.68256 .03042 L
.68503 .03416 L
.69061 .04536 L
.69553 .05828 L
.70077 .075 L
.72223 .17083 L
.74242 .28736 L
.76085 .39837 L
.7713 .45676 L
.78104 .50503 L
.79151 .54793 L
.80104 .57718 L
Mistroke
.80627 .58882 L
.80867 .59304 L
.81122 .59675 L
.81394 .59979 L
.81515 .60085 L
.81645 .60178 L
.81717 .6022 L
.81784 .60253 L
.81915 .60301 L
.81987 .60318 L
.82067 .60329 L
.82142 .60332 L
.82212 .60328 L
.8234 .60305 L
.82405 .60285 L
.82476 .60257 L
.82602 .60191 L
.82719 .60112 L
.82984 .59868 L
.83268 .59507 L
.83788 .58585 L
.84263 .57457 L
.85218 .54404 L
.86124 .50641 L
.89955 .28875 L
.91893 .17416 L
.92922 .12114 L
.94032 .07383 L
.94502 .05751 L
.94997 .04299 L
.95455 .0321 L
.95882 .02428 L
.96088 .02131 L
.96283 .01901 L
.96391 .01795 L
.96507 .01697 L
.96613 .01623 L
.96711 .01567 L
.96821 .0152 L
.96941 .01486 L
.97058 .01472 L
.97184 .01476 L
.973 .01498 L
.97411 .01536 L
.97511 .01583 L
.97619 .0165 L
Mfstroke
.02381 .18698 m
.03279 .1454 L
.04262 .10657 L
.04758 .09016 L
.05288 .07524 L
.05785 .0639 L
.06244 .0558 L
.06508 .05222 L
.06788 .04928 L
.06933 .04811 L
.07069 .04724 L
.07218 .04653 L
.07302 .04625 L
.07379 .04606 L
.07445 .04595 L
.07515 .04589 L
.07641 .04593 L
.07719 .04605 L
.07792 .04622 L
.07857 .04643 L
.07928 .04671 L
.08061 .0474 L
.082 .04834 L
.08451 .0506 L
.0869 .05343 L
.08946 .05718 L
.09408 .06581 L
.09957 .07907 L
.10458 .09388 L
.12366 .17073 L
.14443 .27949 L
.16381 .38725 L
.17411 .44067 L
.18521 .49155 L
.19577 .53104 L
.2004 .54506 L
.20546 .55787 L
.21026 .56747 L
.21472 .57406 L
.21719 .57672 L
.21944 .57853 L
.22068 .57927 L
.22133 .57959 L
.22203 .57987 L
.2233 .58023 L
.22447 .5804 L
.22568 .5804 L
.227 .58021 L
.22825 .57984 L
.2294 .57932 L
Mistroke
.23055 .57866 L
.23159 .57793 L
.23391 .57582 L
.23642 .57284 L
.23913 .56879 L
.24405 .55934 L
.25359 .53352 L
.26236 .50186 L
.28122 .41336 L
.3019 .29829 L
.32309 .18255 L
.34238 .09803 L
.35197 .06807 L
.35739 .05541 L
.35997 .05053 L
.3624 .04664 L
.36468 .04361 L
.36677 .04137 L
.36909 .03948 L
.37031 .03875 L
.37159 .03818 L
.37276 .03782 L
.374 .03763 L
.37518 .03762 L
.37625 .03775 L
.37751 .03808 L
.37821 .03836 L
.37887 .03866 L
.38014 .0394 L
.38134 .04027 L
.38379 .0426 L
.38603 .04534 L
.39106 .05364 L
.39541 .06314 L
.40014 .07584 L
.41086 .11303 L
.42079 .15651 L
.46003 .37303 L
.4797 .47605 L
.48831 .51344 L
.49775 .54683 L
.50229 .55972 L
.50715 .571 L
.50984 .57609 L
.51229 .57998 L
.51461 .58303 L
.51707 .58555 L
.51834 .58657 L
.51974 .58746 L
.52102 .58806 L
Mistroke
.52221 .58845 L
.52293 .5886 L
.52361 .58868 L
.5249 .58868 L
.52562 .5886 L
.52628 .58846 L
.52701 .58825 L
.52779 .58795 L
.5291 .58727 L
.53052 .58631 L
.5331 .58394 L
.53561 .58086 L
.53792 .57736 L
.54262 .5683 L
.54766 .5558 L
.55676 .5264 L
.57742 .43237 L
.59725 .32036 L
.6188 .19694 L
.62885 .14571 L
.63952 .09928 L
.64862 .06787 L
.65381 .05388 L
.65867 .0435 L
.66337 .0361 L
.66603 .0331 L
.66851 .03108 L
.66986 .0303 L
.67114 .02977 L
.67228 .02947 L
.67352 .02933 L
.67416 .02933 L
.67487 .02938 L
.67561 .02951 L
.6763 .02969 L
.67754 .03017 L
.67887 .03089 L
.6801 .03175 L
.68124 .03271 L
.68383 .0355 L
.68854 .04265 L
.69282 .05143 L
.69738 .06309 L
.7077 .09774 L
.71884 .1464 L
.73903 .25555 L
.75863 .37157 L
.78011 .48689 L
.79 .52951 L
.79544 .54908 L
Mistroke
.80058 .56475 L
.80537 .5767 L
.8079 .58193 L
.81057 .58664 L
.81282 .58993 L
.8153 .59284 L
.81639 .59387 L
.81755 .59482 L
.81864 .59555 L
.81967 .5961 L
.8203 .59638 L
.821 .59662 L
.8222 .5969 L
.82288 .59697 L
.82361 .59699 L
.8249 .59685 L
.8261 .59654 L
.82722 .59609 L
.82845 .5954 L
.82977 .59446 L
.83273 .59156 L
.83553 .5878 L
.84079 .57817 L
.84579 .566 L
.85041 .55223 L
.86088 .51283 L
.87953 .41982 L
.90013 .29821 L
.9211 .17654 L
.93028 .12994 L
.94032 .08662 L
.94937 .05601 L
.9537 .04454 L
.95779 .03572 L
.96003 .03175 L
.96245 .02814 L
.96447 .02569 L
.96669 .02359 L
.96793 .02269 L
.96909 .02202 L
.97031 .0215 L
.97163 .02116 L
.97285 .02104 L
.97401 .0211 L
.97505 .0213 L
.97619 .02168 L
Mfstroke
.02381 .18145 m
.03279 .14055 L
.04262 .10265 L
.04758 .08678 L
.05288 .07248 L
.05785 .06174 L
.06244 .05423 L
.06508 .05099 L
.06788 .04842 L
.06933 .04745 L
.07069 .04675 L
.07147 .04645 L
.07218 .04624 L
.073 .04607 L
.07379 .04598 L
.07507 .04599 L
.07579 .04608 L
.07644 .04621 L
.07771 .04661 L
.07891 .04716 L
.08031 .04802 L
.0816 .049 L
.08451 .05194 L
.08691 .0551 L
.08916 .05865 L
.09427 .06879 L
.10458 .09763 L
.11503 .1371 L
.12493 .18232 L
.14349 .28057 L
.16171 .38195 L
.18182 .48182 L
.19133 .51966 L
.20159 .55119 L
.20724 .56392 L
.20972 .56838 L
.21243 .57248 L
.21482 .57539 L
.21738 .57777 L
.2188 .57876 L
.22009 .57945 L
.22138 .57995 L
.2226 .58024 L
.22375 .58035 L
.22499 .58029 L
.22616 .58007 L
.22723 .57972 L
.22848 .57915 L
.22984 .57831 L
.23232 .57623 L
Mistroke
.23491 .57328 L
.23766 .5693 L
.24261 .55997 L
.2523 .53403 L
.26107 .50253 L
.28035 .41206 L
.30118 .29605 L
.32077 .18872 L
.33114 .13896 L
.34224 .09465 L
.34774 .07686 L
.35295 .06289 L
.35762 .05286 L
.36004 .04864 L
.3627 .04477 L
.36519 .04191 L
.36751 .03989 L
.3688 .03905 L
.36997 .03846 L
.37126 .038 L
.37191 .03784 L
.37262 .03773 L
.37382 .03768 L
.37492 .03778 L
.37618 .03808 L
.37737 .03854 L
.37847 .03912 L
.37949 .03978 L
.38178 .04172 L
.38423 .0445 L
.38647 .04764 L
.3915 .05684 L
.39616 .0679 L
.40058 .08055 L
.42124 .16395 L
.45953 .37639 L
.47889 .47735 L
.48918 .52102 L
.49459 .54019 L
.50028 .55722 L
.50532 .56937 L
.50798 .57464 L
.51083 .57937 L
.51346 .58288 L
.51584 .58535 L
.51699 .5863 L
.51824 .58715 L
.51942 .58777 L
.52051 .5882 L
.5216 .58848 L
Mistroke
.52278 .58863 L
.52389 .58861 L
.5249 .58845 L
.52609 .58812 L
.52738 .58755 L
.5286 .58683 L
.52974 .586 L
.53222 .58364 L
.53447 .58086 L
.53952 .57244 L
.5444 .56149 L
.54955 .54707 L
.55878 .51444 L
.5796 .4149 L
.61759 .19769 L
.63712 .10457 L
.64274 .08348 L
.64806 .06642 L
.65281 .05377 L
.65804 .04276 L
.66044 .03878 L
.66302 .03527 L
.66547 .0327 L
.6677 .03099 L
.66894 .0303 L
.67009 .02984 L
.67135 .02952 L
.67206 .02942 L
.6727 .02939 L
.674 .02948 L
.67473 .02963 L
.67541 .02982 L
.67665 .03032 L
.67796 .03106 L
.68015 .03276 L
.6825 .03524 L
.68674 .04142 L
.69178 .05156 L
.69639 .06337 L
.70627 .09639 L
.71543 .13531 L
.73617 .24511 L
.77537 .469 L
.78569 .51641 L
.79112 .53764 L
.79684 .55686 L
.80186 .57084 L
.80736 .58284 L
.80978 .58698 L
.81236 .59063 L
Mistroke
.8148 .59332 L
.81703 .59512 L
.81821 .59583 L
.81932 .59633 L
.82054 .59671 L
.82185 .5969 L
.82251 .59692 L
.82322 .59688 L
.82453 .59663 L
.8258 .59618 L
.82697 .59559 L
.82818 .5948 L
.82931 .5939 L
.83142 .59178 L
.8337 .58887 L
.83616 .58501 L
.84142 .57433 L
.84698 .55954 L
.85694 .5247 L
.87657 .43037 L
.8949 .3235 L
.91353 .21275 L
.9338 .1092 L
.94482 .0669 L
.94967 .05228 L
.95503 .03926 L
.95745 .03448 L
.96006 .03013 L
.96231 .02705 L
.96478 .02441 L
.96615 .02327 L
.96742 .02243 L
.96876 .02177 L
.96951 .02149 L
.97019 .02131 L
.97141 .02112 L
.9721 .02111 L
.97274 .02114 L
.97391 .02134 L
.97515 .02175 L
.97619 .02224 L
Mfstroke
.02381 .17592 m
.03279 .1357 L
.04262 .09874 L
.04758 .0834 L
.05288 .06972 L
.05789 .05953 L
.06244 .05266 L
.06507 .04978 L
.0665 .04853 L
.06785 .04758 L
.06899 .04694 L
.07022 .04642 L
.07092 .0462 L
.07158 .04605 L
.07283 .04589 L
.07354 .04589 L
.07418 .04594 L
.07493 .04605 L
.07563 .04622 L
.07687 .04666 L
.07757 .04698 L
.07822 .04733 L
.08108 .04947 L
.08252 .05091 L
.0841 .05276 L
.08922 .06068 L
.09469 .07238 L
.10458 .10138 L
.11475 .14068 L
.12582 .19227 L
.14594 .30057 L
.16533 .40733 L
.17562 .45885 L
.18672 .50673 L
.19187 .52551 L
.19729 .5426 L
.20231 .55577 L
.20698 .5656 L
.21137 .57263 L
.21382 .5756 L
.21606 .57768 L
.21725 .57856 L
.21851 .5793 L
.21917 .57962 L
.21989 .5799 L
.22117 .58026 L
.22237 .58041 L
.22366 .58039 L
.22488 .58018 L
.22599 .57984 L
Mistroke
.22728 .57926 L
.2285 .57854 L
.23077 .57671 L
.23322 .57407 L
.23586 .57044 L
.24063 .56187 L
.24501 .55176 L
.2551 .52088 L
.26575 .47808 L
.30377 .27504 L
.32496 .1624 L
.33499 .11784 L
.34425 .08415 L
.35385 .05823 L
.3589 .04862 L
.36146 .04488 L
.36427 .04165 L
.36547 .04055 L
.36673 .03959 L
.36782 .03891 L
.36898 .03834 L
.37023 .0379 L
.3714 .03767 L
.37211 .03761 L
.37279 .03761 L
.37405 .03775 L
.37516 .03804 L
.37634 .0385 L
.37734 .03903 L
.37845 .03975 L
.38091 .04188 L
.38321 .04453 L
.38821 .0524 L
.39365 .06422 L
.40354 .09386 L
.41317 .13177 L
.42209 .1735 L
.46132 .39252 L
.48099 .49185 L
.48961 .52673 L
.49449 .54346 L
.49904 .55687 L
.50397 .56887 L
.50845 .57741 L
.51075 .58088 L
.51324 .58393 L
.51461 .58529 L
.51587 .58635 L
.51707 .58717 L
.51836 .58786 L
Mistroke
.51966 .58835 L
.52085 .58861 L
.52205 .58871 L
.52318 .58864 L
.5245 .58835 L
.52572 .5879 L
.52642 .58756 L
.52706 .5872 L
.52849 .58621 L
.53114 .58371 L
.53401 .58005 L
.53921 .57094 L
.54413 .55946 L
.54873 .54634 L
.55916 .50856 L
.58023 .40557 L
.61916 .18358 L
.62935 .13334 L
.64042 .08785 L
.64549 .07087 L
.65087 .05581 L
.65547 .04552 L
.65789 .04107 L
.66054 .03702 L
.66309 .03391 L
.66547 .03173 L
.66678 .03082 L
.66797 .03018 L
.66863 .02991 L
.66935 .02966 L
.67065 .02939 L
.67176 .02932 L
.67299 .02942 L
.67427 .02973 L
.67546 .0302 L
.67658 .0308 L
.67761 .03148 L
.67991 .03349 L
.68256 .03662 L
.68503 .04028 L
.69061 .05125 L
.69553 .0639 L
.70077 .08026 L
.72223 .17404 L
.74242 .28804 L
.76085 .39662 L
.7713 .45373 L
.78104 .50094 L
.79151 .54289 L
.80104 .57148 L
Mistroke
.80627 .58285 L
.80867 .58698 L
.81122 .59059 L
.81251 .59212 L
.81394 .59356 L
.81525 .59467 L
.81645 .59549 L
.81786 .59624 L
.81863 .59654 L
.81937 .59675 L
.82069 .59697 L
.82143 .59699 L
.82212 .59695 L
.8234 .59672 L
.82405 .59652 L
.82476 .59625 L
.82602 .5956 L
.82719 .59482 L
.82984 .59243 L
.83268 .58889 L
.83788 .57985 L
.84263 .5688 L
.85218 .53891 L
.86124 .50207 L
.89955 .28907 L
.91893 .17696 L
.92922 .12509 L
.94032 .07881 L
.94502 .06286 L
.94997 .04865 L
.95455 .03801 L
.95882 .03036 L
.96088 .02747 L
.96283 .02523 L
.96391 .02419 L
.96507 .02323 L
.96613 .02251 L
.96711 .02197 L
.96821 .02151 L
.96941 .02119 L
.97058 .02104 L
.97184 .02109 L
.973 .02131 L
.97411 .02168 L
.97511 .02215 L
.97619 .0228 L
Mfstroke
.02381 .19006 m
.03279 .14947 L
.04262 .11154 L
.04758 .09551 L
.05288 .08093 L
.05785 .06985 L
.06244 .06194 L
.06508 .05843 L
.06788 .05555 L
.06933 .05441 L
.07069 .05355 L
.07218 .05286 L
.07302 .05258 L
.07379 .05239 L
.07445 .05228 L
.07515 .05222 L
.07641 .05226 L
.07719 .05237 L
.07792 .05253 L
.07857 .05274 L
.07928 .05301 L
.08061 .05368 L
.082 .05459 L
.08451 .05679 L
.0869 .05954 L
.08946 .0632 L
.09408 .0716 L
.09957 .08454 L
.10458 .09898 L
.12366 .17396 L
.14443 .28012 L
.16381 .38534 L
.17411 .43751 L
.18521 .4872 L
.19577 .52579 L
.2004 .53949 L
.20546 .55202 L
.21026 .5614 L
.21472 .56785 L
.21719 .57046 L
.21944 .57223 L
.22068 .57295 L
.22133 .57327 L
.22203 .57354 L
.2233 .57391 L
.22447 .57407 L
.22568 .57408 L
.227 .57389 L
.22825 .57353 L
.2294 .57303 L
Mistroke
.23055 .57239 L
.23159 .57168 L
.23391 .56963 L
.23642 .56672 L
.23913 .56278 L
.24405 .55357 L
.25359 .52838 L
.26236 .49748 L
.28122 .41108 L
.3019 .29871 L
.32309 .18564 L
.34238 .10305 L
.35197 .07376 L
.35739 .06138 L
.35997 .0566 L
.3624 .0528 L
.36468 .04983 L
.36677 .04763 L
.36909 .04578 L
.37031 .04507 L
.37159 .0445 L
.37276 .04415 L
.374 .04396 L
.37518 .04394 L
.37625 .04407 L
.37751 .04439 L
.37821 .04465 L
.37887 .04495 L
.38014 .04567 L
.38134 .04652 L
.38379 .04878 L
.38603 .05145 L
.39106 .05955 L
.39541 .06882 L
.40014 .08121 L
.41086 .11751 L
.42079 .15997 L
.46003 .3715 L
.4797 .47218 L
.48831 .50874 L
.49775 .54138 L
.50229 .55399 L
.50715 .56503 L
.50984 .57 L
.51229 .57382 L
.51461 .5768 L
.51707 .57927 L
.51834 .58027 L
.51974 .58115 L
.52102 .58174 L
Mistroke
.52221 .58212 L
.52293 .58227 L
.52361 .58235 L
.5249 .58236 L
.52562 .58228 L
.52628 .58214 L
.52701 .58194 L
.52779 .58165 L
.5291 .58099 L
.53052 .58006 L
.5331 .57774 L
.53561 .57474 L
.53792 .57133 L
.54262 .56249 L
.54766 .55029 L
.55676 .52158 L
.57742 .42972 L
.59725 .32027 L
.6188 .19962 L
.62885 .14953 L
.63952 .10413 L
.64862 .07341 L
.65381 .05971 L
.65867 .04955 L
.66337 .04231 L
.66603 .03937 L
.66851 .03739 L
.66986 .03662 L
.67114 .0361 L
.67228 .0358 L
.67352 .03565 L
.67416 .03565 L
.67487 .03571 L
.67561 .03583 L
.6763 .03601 L
.67754 .03646 L
.67887 .03716 L
.6801 .038 L
.68124 .03894 L
.68383 .04166 L
.68854 .04863 L
.69282 .05721 L
.69738 .06859 L
.7077 .10244 L
.71884 .14999 L
.73903 .25668 L
.75863 .37011 L
.78011 .4829 L
.79 .52459 L
.79544 .54374 L
Mistroke
.80058 .55908 L
.80537 .57077 L
.8079 .57589 L
.81057 .58051 L
.81282 .58373 L
.8153 .58658 L
.81639 .58759 L
.81755 .58852 L
.81864 .58924 L
.81967 .58978 L
.8203 .59005 L
.821 .59029 L
.8222 .59057 L
.82288 .59064 L
.82361 .59066 L
.8249 .59053 L
.8261 .59023 L
.82722 .58979 L
.82845 .58913 L
.82977 .58821 L
.83273 .58538 L
.83553 .58171 L
.84079 .57231 L
.84579 .56042 L
.85041 .54696 L
.86088 .50846 L
.87953 .41752 L
.90013 .29861 L
.9211 .17958 L
.93028 .134 L
.94032 .0916 L
.94937 .06164 L
.9537 .05041 L
.95779 .04177 L
.96003 .03788 L
.96245 .03434 L
.96447 .03194 L
.96669 .02988 L
.96793 .029 L
.96909 .02834 L
.97031 .02783 L
.97163 .02749 L
.97285 .02737 L
.97401 .02742 L
.97505 .02762 L
.97619 .02799 L
Mfstroke
.02381 .18453 m
.03279 .14462 L
.04262 .10762 L
.04758 .09213 L
.05288 .07817 L
.05785 .0677 L
.06244 .06037 L
.06508 .0572 L
.06788 .05469 L
.06933 .05374 L
.07069 .05306 L
.07147 .05277 L
.07218 .05256 L
.073 .0524 L
.07379 .05231 L
.07507 .05232 L
.07579 .0524 L
.07644 .05253 L
.07771 .05292 L
.07891 .05346 L
.08031 .0543 L
.0816 .05526 L
.08451 .05813 L
.08691 .06121 L
.08916 .06467 L
.09427 .07457 L
.10458 .10273 L
.11503 .14126 L
.12493 .18541 L
.14349 .28132 L
.16171 .3803 L
.18182 .47781 L
.19133 .51476 L
.20159 .54555 L
.20724 .55797 L
.20972 .56234 L
.21243 .56633 L
.21482 .56918 L
.21738 .57151 L
.2188 .57247 L
.22009 .57314 L
.22138 .57363 L
.2226 .57391 L
.22375 .57402 L
.22499 .57396 L
.22616 .57375 L
.22723 .57341 L
.22848 .57285 L
.22984 .57203 L
.23232 .56999 L
Mistroke
.23491 .56712 L
.23766 .56323 L
.24261 .55412 L
.2523 .52879 L
.26107 .49802 L
.28035 .40967 L
.30118 .29637 L
.32077 .19154 L
.33114 .14294 L
.34224 .09966 L
.34774 .08228 L
.35295 .06864 L
.35762 .05884 L
.36004 .05471 L
.3627 .05093 L
.36519 .04814 L
.36751 .04617 L
.3688 .04535 L
.36997 .04477 L
.37126 .04432 L
.37191 .04417 L
.37262 .04406 L
.37382 .04401 L
.37492 .04411 L
.37618 .0444 L
.37737 .04485 L
.37847 .04541 L
.37949 .04606 L
.38178 .04796 L
.38423 .05067 L
.38647 .05374 L
.3915 .06272 L
.39616 .07353 L
.40058 .08589 L
.42124 .16736 L
.45953 .37492 L
.47889 .47357 L
.48918 .51623 L
.49459 .53497 L
.50028 .55161 L
.50532 .56348 L
.50798 .56863 L
.51083 .57325 L
.51346 .57668 L
.51584 .5791 L
.51699 .58003 L
.51824 .58085 L
.51942 .58146 L
.52051 .58188 L
.5216 .58216 L
Mistroke
.52278 .5823 L
.52389 .58228 L
.5249 .58213 L
.52609 .5818 L
.52738 .58125 L
.5286 .58055 L
.52974 .57973 L
.53222 .57743 L
.53447 .57471 L
.53952 .56648 L
.5444 .55578 L
.54955 .54169 L
.55878 .5098 L
.5796 .41252 L
.61759 .20022 L
.63712 .1092 L
.64274 .0886 L
.64806 .07191 L
.65281 .05955 L
.65804 .04879 L
.66044 .0449 L
.66302 .04147 L
.66547 .03896 L
.6677 .03728 L
.66894 .03661 L
.67009 .03616 L
.67135 .03584 L
.67206 .03575 L
.6727 .03572 L
.674 .03581 L
.67473 .03595 L
.67541 .03614 L
.67665 .03663 L
.67796 .03735 L
.68015 .03902 L
.6825 .04144 L
.68674 .04748 L
.69178 .05739 L
.69639 .06894 L
.70627 .10122 L
.71543 .13927 L
.73617 .24662 L
.77537 .46551 L
.78569 .51187 L
.79112 .53262 L
.79684 .55142 L
.80186 .56508 L
.80736 .57683 L
.80978 .58088 L
.81236 .58444 L
Mistroke
.8148 .58707 L
.81703 .58883 L
.81821 .58952 L
.81932 .59002 L
.82054 .59038 L
.82185 .59058 L
.82251 .59059 L
.82322 .59055 L
.82453 .59031 L
.8258 .58987 L
.82697 .58929 L
.82818 .58852 L
.82931 .58764 L
.83142 .58556 L
.8337 .58272 L
.83616 .57895 L
.84142 .5685 L
.84698 .55403 L
.85694 .51997 L
.87657 .42772 L
.8949 .3232 L
.91353 .21488 L
.9338 .1136 L
.94482 .07223 L
.94967 .05793 L
.95503 .04519 L
.95745 .04052 L
.96006 .03626 L
.96231 .03325 L
.96478 .03066 L
.96615 .02956 L
.96742 .02873 L
.96876 .02808 L
.96951 .02782 L
.97019 .02763 L
.97141 .02745 L
.9721 .02744 L
.97274 .02747 L
.97391 .02767 L
.97515 .02806 L
.97619 .02854 L
Mfstroke
.02381 .17901 m
.03279 .13976 L
.04262 .10371 L
.04758 .08875 L
.05288 .07541 L
.05789 .06548 L
.06244 .0588 L
.06507 .05599 L
.0665 .05478 L
.06785 .05385 L
.06899 .05323 L
.07022 .05272 L
.07092 .05251 L
.07158 .05236 L
.07283 .05222 L
.07354 .05222 L
.07418 .05227 L
.07493 .05238 L
.07563 .05254 L
.07687 .05298 L
.07757 .0533 L
.07822 .05364 L
.08108 .05574 L
.08252 .05715 L
.0841 .05896 L
.08922 .0667 L
.09469 .07814 L
.10458 .10648 L
.11475 .14487 L
.12582 .19525 L
.14594 .301 L
.16533 .40522 L
.17562 .45551 L
.18672 .50224 L
.19187 .52056 L
.19729 .53723 L
.20231 .55008 L
.20698 .55967 L
.21137 .56652 L
.21382 .56941 L
.21606 .57144 L
.21725 .57229 L
.21851 .57302 L
.21917 .57332 L
.21989 .5736 L
.22117 .57394 L
.22237 .57409 L
.22366 .57406 L
.22488 .57386 L
.22599 .57352 L
Mistroke
.22728 .57295 L
.2285 .57224 L
.23077 .57045 L
.23322 .56786 L
.23586 .56431 L
.24063 .55592 L
.24501 .54604 L
.2551 .51586 L
.26575 .47403 L
.30377 .27571 L
.32496 .16571 L
.33499 .12221 L
.34425 .08932 L
.34881 .0761 L
.35385 .06403 L
.3589 .05465 L
.36167 .05073 L
.36427 .04786 L
.36659 .04595 L
.36776 .04522 L
.36903 .04462 L
.37013 .04425 L
.37129 .04401 L
.37239 .04393 L
.37339 .04398 L
.37466 .04422 L
.37582 .0446 L
.3771 .0452 L
.37845 .04605 L
.38072 .04795 L
.38321 .05073 L
.38844 .05887 L
.3934 .0694 L
.4027 .09614 L
.41271 .13408 L
.4236 .18427 L
.46435 .40707 L
.47408 .45635 L
.48458 .5028 L
.49365 .53561 L
.4988 .55069 L
.50359 .56224 L
.50822 .571 L
.51059 .57455 L
.51316 .57766 L
.51458 .57904 L
.51588 .5801 L
.5171 .58091 L
.51775 .58127 L
.51845 .5816 L
Mistroke
.51966 .58203 L
.52078 .58228 L
.52208 .58238 L
.52326 .5823 L
.52437 .58206 L
.52555 .58165 L
.52667 .58111 L
.52768 .58049 L
.53017 .57846 L
.53251 .57588 L
.53674 .5696 L
.54131 .56051 L
.55082 .53432 L
.56126 .49535 L
.58233 .3919 L
.60349 .2719 L
.62277 .16814 L
.63235 .12412 L
.64277 .08477 L
.64754 .07023 L
.65261 .05742 L
.65693 .04874 L
.6617 .04167 L
.66405 .03917 L
.6654 .03804 L
.66662 .0372 L
.66792 .0365 L
.66864 .03621 L
.66931 .03599 L
.67051 .03573 L
.6718 .03565 L
.67292 .03574 L
.67415 .03602 L
.67543 .0365 L
.67662 .03713 L
.67876 .03869 L
.68106 .04098 L
.68374 .04444 L
.68666 .04917 L
.69197 .06029 L
.70192 .08945 L
.71228 .13006 L
.72165 .17431 L
.74264 .29001 L
.76357 .40987 L
.77273 .45789 L
.78278 .50432 L
.79186 .53904 L
.80158 .56707 L
.80695 .57809 L
Mistroke
.80949 .58213 L
.81184 .58517 L
.8142 .58756 L
.81541 .58853 L
.81676 .58939 L
.81792 .58996 L
.81901 .59034 L
.82016 .59058 L
.8214 .59066 L
.82209 .59063 L
.82273 .59054 L
.82394 .59023 L
.82524 .58971 L
.82664 .58891 L
.82787 .588 L
.82917 .58685 L
.8315 .58427 L
.83676 .57605 L
.84253 .5633 L
.85292 .53116 L
.86262 .49161 L
.90151 .27785 L
.92131 .16738 L
.93176 .11774 L
.94286 .07509 L
.95109 .05156 L
.95577 .04157 L
.95791 .03786 L
.96017 .03455 L
.96209 .03222 L
.96419 .03018 L
.96511 .02946 L
.9661 .02881 L
.96703 .02831 L
.96788 .02794 L
.96895 .0276 L
.97012 .0274 L
.97115 .02737 L
.97223 .02747 L
.97321 .02769 L
.97412 .02801 L
.97512 .02847 L
.97619 .0291 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200.5, 123.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000^B000`400?l00000o`00003oo`3oool]
0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]
0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]
0?ooo`00o`3oool]0?ooo`009`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000W0?ooo`030000
003oool0oooo0?l0oooo0`3oool002L0oooo00<000000?ooo`3oool0o`3oool30?ooo`009`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000W0?ooo`800000lP3oool4000000d0oooo000W0?ooo`03
0000003oool0oooo0?00oooo1000000>0?ooo`009`3oool00`000000oooo0?ooo`2T0?ooo`@00000
A`3oool6000000d0oooo000W0?ooo`030000003oool0oooo0:<0oooo00@000000?ooo`3oool0oooo
0P0000150?ooo`L000003@3oool002L0oooo00<000000?ooo`3oool0EP3oool4000004P0oooo1`00
00150?ooo`@00000403oool002L0oooo0P00001F0?ooo`8000000P3oool2000004H0oooo2@000014
0?ooo`<000004@3oool002L0oooo00<000000?ooo`3oool0203oool4000004P0oooo200000150?oo
o`@0000000<0oooo0000000000000P0000130?ooo`@000004@3oool002L0oooo00<000000?ooo`3o
ool01`3oool3000000030?ooo`000000000004L0oooo200000140?ooo`@000000`3oool400000480
oooo0`00000B0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`L00000A@3oool:000004<0oooo
0`0000050?ooo`<00000@P3oool2000001<0oooo000W0?ooo`030000003oool0oooo00H0oooo1@00
0000103oool000000000000000140?ooo`<00000103oool300000480oooo0`0000070?ooo`800000
@@3oool3000001<0oooo000W0?ooo`030000003oool0oooo00H0oooo2@0000130?ooo`@00000103o
ool400000440oooo0P0000080?ooo`<00000@03oool3000001<0oooo000W0?ooo`8000001P3oool3
000000@0oooo100000120?ooo`<000001P3oool300000400oooo0`0000090?ooo`800000@03oool2
000001@0oooo000W0?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`<00000@@3oool30000
00P0oooo0P0000100?ooo`<000002@3oool2000003l0oooo0`00000D0?ooo`009`3oool00`000000
oooo0?ooo`040?ooo`<000001`3oool200000440oooo0`0000080?ooo`<00000?`3oool2000000X0
oooo0`00000n0?ooo`<00000503oool002L0oooo00<000000?ooo`3oool0103oool3000000L0oooo
0`0000100?ooo`8000002P3oool2000003l0oooo0P00000;0?ooo`800000?@3oool3000001D0oooo
000W0?ooo`030000003oool0oooo00<0oooo0`0000090?ooo`800000?`3oool3000000X0oooo0P00
000n0?ooo`<000002`3oool2000003d0oooo0`00000E0?ooo`009`3oool2000000@0oooo0`000009
0?ooo`800000?`3oool3000000X0oooo0`00000m0?ooo`<00000303oool2000003`0oooo0`00000E
0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`8000002P3oool3000003h0oooo0P00000<0?oo
o`800000?@3oool2000000d0oooo0P00000l0?ooo`8000005P3oool000X0oooo1`0000030?ooo`@0
00001@3oool4000000H0oooo00<000000?ooo`3oool00P3oool3000000/0oooo0P00000m0?ooo`<0
0000303oool2000003d0oooo0P00000=0?ooo`800000>`3oool3000001H0oooo000=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000303oool3000003`0
oooo0P00000=0?ooo`800000?03oool2000000h0oooo0`00000j0?ooo`<000005P3oool000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`<0
0000?03oool2000000h0oooo0P00000k0?ooo`8000003`3oool2000003X0oooo0P00000G0?ooo`00
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000d0
oooo0P00000k0?ooo`<000003P3oool2000003/0oooo0P00000?0?ooo`800000>P3oool2000001L0
oooo00000`3oool0000000000004000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`80
00000P3oool3000000d0oooo0`00000j0?ooo`8000003`3oool2000003/0oooo00<000000?ooo`3o
ool03P3oool2000003X0oooo0P00000G0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`800000>P3oool2000000l0oooo0`00000j0?oo
o`030000003oool0oooo00h0oooo0`00000i0?ooo`8000005`3oool000d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000003`3oool2000003T0oooo0`00000@
0?ooo`800000>@3oool200000140oooo0P00000h0?ooo`800000603oool000/0oooo0`0000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`00000?0?ooo`800000>@3oool300000100oooo0P00000i
0?ooo`8000004@3oool2000003P0oooo0P00000H0?ooo`003@3oool00`000000oooo0?ooo`040?oo
o`@000001@3oool4000000H0oooo00<000000?ooo`3oool00`00000?0?ooo`<00000>03oool20000
0140oooo0P00000i0?ooo`8000004@3oool2000003P0oooo0P00000H0?ooo`009`3oool200000003
0?ooo`00000000000140oooo0P00000h0?ooo`8000004P3oool2000003P0oooo00<000000?ooo`3o
ool0403oool3000003L0oooo0P00000H0?ooo`009`3oool00`000000oooo0?ooo`0200000140oooo
0P00000g0?ooo`<000004P3oool2000003L0oooo0P00000C0?ooo`800000=`3oool2000001P0oooo
000W0?ooo`030000003oool00000008000004@3oool2000003L0oooo0`00000B0?ooo`800000=`3o
ool2000001<0oooo0P00000g0?ooo`030000003oool0oooo01L0oooo000W0?ooo`040000003oool0
000000000180oooo0`00000f0?ooo`8000004`3oool2000003L0oooo0P00000C0?ooo`800000=P3o
ool2000001T0oooo000W0?ooo`040000003oool0000000000180oooo0`00000f0?ooo`800000503o
ool2000003H0oooo0P00000C0?ooo`<00000=@3oool2000001T0oooo000W0?ooo`040000003oool0
0000000001<0oooo0P00000f0?ooo`800000503oool2000003H0oooo00<000000?ooo`3oool04`3o
ool2000003D0oooo0P00000I0?ooo`009`3oool4000001<0oooo0P00000f0?ooo`800000503oool2
000003D0oooo0P00000E0?ooo`800000=@3oool00`000000oooo0?ooo`0H0?ooo`009`3oool30000
01@0oooo0`00000d0?ooo`8000005@3oool2000003D0oooo0P00000E0?ooo`800000=03oool20000
01X0oooo000W0?ooo`<00000503oool3000003@0oooo0P00000F0?ooo`800000=03oool2000001D0
oooo0`00000c0?ooo`8000006P3oool002L0oooo0`00000D0?ooo`<00000=03oool2000001H0oooo
0P00000d0?ooo`8000005P3oool2000003<0oooo0P00000J0?ooo`009`3oool3000001D0oooo0P00
000d0?ooo`8000005P3oool2000003<0oooo0`00000F0?ooo`800000<`3oool00`000000oooo0?oo
o`0I0?ooo`009`3oool2000001H0oooo0`00000c0?ooo`030000003oool0oooo01D0oooo0P00000c
0?ooo`8000005`3oool2000003<0oooo00<000000?ooo`3oool06@3oool002L0oooo0P00000F0?oo
o`<00000<`3oool00`000000oooo0?ooo`0E0?ooo`<00000<P3oool2000001L0oooo0P00000b0?oo
o`8000006`3oool002L0oooo0P00000F0?ooo`<00000<P3oool2000001L0oooo0`00000b0?ooo`80
0000603oool200000340oooo0P00000K0?ooo`009`3oool2000001L0oooo0P00000b0?ooo`800000
603oool200000340oooo0`00000H0?ooo`800000<@3oool2000001/0oooo000W0?ooo`8000005`3o
ool300000340oooo0P00000H0?ooo`800000<@3oool2000001T0oooo0P00000a0?ooo`030000003o
ool0oooo01X0oooo000W0?ooo`030000003oool0oooo01H0oooo0`00000a0?ooo`030000003oool0
oooo01L0oooo0P00000a0?ooo`8000006@3oool200000340oooo00<000000?ooo`3oool06P3oool0
02L0oooo0P00000G0?ooo`<00000<@3oool00`000000oooo0?ooo`0G0?ooo`800000<@3oool20000
01T0oooo0P00000`0?ooo`800000703oool002L0oooo00<000000?ooo`3oool05`3oool200000300
oooo0P00000I0?ooo`<00000<03oool2000001X0oooo00<000000?ooo`3oool0;P3oool2000001`0
oooo000D0?ooo`@000001@3oool4000000H0oooo00<000000?ooo`3oool05`3oool200000300oooo
0P00000I0?ooo`<00000;`3oool2000001/0oooo0P00000_0?ooo`800000703oool001<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`800000<03oool2000001X0oooo0P00000_0?ooo`800000
6`3oool2000002l0oooo00<000000?ooo`3oool06`3oool001P0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool3000002l0oooo
0P00000J0?ooo`800000;`3oool2000001/0oooo0P00000_0?ooo`030000003oool0oooo01/0oooo
000H0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`800000
603oool3000002l0oooo00<000000?ooo`3oool06@3oool2000002l0oooo0P00000K0?ooo`800000
;P3oool2000001d0oooo000:0?ooo`H00000203oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`800000;P3oool2000001/0oooo
0P00000_0?ooo`8000006`3oool2000002h0oooo0P00000M0?ooo`00503oool4000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo0P00
000^0?ooo`8000006`3oool3000002h0oooo00<000000?ooo`3oool06`3oool2000002d0oooo0P00
000M0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`800000;P3oool2000001`0oooo0P00000]
0?ooo`8000007@3oool2000002d0oooo0P00000M0?ooo`00503oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?oo
o`800000;P3oool2000001`0oooo0P00000]0?ooo`8000007@3oool2000002d0oooo0P00000M0?oo
o`00503oool5000000@0oooo100000060?ooo`030000003oool0oooo01P0oooo0`00000]0?ooo`80
0000703oool2000002d0oooo0P00000M0?ooo`800000;@3oool00`000000oooo0?ooo`0L0?ooo`00
9`3oool2000001T0oooo0`00000/0?ooo`8000007@3oool2000002d0oooo0P00000M0?ooo`800000
;03oool2000001h0oooo000W0?ooo`030000003oool0oooo01T0oooo0P00000/0?ooo`8000007@3o
ool3000002`0oooo0P00000M0?ooo`<00000:`3oool2000001h0oooo000W0?ooo`030000003oool0
oooo01T0oooo0P00000/0?ooo`8000007@3oool3000002`0oooo00<000000?ooo`3oool07@3oool2
000002/0oooo0P00000N0?ooo`009`3oool00`000000oooo0?ooo`0I0?ooo`800000;03oool20000
01h0oooo0P00000[0?ooo`8000007`3oool2000002/0oooo0P00000N0?ooo`009`3oool00`000000
oooo0?ooo`0I0?ooo`800000;03oool2000001h0oooo0P00000[0?ooo`8000007`3oool2000002/0
oooo0P00000N0?ooo`009`3oool2000001X0oooo0`00000Z0?ooo`8000007`3oool2000002/0oooo
0P00000O0?ooo`800000:`3oool00`000000oooo0?ooo`0M0?ooo`009`3oool00`000000oooo0?oo
o`0J0?ooo`8000001P3oool7000000<0oooo100000040?ooo`H00000303oool2000000/0oooo1`00
00030?ooo`@000001P3oool4000001T0oooo1`0000030?ooo`@000000P3oool200000080oooo1000
000I0?ooo`P000000`3oool4000000D0oooo1000000D0?ooo`800000103oool700000080oooo1`00
00030?ooo`@00000103oool002L0oooo00<000000?ooo`3oool06P3oool2000000T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0:0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool3000001d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`<0000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0A0?ooo`800000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`009`3oool00`000000oooo0?ooo`0J0?ooo`8000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0>0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool2000001d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0A0?ooo`800000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`009`3oool00`000000oooo0?ooo`0J0?ooo`8000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0=0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo1P00000L0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool300000080oooo0P0000030?ooo`030000003oool0oooo01L0oooo
0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0140oooo0P0000070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo000W0?ooo`030000003oool0oooo01X0oooo0P0000090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
0P00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`040000003oool00000000001d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`<000000P3oool00`000000oooo00000002000001X0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool4000001@0
oooo0P0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000W0?ooo`800000703oool2000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000007@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo01`0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0100oooo0P0000080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo000W0?ooo`030000003oool0oooo01/0oooo0P0000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool02@3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0`00000M0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo00<000000?ooo`3oool06`3oool4000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0403oool2
000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool002L0oooo00<000000?ooo`3oool06`3oool20000
00H0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00T0oooo0P00000=0?ooo`<000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000006P3oool3000000D0oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool06P3oool4000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
403oool2000000H0oooo0`0000060?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo000W0?ooo`030000003oool0oooo01/0oooo0P0000080?ooo`030000003o
ool0oooo00@0oooo100000050?ooo`@00000303oool2000000l0oooo00<000000?ooo`3oool0103o
ool4000000L0oooo0`00000L0?ooo`030000003oool0oooo00@0oooo100000000`3oool000000?oo
o`050?ooo`<000006P3oool3000000H0oooo100000050?ooo`@000004`3oool2000000P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`@00000103oool002L0oooo00<00000
0?ooo`3oool06`3oool2000002L0oooo0`00000R0?ooo`8000009`3oool2000002<0oooo0P00000W
0?ooo`800000803oool002L0oooo0P00000L0?ooo`<000009P3oool2000002<0oooo0P00000W0?oo
o`8000008`3oool2000002H0oooo0`00000P0?ooo`009`3oool00`000000oooo0?ooo`0L0?ooo`80
00009P3oool2000002<0oooo0P00000W0?ooo`8000008`3oool2000002H0oooo0`00000P0?ooo`00
9`3oool00`000000oooo0?ooo`0L0?ooo`8000009P3oool2000002<0oooo0`00000V0?ooo`030000
003oool0oooo0280oooo0`00000U0?ooo`8000008@3oool002L0oooo00<000000?ooo`3oool0703o
ool2000002H0oooo0P00000T0?ooo`8000009P3oool00`000000oooo0?ooo`0S0?ooo`8000009@3o
ool200000240oooo000W0?ooo`030000003oool0oooo01`0oooo0P00000U0?ooo`<00000903oool2
000002H0oooo00<000000?ooo`3oool08`3oool2000002D0oooo0P00000Q0?ooo`009`3oool00`00
0000oooo0?ooo`0L0?ooo`8000009@3oool3000002@0oooo0P00000U0?ooo`8000009@3oool20000
02D0oooo0P00000Q0?ooo`008@3ooooo000000D000001`3oool002L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool3000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`800000
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`000000
0000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`0000060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool002L0oooo
00<000000?ooo`3oool07@3oool2000002@0oooo0P00000V0?ooo`800000903oool00`000000oooo
0?ooo`0T0?ooo`<000008`3oool200000280oooo000W0?ooo`030000003oool0oooo01d0oooo0P00
000S0?ooo`<000009P3oool2000002@0oooo00<000000?ooo`3oool09@3oool2000002<0oooo0P00
000R0?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`8000008`3oool3000002H0oooo0P00000T
0?ooo`030000003oool0oooo02D0oooo0P00000S0?ooo`8000008P3oool002L0oooo0P00000N0?oo
o`8000008`3oool3000002H0oooo0P00000S0?ooo`8000009`3oool200000280oooo0`00000R0?oo
o`009`3oool00`000000oooo0?ooo`0N0?ooo`8000008P3oool2000002L0oooo0P00000S0?ooo`80
00009`3oool200000280oooo0`00000R0?ooo`009`3oool00`000000oooo0?ooo`0N0?ooo`800000
8P3oool2000002P0oooo0P00000R0?ooo`8000009`3oool200000280oooo0`00000R0?ooo`009`3o
ool00`000000oooo0?ooo`0N0?ooo`8000008P3oool2000002P0oooo0P00000R0?ooo`030000003o
ool0oooo02H0oooo0`00000Q0?ooo`8000008`3oool002L0oooo00<000000?ooo`3oool07P3oool2
00000240oooo0`00000X0?ooo`8000008P3oool00`000000oooo0?ooo`0W0?ooo`8000008@3oool2
000002<0oooo000W0?ooo`030000003oool0oooo01h0oooo0P00000Q0?ooo`<00000:03oool20000
0240oooo0P00000Y0?ooo`8000008@3oool2000002<0oooo000W0?ooo`8000007`3oool300000200
oooo0`00000X0?ooo`8000008@3oool2000002T0oooo0P00000P0?ooo`<000008`3oool002L0oooo
00<000000?ooo`3oool07`3oool200000200oooo0P00000Y0?ooo`8000008@3oool2000002T0oooo
0P00000P0?ooo`<000008`3oool002L0oooo00<000000?ooo`3oool07`3oool200000200oooo0P00
000Z0?ooo`800000803oool00`000000oooo0?ooo`0X0?ooo`800000803oool2000002@0oooo000W
0?ooo`030000003oool0oooo01l0oooo0P00000O0?ooo`<00000:P3oool200000200oooo00<00000
0?ooo`3oool0:@3oool2000001l0oooo0P00000T0?ooo`009`3oool00`000000oooo0?ooo`0O0?oo
o`8000007`3oool3000002X0oooo0P00000P0?ooo`030000003oool0oooo02T0oooo0P00000O0?oo
o`800000903oool002L0oooo0P00000P0?ooo`<000007P3oool3000002X0oooo0P00000O0?ooo`80
0000:`3oool2000001h0oooo0`00000T0?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`800000
7P3oool3000002X0oooo0P00000O0?ooo`800000:`3oool2000001h0oooo0`00000T0?ooo`009`3o
ool00`000000oooo0?ooo`0P0?ooo`8000007P3oool2000002/0oooo0`00000N0?ooo`800000:`3o
ool2000001h0oooo0`00000T0?ooo`009`3oool00`000000oooo0?ooo`0P0?ooo`8000007@3oool3
000002`0oooo0P00000N0?ooo`030000003oool0oooo02X0oooo0P00000N0?ooo`8000009@3oool0
02L0oooo00<000000?ooo`3oool0803oool2000001d0oooo0`00000/0?ooo`8000007P3oool00`00
0000oooo0?ooo`0[0?ooo`8000007@3oool2000002D0oooo000W0?ooo`030000003oool0oooo0200
oooo0`00000L0?ooo`<00000;03oool2000001h0oooo00<000000?ooo`3oool0:`3oool2000001d0
oooo0P00000U0?ooo`009`3oool200000240oooo0`00000L0?ooo`<00000;03oool2000001d0oooo
0P00000]0?ooo`800000703oool3000002D0oooo000D0?ooo`@000001@3oool4000000H0oooo00<0
00000?ooo`3oool08@3oool2000001`0oooo0`00000/0?ooo`<00000703oool2000002d0oooo0P00
000L0?ooo`<000009@3oool001<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`8000006`3o
ool3000002h0oooo0P00000L0?ooo`800000;@3oool2000001`0oooo0`00000U0?ooo`00603oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0Q0?ooo`8000006`3oool3000002h0oooo0P00000L0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool06P3oool2000002H0oooo000H0?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0240oooo0`00000J0?ooo`<00000;P3o
ool2000001`0oooo00<000000?ooo`3oool0;@3oool2000001/0oooo0P00000V0?ooo`00603oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool200000280oooo0`00
000J0?ooo`<00000;P3oool2000001/0oooo0P00000_0?ooo`8000006P3oool3000002H0oooo000D
0?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08P3oool2000001X0oooo0`00000^0?ooo`8000006`3oool2000002l0oooo0P00000J
0?ooo`<000009P3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool2000001T0oooo1000000^0?oo
o`<000006P3oool2000002l0oooo0P00000J0?ooo`<000009P3oool001@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool08P3oool3000001P0oooo0`00000`0?ooo`8000006P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01P0oooo0`00000V0?ooo`00503oool5000000@0oooo100000060?ooo`030000
003oool0oooo0280oooo0`00000H0?ooo`<00000<03oool2000001X0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0H0?ooo`8000009`3oool002L0oooo0P00000S0?ooo`<00000603o
ool300000300oooo0P00000I0?ooo`800000<@3oool2000001T0oooo0P00000W0?ooo`009`3oool0
0`000000oooo0?ooo`0S0?ooo`800000603oool300000300oooo0P00000I0?ooo`800000<@3oool2
000001P0oooo0`00000W0?ooo`009`3oool00`000000oooo0?ooo`0S0?ooo`800000603oool20000
0340oooo0`00000H0?ooo`800000<@3oool2000001P0oooo0`00000W0?ooo`009`3oool00`000000
oooo0?ooo`0S0?ooo`<000005P3oool300000380oooo0P00000H0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool05P3oool3000002L0oooo000W0?ooo`030000003oool0oooo02<0oooo
0`00000F0?ooo`<00000<P3oool2000001P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0F0?ooo`800000:03oool002L0oooo00<000000?ooo`3oool0903oool2000001H0oooo0`00
000b0?ooo`8000005`3oool2000003<0oooo0P00000G0?ooo`800000:03oool002L0oooo0P00000U
0?ooo`8000005P3oool300000380oooo0P00000G0?ooo`800000<`3oool2000001H0oooo0`00000X
0?ooo`009`3oool00`000000oooo0?ooo`0T0?ooo`<000005@3oool2000003<0oooo0`00000F0?oo
o`800000<`3oool2000001H0oooo0`00000X0?ooo`009`3oool00`000000oooo0?ooo`0T0?ooo`<0
0000503oool3000003@0oooo0P00000F0?ooo`030000003oool0oooo0380oooo0P00000F0?ooo`80
0000:@3oool002L0oooo00<000000?ooo`3oool0903oool3000001@0oooo0`00000d0?ooo`800000
5@3oool2000003D0oooo00<000000?ooo`3oool0503oool2000002T0oooo000W0?ooo`030000003o
ool0oooo02D0oooo0P00000D0?ooo`<00000=03oool2000001D0oooo0P00000e0?ooo`8000005@3o
ool2000002T0oooo000W0?ooo`8000009P3oool3000001<0oooo0`00000d0?ooo`8000005@3oool2
000003D0oooo0P00000E0?ooo`800000:@3oool002L0oooo00<000000?ooo`3oool09@3oool30000
01<0oooo0P00000e0?ooo`<00000503oool2000003D0oooo0P00000D0?ooo`<00000:@3oool002L0
oooo00<000000?ooo`3oool09@3oool300000180oooo0`00000e0?ooo`<000004`3oool2000003H0
oooo0P00000D0?ooo`<00000:@3oool002L0oooo00<000000?ooo`3oool09P3oool200000180oooo
0`00000f0?ooo`8000004`3oool2000003H0oooo0P00000D0?ooo`800000:P3oool002L0oooo00<0
00000?ooo`3oool09P3oool200000180oooo0`00000f0?ooo`8000004`3oool2000003L0oooo0P00
000C0?ooo`800000:P3oool002L0oooo00<000000?ooo`3oool09P3oool300000140oooo0P00000g
0?ooo`8000004`3oool2000003L0oooo0P00000C0?ooo`800000:P3oool002L0oooo0P00000W0?oo
o`<000004@3oool2000003L0oooo0`00000A0?ooo`<00000=`3oool200000180oooo0`00000Z0?oo
o`009`3oool00`000000oooo0?ooo`0W0?ooo`800000403oool3000003P0oooo0P00000A0?ooo`80
0000>03oool200000180oooo0`00000Z0?ooo`002P3oool7000000<0oooo100000050?ooo`@00000
1P3oool00`000000oooo0?ooo`0W0?ooo`800000403oool3000003P0oooo0P00000A0?ooo`800000
>03oool200000180oooo0P00000[0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool09`3oool200000100oooo0P00000i0?ooo`8000004@3oool2000003T0oooo
00<000000?ooo`3oool0403oool2000002/0oooo000=0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0W0?ooo`<000003`3oool2000003X0oooo0P00000?0?ooo`<00000
>@3oool200000140oooo0P00000[0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo
0P00000X0?ooo`<000003P3oool3000003X0oooo0P00000?0?ooo`<00000>@3oool200000140oooo
0P00000[0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:03oool2000000h0oooo0P00000k0?ooo`8000003`3oool2000003X0oooo0P00000@0?ooo`800000
;03oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo
0P00000>0?ooo`800000>`3oool3000000h0oooo0P00000k0?ooo`8000003`3oool2000002`0oooo
000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`<00000
303oool3000003`0oooo0P00000=0?ooo`<00000>`3oool2000000l0oooo0P00000/0?ooo`002`3o
ool3000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`<00000303oool2000003d0oooo
0`00000<0?ooo`<00000>`3oool2000000l0oooo0P00000/0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`@000001@3oool4000000H0oooo00<000000?ooo`3oool0:@3oool3000000/0oooo0P00
000m0?ooo`<00000303oool2000003`0oooo0`00000=0?ooo`800000;@3oool002L0oooo0P00000Z
0?ooo`<000002P3oool3000003h0oooo0P00000;0?ooo`<00000?@3oool2000000d0oooo0P00000]
0?ooo`009`3oool00`000000oooo0?ooo`0Z0?ooo`<000002@3oool2000003l0oooo0P00000;0?oo
o`<00000?@3oool2000000`0oooo0`00000]0?ooo`009`3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000203oool3000003l0oooo0`00000:0?ooo`<00000?@3oool2000000`0oooo0P00000^0?ooo`00
9`3oool00`000000oooo0?ooo`0Z0?ooo`<00000203oool3000003l0oooo0`0000090?ooo`<00000
?P3oool3000000/0oooo0P00000^0?ooo`009`3oool00`000000oooo0?ooo`0[0?ooo`<000001P3o
ool400000400oooo0P0000090?ooo`<00000?`3oool2000000X0oooo0`00000^0?ooo`009`3oool2
000002`0oooo0`0000060?ooo`<00000@@3oool3000000P0oooo0`00000o0?ooo`8000002P3oool3
000002h0oooo000W0?ooo`030000003oool0oooo02/0oooo100000040?ooo`@00000@@3oool30000
00L0oooo0`0000100?ooo`<000002@3oool2000002l0oooo000W0?ooo`030000003oool0oooo02`0
oooo100000020?ooo`@00000@`3oool3000000D0oooo100000100?ooo`<00000203oool3000002l0
oooo000W0?ooo`030000003oool0oooo02`0oooo2P0000130?ooo`<000001@3oool300000480oooo
0`0000070?ooo`<00000;`3oool002L0oooo00<000000?ooo`3oool0;@3oool8000004@0oooo1@00
00020?ooo`<00000@`3oool3000000H0oooo0`00000`0?ooo`009`3oool00`000000oooo0?ooo`0^
0?ooo`8000000P3oool2000004H0oooo2@0000140?ooo`<00000103oool400000300oooo000W0?oo
o`800000<03oool4000004P0oooo1`0000150?ooo`@000000P3oool400000340oooo000W0?ooo`03
0000003oool0oooo07`0oooo1P0000160?ooo`T00000<@3oool002L0oooo00<000000?ooo`3oool0
O03oool5000004L0oooo10000000103oool0000000000000000b0?ooo`009`3oool00`000000oooo
0?ooo`390?ooo`L00000<P3oool002L0oooo00<000000?ooo`3oool0bP3oool5000003<0oooo000W
0?ooo`800000o`3oool40?ooo`009`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000W0?ooo`03
0000003oool0oooo0?l0oooo0`3oool002L0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3o
ool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3o
ool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3o
ool]0?ooo`00o`3oool]0?ooo`00\
\>"],
  ImageRangeCache->{{{72.9375, 232.313}, {248.438, 150.375}} -> {92.8488, \
347.57, 0.0609519, 2.75143}}],

Cell[BoxData[
    \(\(Plot[Evaluate[grafic], {t, 1000, 1010}];\)\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-95.2143 0.0952381 0.308915 0.000232835 [
[.21429 .29642 -12 -9 ]
[.21429 .29642 12 0 ]
[.40476 .29642 -12 -9 ]
[.40476 .29642 12 0 ]
[.59524 .29642 -12 -9 ]
[.59524 .29642 12 0 ]
[.78571 .29642 -12 -9 ]
[.78571 .29642 12 0 ]
[.97619 .29642 -12 -9 ]
[.97619 .29642 12 0 ]
[.01131 .07608 -30 -4.5 ]
[.01131 .07608 0 4.5 ]
[.01131 .1925 -24 -4.5 ]
[.01131 .1925 0 4.5 ]
[.01131 .42533 -18 -4.5 ]
[.01131 .42533 0 4.5 ]
[.01131 .54175 -24 -4.5 ]
[.01131 .54175 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30892 m
.21429 .31517 L
s
[(1002)] .21429 .29642 0 1 Mshowa
.40476 .30892 m
.40476 .31517 L
s
[(1004)] .40476 .29642 0 1 Mshowa
.59524 .30892 m
.59524 .31517 L
s
[(1006)] .59524 .29642 0 1 Mshowa
.78571 .30892 m
.78571 .31517 L
s
[(1008)] .78571 .29642 0 1 Mshowa
.97619 .30892 m
.97619 .31517 L
s
[(1010)] .97619 .29642 0 1 Mshowa
.125 Mabswid
.07143 .30892 m
.07143 .31267 L
s
.11905 .30892 m
.11905 .31267 L
s
.16667 .30892 m
.16667 .31267 L
s
.2619 .30892 m
.2619 .31267 L
s
.30952 .30892 m
.30952 .31267 L
s
.35714 .30892 m
.35714 .31267 L
s
.45238 .30892 m
.45238 .31267 L
s
.5 .30892 m
.5 .31267 L
s
.54762 .30892 m
.54762 .31267 L
s
.64286 .30892 m
.64286 .31267 L
s
.69048 .30892 m
.69048 .31267 L
s
.7381 .30892 m
.7381 .31267 L
s
.83333 .30892 m
.83333 .31267 L
s
.88095 .30892 m
.88095 .31267 L
s
.92857 .30892 m
.92857 .31267 L
s
.25 Mabswid
0 .30892 m
1 .30892 L
s
.02381 .07608 m
.03006 .07608 L
s
[(-1000)] .01131 .07608 1 0 Mshowa
.02381 .1925 m
.03006 .1925 L
s
[(-500)] .01131 .1925 1 0 Mshowa
.02381 .42533 m
.03006 .42533 L
s
[(500)] .01131 .42533 1 0 Mshowa
.02381 .54175 m
.03006 .54175 L
s
[(1000)] .01131 .54175 1 0 Mshowa
.125 Mabswid
.02381 .09936 m
.02756 .09936 L
s
.02381 .12265 m
.02756 .12265 L
s
.02381 .14593 m
.02756 .14593 L
s
.02381 .16921 m
.02756 .16921 L
s
.02381 .21578 m
.02756 .21578 L
s
.02381 .23906 m
.02756 .23906 L
s
.02381 .26235 m
.02756 .26235 L
s
.02381 .28563 m
.02756 .28563 L
s
.02381 .3322 m
.02756 .3322 L
s
.02381 .35548 m
.02756 .35548 L
s
.02381 .37877 m
.02756 .37877 L
s
.02381 .40205 m
.02756 .40205 L
s
.02381 .44862 m
.02756 .44862 L
s
.02381 .4719 m
.02756 .4719 L
s
.02381 .49518 m
.02756 .49518 L
s
.02381 .51847 m
.02756 .51847 L
s
.02381 .0528 m
.02756 .0528 L
s
.02381 .02951 m
.02756 .02951 L
s
.02381 .00623 m
.02756 .00623 L
s
.02381 .56503 m
.02756 .56503 L
s
.02381 .58832 m
.02756 .58832 L
s
.02381 .6116 m
.02756 .6116 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4156 m
.03279 .46461 L
.04262 .51191 L
.053 .55247 L
.05753 .56665 L
.06244 .5794 L
.06526 .58542 L
.06786 .59012 L
.07051 .59403 L
.07298 .5969 L
.07434 .59815 L
.07559 .59908 L
.07697 .59989 L
.07773 .60022 L
.07846 .60048 L
.07915 .60066 L
.0799 .60078 L
.0806 .60083 L
.08123 .60082 L
.08198 .60074 L
.08279 .60058 L
.08355 .60035 L
.08426 .60007 L
.08543 .59945 L
.08669 .5986 L
.08897 .59655 L
.09167 .59326 L
.09414 .58946 L
.0995 .57862 L
.10458 .56519 L
.11423 .53179 L
.12449 .48634 L
.14291 .38573 L
.18066 .16203 L
.19008 .11521 L
.20001 .0741 L
.2052 .05653 L
.21089 .04075 L
.21606 .02971 L
.21839 .0258 L
.22086 .02239 L
.22211 .02096 L
.22349 .01962 L
.22476 .0186 L
.22591 .01784 L
.22728 .01717 L
.22803 .01691 L
.22874 .01672 L
.23001 .01655 L
.23072 .01655 L
Mistroke
.23139 .0166 L
.23269 .01688 L
.23391 .01733 L
.23501 .01791 L
.2362 .0187 L
.23887 .02115 L
.24132 .02419 L
.24564 .03137 L
.25037 .04186 L
.25991 .0709 L
.27014 .11258 L
.27946 .15847 L
.30038 .2795 L
.32112 .40506 L
.33024 .4559 L
.34028 .50566 L
.34925 .54278 L
.35891 .57347 L
.36423 .58583 L
.36656 .59015 L
.3691 .59411 L
.37136 .59693 L
.37376 .59924 L
.3751 .60019 L
.3763 .60086 L
.37752 .60135 L
.37866 .60163 L
.37982 .60174 L
.38107 .60167 L
.38224 .60142 L
.38331 .60104 L
.38456 .60041 L
.38593 .59948 L
.38841 .59719 L
.391 .59397 L
.39376 .58961 L
.39872 .57942 L
.40749 .55429 L
.41718 .51692 L
.43651 .41862 L
.45735 .29309 L
.47698 .17717 L
.48736 .12363 L
.49846 .07613 L
.50398 .05706 L
.5092 .04214 L
.51388 .03147 L
.5163 .027 L
.51896 .02292 L
.52145 .01991 L
Mistroke
.52378 .01781 L
.52507 .01696 L
.52625 .01636 L
.52689 .0161 L
.5276 .01589 L
.52889 .01566 L
.5301 .01564 L
.53119 .01579 L
.53245 .01615 L
.53364 .01668 L
.53475 .01734 L
.53576 .01808 L
.53805 .02023 L
.54051 .02329 L
.54276 .02675 L
.5478 .03678 L
.55689 .06249 L
.56751 .10376 L
.57756 .15225 L
.61591 .3793 L
.63531 .48649 L
.64561 .53257 L
.65102 .55271 L
.65671 .57051 L
.66176 .58318 L
.66444 .58865 L
.66729 .59351 L
.66992 .5971 L
.67231 .59959 L
.67346 .60053 L
.67471 .60136 L
.67589 .60195 L
.67698 .60234 L
.67808 .60258 L
.67925 .60266 L
.68037 .60257 L
.68138 .60235 L
.68257 .60193 L
.68386 .60125 L
.68509 .60042 L
.68622 .59948 L
.68871 .59683 L
.69096 .59376 L
.696 .58458 L
.70089 .5727 L
.70606 .55716 L
.7153 .52222 L
.73614 .41649 L
.77418 .18788 L
.79374 .09089 L
Mistroke
.79938 .06911 L
.8047 .05159 L
.80945 .03868 L
.81197 .03291 L
.81468 .02756 L
.81729 .02327 L
.81968 .0201 L
.82208 .01764 L
.82328 .01669 L
.82437 .01599 L
.8256 .01538 L
.82691 .01494 L
.82813 .01474 L
.82928 .01473 L
.82993 .0148 L
.83062 .01493 L
.83185 .01532 L
.83254 .01562 L
.83318 .01596 L
.83464 .01692 L
.83703 .01909 L
.83929 .02183 L
.84354 .02869 L
.84811 .03856 L
.85308 .05213 L
.86247 .08526 L
.87284 .13186 L
.89385 .24918 L
.91481 .37774 L
.93404 .48473 L
.9438 .52915 L
.95288 .56225 L
.95784 .57653 L
.96235 .58699 L
.96736 .59569 L
.97011 .59912 L
.97138 .60037 L
.97271 .60148 L
.97358 .60206 L
.97452 .6026 L
.97538 .60298 L
.97619 .60326 L
Mfstroke
.02381 .41625 m
.03279 .4652 L
.04262 .51241 L
.053 .55285 L
.05753 .56698 L
.06244 .57966 L
.06526 .58564 L
.06786 .5903 L
.07051 .59418 L
.07298 .59702 L
.07434 .59824 L
.07559 .59916 L
.07697 .59994 L
.07773 .60027 L
.07846 .60051 L
.07915 .60068 L
.0799 .60079 L
.0806 .60083 L
.08123 .60081 L
.08198 .60072 L
.08279 .60055 L
.08355 .6003 L
.08426 .60001 L
.08543 .59938 L
.08669 .59851 L
.08897 .59643 L
.09167 .5931 L
.09414 .58927 L
.0995 .57835 L
.10458 .56486 L
.11423 .53134 L
.12449 .48579 L
.14291 .38506 L
.18066 .16143 L
.19008 .11469 L
.20001 .07369 L
.2052 .05618 L
.21089 .04048 L
.21606 .02951 L
.21839 .02562 L
.22086 .02225 L
.22211 .02084 L
.22349 .01952 L
.22476 .01851 L
.22591 .01778 L
.22728 .01713 L
.22803 .01687 L
.22874 .0167 L
.23001 .01655 L
.23072 .01655 L
Mistroke
.23139 .01662 L
.23269 .01691 L
.23391 .01739 L
.23501 .01798 L
.2362 .01879 L
.23887 .02127 L
.24132 .02435 L
.24564 .03159 L
.25037 .04214 L
.25991 .0713 L
.27014 .1131 L
.27946 .15906 L
.30038 .28019 L
.32112 .40572 L
.33024 .4565 L
.34028 .50618 L
.34925 .5432 L
.35891 .57377 L
.36423 .58605 L
.36656 .59034 L
.3691 .59426 L
.37136 .59706 L
.37376 .59933 L
.3751 .60026 L
.3763 .60092 L
.37752 .60138 L
.37866 .60165 L
.37982 .60175 L
.38107 .60166 L
.38224 .60139 L
.38331 .60099 L
.38456 .60034 L
.38593 .5994 L
.38841 .59707 L
.391 .59381 L
.39376 .58941 L
.39872 .57915 L
.40749 .55391 L
.41718 .51643 L
.43651 .41797 L
.45735 .29239 L
.47698 .17655 L
.48736 .12309 L
.49846 .07571 L
.50398 .0567 L
.5092 .04185 L
.51388 .03124 L
.5163 .02681 L
.51896 .02277 L
.52145 .0198 L
Mistroke
.52378 .01773 L
.52507 .01689 L
.52625 .01631 L
.52689 .01606 L
.5276 .01586 L
.52889 .01565 L
.5301 .01565 L
.53119 .01581 L
.53245 .0162 L
.53364 .01674 L
.53475 .01741 L
.53576 .01817 L
.53805 .02036 L
.54051 .02345 L
.54276 .02694 L
.5478 .03704 L
.55689 .06287 L
.56751 .10426 L
.57756 .15284 L
.61591 .37998 L
.63531 .48705 L
.64561 .53302 L
.65102 .5531 L
.65671 .57082 L
.66176 .58343 L
.66444 .58886 L
.66729 .59368 L
.66992 .59723 L
.67231 .59969 L
.67346 .60061 L
.67471 .60142 L
.67589 .602 L
.67698 .60237 L
.67808 .60259 L
.67925 .60266 L
.68037 .60255 L
.68138 .60232 L
.68257 .60188 L
.68386 .60118 L
.68509 .60033 L
.68622 .59937 L
.68871 .59669 L
.69096 .59358 L
.696 .58433 L
.70089 .57239 L
.70606 .55679 L
.7153 .52174 L
.73614 .41584 L
.77418 .18725 L
.79374 .09043 L
Mistroke
.79938 .06871 L
.8047 .05125 L
.80945 .0384 L
.81197 .03267 L
.81468 .02736 L
.81729 .0231 L
.81968 .01996 L
.82083 .01871 L
.82208 .01754 L
.82326 .01662 L
.82437 .01592 L
.82502 .01559 L
.82572 .01529 L
.82694 .01491 L
.82764 .01478 L
.82838 .01472 L
.82969 .01478 L
.83091 .01503 L
.83205 .01545 L
.8333 .01609 L
.83464 .01701 L
.83701 .0192 L
.83959 .02239 L
.84428 .03035 L
.84885 .0407 L
.85308 .05247 L
.8627 .08663 L
.87173 .12698 L
.89233 .24071 L
.93101 .46992 L
.94138 .51944 L
.95104 .55664 L
.95632 .57276 L
.96111 .58461 L
.96644 .5945 L
.96937 .59842 L
.97071 .59985 L
.97214 .60112 L
.97314 .60185 L
.97425 .60251 L
.97525 .60297 L
.97619 .60329 L
Mfstroke
.02381 .4169 m
.03279 .46579 L
.04262 .51291 L
.053 .55324 L
.05753 .5673 L
.06244 .57993 L
.06526 .58586 L
.06786 .59049 L
.07051 .59433 L
.07298 .59713 L
.07434 .59833 L
.07559 .59923 L
.07697 .59999 L
.07773 .60031 L
.07846 .60054 L
.07915 .6007 L
.0799 .6008 L
.0806 .60083 L
.08123 .6008 L
.08198 .60071 L
.08279 .60052 L
.08355 .60026 L
.08426 .59996 L
.08543 .59932 L
.08669 .59843 L
.08897 .59631 L
.09167 .59294 L
.09414 .58907 L
.0995 .57808 L
.10458 .56452 L
.11423 .53089 L
.12449 .48523 L
.14291 .38439 L
.18066 .16083 L
.19008 .11416 L
.20001 .07327 L
.2052 .05583 L
.21089 .0402 L
.21606 .0293 L
.21839 .02545 L
.22086 .02212 L
.22211 .02072 L
.22349 .01942 L
.22476 .01843 L
.22591 .01771 L
.22728 .01708 L
.22803 .01684 L
.22874 .01667 L
.23001 .01654 L
.23072 .01656 L
Mistroke
.23139 .01664 L
.23269 .01695 L
.23391 .01744 L
.23501 .01805 L
.2362 .01887 L
.23887 .0214 L
.24132 .02451 L
.24564 .03181 L
.25037 .04243 L
.25991 .07171 L
.27014 .11362 L
.27946 .15966 L
.30038 .28089 L
.32112 .40638 L
.33024 .45711 L
.34028 .5067 L
.34925 .54362 L
.35891 .57407 L
.36423 .58628 L
.36656 .59054 L
.3691 .59442 L
.37152 .59735 L
.37376 .59941 L
.37501 .60028 L
.37613 .60089 L
.37744 .60139 L
.37866 .60167 L
.37982 .60175 L
.38107 .60164 L
.38224 .60136 L
.38331 .60094 L
.38456 .60027 L
.38593 .59931 L
.38841 .59695 L
.391 .59364 L
.39376 .58921 L
.39872 .57888 L
.40749 .55353 L
.41718 .51593 L
.43651 .41732 L
.45735 .29169 L
.47698 .17593 L
.48736 .12255 L
.49846 .07528 L
.50398 .05635 L
.5092 .04156 L
.51388 .03102 L
.5163 .02661 L
.51896 .02261 L
.52145 .01968 L
Mistroke
.52378 .01765 L
.52507 .01683 L
.52625 .01626 L
.52689 .01603 L
.5276 .01583 L
.52889 .01564 L
.5301 .01566 L
.53119 .01584 L
.53245 .01624 L
.53364 .0168 L
.53475 .01749 L
.53576 .01826 L
.53805 .02048 L
.54051 .02361 L
.54276 .02713 L
.5478 .0373 L
.55689 .06325 L
.56751 .10476 L
.57756 .15343 L
.61591 .38066 L
.63531 .4876 L
.64561 .53347 L
.65102 .55349 L
.65671 .57114 L
.66176 .58368 L
.66444 .58907 L
.66729 .59386 L
.66992 .59736 L
.67231 .59979 L
.67346 .60069 L
.67471 .60148 L
.67589 .60204 L
.67698 .6024 L
.67808 .60261 L
.67925 .60266 L
.68037 .60254 L
.68138 .60229 L
.68257 .60183 L
.68386 .60111 L
.68509 .60025 L
.68622 .59927 L
.68871 .59655 L
.69096 .59341 L
.696 .58409 L
.70089 .57209 L
.70606 .55641 L
.7153 .52126 L
.73614 .41519 L
.77418 .18661 L
.79374 .08996 L
Mistroke
.79938 .0683 L
.8047 .05091 L
.80945 .03813 L
.81197 .03243 L
.81468 .02716 L
.81729 .02294 L
.81968 .01983 L
.82083 .0186 L
.82208 .01744 L
.82326 .01655 L
.82437 .01586 L
.82502 .01553 L
.82572 .01524 L
.82694 .01489 L
.82764 .01477 L
.82838 .01472 L
.82969 .01479 L
.83091 .01507 L
.83205 .0155 L
.8333 .01616 L
.83464 .0171 L
.83701 .01932 L
.83959 .02255 L
.84428 .03058 L
.84885 .04098 L
.85308 .05281 L
.8627 .08709 L
.87173 .12753 L
.89233 .24139 L
.93101 .4705 L
.94138 .51993 L
.95104 .55702 L
.95632 .57307 L
.96111 .58486 L
.96644 .59467 L
.96937 .59855 L
.97071 .59996 L
.97214 .60121 L
.97314 .60193 L
.97425 .60257 L
.97525 .60302 L
.97619 .60332 L
Mfstroke
.02381 .41535 m
.03279 .46424 L
.04262 .51142 L
.053 .55189 L
.05753 .56603 L
.06244 .57876 L
.06526 .58476 L
.06786 .58944 L
.07051 .59335 L
.07298 .59621 L
.07434 .59746 L
.07559 .59839 L
.07697 .59919 L
.07773 .59953 L
.07846 .59978 L
.07915 .59996 L
.0799 .60008 L
.0806 .60013 L
.08123 .60012 L
.08198 .60005 L
.08279 .59988 L
.08355 .59965 L
.08426 .59937 L
.08543 .59876 L
.08669 .59791 L
.08897 .59586 L
.09167 .59258 L
.09414 .58879 L
.0995 .57797 L
.10458 .56458 L
.11423 .53126 L
.12449 .48592 L
.14291 .38555 L
.18066 .16238 L
.19008 .11567 L
.20001 .07467 L
.2052 .05714 L
.21089 .0414 L
.21606 .03038 L
.21839 .02647 L
.22086 .02308 L
.22211 .02165 L
.22349 .02031 L
.22476 .01929 L
.22591 .01854 L
.22728 .01787 L
.22803 .0176 L
.22874 .01742 L
.23001 .01725 L
.23072 .01725 L
Mistroke
.23139 .0173 L
.23269 .01757 L
.23391 .01803 L
.23501 .0186 L
.2362 .0194 L
.23887 .02183 L
.24132 .02487 L
.24564 .03203 L
.25037 .04249 L
.25991 .07146 L
.27014 .11305 L
.27946 .15882 L
.30038 .27957 L
.32112 .40483 L
.33024 .45555 L
.34028 .50519 L
.34925 .54222 L
.35891 .57284 L
.36423 .58516 L
.36656 .58948 L
.3691 .59343 L
.37136 .59625 L
.37376 .59854 L
.3751 .5995 L
.3763 .60017 L
.37752 .60065 L
.37866 .60093 L
.37982 .60105 L
.38107 .60098 L
.38224 .60073 L
.38331 .60034 L
.38456 .59971 L
.38593 .59879 L
.38841 .59651 L
.391 .59329 L
.39376 .58894 L
.39872 .57878 L
.40749 .55371 L
.41718 .51642 L
.43651 .41836 L
.45735 .29313 L
.47698 .17749 L
.48736 .12407 L
.49846 .07669 L
.50398 .05766 L
.5092 .04278 L
.51388 .03213 L
.5163 .02767 L
.51896 .0236 L
.52145 .0206 L
Mistroke
.52378 .01851 L
.52507 .01765 L
.52625 .01705 L
.52689 .0168 L
.5276 .01658 L
.52889 .01636 L
.5301 .01634 L
.53119 .01649 L
.53245 .01685 L
.53364 .01738 L
.53475 .01803 L
.53576 .01877 L
.53805 .02092 L
.54051 .02397 L
.54276 .02742 L
.5478 .03743 L
.55689 .06307 L
.56751 .10425 L
.57756 .15262 L
.61591 .37913 L
.63531 .48607 L
.64561 .53204 L
.65102 .55213 L
.65671 .56988 L
.66176 .58253 L
.66444 .58798 L
.66729 .59284 L
.66992 .59641 L
.67231 .5989 L
.67346 .59984 L
.67471 .60066 L
.67589 .60125 L
.67698 .60164 L
.67808 .60188 L
.67925 .60196 L
.68037 .60187 L
.68138 .60166 L
.68257 .60123 L
.68386 .60056 L
.68509 .59973 L
.68622 .59879 L
.68871 .59615 L
.69096 .59308 L
.696 .58392 L
.70089 .57208 L
.70606 .55657 L
.7153 .52171 L
.73614 .41623 L
.77418 .18817 L
.79374 .09141 L
Mistroke
.79938 .06968 L
.8047 .0522 L
.80945 .03932 L
.81197 .03356 L
.81468 .02823 L
.81729 .02395 L
.81968 .02078 L
.82208 .01833 L
.82328 .01738 L
.82437 .01668 L
.8256 .01608 L
.82691 .01564 L
.82813 .01544 L
.82928 .01543 L
.82993 .01549 L
.83062 .01562 L
.83185 .01601 L
.83254 .01631 L
.83318 .01665 L
.83464 .01761 L
.83703 .01978 L
.83929 .02251 L
.84354 .02935 L
.84811 .0392 L
.85308 .05274 L
.86247 .08579 L
.87284 .13228 L
.89385 .24932 L
.91481 .37757 L
.93404 .48431 L
.9438 .52862 L
.95288 .56165 L
.95784 .57589 L
.96235 .58633 L
.96736 .59501 L
.97011 .59844 L
.97138 .59968 L
.97271 .60078 L
.97358 .60137 L
.97452 .6019 L
.97538 .60229 L
.97619 .60256 L
Mfstroke
.02381 .416 m
.03279 .46483 L
.04262 .51192 L
.053 .55227 L
.05753 .56636 L
.06244 .57902 L
.06526 .58498 L
.06786 .58963 L
.07051 .5935 L
.07298 .59633 L
.07434 .59755 L
.07559 .59846 L
.07697 .59924 L
.07773 .59957 L
.07846 .59981 L
.07915 .59998 L
.0799 .60009 L
.0806 .60013 L
.08123 .60011 L
.08198 .60003 L
.08279 .59985 L
.08355 .59961 L
.08426 .59932 L
.08543 .59869 L
.08669 .59782 L
.08897 .59574 L
.09167 .59242 L
.09414 .58859 L
.0995 .5777 L
.10458 .56425 L
.11423 .53081 L
.12449 .48536 L
.14291 .38488 L
.18066 .16178 L
.19008 .11515 L
.20001 .07425 L
.2052 .05679 L
.21089 .04112 L
.21606 .03018 L
.21839 .0263 L
.22086 .02294 L
.22211 .02153 L
.22349 .02021 L
.22476 .01921 L
.22591 .01847 L
.22728 .01783 L
.22803 .01757 L
.22874 .0174 L
.23001 .01725 L
.23072 .01725 L
Mistroke
.23139 .01732 L
.23269 .01761 L
.23391 .01808 L
.23501 .01867 L
.2362 .01948 L
.23887 .02196 L
.24132 .02503 L
.24564 .03225 L
.25037 .04278 L
.25991 .07187 L
.27014 .11357 L
.27946 .15942 L
.30038 .28026 L
.32112 .40549 L
.33024 .45615 L
.34028 .50571 L
.34925 .54264 L
.35891 .57314 L
.36423 .58539 L
.36656 .58967 L
.3691 .59358 L
.37136 .59637 L
.37376 .59863 L
.3751 .59957 L
.3763 .60022 L
.37752 .60068 L
.37866 .60095 L
.37982 .60105 L
.38107 .60096 L
.38224 .60069 L
.38331 .60029 L
.38456 .59964 L
.38593 .5987 L
.38841 .59638 L
.391 .59313 L
.39376 .58874 L
.39872 .57851 L
.40749 .55333 L
.41718 .51593 L
.43651 .41771 L
.45735 .29243 L
.47698 .17686 L
.48736 .12353 L
.49846 .07626 L
.50398 .0573 L
.5092 .04249 L
.51388 .0319 L
.5163 .02748 L
.51896 .02345 L
.52145 .02048 L
Mistroke
.52378 .01842 L
.52507 .01759 L
.52625 .01701 L
.52689 .01676 L
.5276 .01656 L
.52889 .01635 L
.5301 .01635 L
.53119 .01651 L
.53245 .01689 L
.53364 .01744 L
.53475 .01811 L
.53576 .01886 L
.53805 .02104 L
.54051 .02413 L
.54276 .02761 L
.5478 .03769 L
.55689 .06345 L
.56751 .10475 L
.57756 .15321 L
.61591 .37981 L
.63531 .48662 L
.64561 .53249 L
.65102 .55252 L
.65671 .5702 L
.66176 .58278 L
.66444 .5882 L
.66729 .59301 L
.66992 .59654 L
.67231 .599 L
.67346 .59992 L
.67471 .60072 L
.67589 .6013 L
.67698 .60167 L
.67808 .6019 L
.67925 .60196 L
.68037 .60186 L
.68138 .60162 L
.68257 .60118 L
.68386 .60049 L
.68509 .59964 L
.68622 .59868 L
.68871 .59601 L
.69096 .59291 L
.696 .58368 L
.70089 .57177 L
.70606 .5562 L
.7153 .52123 L
.73614 .41558 L
.77418 .18754 L
.79374 .09094 L
Mistroke
.79938 .06928 L
.8047 .05186 L
.80945 .03904 L
.81197 .03332 L
.81468 .02803 L
.81729 .02378 L
.81968 .02065 L
.82083 .0194 L
.82208 .01823 L
.82326 .01732 L
.82437 .01662 L
.82502 .01628 L
.82572 .01598 L
.82694 .01561 L
.82764 .01548 L
.82838 .01542 L
.82969 .01548 L
.83091 .01573 L
.83205 .01614 L
.8333 .01679 L
.83464 .0177 L
.83701 .01988 L
.83959 .02307 L
.84428 .03101 L
.84885 .04133 L
.85308 .05308 L
.8627 .08716 L
.87173 .12741 L
.89233 .24087 L
.93101 .46954 L
.94138 .51894 L
.95104 .55605 L
.95632 .57214 L
.96111 .58396 L
.96644 .59382 L
.96937 .59773 L
.97071 .59916 L
.97214 .60042 L
.97314 .60116 L
.97425 .60182 L
.97525 .60228 L
.97619 .60259 L
Mfstroke
.02381 .41665 m
.03279 .46542 L
.04262 .51243 L
.053 .55265 L
.05753 .56669 L
.06244 .57928 L
.06526 .5852 L
.06786 .58982 L
.07051 .59365 L
.07298 .59644 L
.07434 .59764 L
.07559 .59854 L
.07697 .5993 L
.07773 .59961 L
.07846 .59984 L
.07915 .6 L
.0799 .6001 L
.0806 .60013 L
.08123 .60011 L
.08198 .60001 L
.08279 .59982 L
.08355 .59956 L
.08426 .59926 L
.08543 .59862 L
.08669 .59773 L
.08897 .59562 L
.09167 .59226 L
.09414 .5884 L
.0995 .57744 L
.10458 .56391 L
.11423 .53036 L
.12449 .48481 L
.14291 .3842 L
.18066 .16118 L
.19008 .11463 L
.20001 .07384 L
.2052 .05643 L
.21089 .04084 L
.21606 .02997 L
.21839 .02613 L
.22086 .0228 L
.22211 .02141 L
.22349 .02011 L
.22476 .01913 L
.22591 .01841 L
.22728 .01778 L
.22803 .01754 L
.22874 .01737 L
.23001 .01724 L
.23072 .01726 L
Mistroke
.23139 .01733 L
.23269 .01764 L
.23391 .01814 L
.23501 .01874 L
.2362 .01957 L
.23887 .02208 L
.24132 .02519 L
.24564 .03248 L
.25037 .04307 L
.25991 .07228 L
.27014 .11409 L
.27946 .16002 L
.30038 .28096 L
.32112 .40615 L
.33024 .45676 L
.34028 .50623 L
.34925 .54306 L
.35891 .57344 L
.36423 .58562 L
.36656 .58987 L
.3691 .59374 L
.37152 .59667 L
.37376 .59872 L
.37501 .59958 L
.37613 .60019 L
.37744 .6007 L
.37866 .60097 L
.37982 .60105 L
.38107 .60094 L
.38224 .60066 L
.38331 .60024 L
.38456 .59957 L
.38593 .59861 L
.38841 .59626 L
.391 .59296 L
.39376 .58854 L
.39872 .57824 L
.40749 .55294 L
.41718 .51544 L
.43651 .41706 L
.45735 .29173 L
.47698 .17624 L
.48736 .12299 L
.49846 .07584 L
.50398 .05695 L
.5092 .0422 L
.51388 .03168 L
.5163 .02729 L
.51896 .02329 L
.52145 .02037 L
Mistroke
.52378 .01834 L
.52507 .01752 L
.52625 .01696 L
.52689 .01672 L
.5276 .01653 L
.52889 .01634 L
.5301 .01636 L
.53119 .01654 L
.53245 .01694 L
.53364 .0175 L
.53475 .01818 L
.53576 .01895 L
.53805 .02117 L
.54051 .02429 L
.54276 .0278 L
.5478 .03795 L
.55689 .06384 L
.56751 .10525 L
.57756 .1538 L
.61591 .38049 L
.63531 .48718 L
.64561 .53294 L
.65102 .5529 L
.65671 .57052 L
.66176 .58303 L
.66444 .58841 L
.66729 .59318 L
.66992 .59668 L
.67231 .5991 L
.67346 .6 L
.67471 .60079 L
.67589 .60135 L
.67698 .6017 L
.67808 .60191 L
.67925 .60196 L
.68037 .60184 L
.68138 .60159 L
.68257 .60113 L
.68386 .60042 L
.68509 .59955 L
.68622 .59858 L
.68871 .59587 L
.69096 .59274 L
.696 .58344 L
.70089 .57146 L
.70606 .55582 L
.7153 .52075 L
.73614 .41493 L
.77418 .1869 L
.79374 .09048 L
Mistroke
.79938 .06887 L
.8047 .05152 L
.80945 .03877 L
.81197 .03308 L
.81468 .02782 L
.81729 .02362 L
.81968 .02052 L
.82083 .01929 L
.82208 .01814 L
.82326 .01724 L
.82437 .01656 L
.82502 .01623 L
.82572 .01594 L
.82694 .01558 L
.82764 .01547 L
.82838 .01541 L
.82969 .01549 L
.83091 .01576 L
.83205 .01619 L
.8333 .01685 L
.83464 .01779 L
.83701 .02001 L
.83959 .02323 L
.84428 .03124 L
.84885 .04162 L
.85308 .05342 L
.8627 .08762 L
.87173 .12796 L
.89233 .24155 L
.93101 .47012 L
.94138 .51943 L
.95104 .55643 L
.95632 .57245 L
.96111 .58421 L
.96644 .594 L
.96937 .59786 L
.97071 .59927 L
.97214 .60051 L
.97314 .60123 L
.97425 .60188 L
.97525 .60232 L
.97619 .60262 L
Mfstroke
.02381 .41509 m
.03279 .46386 L
.04262 .51094 L
.053 .5513 L
.05753 .56542 L
.06244 .57811 L
.06526 .5841 L
.06786 .58877 L
.07051 .59267 L
.07298 .59552 L
.07434 .59676 L
.07559 .59769 L
.07697 .59849 L
.07773 .59883 L
.07846 .59908 L
.07915 .59926 L
.0799 .59938 L
.0806 .59943 L
.08123 .59942 L
.08198 .59935 L
.08279 .59918 L
.08355 .59895 L
.08426 .59867 L
.08543 .59806 L
.08669 .59722 L
.08897 .59518 L
.09167 .5919 L
.09414 .58812 L
.0995 .57733 L
.10458 .56397 L
.11423 .53073 L
.12449 .4855 L
.14291 .38537 L
.18066 .16274 L
.19008 .11614 L
.20001 .07523 L
.2052 .05774 L
.21089 .04204 L
.21606 .03105 L
.21839 .02715 L
.22086 .02376 L
.22211 .02234 L
.22349 .021 L
.22476 .01998 L
.22591 .01923 L
.22728 .01857 L
.22803 .0183 L
.22874 .01812 L
.23001 .01795 L
.23072 .01794 L
Mistroke
.23139 .018 L
.23269 .01827 L
.23391 .01873 L
.23501 .0193 L
.2362 .02009 L
.23887 .02252 L
.24132 .02555 L
.24564 .0327 L
.25037 .04313 L
.25991 .07203 L
.27014 .11352 L
.27946 .15918 L
.30038 .27963 L
.32112 .4046 L
.33024 .4552 L
.34028 .50472 L
.34925 .54166 L
.35891 .57221 L
.36423 .5845 L
.36656 .58881 L
.3691 .59275 L
.37136 .59556 L
.37376 .59785 L
.3751 .5988 L
.3763 .59947 L
.37752 .59995 L
.37866 .60023 L
.37982 .60035 L
.38107 .60028 L
.38224 .60003 L
.38331 .59965 L
.38456 .59902 L
.38593 .5981 L
.38841 .59582 L
.391 .59261 L
.39376 .58827 L
.39872 .57813 L
.40749 .55313 L
.41718 .51593 L
.43651 .4181 L
.45735 .29317 L
.47698 .1778 L
.48736 .12451 L
.49846 .07724 L
.50398 .05826 L
.5092 .04341 L
.51388 .03279 L
.5163 .02834 L
.51896 .02428 L
.52145 .02129 L
Mistroke
.52378 .0192 L
.52507 .01835 L
.52625 .01775 L
.52689 .0175 L
.5276 .01728 L
.52889 .01706 L
.5301 .01704 L
.53119 .01719 L
.53245 .01755 L
.53364 .01807 L
.53475 .01872 L
.53576 .01946 L
.53805 .02161 L
.54051 .02465 L
.54276 .02809 L
.5478 .03807 L
.55689 .06366 L
.56751 .10474 L
.57756 .15299 L
.61591 .37896 L
.63531 .48565 L
.64561 .53151 L
.65102 .55155 L
.65671 .56926 L
.66176 .58188 L
.66444 .58732 L
.66729 .59216 L
.66992 .59573 L
.67231 .59821 L
.67346 .59914 L
.67471 .59996 L
.67589 .60056 L
.67698 .60095 L
.67808 .60118 L
.67925 .60126 L
.68037 .60118 L
.68138 .60096 L
.68257 .60053 L
.68386 .59986 L
.68509 .59904 L
.68622 .5981 L
.68871 .59546 L
.69096 .5924 L
.696 .58327 L
.70089 .57145 L
.70606 .55598 L
.7153 .52121 L
.73614 .41598 L
.77418 .18846 L
.79374 .09193 L
Mistroke
.79938 .07025 L
.8047 .05281 L
.80945 .03996 L
.81197 .03422 L
.81468 .0289 L
.81729 .02463 L
.81968 .02147 L
.82208 .01902 L
.82328 .01808 L
.82437 .01738 L
.8256 .01677 L
.82691 .01634 L
.82813 .01614 L
.82928 .01612 L
.82993 .01619 L
.83062 .01632 L
.83185 .01671 L
.83254 .01701 L
.83318 .01735 L
.83464 .01831 L
.83703 .02047 L
.83929 .02319 L
.84354 .03002 L
.84811 .03984 L
.85308 .05335 L
.86247 .08632 L
.87284 .1327 L
.89385 .24946 L
.91481 .37741 L
.93404 .48389 L
.9438 .5281 L
.95288 .56105 L
.95784 .57526 L
.96235 .58567 L
.96736 .59433 L
.97011 .59775 L
.97138 .59899 L
.97271 .60009 L
.97358 .60067 L
.97452 .60121 L
.97538 .60159 L
.97619 .60186 L
Mfstroke
.02381 .41574 m
.03279 .46445 L
.04262 .51144 L
.053 .55169 L
.05753 .56574 L
.06244 .57837 L
.06526 .58432 L
.06786 .58896 L
.07051 .59282 L
.07298 .59564 L
.07434 .59686 L
.07559 .59777 L
.07697 .59855 L
.07773 .59887 L
.07846 .59911 L
.07915 .59928 L
.0799 .59939 L
.0806 .59943 L
.08123 .59942 L
.08198 .59933 L
.08279 .59915 L
.08355 .59891 L
.08426 .59862 L
.08543 .59799 L
.08669 .59713 L
.08897 .59506 L
.09167 .59174 L
.09414 .58792 L
.0995 .57706 L
.10458 .56363 L
.11423 .53028 L
.12449 .48494 L
.14291 .3847 L
.18066 .16213 L
.19008 .11561 L
.20001 .07481 L
.2052 .05739 L
.21089 .04176 L
.21606 .03084 L
.21839 .02698 L
.22086 .02362 L
.22211 .02222 L
.22349 .0209 L
.22476 .0199 L
.22591 .01917 L
.22728 .01852 L
.22803 .01827 L
.22874 .01809 L
.23001 .01794 L
.23072 .01795 L
Mistroke
.23139 .01802 L
.23269 .01831 L
.23391 .01878 L
.23501 .01937 L
.2362 .02017 L
.23887 .02265 L
.24132 .02571 L
.24564 .03292 L
.25037 .04342 L
.25991 .07244 L
.27014 .11404 L
.27946 .15978 L
.30038 .28033 L
.32112 .40526 L
.33024 .4558 L
.34028 .50524 L
.34925 .54208 L
.35891 .57251 L
.36423 .58473 L
.36656 .589 L
.3691 .5929 L
.37136 .59568 L
.37376 .59794 L
.3751 .59887 L
.3763 .59952 L
.37752 .59999 L
.37866 .60025 L
.37982 .60035 L
.38107 .60026 L
.38224 .59999 L
.38331 .5996 L
.38456 .59895 L
.38593 .59801 L
.38841 .5957 L
.391 .59245 L
.39376 .58807 L
.39872 .57786 L
.40749 .55274 L
.41718 .51543 L
.43651 .41745 L
.45735 .29247 L
.47698 .17718 L
.48736 .12397 L
.49846 .07682 L
.50398 .0579 L
.5092 .04312 L
.51388 .03256 L
.5163 .02815 L
.51896 .02413 L
.52145 .02117 L
Mistroke
.52378 .01912 L
.52507 .01828 L
.52625 .0177 L
.52689 .01746 L
.5276 .01725 L
.52889 .01705 L
.5301 .01705 L
.53119 .01721 L
.53245 .01759 L
.53364 .01813 L
.53475 .0188 L
.53576 .01955 L
.53805 .02173 L
.54051 .02481 L
.54276 .02828 L
.5478 .03834 L
.55689 .06404 L
.56751 .10524 L
.57756 .15358 L
.61591 .37964 L
.63531 .4862 L
.64561 .53196 L
.65102 .55194 L
.65671 .56958 L
.66176 .58213 L
.66444 .58753 L
.66729 .59233 L
.66992 .59586 L
.67231 .5983 L
.67346 .59922 L
.67471 .60003 L
.67589 .6006 L
.67698 .60098 L
.67808 .6012 L
.67925 .60126 L
.68037 .60116 L
.68138 .60092 L
.68257 .60048 L
.68386 .59979 L
.68509 .59895 L
.68622 .59799 L
.68871 .59532 L
.69096 .59223 L
.696 .58302 L
.70089 .57114 L
.70606 .55561 L
.7153 .52073 L
.73614 .41533 L
.77418 .18783 L
.79374 .09146 L
Mistroke
.79938 .06985 L
.8047 .05247 L
.80945 .03969 L
.81197 .03398 L
.81468 .02869 L
.81729 .02446 L
.81968 .02134 L
.82083 .02009 L
.82208 .01892 L
.82326 .01801 L
.82437 .01732 L
.82502 .01698 L
.82572 .01668 L
.82694 .01631 L
.82764 .01618 L
.82838 .01612 L
.82969 .01618 L
.83091 .01643 L
.83205 .01684 L
.8333 .01748 L
.83464 .01839 L
.83701 .02057 L
.83959 .02375 L
.84428 .03167 L
.84885 .04197 L
.85308 .05369 L
.8627 .08769 L
.87173 .12784 L
.89233 .24104 L
.93101 .46915 L
.94138 .51844 L
.95104 .55547 L
.95632 .57151 L
.96111 .58331 L
.96644 .59315 L
.96937 .59705 L
.97071 .59847 L
.97214 .59973 L
.97314 .60046 L
.97425 .60112 L
.97525 .60158 L
.97619 .60189 L
Mfstroke
.02381 .41639 m
.03279 .46504 L
.04262 .51194 L
.053 .55207 L
.05753 .56607 L
.06244 .57863 L
.06526 .58454 L
.06786 .58914 L
.07051 .59296 L
.07298 .59575 L
.07434 .59695 L
.07559 .59784 L
.07697 .5986 L
.07773 .59892 L
.07846 .59915 L
.07915 .59931 L
.0799 .59941 L
.0806 .59944 L
.08123 .59941 L
.08198 .59931 L
.08279 .59912 L
.08355 .59887 L
.08426 .59857 L
.08543 .59793 L
.08669 .59704 L
.08897 .59493 L
.09167 .59158 L
.09414 .58773 L
.0995 .57679 L
.10458 .5633 L
.11423 .52983 L
.12449 .48438 L
.14291 .38402 L
.18066 .16153 L
.19008 .11509 L
.20001 .0744 L
.2052 .05704 L
.21089 .04148 L
.21606 .03064 L
.21839 .0268 L
.22086 .02349 L
.22211 .0221 L
.22349 .0208 L
.22476 .01982 L
.22591 .0191 L
.22728 .01848 L
.22803 .01823 L
.22874 .01807 L
.23001 .01794 L
.23072 .01796 L
Mistroke
.23139 .01803 L
.23269 .01834 L
.23391 .01883 L
.23501 .01944 L
.2362 .02026 L
.23887 .02277 L
.24132 .02587 L
.24564 .03314 L
.25037 .0437 L
.25991 .07285 L
.27014 .11456 L
.27946 .16038 L
.30038 .28102 L
.32112 .40592 L
.33024 .4564 L
.34028 .50576 L
.34925 .5425 L
.35891 .57281 L
.36423 .58495 L
.36656 .58919 L
.3691 .59306 L
.37152 .59598 L
.37376 .59803 L
.37501 .59889 L
.37613 .5995 L
.37744 .6 L
.37866 .60027 L
.37982 .60035 L
.38107 .60024 L
.38224 .59996 L
.38331 .59955 L
.38456 .59888 L
.38593 .59792 L
.38841 .59557 L
.391 .59228 L
.39376 .58787 L
.39872 .57759 L
.40749 .55236 L
.41718 .51494 L
.43651 .4168 L
.45735 .29177 L
.47698 .17656 L
.48736 .12343 L
.49846 .07639 L
.50398 .05755 L
.5092 .04284 L
.51388 .03234 L
.5163 .02796 L
.51896 .02397 L
.52145 .02106 L
Mistroke
.52378 .01903 L
.52507 .01822 L
.52625 .01765 L
.52689 .01742 L
.5276 .01723 L
.52889 .01704 L
.5301 .01706 L
.53119 .01724 L
.53245 .01763 L
.53364 .01819 L
.53475 .01888 L
.53576 .01964 L
.53805 .02186 L
.54051 .02497 L
.54276 .02847 L
.5478 .0386 L
.55689 .06442 L
.56751 .10574 L
.57756 .15418 L
.61591 .38032 L
.63531 .48676 L
.64561 .53241 L
.65102 .55232 L
.65671 .56989 L
.66176 .58238 L
.66444 .58774 L
.66729 .5925 L
.66992 .59599 L
.67231 .5984 L
.67346 .59931 L
.67471 .60009 L
.67589 .60065 L
.67698 .60101 L
.67808 .60121 L
.67925 .60126 L
.68037 .60114 L
.68138 .60089 L
.68257 .60043 L
.68386 .59972 L
.68509 .59886 L
.68622 .59789 L
.68871 .59518 L
.69096 .59206 L
.696 .58278 L
.70089 .57083 L
.70606 .55524 L
.7153 .52024 L
.73614 .41468 L
.77418 .18719 L
.79374 .09099 L
Mistroke
.79938 .06944 L
.8047 .05214 L
.80945 .03941 L
.81197 .03374 L
.81468 .02849 L
.81729 .0243 L
.81968 .0212 L
.82083 .01998 L
.82208 .01883 L
.82326 .01793 L
.82437 .01725 L
.82502 .01693 L
.82572 .01664 L
.82694 .01628 L
.82764 .01617 L
.82838 .01611 L
.82969 .01619 L
.83091 .01646 L
.83205 .01689 L
.8333 .01755 L
.83464 .01848 L
.83701 .02069 L
.83959 .02391 L
.84428 .0319 L
.84885 .04226 L
.85308 .05403 L
.8627 .08814 L
.87173 .12839 L
.89233 .24172 L
.93101 .46974 L
.94138 .51893 L
.95104 .55584 L
.95632 .57182 L
.96111 .58355 L
.96644 .59332 L
.96937 .59718 L
.97071 .59858 L
.97214 .59982 L
.97314 .60054 L
.97425 .60118 L
.97525 .60162 L
.97619 .60192 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{238.313, 147.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000g2000`400?l00000o`00003oo`3ooomV
0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV
0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV
0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV
0?ooo`00<03oool00`000000oooo0?ooo`3o0?oooc<0oooo000`0?ooo`030000003oool0oooo0?l0
oooo<`3oool00300oooo0P00003o0?oooc@0oooo000`0?ooo`030000003oool0oooo0?l0oooo<`3o
ool00300oooo00<000000?ooo`3oool0U`3oool2000005P0oooo0`00000n0?ooo`00<03oool00`00
0000oooo0?ooo`0j0?ooo`D00000EP3oool5000005H0oooo1P00000l0?ooo`00<03oool00`000000
oooo0?ooo`0i0?ooo`8000000`3oool2000005D0oooo00@000000?ooo`3oool0oooo0P00001D0?oo
o`800000103oool00`000000oooo0?ooo`0j0?ooo`00<03oool00`000000oooo0?ooo`0h0?ooo`80
00001@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`030?ooo`800000>`3oool00300oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`040?ooo`800000DP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool01@3oool2000003X0oooo000`0?ooo`800000>@3o
ool00`000000oooo0?ooo`050?ooo`800000D03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`00<03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01`3oool2
000003T0oooo000`0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01`3oool20000
04h0oooo0P00000:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0g0?ooo`00<03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`00<03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04/0oooo0P00000;0?ooo`030000003oool0oooo03L0oooo
000`0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02P3oool2000004`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00X0oooo0P00
000h0?ooo`00<03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0f0?ooo`00<03oool2000003D0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo000`0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool2000004X0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`190?ooo`8000003@3oool00`000000oooo0?ooo`0f0?ooo`00
<03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0e0?ooo`002P3oool7000000<0oooo100000050?ooo`@000001@3o
ool4000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`170?ooo`8000003`3o
ool00`000000oooo0?ooo`0e0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
3P3oool2000004P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0=@3oool000d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0e0?ooo`00
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool200000140oooo00<000000?oo
o`3oool0=03oool000030?ooo`000000000000@000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<00000<`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool000d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0b0?ooo`8000004@3oool2000004L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=03oool000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0c0?ooo`002`3oool3000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`130?ooo`8000004`3oool00`000000
oooo0?ooo`0c0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`@000001@3oool4000000D0oooo
100000060?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0140oooo0P0000140?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0<`3oool00300oooo00<000000?ooo`3oool0<@3oool2000001<0oooo0P00
00150?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0B0?ooo`800000=03oool00300oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<P3oool00300oooo0P00000b0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0C0?oo
o`800000@P3oool2000001D0oooo00<000000?ooo`3oool0<P3oool00300oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0<P3oool00300oooo00<000000?ooo`3oool0<03oool2000001D0oooo0P0000120?ooo`800000
5P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01@0oooo0P00000c0?ooo`00<03o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0a0?ooo`00<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0E0?ooo`800000@@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0340oooo000`0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0E0?ooo`800000<P3oool00300
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03l0
oooo0P00000H0?ooo`030000003oool0oooo03h0oooo0P00000G0?ooo`800000<P3oool00300oooo
0P00000`0?ooo`800000603oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0300oooo
000`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo0P00000o
0?ooo`030000003oool0oooo01L0oooo0P00000a0?ooo`00<03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?@3oool2000001X0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0G0?ooo`800000<@3oool00300oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01L0oooo0P00000a0?ooo`00
<03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03`0oooo0P00000J0?ooo`030000
003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0I0?ooo`800000<03oool00300oooo0P00000_0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0I0?ooo`800000?@3oool0
0`000000oooo0?ooo`0I0?ooo`800000<03oool00300oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo03/0oooo0P00000L0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool06@3oool200000300oooo000`0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0I0?ooo`800000<03oool00300oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01T0oooo
0P00000`0?ooo`00<03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo0P00
000L0?ooo`030000003oool0oooo02h0oooo000`0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0K0?ooo`800000;`3oool00300oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool06`3oool2000003/0oooo00<000000?ooo`3oool06`3oool2000002l0oooo000`0?ooo`80
0000;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03T0oooo0P00000N0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool06`3oool2000002l0oooo000`0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0K0?ooo`800000
;`3oool00300oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01/0oooo0P00000_0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03P0oooo0P00000N0?ooo`030000003oool0oooo02d0oooo000D0?ooo`@000001@3oool40000
00D0oooo100000060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0M0?ooo`800000;P3oool001<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03L0oooo0P00000O0?ooo`800000>@3oool00`000000oooo0?ooo`0M0?ooo`800000;P3oool0
01P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0M0?ooo`800000;P3oool001P0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<00000
;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo0P00000^0?ooo`002P3o
ool6000000P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0=P3oool200000200oooo00<000000?ooo`3oool0;03oool001@0oooo100000040?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0;03oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0O0?ooo`80
0000;@3oool001@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0e0?ooo`8000008@3oool2000003L0
oooo00<000000?ooo`3oool07`3oool2000002d0oooo000D0?ooo`D00000103oool4000000D0oooo
100000060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0O0?ooo`800000;@3oool00300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo01l0oooo0P00000]0?ooo`00<03oool2000002/0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0=03oool200000280oooo00<000000?ooo`3oool0:`3oool00300oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0:`3oool00300oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0240oooo0P00000/0?ooo`00<03oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0<`3oool2000002<0oooo0P00000e0?ooo`030000
003oool0oooo0240oooo0P00000/0?ooo`00<03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool08@3oool2000002`0oooo000`0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0Q0?ooo`800000;03oool0
0300oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`800000903oool00`00
0000oooo0?ooo`0Z0?ooo`00<03oool2000002X0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo000`0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`800000:`3oool00300oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0340oooo0P00
000U0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool2000002/0oooo000`
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S
0?ooo`800000:`3oool00300oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool00300oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0`0?ooo`8000009P3oool00`000000oooo0?ooo`0Y0?ooo`00
<03oool00`000000oooo0?ooo`0V0?ooo`L000000`3oool4000000D0oooo100000040?ooo`H00000
2@3oool00`000000oooo0?ooo`0=0?ooo`L000000`3oool4000000D0oooo100000060?ooo`@00000
0P3oool00`000000oooo0?ooo`0D0?ooo`L000000`3oool4000000<0oooo00<000000?ooo`000000
0`0000060?ooo`@000006@3oool7000000<0oooo100000050?ooo`@000001@3oool400000180oooo
00<000000?ooo`3oool01@3oool7000000<0oooo100000040?ooo`L000000`3oool4000000@0oooo
000`0?ooo`800000:@3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0?0?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool00300oooo00<000000?ooo`3oool0:03oool2000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo008000006@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0
oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool03`3oool2000000T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo
02P0oooo0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool0oooo1P0000000`3oool000000?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000@0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00l0oooo0P0000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00<03oool00`000000
oooo0?ooo`0X0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
00000002000001`0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo1000000C0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo000`0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool00300oooo
00<000000?ooo`3oool09`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000`0?ooo`030000
003oool0oooo02L0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0F0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo0`00
00050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`8000001P3oool3000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0040oooo000`0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`0000001P3oool4000000D0oooo100000050?ooo`@000002`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo100000050?ooo`@000001`3oool2000000030?oo
o`000000000001X0oooo00<000000?ooo`3oool0103oool4000000@0oooo1@0000080?ooo`<00000
6`3oool00`000000oooo0?ooo`030?ooo`D000001@3oool4000000D0oooo1000000C0?ooo`800000
203oool00`000000oooo0?ooo`040?ooo`@000001`3oool00`000000oooo0?ooo`040?ooo`@00000
103oool00300oooo0P00000X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0X0?ooo`800000;`3oool00`000000oooo0?ooo`0W0?ooo`800000:@3o
ool00300oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool09`3oool00300oooo00<000000?ooo`3oool09P3oool20000
02X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`00<03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0W0?ooo`00<03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`00<03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:`3oool2000002/0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?ooo`800000:03oool00300oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02T0oooo0P00000X
0?ooo`00:@3ooooo0000038000002`3oool00300oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`8000003P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@
0?ooo`00<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0V0?ooo`00<03oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0V0?ooo`00
<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
:@3oool2000002d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`800000
9`3oool00300oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02/0oooo0P00000W0?ooo`00<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo02P0oooo0P00000^0?ooo`030000003oool0oooo02D0oooo000`0?ooo`8000009@3oool20000
02h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U0?ooo`00<03oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0U0?ooo`00<03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0U0?ooo`00<03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09`3oool2000002l0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02D0oooo000`
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0]
0?ooo`8000009P3oool00300oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0903oool00300oooo00<000000?ooo`3o
ool08`3oool200000300oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`00
<03oool2000002@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo02@0oooo000`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000`0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02@0oooo000`0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0T0?ooo`800000<@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02l0oooo0P00000U0?ooo`00<03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`00<03oool00`000000oooo
0?ooo`0R0?ooo`800000<P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02<0oooo
000`0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo02<0oooo000`0?ooo`8000008`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool00300oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool08`3oool00300oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0280oooo0P00000c0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0<@3oool2000002@0oooo000`0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0280oooo000`0?ooo`030000003o
ool0oooo0240oooo0P00000d0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08P3o
ool00300oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool08P3oool00300oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool08P3oool00300
oooo0P00000R0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0<`3oool2000002<0
oooo000`0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0P0?ooo`800000=@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo
0P00000S0?ooo`00<03oool00`000000oooo0?ooo`0P0?ooo`800000=P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0240oooo000D0?ooo`@000001@3oool4000000D0oooo10000006
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0240oooo000C0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo0240oooo000H0?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo03D0oooo0P00000Q0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo
000H0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0=@3oool200000280oooo000H0?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool30000
01l0oooo0P00000h0?ooo`030000003oool0oooo01h0oooo0P00000h0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`00503oool4000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00`3oool200000200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0200oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool20000
0200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0200oooo000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool200000200oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo000D0?ooo`D0
0000103oool4000000D0oooo100000060?ooo`800000803oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`000000
7`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01d0oooo0P00000i0?ooo`800000
7P3oool00`000000oooo0?ooo`0h0?ooo`8000008@3oool00300oooo00<000000?ooo`0000007P3o
ool2000003T0oooo0P00000N0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo000`0?ooo`<000007P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool07`3oool0
0300oooo00<000000?ooo`0000007P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`0000007P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool07`3oool00300oooo
00@000000?ooo`3oool000007@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01/0
oooo0P00000k0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>@3oool200000200
oooo000`0?ooo`040000003oool0oooo000001`0oooo0P00000k0?ooo`800000703oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>P3oool200000200
oooo000`0?ooo`040000003oool0oooo000001`0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01h0oooo000`0?ooo`040000003oool0oooo000001`0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01h0
oooo000`0?ooo`80000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool00300oooo00D000000?ooo`3oool0oooo
0000000K0?ooo`030000003oool0oooo03/0oooo0P00000J0?ooo`800000?@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool07P3oool00300oooo00D0
00000?ooo`3oool0oooo0000000J0?ooo`800000?P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo03`0oooo0P00000J0?ooo`030000003oool0oooo03`0oooo0P00000O0?ooo`00<03o
ool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo01d0oooo000`0?ooo`050000003oool0oooo0?ooo`000000
6P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
7@3oool00300oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo03d0oooo
0P00000I0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo01d0oooo000`0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01H0oooo0P00
000o0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0M0?ooo`00<03oool2000000<0oooo00<000000?ooo`3oool05P3oool200000400oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0n0?ooo`800000603oool00`000000oooo0?ooo`0n
0?ooo`8000007P3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0L0?oo
o`00<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0?`3oool2000001L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0703oool00300oooo00<000000?ooo`3oool0
0P3oool2000001L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo01`0oooo000`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool200000480oooo00<000000?ooo`3oool0503oool200000440oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0o0?ooo`8000007@3oool00300oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`100?ooo`8000005`3oool00`000000oooo0?ooo`0o0?ooo`8000007@3oool0
0300oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0440oooo0P00000E0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo01/0oooo000`0?ooo`800000103oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0K0?ooo`00<03oool00`000000oooo0?ooo`030?ooo`8000005@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0180oooo0P0000130?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0@@3oool2000001`0oooo000`0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0@P3oool2000001D0oooo00<000000?ooo`3oool0@@3oool2000001`0oooo000`
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool06P3oool000X0oooo1`0000030?oo
o`@000001@3oool4000000D0oooo100000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool06P3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`8000004`3oool00`000000oooo0?ooo`13
0?ooo`8000004P3oool2000004D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`13
0?ooo`8000006`3oool000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo0P00
000C0?ooo`030000003oool0oooo04<0oooo0P00000K0?ooo`003@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`<000001@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0I0?ooo`003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06@3oool000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`800000403oool2000004L0oooo0P00000@0?ooo`800000A`3oool20000
0140oooo00<000000?ooo`3oool0A@3oool2000001X0oooo000=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool2
000001X0oooo000;0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01P0oooo000=0?ooo`030000003oool0
oooo00@0oooo100000050?ooo`@000001@3oool4000000H0oooo00<000000?ooo`3oool01P3oool2
000000l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo04L0oooo0P00000?0?ooo`030000003oool0oooo04L0oooo0P00000I0?ooo`00<03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo0P00001:0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0<0?ooo`800000B@3oool20000
01T0oooo000`0?ooo`800000203oool2000000d0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo01L0oooo000`0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool2000004/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00X0oooo0P00001;0?ooo`030000003oool0oooo01L0oooo
000`0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo04X0oooo0P00000H0?ooo`00<03oool00`000000oooo0?ooo`08
0?ooo`8000002P3oool2000004d0oooo00<000000?ooo`3oool02@3oool2000004d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01H0oooo000`0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?oo
o`8000002P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00T0oooo0P00001=0?oo
o`030000003oool0oooo01H0oooo000`0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04`0oooo0P00000G0?ooo`00
<03oool00`000000oooo0?ooo`090?ooo`800000203oool2000004l0oooo0P0000080?ooo`800000
C`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
5@3oool00300oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1>0?ooo`800000203o
ool00`000000oooo0?ooo`1>0?ooo`8000005P3oool00300oooo0P00000<0?ooo`030000003oool0
oooo00@0oooo0P00001B0?ooo`030000003oool0oooo00@0oooo0P00001A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0D0?ooo`00<03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo01<0oooo000`0?ooo`030000003oool0oooo00`0
oooo0P0000020?ooo`800000E@3oool200000080oooo0P00001E0?ooo`030000003oool0oooo0080
oooo0P00001C0?ooo`800000503oool00300oooo00<000000?ooo`3oool03@3oool4000005L0oooo
1000001G0?ooo`D00000E@3oool2000001<0oooo000`0?ooo`030000003oool0oooo06T0oooo0P00
001H0?ooo`@00000E`3oool200000180oooo000`0?ooo`030000003oool0oooo0?l0oooo<`3oool0
0300oooo00<000000?ooo`3oool0o`3ooolc0?ooo`00<03oool200000?l0oooo=03oool00300oooo
00<000000?ooo`3oool0o`3ooolc0?ooo`00<03oool00`000000oooo0?ooo`3o0?oooc<0oooo003o
0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o
0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o
0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo0000
\
\>"],
  ImageRangeCache->{{{72.9375, 262.563}, {394.75, 278}} -> {993.574, 5833.77, \
0.0519473, 21.2483}}],

Cell[TextData[{
  "Remark: Experiment with small and big values of t, time. Some times only \
one graph is appearing. Analyse the reason. (Solution of the homogeneous \
equation are ",
  StyleBox["periodic",
    CellMargins->{{18, 1}, {Inherited, Inherited}},
    Evaluatable->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    AspectRatioFixed->True],
  ") and for some values of the constant only steady-state response are \
represented.\n"
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Critical damping", "Subsubsection",
  FontSize->18,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(If[n\^2 - 4\ k\ m == 0, Print["\<Critical damping\>"], 
      Print["\< Another case\>"]]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(" Another case"\)], "Print"],

Cell["\<\
If the answer is Critical damping we solve the equation with null initial \
conditions.\
\>", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"solecua", "=", 
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{"ecua", ",", \(x[0] == 0\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
            "}"}], ",", \(x[t]\), ",", "t"}], "]"}]}]], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["Easier form", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solpar[t_] = 
      Simplify[x[t] /. solecua\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], 
  "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["General solution:", "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(solfin[t_, c1_, c2_] = solgenh[t, c1, c2] + solpar[t]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We graph some solutions. In this case for f[t] = Fsin[wt] the \
solutions decay exponentially for every values of c1 and c2 but with change \
of sign, due to sine and cosine functions. in the resonance phenomenon the \
solutions are going to infinity, due to solution tsin[wt]. Also have to be \
careful with the values of constants c1 and c2 and the chosen interval for \
independent variable.\nA bad election implies a bad understanding of the \
graph. ",
    Background->RGBColor[0, 1, 0]],
  StyleBox["Please check in all the cases with several values of constants \
and several intervals, for small and big values of time.",
    FontColor->RGBColor[1, 0, 0],
    Background->RGBColor[0, 1, 0]]
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(grafic = 
      Table[solfin[t, c1, c2], {c1, \(-3\), 3, 3}, {c2, \(-3\), 3, 
          3}]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(Plot[Evaluate[grafic], {t, 0, 3}]\)], "Input",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark: Experiment with small and big values of time. Some times \
only one graph is appearing. Analyse the reason. (Solution of homogeneous \
equation are periodic) and for some values of the constant only steady-state \
response is represented.",
    Background->RGBColor[0, 1, 0]],
  "\n"
}], "Text",
  CellMargins->{{18, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1011, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{48.3125, 48.3125}, {66.3125, \
66.3125}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 143, 4, 158, "Title"],
Cell[1900, 57, 122, 3, 99, "Subsection"],
Cell[2025, 62, 1216, 28, 151, "Text",
  Evaluatable->False],
Cell[3244, 92, 264, 6, 68, "Input"],
Cell[3511, 100, 42, 1, 35, "Print"],
Cell[3556, 103, 463, 12, 47, "Text",
  Evaluatable->False],
Cell[4022, 117, 270, 6, 68, "Input"],
Cell[4295, 125, 34, 1, 35, "Print"],
Cell[4332, 128, 53, 1, 35, "Print"],
Cell[4388, 131, 654, 18, 47, "Text",
  Evaluatable->False],
Cell[5045, 151, 248, 5, 76, "Input"],
Cell[5296, 158, 44, 1, 35, "Print"],
Cell[5343, 161, 453, 12, 47, "Text",
  Evaluatable->False],
Cell[5799, 175, 221, 5, 68, "Input"],
Cell[6023, 182, 34, 1, 35, "Print"],
Cell[6060, 185, 609, 15, 42, "Input"],
Cell[6672, 202, 233, 6, 41, "Output"],
Cell[6908, 210, 120, 3, 99, "Subsection"],
Cell[7031, 215, 419, 10, 73, "Text",
  Evaluatable->False],
Cell[7453, 227, 94, 2, 51, "Subsubsection"],
Cell[7550, 231, 264, 5, 43, "Input"],
Cell[7817, 238, 48, 1, 35, "Print"],
Cell[7868, 241, 316, 7, 47, "Text",
  Evaluatable->False],
Cell[8187, 250, 213, 4, 43, "Input"],
Cell[8403, 256, 363, 7, 42, "Input"],
Cell[8769, 265, 206, 4, 47, "Text",
  Evaluatable->False],
Cell[8978, 271, 93, 2, 51, "Subsubsection"],
Cell[9074, 275, 263, 5, 43, "Input"],
Cell[9340, 282, 55, 1, 35, "Print"],
Cell[9398, 285, 579, 15, 84, "Text",
  Evaluatable->False],
Cell[9980, 302, 213, 4, 43, "Input"],
Cell[10196, 308, 104, 2, 41, "Output"],
Cell[10303, 312, 190, 4, 47, "Text",
  Evaluatable->False],
Cell[10496, 318, 229, 4, 42, "Input"],
Cell[10728, 324, 50, 1, 41, "Output"],
Cell[10781, 327, 228, 4, 42, "Input"],
Cell[11012, 333, 55, 1, 41, "Output"],
Cell[11070, 336, 293, 7, 47, "Text",
  Evaluatable->False],
Cell[11366, 345, 256, 5, 42, "Input"],
Cell[11625, 352, 52, 1, 35, "Print"],
Cell[11680, 355, 205, 4, 47, "Text",
  Evaluatable->False],
Cell[11888, 361, 262, 5, 42, "Input"],
Cell[12153, 368, 60, 1, 35, "Print"],
Cell[12216, 371, 197, 4, 47, "Text",
  Evaluatable->False],
Cell[12416, 377, 290, 6, 68, "Input"],
Cell[12709, 385, 63, 1, 41, "Output"],
Cell[12775, 388, 206, 4, 47, "Text",
  Evaluatable->False],
Cell[12984, 394, 89, 2, 51, "Subsubsection"],
Cell[13076, 398, 260, 5, 43, "Input"],
Cell[13339, 405, 48, 1, 35, "Print"],
Cell[13390, 408, 323, 7, 73, "Text",
  Evaluatable->False],
Cell[13716, 417, 213, 4, 43, "Input"],
Cell[13932, 423, 229, 4, 42, "Input"],
Cell[14164, 429, 228, 4, 42, "Input"],
Cell[14395, 435, 240, 5, 42, "Input"],
Cell[14638, 442, 117, 3, 99, "Subsection"],
Cell[14758, 447, 959, 23, 99, "Text",
  Evaluatable->False],
Cell[15720, 472, 94, 2, 51, "Subsubsection"],
Cell[15817, 476, 264, 5, 43, "Input"],
Cell[16084, 483, 48, 1, 35, "Print"],
Cell[16135, 486, 276, 7, 47, "Text",
  Evaluatable->False],
Cell[16414, 495, 547, 13, 42, "Input"],
Cell[16964, 510, 188, 4, 47, "Text",
  Evaluatable->False],
Cell[17155, 516, 261, 6, 42, "Input"],
Cell[17419, 524, 208, 4, 47, "Text",
  Evaluatable->False],
Cell[17630, 530, 224, 4, 42, "Input"],
Cell[17857, 536, 297, 7, 47, "Text",
  Evaluatable->False],
Cell[18157, 545, 262, 6, 42, "Input"],
Cell[18422, 553, 1065, 27, 73, "Text",
  Evaluatable->False],
Cell[19490, 582, 204, 4, 42, "Input"],
Cell[19697, 588, 600, 13, 73, "Text",
  Evaluatable->False],
Cell[20300, 603, 93, 2, 51, "Subsubsection"],
Cell[20396, 607, 263, 5, 43, "Input"],
Cell[20662, 614, 55, 1, 35, "Print"],
Cell[20720, 617, 275, 7, 47, "Text",
  Evaluatable->False],
Cell[20998, 626, 547, 13, 42, "Input"],
Cell[21548, 641, 176, 3, 57, "Output"],
Cell[21727, 646, 188, 4, 47, "Text",
  Evaluatable->False],
Cell[21918, 652, 269, 6, 42, "Input"],
Cell[22190, 660, 84, 1, 57, "Output"],
Cell[22277, 663, 208, 4, 47, "Text",
  Evaluatable->False],
Cell[22488, 669, 224, 4, 42, "Input"],
Cell[22715, 675, 114, 2, 57, "Output"],
Cell[22832, 679, 699, 15, 99, "Text",
  Evaluatable->False],
Cell[23534, 696, 262, 6, 42, "Input"],
Cell[23799, 704, 1234, 32, 125, "Text",
  Evaluatable->False],
Cell[25036, 738, 250, 5, 42, "Input"],
Cell[25289, 745, 83248, 2649, 180, 30864, 1998, "GraphicsData", "PostScript", \
"Graphics"],
Cell[108540, 3396, 57081, 2328, 198, 30878, 2000, "GraphicsData", \
"PostScript", "Graphics"],
Cell[165624, 5726, 215, 4, 42, "Input"],
Cell[165842, 5732, 74438, 2525, 233, 30607, 1979, "GraphicsData", \
"PostScript", "Graphics"],
Cell[240283, 8259, 638, 15, 99, "Text",
  Evaluatable->False],
Cell[240924, 8276, 89, 2, 51, "Subsubsection"],
Cell[241016, 8280, 260, 5, 43, "Input"],
Cell[241279, 8287, 48, 1, 35, "Print"],
Cell[241330, 8290, 271, 7, 47, "Text",
  Evaluatable->False],
Cell[241604, 8299, 547, 13, 42, "Input"],
Cell[242154, 8314, 187, 4, 47, "Text",
  Evaluatable->False],
Cell[242344, 8320, 261, 6, 42, "Input"],
Cell[242608, 8328, 193, 4, 47, "Text",
  Evaluatable->False],
Cell[242804, 8334, 224, 4, 42, "Input"],
Cell[243031, 8340, 898, 17, 151, "Text",
  Evaluatable->False],
Cell[243932, 8359, 262, 6, 42, "Input"],
Cell[244197, 8367, 204, 4, 42, "Input"],
Cell[244404, 8373, 491, 11, 99, "Text",
  Evaluatable->False]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

