(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    385922,       9859]*)
(*NotebookOutlinePosition[    386709,       9886]*)
(*  CellTagsIndexPosition[    386665,       9882]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["EXAMPLE 5",
  FontSize->46,
  FontColor->RGBColor[1, 0, 0]]], "Title",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0],

Cell["Conservative systems", "Subsection",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  FontSize->24,
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "For ",
  StyleBox["special conservative systems",
    FontColor->RGBColor[1, 0, 0]],
  " like the following x'= y, y\.b4= f(x) we can draw the orbits or \
trajectories only using the total energy  ",
  StyleBox["E=  ",
    Background->RGBColor[1, 1, 0]],
  Cell[BoxData[
      \(y\^2\/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x\)],
    Background->RGBColor[1, 1, 0]],
  StyleBox[". ",
    Background->RGBColor[1, 1, 0]],
  "These systems can represent different technical and physical situations \
and we describe some examples."
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["A spring, with non elastic component",
  FontSize->24,
  FontColor->RGBColor[0, 0, 1]]], "Title",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "We assume that the associated ODE is  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "+", "kx", "+", \(ax\^3\)}], "=", 
        "0"}]]],
  ", which it is equivalent to  ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "=", \(\(-kx\) - ax\^3\)}]]],
  ". (The term ",
  Cell[BoxData[
      \(ax\^3\)]],
  " is the non linear component). The behaviour is completely different in \
the cases: ",
  StyleBox["a <0, heavy spring. ",
    FontColor->RGBColor[0, 0, 1]],
  "and ",
  StyleBox["a>0,  soft spring",
    FontColor->RGBColor[0, 0, 1]],
  " .\nWe analyse both of them. We need the package:"
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(<< Graphics`ImplicitPlot`\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["a<0. Heavy spring.",
    Background->RGBColor[1, 1, 0]],
  "\nWe suppose m=1, being m the mass of the spring. We draw several \
trajectories."
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "We assume the ODE associated is ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "+", "kx", "+", \(ax\^3\)}], "=", 
        "0"}]]],
  ", with a < 0."
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Suppose f(x) = ",
  Cell[BoxData[
      \(\(\(\ \)\(\(-2\)\ x - 8\ x\^3\)\)\)]]
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(Clear[x, t, f]\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(f[x_] := \(-2\)\ x - 8\ x\^3\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell["\<\
We plot the graphs for different trajectories, using the Table command.\
\>", "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(ImplicitPlot[
        Table[y^2/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x \[Equal] 
            c, {c, 1, 126, 25}], {x, \(-3\), 3}];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.72405 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.171705 2.86203 0.171705 [
[.15659 2.84953 -6 -9 ]
[.15659 2.84953 6 0 ]
[.32829 2.84953 -6 -9 ]
[.32829 2.84953 6 0 ]
[.67171 2.84953 -3 -9 ]
[.67171 2.84953 3 0 ]
[.84341 2.84953 -3 -9 ]
[.84341 2.84953 3 0 ]
[.4875 .28644 -18 -4.5 ]
[.4875 .28644 0 4.5 ]
[.4875 1.14497 -18 -4.5 ]
[.4875 1.14497 0 4.5 ]
[.4875 2.0035 -12 -4.5 ]
[.4875 2.0035 0 4.5 ]
[.4875 3.72055 -6 -4.5 ]
[.4875 3.72055 0 4.5 ]
[.4875 4.57908 -12 -4.5 ]
[.4875 4.57908 0 4.5 ]
[.4875 5.43761 -12 -4.5 ]
[.4875 5.43761 0 4.5 ]
[ 0 0 0 0 ]
[ 1 5.72405 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15659 2.86203 m
.15659 2.86828 L
s
[(-2)] .15659 2.84953 0 1 Mshowa
.32829 2.86203 m
.32829 2.86828 L
s
[(-1)] .32829 2.84953 0 1 Mshowa
.67171 2.86203 m
.67171 2.86828 L
s
[(1)] .67171 2.84953 0 1 Mshowa
.84341 2.86203 m
.84341 2.86828 L
s
[(2)] .84341 2.84953 0 1 Mshowa
.125 Mabswid
.19093 2.86203 m
.19093 2.86578 L
s
.22527 2.86203 m
.22527 2.86578 L
s
.25961 2.86203 m
.25961 2.86578 L
s
.29395 2.86203 m
.29395 2.86578 L
s
.36264 2.86203 m
.36264 2.86578 L
s
.39698 2.86203 m
.39698 2.86578 L
s
.43132 2.86203 m
.43132 2.86578 L
s
.46566 2.86203 m
.46566 2.86578 L
s
.53434 2.86203 m
.53434 2.86578 L
s
.56868 2.86203 m
.56868 2.86578 L
s
.60302 2.86203 m
.60302 2.86578 L
s
.63736 2.86203 m
.63736 2.86578 L
s
.70605 2.86203 m
.70605 2.86578 L
s
.74039 2.86203 m
.74039 2.86578 L
s
.77473 2.86203 m
.77473 2.86578 L
s
.80907 2.86203 m
.80907 2.86578 L
s
.12225 2.86203 m
.12225 2.86578 L
s
.08791 2.86203 m
.08791 2.86578 L
s
.05357 2.86203 m
.05357 2.86578 L
s
.01922 2.86203 m
.01922 2.86578 L
s
.87775 2.86203 m
.87775 2.86578 L
s
.91209 2.86203 m
.91209 2.86578 L
s
.94643 2.86203 m
.94643 2.86578 L
s
.98078 2.86203 m
.98078 2.86578 L
s
.25 Mabswid
0 2.86203 m
1 2.86203 L
s
.5 .28644 m
.50625 .28644 L
s
[(-15)] .4875 .28644 1 0 Mshowa
.5 1.14497 m
.50625 1.14497 L
s
[(-10)] .4875 1.14497 1 0 Mshowa
.5 2.0035 m
.50625 2.0035 L
s
[(-5)] .4875 2.0035 1 0 Mshowa
.5 3.72055 m
.50625 3.72055 L
s
[(5)] .4875 3.72055 1 0 Mshowa
.5 4.57908 m
.50625 4.57908 L
s
[(10)] .4875 4.57908 1 0 Mshowa
.5 5.43761 m
.50625 5.43761 L
s
[(15)] .4875 5.43761 1 0 Mshowa
.125 Mabswid
.5 .45815 m
.50375 .45815 L
s
.5 .62986 m
.50375 .62986 L
s
.5 .80156 m
.50375 .80156 L
s
.5 .97327 m
.50375 .97327 L
s
.5 1.31668 m
.50375 1.31668 L
s
.5 1.48838 m
.50375 1.48838 L
s
.5 1.66009 m
.50375 1.66009 L
s
.5 1.83179 m
.50375 1.83179 L
s
.5 2.1752 m
.50375 2.1752 L
s
.5 2.34691 m
.50375 2.34691 L
s
.5 2.51861 m
.50375 2.51861 L
s
.5 2.69032 m
.50375 2.69032 L
s
.5 3.03373 m
.50375 3.03373 L
s
.5 3.20544 m
.50375 3.20544 L
s
.5 3.37714 m
.50375 3.37714 L
s
.5 3.54885 m
.50375 3.54885 L
s
.5 3.89226 m
.50375 3.89226 L
s
.5 4.06396 m
.50375 4.06396 L
s
.5 4.23567 m
.50375 4.23567 L
s
.5 4.40737 m
.50375 4.40737 L
s
.5 4.75078 m
.50375 4.75078 L
s
.5 4.92249 m
.50375 4.92249 L
s
.5 5.0942 m
.50375 5.0942 L
s
.5 5.2659 m
.50375 5.2659 L
s
.5 .11474 m
.50375 .11474 L
s
.5 5.60931 m
.50375 5.60931 L
s
.25 Mabswid
.5 0 m
.5 5.72405 L
s
0 0 m
1 0 L
1 5.72405 L
0 5.72405 L
closepath
clip
newpath
.5 Mabswid
.37859 2.8619 m
.379 2.83749 L
.38024 2.8133 L
.3823 2.78975 L
.38516 2.76717 L
.38881 2.74582 L
.39322 2.72593 L
.39836 2.70768 L
.40419 2.69123 L
.41067 2.67664 L
.41777 2.66394 L
.42543 2.65311 L
.43359 2.64406 L
.44221 2.63669 L
.45123 2.63085 L
.46058 2.62638 L
.47019 2.62311 L
.48002 2.62089 L
.48997 2.61961 L
.5 2.6192 L
.51003 2.61961 L
.51998 2.62089 L
.52981 2.62311 L
.53942 2.62638 L
.54877 2.63085 L
.55779 2.63669 L
.56641 2.64406 L
.57457 2.65311 L
.58223 2.66394 L
.58933 2.67664 L
.59581 2.69123 L
.60164 2.70768 L
.60678 2.72593 L
.61119 2.74582 L
.61484 2.76717 L
.6177 2.78975 L
.61976 2.8133 L
.621 2.83749 L
.62141 2.8619 L
s
.37859 2.86215 m
.379 2.88656 L
.38024 2.91076 L
.3823 2.9343 L
.38516 2.95688 L
.38881 2.97823 L
.39322 2.99812 L
.39836 3.01637 L
.40419 3.03282 L
.41067 3.04741 L
.41777 3.06011 L
.42543 3.07094 L
.43359 3.07999 L
.44221 3.08736 L
.45123 3.0932 L
.46058 3.09767 L
.47019 3.10094 L
.48002 3.10316 L
.48997 3.10444 L
.5 3.10485 L
.51003 3.10444 L
.51998 3.10316 L
.52981 3.10094 L
.53942 3.09767 L
.54877 3.0932 L
.55779 3.08736 L
.56641 3.07999 L
.57457 3.07094 L
.58223 3.06011 L
.58933 3.04741 L
.59581 3.03282 L
.60164 3.01637 L
.60678 2.99812 L
.61119 2.97823 L
.61484 2.95688 L
.6177 2.9343 L
.61976 2.91076 L
.621 2.88656 L
.62141 2.86215 L
s
.18506 2.86159 m
.18614 2.7224 L
.18936 2.58505 L
.1947 2.45218 L
.20213 2.32582 L
.21159 2.20781 L
.22302 2.09969 L
.23634 2.00268 L
.25147 1.9176 L
.26829 1.84484 L
.2867 1.78441 L
.30656 1.73584 L
.32775 1.69828 L
.35011 1.67052 L
.37349 1.6511 L
.39774 1.63836 L
.42269 1.63064 L
.44816 1.62641 L
.47399 1.62441 L
.5 1.62384 L
.52601 1.62441 L
.55184 1.62641 L
.57731 1.63064 L
.60226 1.63836 L
.62651 1.6511 L
.64989 1.67052 L
.67225 1.69828 L
.69344 1.73584 L
.7133 1.78441 L
.73171 1.84484 L
.74853 1.9176 L
.76366 2.00268 L
.77698 2.09969 L
.78841 2.20781 L
.79787 2.32582 L
.8053 2.45218 L
.81064 2.58505 L
.81386 2.7224 L
.81494 2.86159 L
s
.18506 2.86246 m
.18614 3.00165 L
.18936 3.139 L
.1947 3.27188 L
.20213 3.39823 L
.21159 3.51624 L
.22302 3.62436 L
.23634 3.72137 L
.25147 3.80646 L
.26829 3.87921 L
.2867 3.93964 L
.30656 3.98821 L
.32775 4.02577 L
.35011 4.05353 L
.37349 4.07295 L
.39774 4.08569 L
.42269 4.09341 L
.44816 4.09764 L
.47399 4.09964 L
.5 4.10021 L
.52601 4.09964 L
.55184 4.09764 L
.57731 4.09341 L
.60226 4.08569 L
.62651 4.07295 L
.64989 4.05353 L
.67225 4.02577 L
.69344 3.98821 L
.7133 3.93964 L
.73171 3.87921 L
.74853 3.80646 L
.76366 3.72137 L
.77698 3.62436 L
.78841 3.51624 L
.79787 3.39823 L
.8053 3.27188 L
.81064 3.139 L
.81386 3.00165 L
.81494 2.86246 L
s
.12358 2.86147 m
.12487 2.66465 L
.12871 2.47054 L
.1351 2.28282 L
.14398 2.10443 L
.15528 1.93799 L
.16895 1.7857 L
.18487 1.6493 L
.20295 1.52995 L
.22306 1.42823 L
.24506 1.3441 L
.2688 1.27689 L
.29412 1.22535 L
.32084 1.18773 L
.34879 1.16185 L
.37778 1.14532 L
.40759 1.13568 L
.43804 1.13068 L
.46892 1.12848 L
.5 1.12789 L
.53108 1.12848 L
.56196 1.13068 L
.59241 1.13568 L
.62222 1.14532 L
.65121 1.16185 L
.67916 1.18773 L
.70588 1.22535 L
.7312 1.27689 L
.75494 1.3441 L
.77694 1.42823 L
.79705 1.52995 L
.81513 1.6493 L
.83105 1.7857 L
.84472 1.93799 L
.85602 2.10443 L
.8649 2.28282 L
.87129 2.47054 L
.87513 2.66465 L
.87642 2.86147 L
s
.12358 2.86259 m
.12487 3.0594 L
.12871 3.25352 L
.1351 3.44123 L
.14398 3.61962 L
.15528 3.78606 L
.16895 3.93835 L
.18487 4.07475 L
.20295 4.1941 L
.22306 4.29582 L
.24506 4.37995 L
.2688 4.44716 L
.29412 4.4987 L
.32084 4.53632 L
.34879 4.5622 L
.37778 4.57873 L
.40759 4.58837 L
.43804 4.59337 L
.46892 4.59557 L
.5 4.59617 L
.53108 4.59557 L
.56196 4.59337 L
.59241 4.58837 L
.62222 4.57873 L
.65121 4.5622 L
.67916 4.53632 L
.70588 4.4987 L
.7312 4.44716 L
.75494 4.37995 L
.77694 4.29582 L
.79705 4.1941 L
.81513 4.07475 L
.83105 3.93835 L
.84472 3.78606 L
.85602 3.61962 L
.8649 3.44123 L
.87129 3.25352 L
.87513 3.0594 L
.87642 2.86259 L
s
.08224 2.86137 m
.08367 2.62006 L
.08794 2.3821 L
.09502 2.15204 L
.10488 1.93347 L
.11743 1.72963 L
.13259 1.54325 L
.15027 1.37643 L
.17033 1.23063 L
.19264 1.10655 L
.21706 1.00413 L
.24341 .92255 L
.27151 .86024 L
.30117 .81501 L
.33219 .78418 L
.36435 .76473 L
.39745 .75363 L
.43124 .74805 L
.4655 .74571 L
.5 .7451 L
.5345 .74571 L
.56876 .74805 L
.60255 .75363 L
.63565 .76473 L
.66781 .78418 L
.69883 .81501 L
.72849 .86024 L
.75659 .92255 L
.78294 1.00413 L
.80736 1.10655 L
.82967 1.23063 L
.84973 1.37643 L
.86741 1.54325 L
.88257 1.72963 L
.89512 1.93347 L
.90498 2.15204 L
.91206 2.3821 L
.91633 2.62006 L
.91776 2.86137 L
s
.08224 2.86268 m
.08367 3.10399 L
.08794 3.34195 L
.09502 3.57201 L
.10488 3.79058 L
.11743 3.99442 L
.13259 4.18081 L
.15027 4.34762 L
.17033 4.49342 L
.19264 4.6175 L
.21706 4.71992 L
.24341 4.8015 L
.27151 4.86381 L
.30117 4.90904 L
.33219 4.93988 L
.36435 4.95932 L
.39745 4.97042 L
.43124 4.976 L
.4655 4.97834 L
.5 4.97895 L
.5345 4.97834 L
.56876 4.976 L
.60255 4.97042 L
.63565 4.95932 L
.66781 4.93988 L
.69883 4.90904 L
.72849 4.86381 L
.75659 4.8015 L
.78294 4.71992 L
.80736 4.6175 L
.82967 4.49342 L
.84973 4.34762 L
.86741 4.18081 L
.88257 3.99442 L
.89512 3.79058 L
.90498 3.57201 L
.91206 3.34195 L
.91633 3.10399 L
.91776 2.86268 L
s
.05025 2.8613 m
.05179 2.58237 L
.05639 2.30736 L
.06401 2.0415 L
.07462 1.78898 L
.08813 1.55353 L
.10446 1.33832 L
.12349 1.1458 L
.14509 .97765 L
.16911 .83468 L
.19539 .71681 L
.22376 .62308 L
.25401 .55167 L
.28594 .50003 L
.31934 .46501 L
.35397 .44311 L
.38959 .43078 L
.42597 .42472 L
.46286 .42225 L
.5 .42163 L
.53714 .42225 L
.57403 .42472 L
.61041 .43078 L
.64603 .44311 L
.68066 .46501 L
.71406 .50003 L
.74599 .55167 L
.77624 .62308 L
.80461 .71681 L
.83089 .83468 L
.85491 .97765 L
.87651 1.1458 L
.89554 1.33832 L
.91187 1.55353 L
.92538 1.78898 L
.93599 2.0415 L
.94361 2.30736 L
.94821 2.58237 L
.94975 2.8613 L
s
.05025 2.86275 m
.05179 3.14168 L
.05639 3.41669 L
.06401 3.68255 L
.07462 3.93507 L
.08813 4.17052 L
.10446 4.38573 L
.12349 4.57825 L
.14509 4.7464 L
.16911 4.88937 L
.19539 5.00724 L
.22376 5.10097 L
.25401 5.17238 L
.28594 5.22402 L
.31934 5.25905 L
.35397 5.28094 L
.38959 5.29328 L
.42597 5.29934 L
.46286 5.3018 L
.5 5.30242 L
.53714 5.3018 L
.57403 5.29934 L
.61041 5.29328 L
.64603 5.28094 L
.68066 5.25905 L
.71406 5.22402 L
.74599 5.17238 L
.77624 5.10097 L
.80461 5.00724 L
.83089 4.88937 L
.85491 4.7464 L
.87651 4.57825 L
.89554 4.38573 L
.91187 4.17052 L
.92538 3.93507 L
.93599 3.68255 L
.94361 3.41669 L
.94821 3.14168 L
.94975 2.86275 L
s
.02381 2.86124 m
.02544 2.54911 L
.0303 2.24142 L
.03838 1.94398 L
.04961 1.6615 L
.06392 1.39817 L
.0812 1.15753 L
.10135 .94233 L
.12422 .75446 L
.14966 .59482 L
.17748 .46333 L
.20752 .35889 L
.23955 .27945 L
.27336 .22215 L
.30872 .18344 L
.34538 .15938 L
.3831 .14596 L
.42162 .13948 L
.46068 .13691 L
.5 .13629 L
.53932 .13691 L
.57838 .13948 L
.6169 .14596 L
.65462 .15938 L
.69128 .18344 L
.72664 .22215 L
.76045 .27945 L
.79248 .35889 L
.82252 .46333 L
.85034 .59482 L
.87578 .75446 L
.89865 .94233 L
.9188 1.15753 L
.93608 1.39817 L
.95039 1.6615 L
.96162 1.94398 L
.9697 2.24142 L
.97456 2.54911 L
.97619 2.86124 L
s
.02381 2.86282 m
.02544 3.17494 L
.0303 3.48263 L
.03838 3.78007 L
.04961 4.06255 L
.06392 4.32588 L
.0812 4.56652 L
.10135 4.78172 L
.12422 4.96959 L
.14966 5.12923 L
.17748 5.26072 L
.20752 5.36516 L
.23955 5.4446 L
.27336 5.5019 L
.30872 5.54061 L
.34538 5.56467 L
.3831 5.57809 L
.42162 5.58457 L
.46068 5.58714 L
.5 5.58776 L
.53932 5.58714 L
.57838 5.58457 L
.6169 5.57809 L
.65462 5.56467 L
.69128 5.54061 L
.72664 5.5019 L
.76045 5.4446 L
.79248 5.36516 L
.82252 5.26072 L
.85034 5.12923 L
.87578 4.96959 L
.89865 4.78172 L
.9188 4.56652 L
.93608 4.32588 L
.95039 4.06255 L
.96162 3.78007 L
.9697 3.48263 L
.97456 3.17494 L
.97619 2.86282 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  ImageSize->{33.9375, 194.438},
  ImageMargins->{{225.5, 0}, {0, 14}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000130001Q2000`400?l00000o`00003o@`3oool0
04<0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3o
ool004<0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00
@`3oool004<0oooo00130?ooo`00903oool00`000000oooo0?ooo`0L0?ooo`00903oool00`000000
oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?oo
o`0L0?ooo`00903oool00`000000oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?ooo`0L0?oo
o`00903oool00`000000oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?ooo`0L0?ooo`008P3o
ool6000001/0oooo000M0?ooo`D000000P3oool010000000oooo0?ooo`3oool5000001H0oooo000K
0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`800000503oool001T0oooo0P0000090?oo
o`030000003oool0oooo00P0oooo0P00000B0?ooo`003`3oool700000080oooo00@000000?ooo`3o
ool0oooo100000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00180
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`004P3oool01@000000oooo0?ooo`3oool0000000X0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0=0?ooo`004P3oool01@000000oooo0?ooo`3oool0000000X0oooo
00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0=0?ooo`000P3oool8000000P0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02000000h0oooo00<000000?ooo`3o
ool0303oool00180oooo00@000000?ooo`3oool000001@3oool2000000<0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`030000003oool0oooo00`0oooo000B0?ooo`030000003oool0000000H0
oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02`3oool00180oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00180oooo0P0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`004P3oool2
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo000>0?ooo`<0000000<0oooo0000000000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00140oooo0P0000080?ooo`H0
00000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo000B0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`004P3o
ool00`000000oooo0?ooo`080?ooo`l000002`3oool00`000000oooo0?ooo`090?ooo`004@3oool0
0`000000oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`8000002P3oool0
0`000000oooo0?ooo`080?ooo`004@3oool00`000000oooo0?ooo`050?ooo`8000002@3oool00`00
0000oooo0?ooo`070?ooo`800000203oool00`000000oooo0?ooo`080?ooo`004@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo000@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool000l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo000000090?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000000T0oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
00l0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00l0oooo00D00000
0?ooo`3oool0oooo000000080?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000P0oooo000>
0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0@0?ooo`040000003o
ool0oooo000000P0oooo000>0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo000000P0oooo000>0?ooo`050000003oool0oooo0?ooo`00
00004@3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000001`3oool000h0
oooo00@000000?ooo`3oool000003P3oool9000000h0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`003P3oool010000000oooo0?ooo`00000:0?ooo`@00000103oool00`000000oooo0?ooo`02
0?ooo`@000002P3oool01@000000oooo0?ooo`3oool0000000L0oooo000>0?ooo`040000003oool0
oooo000000P0oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`040000003o
ool0oooo000000L0oooo000>0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
00001`3oool000d0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000070?oo
o`003@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo000=0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000001`3oool000d0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo000=0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000001P3oool000d0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000060?ooo`00303oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000H0oooo000<0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001P3oool000`0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00060?ooo`00303oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo000<
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001P3oool000`0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000060?ooo`00303oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000H0oooo000<0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001P3oool000`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00l0oooo00L000000?ooo`3oool0oooo0000003oool0000000H0
oooo000;0?ooo`030000003oool0oooo00P000001P3oool4000000@0oooo00<000000?ooo`3oool0
3`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool000/0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001@3oool000/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`002`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000B0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000050?ooo`002`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool8000000h0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000D0oooo00020?ooo`P0000000D0oooo0000003oool0oooo
000000020?ooo`8000001`3oool00`000000oooo0?ooo`0500000080oooo0P0000030?ooo`@00000
2P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool000/0oooo00@000000?ooo`3o
ool000000P3oool2000000L0oooo0`0000040?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool01`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool000/0oooo00@0
00000?ooo`3oool000000P3oool2000000L0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`002`3oool00`000000oooo000000030?ooo`8000001P3oool2000000H0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool00000
1@3oool000/0oooo00<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003o
ool0000000H0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`050?ooo`060000
003oool0oooo0000003oool000001@3oool000/0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`002`3oool00`000000oooo00000003000000030?ooo`000000oooo00<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool000/0oooo
00<000000?ooo`0000000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool4000000@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo000:0?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
103oool000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`060000003o
ool0oooo0000003oool00000103oool000X0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool00000103oool000X0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00@3oool000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00@3oool000X0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00@3oool000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000`3oool000X0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool000X0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0`3oool000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000`3oool000X0oooo0P0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo000000030?ooo`002P3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool01P000000oooo0?ooo`000000oooo000000<0oooo000:0?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool000X0oooo0P0000020?ooo`05
0000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000oooo
000000020?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool03`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool000T0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000oooo00000002
0?ooo`040000003oool0oooo000000h0oooo2P00000=0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000`3oool000T0oooo00D000000?ooo`000000oooo000000030?ooo`030000
003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`002@3oool01@00
0000oooo0000003oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`090000003oool0oooo0?ooo`000000oooo
0000003oool0000000<0oooo00090?ooo`050000003oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`070?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool000T0oooo00D00000
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000080oooo
0P0000030?ooo`002@3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000030?ooo`002@3oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000030?ooo`002@3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool010000000oooo0?ooo`0000020?ooo`8000000`3oool000T0oooo00D000000?oo
o`000000oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3o
ool2000000<0oooo00090?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo0P0000030?ooo`002@3oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`80
00000`3oool000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`00203oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00080?ooo`030000003oool0oooo008000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00080?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`09
0000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00080?ooo`030000003oool0
oooo008000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`080000003oool0oooo0000003oool00000
0?ooo`0000020?ooo`00203oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool020000000oooo0?ooo`000000oooo0000003oool000000P3oool000P0oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo00000080oooo00080?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo100000040?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool000P0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000003P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`00203oool01@00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`00203oool01@000000oooo0000
003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`8000000P3oool000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool200000080oooo00080?ooo`060000003oool0
00000?ooo`000000oooo2000000;0?ooo`030000003oool0oooo008000003P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`00203oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`80
00000`3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`8000000P3oool000P0oooo00D000000?ooo`000000oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo00000002
000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
00000080oooo0P0000020?ooo`00203oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P00
00020?ooo`00203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`00203o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`00203oool01@000000oooo
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`08
0000003oool0oooo0000003oool000000?ooo`0000010?ooo`00203oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`H000000`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00P000000?ooo`3oool00000
0?ooo`000000oooo00000040oooo00080?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`080000003oool0oooo0000003oool000000?ooo`0000010?ooo`00203o
ool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`000000oooo
0000003oool000000@3oool000P0oooo00D000000?ooo`000000oooo000000020?ooo`050000003o
ool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0000003oool000000040oooo00080?ooo`050000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03`3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000010?ooo`00203o
ool01`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool00000
0?ooo`0000000@3oool000P0oooo00L000000?ooo`000000oooo0000003oool0000000@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0000003oool000000040oooo00080?ooo`070000003oool000000?ooo`00
0000oooo000000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000010?ooo`00203oool0
1`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?oo
o`0000000@3oool000P0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0
00000140oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`000000oooo000000010?ooo`00203oool010000000oooo0000000000020?ooo`050000
003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0000003oool000000040oooo00080?ooo`040000003oool00000
00000080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00l0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000@3oool000P0oooo
00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000
00010?ooo`00203oool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`000000
4@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0000003oool000000040oooo00080?ooo`040000003oool0000000000080oooo00D000000?oo
o`3oool0oooo0000000A0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool000000?ooo`0000000@3oool000P0oooo00@000000?ooo`0000000000
0P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo000000010?ooo`00203oool01000
0000oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000040
oooo00080?ooo`040000003oool0000000000080oooo00D000000?ooo`3oool0oooo0000000A0?oo
o`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000010?ooo`00203oool010000000oooo0000000000020?ooo`050000003oool0oooo0?oo
o`0000004@3oool00`000000oooo0?ooo`0@0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000@3oool000P0oooo00@000000?ooo`00000000000P3oool01@000000
oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0403oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000040oooo00080?ooo`80000000D0oooo0000003oool0
oooo000000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo00080?ooo`80000000D0
oooo0000003oool0oooo000000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo0008
0?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000040oooo00080?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0403oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000040oooo00080?ooo`80000000D0oooo0000003oool0oooo000000030?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000040oooo00080?ooo`80000000D0oooo0000003oool0
oooo000000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool02`000000
oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo00080?ooo`80000000D0
oooo0000003oool0oooo000000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo0008
0?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
00000040oooo00080?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`P000000`3oool8
000000L0oooo1`0000020?ooo`T0000000@0oooo0000003oool000000@3oool000P0oooo0P000000
1@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0000000<0oooo0`000000103oool000000?ooo`0000010?ooo`00203oool2000000050?oo
o`000000oooo0?ooo`0000000`3oool2000000`0oooo00<000000?ooo`0000001@0000070?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`070000003oool000000?ooo`000000oooo00000001
0?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0000000;
0?ooo`8000000P3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool01@3oool0
2`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo00080?ooo`80
000000D0oooo0000003oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000002P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`8000000P3oool01`000000oooo0000003oool000000?ooo`0000000@3oool000H0oooo
2@0000000`3oool0000000000006000000L0oooo0P0000030?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`030000003oool0oooo00D0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`02000000060?ooo`000000oooo0000003oool000000@3oool000P0oooo
0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001`3oool010000000
oooo0?ooo`3oool3000000040?ooo`000000oooo00000040oooo00080?ooo`80000000D0oooo0000
003oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000003oool000000@3oool000P0oooo
0P0000001@3oool000000?ooo`3oool000000080oooo0P0000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000030?ooo`<0000000@0oooo0000003oool000000@3oool0
00P0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`000000103oool0
10000000oooo0?ooo`3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0103o
ool3000000030?ooo`000000oooo00D0oooo0P0000030?ooo`070000003oool000000?ooo`000000
oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`04000000D0oooo00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo008000001`3oool5000000060?ooo`000000oooo0000003oool000000@3o
ool000P0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo00080?oo
o`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool200000005
0?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000@3oool000P0oooo0P0000001@3oool00000
0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000040oooo00060?ooocd0000000080?ooo`80000000D0oooo
0000003oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00/000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`0;0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`0000000@3oool000P0oooo0P0000001@3oool000000?ooo`3oool00000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool000000040oooo00080?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000@3o
ool000P0oooo0P0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool000000040oooo00080?oo
o`80000000D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool200000005
0?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`0;0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`0000000@3oool000P0oooo0P0000001@3oool00000
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool02`000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000003oool000000040oooo00080?ooo`80000000D0oooo0000003oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00/000000?ooo`3oool0oooo0000003oool00000
0?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool2000000`0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo00000001
0?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`0;0000003o
ool0oooo0?ooo`000000oooo0000003oool000000?ooo`0000000@3oool000P0oooo0P0000001@3o
ool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool02`3oool200000080oooo00<00000
0?ooo`3oool00P00000>0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?oo
o`0000000@3oool000P0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?oo
o`3oool03@3oool6000000l0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool20000
00050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?oo
o`00203oool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/000000?ooo`3oool0
oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool2000000050?ooo`000000
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00/0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool20000
00050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo000000010?oo
o`00203oool2000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo000000010?ooo`00203oool010000000oooo0000000000020?ooo`050000003oool0oooo0?oo
o`0000004@3oool00`000000oooo0?ooo`0@0?ooo`0;0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`0000000@3oool000P0oooo00@000000?ooo`00000000000P3oool01@000000
oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0403oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool000000040oooo00080?ooo`040000003oool0000000000080
oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo0100oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo000000010?ooo`00203oool010000000oooo
0000000000020?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo00L000000?ooo`000000oooo0000003oool000000040oooo0008
0?ooo`040000003oool0000000000080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000
003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool000000?oo
o`0000000@3oool000P0oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0
00000140oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`000000oooo000000010?ooo`00203oool010000000oooo0000000000020?ooo`050000
003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0000003oool000000040oooo00080?ooo`040000003oool00000
00000080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00l0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool000000?ooo`0000000@3oool000P0oooo
00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?oo
o`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo0000
00010?ooo`00203oool010000000oooo0000000000020?ooo`050000003oool0oooo0?ooo`000000
4@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0000003oool000000040oooo00080?ooo`040000003oool0000000000080oooo00D000000?oo
o`3oool0oooo0000000A0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`050000003oool000000?ooo`0000000@3oool000P0oooo00L000000?ooo`000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool000000040oooo00080?oo
o`070000003oool000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000
oooo000000010?ooo`00203oool01`000000oooo0000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`050000003oool000000?ooo`0000000@3oool000P0oooo00L000000?ooo`000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool000000040oooo00080?ooo`05
0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`000000oooo
000000010?ooo`00203oool01@000000oooo0000003oool000000080oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool000000?ooo`0000000@3oool000P0oooo00D000000?ooo`000000oooo00000002
0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0080oooo00P000000?ooo`3oool000000?ooo`000000oooo00000040oooo00080?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`080000003oool0oooo
0000003oool000000?ooo`0000010?ooo`00203oool01@000000oooo0000003oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool020000000oooo0?ooo`000000oooo0000003oool000000@3oool0
00P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00P00000
0?ooo`3oool000000?ooo`000000oooo00000040oooo00080?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo100000040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo
008000000P3oool000P0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P00
00020?ooo`00203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
3`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0000003oool00P0000020?ooo`00
203oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000020?ooo`8000000P3oool000P0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000?
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool200000080oooo0008
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P00000>0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool200000080oooo00080?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo0P0000020?ooo`00203oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000800000103oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool2
00000080oooo00080?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool200000080oooo0008
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool200000080oooo00080?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool200000080oooo00080?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3oool0
00000?ooo`000000oooo00000080oooo00080?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo1P0000030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool020000000oooo0?ooo`000000oooo0000003oool00000
0P3oool000P0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00P0
00000?ooo`3oool000000?ooo`000000oooo00000080oooo00080?ooo`030000003oool0oooo0080
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`030?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool000000080oooo00080?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080oooo00080?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000P3oool000P0oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000020?ooo`002@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`8000000`3oool000T0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool20000
00<0oooo00090?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo00000080oooo0P0000030?ooo`002@3oool01@000000oooo0000003oool0
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`8000000`3o
ool000T0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo00090?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000<0
oooo00090?ooo`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool2000000<0oooo00090?ooo`050000003oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool2000000P0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0`3oool000T0oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
00T000000?ooo`3oool0oooo0000003oool000000?ooo`0000000`3oool000T0oooo00D000000?oo
o`000000oooo000000030?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0
oooo00<0oooo0`00000:0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0000000<0
oooo00090?ooo`030000003oool000000080oooo00@000000?ooo`3oool000003@3oool;000000d0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`002@3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0403oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00090?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000000`3oool000T0oooo00<000000?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`0000000`3oool000T0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool000T0oooo00<000000?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool000T0oooo00<000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool000X0oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`002P3oool200000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0000000<0oooo000:0?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool000X0oooo0P00
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`002P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000030?ooo`002P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000030?ooo`002P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`002P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00030?ooo`002P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`010?ooo`002P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`002P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool00000
0?ooo`0000040?ooo`002P3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000@0oooo000:0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000103o
ool000/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`002`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`002`3o
ool010000000oooo0000003oool700000080oooo00@000000?ooo`3oool0oooo100000040?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo000;0?ooo`030000003oool000000080oooo00<000000?ooo`00
00001@3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000002`3oool0
0`000000oooo0?ooo`050?ooo`060000003oool0oooo0000003oool000001@3oool000/0oooo00<0
00000?ooo`0000000`3oool2000000H0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool000001@3oool000/0
oooo00@000000?ooo`3oool000000P3oool2000000L0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?oo
o`0000050?ooo`002`3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool2000000D0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`070000003oool0oooo0?oo
o`000000oooo000000050?ooo`002`3oool010000000oooo0?ooo`0000020?ooo`8000001`3oool0
10000000oooo0000000000030?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?oo
o`080?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`002`3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo3P00000;0?oo
o`070000003oool0oooo0?ooo`000000oooo000000050?ooo`002`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`00000B0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`002`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000B0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`002`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00001@3oool000/0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`00303oool00`000000oooo000000020000
00030?ooo`000000000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000140oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo000<0?ooo`050000003o
ool0oooo0000003oool00`0000080?ooo`@00000103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000001P3oool000`0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000060?ooo`00303oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000H0oooo000<0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
1P3oool000`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`00303o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo000<0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool000`0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000060?ooo`00303oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000001P3oool000d0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`0000060?ooo`003@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000001P3oool000d0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`0000070?ooo`003@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
00L0oooo000=0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001`3oool0
00d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000L0oooo000>
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000001`3oool000h0oooo00@0
00000?ooo`3oool000002@3oool2000000L0oooo00<000000?ooo`3oool01@3oool2000000T0oooo
00D000000?ooo`3oool0oooo000000070?ooo`003P3oool010000000oooo0?ooo`00000;0?ooo`l0
00002`3oool01@000000oooo0?ooo`3oool0000000L0oooo000>0?ooo`050000003oool0oooo0?oo
o`0000004@3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000001`3oool0
00h0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo0100oooo00D00000
0?ooo`3oool0oooo000000070?ooo`003P3oool01@000000oooo0?ooo`3oool000000140oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`0000080?ooo`003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?oo
o`3oool0000000P0oooo000?0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo
0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000203oool000l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000T0oooo
000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000002@3oool000l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`00403oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo000@0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00140oooo00<000000?ooo`3oool0
1P3oool3000000L0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool0
203oool00180oooo00<000000?ooo`3oool0203oool4000000<0oooo00@000000?ooo`3oool0oooo
1@00000:0?ooo`030000003oool0oooo00T0oooo000B0?ooo`030000003oool0oooo00`0oooo1`00
000?0?ooo`030000003oool0oooo00T0oooo000B0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`004`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool000l0oooo1`0000060?ooo`@0
0000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo000B0?ooo`800000
1`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000
oooo0?ooo`0:0?ooo`004P3oool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0;0?ooo`004P3oool00`000000oooo
0000000<0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool02`3oool00180oooo
00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo
00`0oooo000B0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P00000>0?oo
o`030000003oool0oooo00`0oooo000B0?ooo`040000003oool0oooo000000D0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0?ooo`0=0?ooo`004P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00180oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>
0?ooo`004P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo000B0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00l0oooo000>0?ooo`<0000000<0oooo0000003oool01@3oool00`000000oooo000000080?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00140oooo0P0000070?ooo`L0
00000`3oool00`000000oooo0?ooo`060?ooo`<000004`3oool001`0oooo0`0000050?ooo`030000
003oool0oooo00@0oooo0P00000F0?ooo`007`3oool<000001P0oooo000T0?ooo`030000003oool0
oooo01`0oooo000T0?ooo`030000003oool0oooo01`0oooo000T0?ooo`030000003oool0oooo01`0
oooo000T0?ooo`030000003oool0oooo01`0oooo000T0?ooo`030000003oool0oooo01`0oooo000T
0?ooo`030000003oool0oooo01`0oooo000T0?ooo`030000003oool0oooo01`0oooo000T0?ooo`03
0000003oool0oooo01`0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0oooo
00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0
oooo00130?ooo`00@`3oool004<0oooo00130?ooo`00@`3oool004<0oooo0000\
\>"],
  ImageRangeCache->{{{233.5, 259.625}, {222.875, 68.375}} -> {-63.18, \
-2.25931, 0.203654, 0.203654}}],

Cell[TextData[StyleBox["Case a>0. Soft spring.",
  Background->RGBColor[1, 1, 0]]], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "We suppose the external force is f(x) = ",
  StyleBox["-4x+4x^3", "InlineFormula"]
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(f[x_] := \(-4\)\ x + 4\ x\^3\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell["\<\
We plot the graphs for some integral curves, corresponding to different \
values of energy E.\
\>", "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(s1 = 
        ImplicitPlot[
          Table[y\^2\/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x \[Equal] 
              c, {c,  .1,  .9,  .2}], {x, \(-1\), 1}];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.62248 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.575871 0.811242 0.575871 [
[.0681 .79874 -15 -9 ]
[.0681 .79874 15 0 ]
[.21206 .79874 -12 -9 ]
[.21206 .79874 12 0 ]
[.35603 .79874 -15 -9 ]
[.35603 .79874 15 0 ]
[.64397 .79874 -12 -9 ]
[.64397 .79874 12 0 ]
[.78794 .79874 -9 -9 ]
[.78794 .79874 9 0 ]
[.9319 .79874 -12 -9 ]
[.9319 .79874 12 0 ]
[.4875 .23537 -12 -4.5 ]
[.4875 .23537 0 4.5 ]
[.4875 .52331 -24 -4.5 ]
[.4875 .52331 0 4.5 ]
[.4875 1.09918 -18 -4.5 ]
[.4875 1.09918 0 4.5 ]
[.4875 1.38711 -6 -4.5 ]
[.4875 1.38711 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.62248 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0681 .81124 m
.0681 .81749 L
s
[(-0.75)] .0681 .79874 0 1 Mshowa
.21206 .81124 m
.21206 .81749 L
s
[(-0.5)] .21206 .79874 0 1 Mshowa
.35603 .81124 m
.35603 .81749 L
s
[(-0.25)] .35603 .79874 0 1 Mshowa
.64397 .81124 m
.64397 .81749 L
s
[(0.25)] .64397 .79874 0 1 Mshowa
.78794 .81124 m
.78794 .81749 L
s
[(0.5)] .78794 .79874 0 1 Mshowa
.9319 .81124 m
.9319 .81749 L
s
[(0.75)] .9319 .79874 0 1 Mshowa
.125 Mabswid
.09689 .81124 m
.09689 .81499 L
s
.12568 .81124 m
.12568 .81499 L
s
.15448 .81124 m
.15448 .81499 L
s
.18327 .81124 m
.18327 .81499 L
s
.24086 .81124 m
.24086 .81499 L
s
.26965 .81124 m
.26965 .81499 L
s
.29845 .81124 m
.29845 .81499 L
s
.32724 .81124 m
.32724 .81499 L
s
.38483 .81124 m
.38483 .81499 L
s
.41362 .81124 m
.41362 .81499 L
s
.44241 .81124 m
.44241 .81499 L
s
.47121 .81124 m
.47121 .81499 L
s
.52879 .81124 m
.52879 .81499 L
s
.55759 .81124 m
.55759 .81499 L
s
.58638 .81124 m
.58638 .81499 L
s
.61517 .81124 m
.61517 .81499 L
s
.67276 .81124 m
.67276 .81499 L
s
.70155 .81124 m
.70155 .81499 L
s
.73035 .81124 m
.73035 .81499 L
s
.75914 .81124 m
.75914 .81499 L
s
.81673 .81124 m
.81673 .81499 L
s
.84552 .81124 m
.84552 .81499 L
s
.87432 .81124 m
.87432 .81499 L
s
.90311 .81124 m
.90311 .81499 L
s
.0393 .81124 m
.0393 .81499 L
s
.01051 .81124 m
.01051 .81499 L
s
.9607 .81124 m
.9607 .81499 L
s
.98949 .81124 m
.98949 .81499 L
s
.25 Mabswid
0 .81124 m
1 .81124 L
s
.5 .23537 m
.50625 .23537 L
s
[(-1)] .4875 .23537 1 0 Mshowa
.5 .52331 m
.50625 .52331 L
s
[(-0.5)] .4875 .52331 1 0 Mshowa
.5 1.09918 m
.50625 1.09918 L
s
[(0.5)] .4875 1.09918 1 0 Mshowa
.5 1.38711 m
.50625 1.38711 L
s
[(1)] .4875 1.38711 1 0 Mshowa
.125 Mabswid
.5 .29296 m
.50375 .29296 L
s
.5 .35055 m
.50375 .35055 L
s
.5 .40813 m
.50375 .40813 L
s
.5 .46572 m
.50375 .46572 L
s
.5 .58089 m
.50375 .58089 L
s
.5 .63848 m
.50375 .63848 L
s
.5 .69607 m
.50375 .69607 L
s
.5 .75366 m
.50375 .75366 L
s
.5 .86883 m
.50375 .86883 L
s
.5 .92642 m
.50375 .92642 L
s
.5 .984 m
.50375 .984 L
s
.5 1.04159 m
.50375 1.04159 L
s
.5 1.15676 m
.50375 1.15676 L
s
.5 1.21435 m
.50375 1.21435 L
s
.5 1.27194 m
.50375 1.27194 L
s
.5 1.32953 m
.50375 1.32953 L
s
.5 .17778 m
.50375 .17778 L
s
.5 .1202 m
.50375 .1202 L
s
.5 .06261 m
.50375 .06261 L
s
.5 .00502 m
.50375 .00502 L
s
.5 1.4447 m
.50375 1.4447 L
s
.5 1.50229 m
.50375 1.50229 L
s
.5 1.55987 m
.50375 1.55987 L
s
.5 1.61746 m
.50375 1.61746 L
s
.25 Mabswid
.5 0 m
.5 1.62248 L
s
0 0 m
1 0 L
1 1.62248 L
0 1.62248 L
closepath
clip
newpath
.5 Mabswid
.36955 .81114 m
.36999 .79025 L
.37133 .7694 L
.37354 .74881 L
.37662 .72861 L
.38053 .70894 L
.38527 .68992 L
.39079 .67169 L
.39705 .65436 L
.40402 .63806 L
.41165 .62291 L
.41987 .60902 L
.42865 .59649 L
.43791 .58542 L
.4476 .5759 L
.45764 .568 L
.46798 .56178 L
.47853 .55731 L
.48923 .55461 L
.5 .5537 L
.51077 .55461 L
.52147 .55731 L
.53202 .56178 L
.54236 .568 L
.5524 .5759 L
.56209 .58542 L
.57135 .59649 L
.58013 .60902 L
.58835 .62291 L
.59598 .63806 L
.60295 .65436 L
.60921 .67169 L
.61473 .68992 L
.61947 .70894 L
.62338 .72861 L
.62646 .74881 L
.62867 .7694 L
.63001 .79025 L
.63045 .81114 L
s
.36955 .81135 m
.36999 .83223 L
.37133 .85309 L
.37354 .87368 L
.37662 .89387 L
.38053 .91355 L
.38527 .93256 L
.39079 .9508 L
.39705 .96812 L
.40402 .98442 L
.41165 .99957 L
.41987 1.01346 L
.42865 1.02599 L
.43791 1.03706 L
.4476 1.04659 L
.45764 1.05449 L
.46798 1.0607 L
.47853 1.06518 L
.48923 1.06788 L
.5 1.06878 L
.51077 1.06788 L
.52147 1.06518 L
.53202 1.0607 L
.54236 1.05449 L
.5524 1.04659 L
.56209 1.03706 L
.57135 1.02599 L
.58013 1.01346 L
.58835 .99957 L
.59598 .98442 L
.60295 .96812 L
.60921 .9508 L
.61473 .93256 L
.61947 .91355 L
.62338 .89387 L
.62646 .87368 L
.62867 .85309 L
.63001 .83223 L
.63045 .81135 L
s
.26726 .81111 m
.26805 .77607 L
.27043 .74107 L
.27438 .70641 L
.27987 .67229 L
.28686 .63887 L
.29531 .60637 L
.30516 .57499 L
.31634 .54496 L
.32877 .51649 L
.34237 .48982 L
.35705 .46519 L
.3727 .44281 L
.38923 .42291 L
.40651 .40569 L
.42443 .39133 L
.44287 .37998 L
.46169 .37179 L
.48078 .36683 L
.5 .36517 L
.51922 .36683 L
.53831 .37179 L
.55713 .37998 L
.57557 .39133 L
.59349 .40569 L
.61077 .42291 L
.6273 .44281 L
.64295 .46519 L
.65763 .48982 L
.67123 .51649 L
.68366 .54496 L
.69484 .57499 L
.70469 .60637 L
.71314 .63887 L
.72013 .67229 L
.72562 .70641 L
.72957 .74107 L
.73195 .77607 L
.73274 .81111 L
s
.26726 .81138 m
.26805 .84641 L
.27043 .88141 L
.27438 .91607 L
.27987 .9502 L
.28686 .98361 L
.29531 1.01611 L
.30516 1.04749 L
.31634 1.07753 L
.32877 1.10599 L
.34237 1.13266 L
.35705 1.1573 L
.3727 1.17967 L
.38923 1.19958 L
.40651 1.2168 L
.42443 1.23116 L
.44287 1.2425 L
.46169 1.2507 L
.48078 1.25565 L
.5 1.25731 L
.51922 1.25565 L
.53831 1.2507 L
.55713 1.2425 L
.57557 1.23116 L
.59349 1.2168 L
.61077 1.19958 L
.6273 1.17967 L
.64295 1.1573 L
.65763 1.13266 L
.67123 1.10599 L
.68366 1.07753 L
.69484 1.04749 L
.70469 1.01611 L
.71314 .98361 L
.72013 .9502 L
.72562 .91607 L
.72957 .88141 L
.73195 .84641 L
.73274 .81138 L
s
.18834 .8111 m
.18941 .76793 L
.19259 .72473 L
.19788 .68177 L
.20523 .6392 L
.21459 .59721 L
.2259 .55599 L
.23909 .51581 L
.25406 .47696 L
.27071 .43977 L
.28892 .40457 L
.30858 .37175 L
.32954 .34168 L
.35167 .31472 L
.37481 .29123 L
.3988 .27152 L
.42349 .25589 L
.4487 .24455 L
.47426 .23767 L
.5 .23537 L
.52574 .23767 L
.5513 .24455 L
.57651 .25589 L
.6012 .27152 L
.62519 .29123 L
.64833 .31472 L
.67046 .34168 L
.69142 .37175 L
.71108 .40457 L
.72929 .43977 L
.74594 .47696 L
.76091 .51581 L
.7741 .55599 L
.78541 .59721 L
.79477 .6392 L
.80212 .68177 L
.80741 .72473 L
.81059 .76793 L
.81166 .8111 L
s
.18834 .81138 m
.18941 .85456 L
.19259 .89776 L
.19788 .94071 L
.20523 .98328 L
.21459 1.02528 L
.2259 1.06649 L
.23909 1.10667 L
.25406 1.14552 L
.27071 1.18272 L
.28892 1.21791 L
.30858 1.25073 L
.32954 1.28081 L
.35167 1.30777 L
.37481 1.33126 L
.3988 1.35096 L
.42349 1.3666 L
.4487 1.37794 L
.47426 1.38481 L
.5 1.38711 L
.52574 1.38481 L
.5513 1.37794 L
.57651 1.3666 L
.6012 1.35096 L
.62519 1.33126 L
.64833 1.30777 L
.67046 1.28081 L
.69142 1.25073 L
.71108 1.21791 L
.72929 1.18272 L
.74594 1.14552 L
.76091 1.10667 L
.7741 1.06649 L
.78541 1.02528 L
.79477 .98328 L
.80212 .94071 L
.80741 .89776 L
.81059 .85456 L
.81166 .81138 L
s
.11272 .8111 m
.11404 .76384 L
.118 .71636 L
.12457 .66878 L
.1337 .6211 L
.14534 .57343 L
.1594 .52594 L
.17578 .47891 L
.19438 .43272 L
.21507 .38782 L
.2377 .34474 L
.26213 .30404 L
.28818 .26632 L
.31567 .23216 L
.34443 .20214 L
.37425 .17679 L
.40493 .15655 L
.43626 .14182 L
.46802 .13287 L
.5 .12986 L
.53198 .13287 L
.56374 .14182 L
.59507 .15655 L
.62575 .17679 L
.65557 .20214 L
.68433 .23216 L
.71182 .26632 L
.73787 .30404 L
.7623 .34474 L
.78493 .38782 L
.80562 .43272 L
.82422 .47891 L
.8406 .52594 L
.85466 .57343 L
.8663 .6211 L
.87543 .66878 L
.882 .71636 L
.88596 .76384 L
.88728 .8111 L
s
.11272 .81138 m
.11404 .85865 L
.118 .90612 L
.12457 .9537 L
.1337 1.00138 L
.14534 1.04906 L
.1594 1.09655 L
.17578 1.14357 L
.19438 1.18976 L
.21507 1.23466 L
.2377 1.27774 L
.26213 1.31844 L
.28818 1.35617 L
.31567 1.39032 L
.34443 1.42034 L
.37425 1.4457 L
.40493 1.46593 L
.43626 1.48066 L
.46802 1.48962 L
.5 1.49262 L
.53198 1.48962 L
.56374 1.48066 L
.59507 1.46593 L
.62575 1.4457 L
.65557 1.42034 L
.68433 1.39032 L
.71182 1.35617 L
.73787 1.31844 L
.7623 1.27774 L
.78493 1.23466 L
.80562 1.18976 L
.82422 1.14357 L
.8406 1.09655 L
.85466 1.04906 L
.8663 1.00138 L
.87543 .9537 L
.882 .90612 L
.88596 .85865 L
.88728 .81138 L
s
.02381 .81112 m
.02544 .76685 L
.0303 .72181 L
.03838 .67555 L
.04961 .6277 L
.06392 .5781 L
.0812 .52684 L
.10135 .47426 L
.12422 .42093 L
.14966 .3676 L
.17748 .31514 L
.20752 .26454 L
.23955 .21682 L
.27336 .17298 L
.30872 .13401 L
.34538 .10079 L
.3831 .07409 L
.42162 .05455 L
.46068 .04263 L
.5 .03863 L
.53932 .04263 L
.57838 .05455 L
.6169 .07409 L
.65462 .10079 L
.69128 .13401 L
.72664 .17298 L
.76045 .21682 L
.79248 .26454 L
.82252 .31514 L
.85034 .3676 L
.87578 .42093 L
.89865 .47426 L
.9188 .52684 L
.93608 .5781 L
.95039 .6277 L
.96162 .67555 L
.9697 .72181 L
.97456 .76685 L
.97619 .81112 L
s
.02381 .81136 m
.02544 .85563 L
.0303 .90067 L
.03838 .94693 L
.04961 .99478 L
.06392 1.04439 L
.0812 1.09565 L
.10135 1.14822 L
.12422 1.20155 L
.14966 1.25489 L
.17748 1.30734 L
.20752 1.35794 L
.23955 1.40567 L
.27336 1.4495 L
.30872 1.48848 L
.34538 1.5217 L
.3831 1.5484 L
.42162 1.56793 L
.46068 1.57985 L
.5 1.58385 L
.53932 1.57985 L
.57838 1.56793 L
.6169 1.5484 L
.65462 1.5217 L
.69128 1.48848 L
.72664 1.4495 L
.76045 1.40567 L
.79248 1.35794 L
.82252 1.30734 L
.85034 1.25489 L
.87578 1.20155 L
.89865 1.14822 L
.9188 1.09565 L
.93608 1.04439 L
.95039 .99478 L
.96162 .94693 L
.9697 .90067 L
.97456 .85563 L
.97619 .81136 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  ImageSize->{135.813, 220.438},
  ImageMargins->{{43, 0}, {0, 24.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004?0001^2000`400?l00000o`00003oo`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00RP3oool00`000000oooo0?ooo`220?ooo`00RP3oool2000008<0oooo002:0?ooo`030000
003oool0oooo0880oooo002:0?ooo`030000003oool0oooo0880oooo002:0?ooo`030000003oool0
oooo0880oooo002:0?ooo`030000003oool0oooo0880oooo002:0?ooo`030000003oool0oooo0880
oooo002:0?ooo`030000003oool0oooo0880oooo002:0?ooo`030000003oool0oooo0880oooo002:
0?ooo`030000003oool0oooo0880oooo00260?ooo`T00000P03oool007l0oooo1`0000040?ooo`03
0000003oool0oooo0080oooo1`00001i0?ooo`00O03oool3000000/0oooo00<000000?ooo`3oool0
2@3oool3000007H0oooo001h0?ooo`@000003P3oool00`000000oooo0?ooo`0<0?ooo`<00000L`3o
ool007H0oooo0P00000B0?ooo`030000003oool0oooo00l0oooo0P00001a0?ooo`00M03oool20000
01@0oooo00<000000?ooo`3oool04@3oool2000006l0oooo001b0?ooo`8000005P3oool2000001@0
oooo0P00001]0?ooo`00L03oool2000001P0oooo00<000000?ooo`3oool05@3oool2000006/0oooo
001^0?ooo`8000006P3oool00`000000oooo0?ooo`0G0?ooo`800000J@3oool006`0oooo0P00000L
0?ooo`030000003oool0oooo01T0oooo0P00001W0?ooo`00JP3oool2000001h0oooo00<000000?oo
o`3oool06`3oool2000006D0oooo001Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool07@3oool2000006<0oooo001W0?ooo`8000008@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0600oooo001V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803o
ool200000600oooo001T0?ooo`800000903oool00`000000oooo0?ooo`0R0?ooo`800000GP3oool0
06<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
05/0oooo001R0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`1J0?ooo`00H@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0F@3oool00600oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo05P0oooo001O0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`1G0?ooo`00GP3oool00`000000oooo0?ooo`0Y0?oo
o`800000:P3oool00`000000oooo0?ooo`1F0?ooo`00G@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0E@3oool005`0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo05@0oooo001K0?ooo`030000003o
ool0oooo02<0oooo4`00000U0?ooo`030000003oool0oooo05<0oooo001J0?ooo`030000003oool0
oooo0280oooo0P0000090?ooo`030000003oool0oooo00L0oooo0P00000T0?ooo`030000003oool0
oooo0580oooo001I0?ooo`030000003oool0oooo0200oooo0`00000;0?ooo`030000003oool0oooo
00T0oooo0`00000R0?ooo`030000003oool0oooo0540oooo001H0?ooo`030000003oool0oooo01h0
oooo0`00000>0?ooo`030000003oool0oooo00`0oooo0`00000P0?ooo`030000003oool0oooo0500
oooo001G0?ooo`030000003oool0oooo01d0oooo0P00000A0?ooo`030000003oool0oooo00l0oooo
0P00000O0?ooo`030000003oool0oooo04l0oooo001F0?ooo`030000003oool0oooo01/0oooo0`00
000C0?ooo`030000003oool0oooo0140oooo0`00000M0?ooo`030000003oool0oooo04h0oooo001E
0?ooo`030000003oool0oooo01X0oooo0P00000F0?ooo`030000003oool0oooo01@0oooo0P00000L
0?ooo`030000003oool0oooo04d0oooo001D0?ooo`030000003oool0oooo01T0oooo0P00000H0?oo
o`030000003oool0oooo01H0oooo0P00000K0?ooo`030000003oool0oooo04`0oooo001C0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0B`3oool00580oooo00<000000?ooo`3oool0
603oool2000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04X0oooo001A0?ooo`030000003oool0oooo01L0oooo0P00000M0?ooo`030000003o
ool0oooo01X0oooo0P00000J0?ooo`030000003oool0oooo04T0oooo001@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0B03oool004l0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0N0?ooo`8000007P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04P0oooo001?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool004h0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`160?ooo`00C@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool2000001P0oooo00<0
00000?ooo`3oool0A@3oool004`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`15
0?ooo`00B`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04@0oooo001:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool004X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`120?ooo`00B@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0480oooo00180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool7
000000D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0440oooo00170?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`100?ooo`00A`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0@03oool004H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo03l0oooo00150?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0n0?ooo`00A@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo200000080?ooo`030000003oool0oooo00<0oooo1P00000/
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool004@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`H000000`3oool00`000000oooo0?ooo`070000
02H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0m0?ooo`00@`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo1@0000080?ooo`030000003oool0oooo00L0
oooo1000000R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?03oool004<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`800000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00/0oooo0P00000Q0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0?03oool00480oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0N0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00
000P0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>`3oool00440oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`800000203oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00l0oooo0P00000O0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0>P3oool00440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?oo
o`8000001P3oool3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool04@3oool20000
01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0j0?ooo`00@03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01X0oooo0P00000;0?ooo`800000203oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0i0?ooo`00?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01T0oooo
0P00000G0?ooo`030000003oool0oooo01@0oooo0P00000L0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0>03oool003l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0>03oool003h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0=`3oool003h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0=`3oool003d0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0G0?ooo`800000703oool00`000000oooo0?ooo`0I0?ooo`80
00006P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03H0oooo000m0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03D0oooo000l0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03D0oooo000l0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`8000007P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=03oool0
03/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0<`3oool003/0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3oool003X0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0<P3oool003X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3oool003T0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0<@3oool003P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03oool003P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0<03oool003L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0;`3oool003L0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;`3o
ool003H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0;P3oool003H0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;P3oool003D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0;@3oool003D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool003@0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo0P00
000Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0/0?ooo`00=03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`00<`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?oo
o`00<`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0[0?ooo`00<P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool09@3oool>000002P0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02X0oooo000b0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0R0?ooo`@000001`3o
ool00`000000oooo0?ooo`040?ooo`@000009@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0:P3oool00340oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo0P00000;0?ooo`030000003oool0
oooo00P0oooo0P00000T0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0Y0?ooo`00<@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool07`3oool2000000d0oooo00<000000?ooo`3oool02P3oool20000
0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02T0oooo000`0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool200000240
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02P0
oooo000`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0M0?ooo`800000403oool00`000000oooo0?ooo`0>0?ooo`8000007`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:03oool002l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo000_
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W
0?ooo`00;`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06`3oool2000001@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?oo
o`00;P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool09P3oool002h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool05@3oool2000001D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
9P3oool002d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo02D0oooo000]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool2
000001/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02D0oooo000/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0T0?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0903oool002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02@0oooo000[0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`00:`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08`3oool002X0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0280oooo000Z0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0R0?ooo`00
:@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
8@3oool002T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0240oooo000X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0P0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0803oool002L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo000W0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo
0P00000R0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01l0oooo000V0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0N0?ooo`009P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07P3oool002H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01h0oooo000U0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0M0?ooo`00
9@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
7@3oool002@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01`0oooo000T0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0L0?ooo`00903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0703oool002<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool4000000P0
oooo0`0000090?ooo`@000001`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0
oooo000S0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`008`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool3000000L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool06`3oool00280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01X0oooo000R0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool8000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0P00000Y0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01T0oooo000Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0?0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00240oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`0000000P00
00070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00200oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo000P0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?oo
o`007`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0603oool001l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01L0oooo000O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo1000000C0?ooo`H000001P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo000N0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02P0oooo2000000[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo000N0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02H0oooo0P0000040?ooo`040000003oool0oooo0?ooo`<00000:03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G
0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`8000001P3oool00`000000oooo0?ooo`040?oo
o`8000009`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`007@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`80
0000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool05P3oool001d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`00703o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool2000002@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool001`0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`00703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0P0?ooo`8000003@3oool20000
00`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`00703oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo000K0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0503oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0D0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo000K0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool001X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0C0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01<0oooo000J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04P3o
ool001X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`006@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo000I0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool04@3oool001T0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000H
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool2000001H0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`00603oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0100oooo000H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0403oool001P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`005`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo000G0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool03`3oool001L0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0
oooo000F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool001H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00h0oooo000F0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool03P3oool001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`00
5@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03@3oool001D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`8000006`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00d0oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool001D0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo000D0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`00503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo000D0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0<0?ooo`00403oool5000000L0oooo0`00000;0?ooo`030000003o
ool0oooo00L0oooo100000020?ooo`@00000203oool3000000L0oooo00<000000?ooo`0000000`00
00020?ooo`@00000203oool3000000@0oooo00<000000?ooo`3oool0200000060?ooo`@000002P3o
ool00`000000oooo0?ooo`0=0?ooo`@00000203oool4000000H0oooo200000060?ooo`@0000000<0
oooo0000000000000`0000080?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`@000000P3o
ool4000000@0oooo00@000000?ooo`3oool0oooo0`00000;0?ooo`050000003oool0oooo0?ooo`00
00001@3oool4000000D0oooo000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool3000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`800000
0`3oool2000000L0oooo0`0000070?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0
1@3oool3000000@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool4000000H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo00D0oooo0`0000040?ooo`050000003oool0oooo0?ooo`000000103oool20000
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`<000002`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`003P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`00000:0?ooo`8000001`3oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool2000000L0oooo0`0000070?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`030000003oool0oooo00D0oooo0`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo0`0000000`3oool000000?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool01@3oool3000000@0oooo00@00000
0?ooo`3oool000001@3oool2000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`<00000
2`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001<0oooo
0P00000=0?ooo`8000000`3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0=0?ooo`8000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo
0P0000050?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000C0?ooo`030000003oool0000000`0oooo0P0000020?ooo`040000
003oool0oooo00000100oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0P0000050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`01
0?ooo`000P3oool8000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000C0?oo
o`030000003oool0000000P00000103oool200000080oooo00@000000?ooo`3oool000002P3oool8
000000@0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P00000<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00/0oooo0P0000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool2
000000D0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`010?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000001<0oooo00<000000?ooo`0000001`3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00h0oooo0`0000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000140
oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001<0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo00000003000000<0oooo00@000000?ooo`3oool00000403oool2
000000030?ooo`0000000000008000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo00000002000000X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000<0000000<0oooo
0000003oool00`3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0000003oool01000
00060?ooo`050000003oool0oooo0?ooo`0000004P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool00000008000001@3oool000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000C0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1`3oool000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000C0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool03P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool000l0oooo00@00000
0?ooo`3oool0oooo0P00000D0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool000004@3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2
000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01`3oool000l0oooo00@000000?ooo`3oool0oooo0P00
000A0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`060000003oool0oooo0000003oool000004@3oool2000000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool2000000<0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`07
0?ooo`00403oool400000180oooo200000050?ooo`H0000000<0oooo0000000000000P00000B0?oo
o`L0000000<0oooo0000000000000P00000=0?ooo`030000003oool0oooo00@0oooo100000070?oo
o`H000002@3oool00`000000oooo0?ooo`0=0?ooo`@00000303oool00`000000oooo0?ooo`050?oo
o`@000001`3oool6000000030?ooo`000000000000800000403oool00`000000oooo0?ooo`060000
00030?ooo`0000000000008000001@3oool00`000000oooo0?ooo`0:0?ooo`P0000000<0oooo0000
003oool00P3oool6000000@0oooo000C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool02`3oool00180oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`004P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000B0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02`3oool00180oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0;0?ooo`004P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0
oooo000B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool000`0ooooo000
00070?ooo`003`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`070?ooo`004P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000B0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00180oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0;0?ooo`004P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00/0oooo000C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3o
ool001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`004`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000C0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool02`3oool001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0;0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool001<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`004`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01d0oooo0P00000N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool02`3oool001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`004`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000D0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0
oooo000D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool001@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0303oool001@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`00
503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03@3oool001D0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0=0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01X0oooo0P00000K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool001D0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`005@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03P3oool001H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>
0?ooo`005P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo000F0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool001H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00l0oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool0
01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo000G0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0403oool001P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`00603oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo000H0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool2000001H0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`00603oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0140oooo000I0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
4@3oool001T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`006@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo000I0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04P3oool001X0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0B0?ooo`006P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo
000J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool001X0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`006`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01<0oooo000K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0503oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0D0?ooo`006`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo000L0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`00703oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01D0oooo000L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool001d0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
0P00000T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01H0oooo000M0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo0P00
00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0F0?ooo`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`8000001`3oool00`000000oooo0?ooo`04
0?ooo`<000009P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`007P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0U0?oo
o`<00000103oool00`000000oooo0?ooo`020?ooo`800000:03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?oo
o`007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0X0?ooo`T00000:P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`00
7`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5`3oool001l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01L0oooo000O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo100000080?ooo`<000002@3oool4
000000L0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`00803oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool30000
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0603oool00200oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0
oooo000Q0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0I0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool06@3oool00240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool2000002T0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00l0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo00000002000000L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`008`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool002<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0oooo000S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K
0?ooo`00903oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0703oool002@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool4000001<0oooo1P0000060?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0703oool002@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo000U0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`009@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool0
02H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01h0oooo000V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0N0?ooo`009P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool07P3oool002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08@3oool200000280oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool07`3oool002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01l0oooo000X0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0P0?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0803oool002T0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0240oooo000Y0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`00:P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08P3oool0
02X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0280oooo000[0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0S0?ooo`00:`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool08`3oool002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02@0oooo000/0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0T0?ooo`00;03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0903oool002d0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0F0?ooo`8000006`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool09@3oool002d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo000^0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01D0oooo0P00000E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo000^0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`00;`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool20000
01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0W0?ooo`00;`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09`3oool002l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02L0oooo
000`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool2000001l0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02P0oooo000`
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0N
0?ooo`8000003`3oool00`000000oooo0?ooo`0<0?ooo`8000008@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:03oool00340oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo0P00000=0?oo
o`030000003oool0oooo00X0oooo0P00000R0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0Y0?ooo`00<@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool08@3oool2000000/0oooo00<000000?ooo`3o
ool0203oool2000002@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0R0?ooo`@000001`3oool00`000000oooo0?ooo`050?ooo`<00000
9@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
:P3oool00380oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02D0oooo3`00000W0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0Z0?ooo`00<`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0[0?ooo`00<`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0[0?ooo`00=03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`00=03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:@3oool2000002X0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo
000e0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02d0oooo000e0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02d0oooo000f0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02h0oooo000f0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo000g0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo02l0oooo000g0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0oooo000h0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0300oooo000h0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo000i0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0340
oooo000j0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0380oooo000j0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0380oooo000k
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo03<0oooo000k0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03<0oooo000l0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0M0?ooo`8000007@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0=@3oool003d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=@3o
ool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0=P3oool003h0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0G0?ooo`8000006`3oool00`000000oooo0?ooo`0H0?ooo`8000006P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03L0oooo000n0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03L0
oooo000o0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo03P0oooo000o0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool06@3oool2000001L0oooo00<000000?ooo`3oool0503oool2000001`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0h0?ooo`00@03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01X0oooo0P00000E0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03T0oooo00110?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool2000001<0oooo00<000000?oo
o`3oool04@3oool2000001d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0j0?oo
o`00@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0103oool7000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool00480oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0M0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00h0oooo0P00000O0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
>`3oool004<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`8000001@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0P00000P0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?03oool004<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0O0?ooo`@0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`07
0?ooo`D000008@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03`0oooo00140?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool7000000<0oooo00@000000?oo
o`3oool0oooo1P00000V0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool0
04D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00<0oooo1`00000[0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool004D0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03h0
oooo00160?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0o0?ooo`00A`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0@03oool004L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0400oooo00180?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`110?ooo`00B@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01T0oooo0`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`120?ooo`00BP3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01/0oooo0P0000080?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`120?ooo`00BP3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04<0oooo001;0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0A03oool004`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`150?oo
o`00C@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo001>0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`800000
603oool00`000000oooo0?ooo`160?ooo`00C`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo04L0oooo001?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool2
000001h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`180?ooo`00D03oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04P0oooo001A0?ooo`030000003oool0oooo01L0
oooo0P00000M0?ooo`030000003oool0oooo01X0oooo0P00000J0?ooo`030000003oool0oooo04T0
oooo001B0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0BP3oool005<0oooo00<0
00000?ooo`3oool0603oool2000001X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo04/0oooo001D0?ooo`030000003oool0oooo01T0oooo0P00000H
0?ooo`030000003oool0oooo01H0oooo0P00000K0?ooo`030000003oool0oooo04`0oooo001E0?oo
o`030000003oool0oooo01X0oooo0P00000F0?ooo`030000003oool0oooo01@0oooo0P00000L0?oo
o`030000003oool0oooo04d0oooo001F0?ooo`030000003oool0oooo01/0oooo0P00000D0?ooo`03
0000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo04h0oooo001G0?ooo`030000
003oool0oooo01`0oooo0`00000A0?ooo`030000003oool0oooo00l0oooo0`00000N0?ooo`030000
003oool0oooo04l0oooo001H0?ooo`030000003oool0oooo01h0oooo0`00000>0?ooo`030000003o
ool0oooo00`0oooo0`00000P0?ooo`030000003oool0oooo0500oooo001I0?ooo`030000003oool0
oooo0200oooo0P00000<0?ooo`030000003oool0oooo00X0oooo0P00000R0?ooo`030000003oool0
oooo0540oooo001J0?ooo`030000003oool0oooo0240oooo0`0000090?ooo`030000003oool0oooo
00L0oooo0`00000S0?ooo`030000003oool0oooo0580oooo001K0?ooo`030000003oool0oooo02<0
oooo4`00000U0?ooo`030000003oool0oooo05<0oooo001L0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1D0?ooo`00G@3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0E@3oool005h0oooo00<00000
0?ooo`3oool0:@3oool2000002X0oooo00<000000?ooo`3oool0EP3oool005l0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo05L0oooo001P0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1H0?ooo`00
H@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
F@3oool00680oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo05X0oooo001S0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1K0?ooo`00I03oool2000002@0oooo00<000000?ooo`3oool08P3oool20000
05h0oooo001V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0803oool200000600
oooo001W0?ooo`8000008@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0600oooo
001Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool2000006<0oooo001Z
0?ooo`8000007P3oool00`000000oooo0?ooo`0K0?ooo`800000I@3oool006`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06D0oooo001]0?ooo`80
00006`3oool00`000000oooo0?ooo`0H0?ooo`800000J03oool006l0oooo0P00000I0?ooo`030000
003oool0oooo01H0oooo0P00001Z0?ooo`00L@3oool2000001L0oooo0P00000E0?ooo`800000K03o
ool007<0oooo0P00000E0?ooo`030000003oool0oooo0180oooo0P00001^0?ooo`00M@3oool30000
0180oooo00<000000?ooo`3oool03`3oool300000700oooo001h0?ooo`<000003`3oool00`000000
oooo0?ooo`0<0?ooo`<00000L`3oool007/0oooo1000000;0?ooo`030000003oool0oooo00T0oooo
0`00001f0?ooo`00O`3oool6000000D0oooo00<000000?ooo`3oool00`3oool6000007T0oooo0025
0?ooo`/00000O`3oool008X0oooo00<000000?ooo`3oool0PP3oool008X0oooo00<000000?ooo`3o
ool0PP3oool008X0oooo00<000000?ooo`3oool0PP3oool008X0oooo00<000000?ooo`3oool0PP3o
ool008X0oooo00<000000?ooo`3oool0PP3oool008X0oooo00<000000?ooo`3oool0PP3oool008X0
oooo00<000000?ooo`3oool0PP3oool008X0oooo00<000000?ooo`3oool0PP3oool008X0oooo0P00
00230?ooo`00RP3oool00`000000oooo0?ooo`220?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00
o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00
o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00
o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00\
\>"],
  ImageRangeCache->{{{87.5, 195.125}, {560.688, 385.375}} -> {-2.48497, \
5.19127, 0.0139495, 0.0139495}}],

Cell[BoxData[
    \(\(s1 = 
        ImplicitPlot[
          Table[y^2/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x \[Equal] 
              c, {c,  .1,  .9,  .2}], {x, \(-3\), 3}, 
          PlotStyle \[Rule] {RGBColor[0, \ 1, \ 0]}];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.76829 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 1.88414 0.15873 [
[.02381 1.87164 -6 -9 ]
[.02381 1.87164 6 0 ]
[.18254 1.87164 -6 -9 ]
[.18254 1.87164 6 0 ]
[.34127 1.87164 -6 -9 ]
[.34127 1.87164 6 0 ]
[.65873 1.87164 -3 -9 ]
[.65873 1.87164 3 0 ]
[.81746 1.87164 -3 -9 ]
[.81746 1.87164 3 0 ]
[.97619 1.87164 -3 -9 ]
[.97619 1.87164 3 0 ]
[.4875 .29684 -18 -4.5 ]
[.4875 .29684 0 4.5 ]
[.4875 1.09049 -12 -4.5 ]
[.4875 1.09049 0 4.5 ]
[.4875 2.6778 -6 -4.5 ]
[.4875 2.6778 0 4.5 ]
[.4875 3.47145 -12 -4.5 ]
[.4875 3.47145 0 4.5 ]
[ 0 0 0 0 ]
[ 1 3.76829 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 1.88414 m
.02381 1.89039 L
s
[(-3)] .02381 1.87164 0 1 Mshowa
.18254 1.88414 m
.18254 1.89039 L
s
[(-2)] .18254 1.87164 0 1 Mshowa
.34127 1.88414 m
.34127 1.89039 L
s
[(-1)] .34127 1.87164 0 1 Mshowa
.65873 1.88414 m
.65873 1.89039 L
s
[(1)] .65873 1.87164 0 1 Mshowa
.81746 1.88414 m
.81746 1.89039 L
s
[(2)] .81746 1.87164 0 1 Mshowa
.97619 1.88414 m
.97619 1.89039 L
s
[(3)] .97619 1.87164 0 1 Mshowa
.125 Mabswid
.05556 1.88414 m
.05556 1.88789 L
s
.0873 1.88414 m
.0873 1.88789 L
s
.11905 1.88414 m
.11905 1.88789 L
s
.15079 1.88414 m
.15079 1.88789 L
s
.21429 1.88414 m
.21429 1.88789 L
s
.24603 1.88414 m
.24603 1.88789 L
s
.27778 1.88414 m
.27778 1.88789 L
s
.30952 1.88414 m
.30952 1.88789 L
s
.37302 1.88414 m
.37302 1.88789 L
s
.40476 1.88414 m
.40476 1.88789 L
s
.43651 1.88414 m
.43651 1.88789 L
s
.46825 1.88414 m
.46825 1.88789 L
s
.53175 1.88414 m
.53175 1.88789 L
s
.56349 1.88414 m
.56349 1.88789 L
s
.59524 1.88414 m
.59524 1.88789 L
s
.62698 1.88414 m
.62698 1.88789 L
s
.69048 1.88414 m
.69048 1.88789 L
s
.72222 1.88414 m
.72222 1.88789 L
s
.75397 1.88414 m
.75397 1.88789 L
s
.78571 1.88414 m
.78571 1.88789 L
s
.84921 1.88414 m
.84921 1.88789 L
s
.88095 1.88414 m
.88095 1.88789 L
s
.9127 1.88414 m
.9127 1.88789 L
s
.94444 1.88414 m
.94444 1.88789 L
s
.25 Mabswid
0 1.88414 m
1 1.88414 L
s
.5 .29684 m
.50625 .29684 L
s
[(-10)] .4875 .29684 1 0 Mshowa
.5 1.09049 m
.50625 1.09049 L
s
[(-5)] .4875 1.09049 1 0 Mshowa
.5 2.6778 m
.50625 2.6778 L
s
[(5)] .4875 2.6778 1 0 Mshowa
.5 3.47145 m
.50625 3.47145 L
s
[(10)] .4875 3.47145 1 0 Mshowa
.125 Mabswid
.5 .45557 m
.50375 .45557 L
s
.5 .6143 m
.50375 .6143 L
s
.5 .77303 m
.50375 .77303 L
s
.5 .93176 m
.50375 .93176 L
s
.5 1.24922 m
.50375 1.24922 L
s
.5 1.40795 m
.50375 1.40795 L
s
.5 1.56668 m
.50375 1.56668 L
s
.5 1.72541 m
.50375 1.72541 L
s
.5 2.04287 m
.50375 2.04287 L
s
.5 2.2016 m
.50375 2.2016 L
s
.5 2.36033 m
.50375 2.36033 L
s
.5 2.51906 m
.50375 2.51906 L
s
.5 2.83653 m
.50375 2.83653 L
s
.5 2.99526 m
.50375 2.99526 L
s
.5 3.15399 m
.50375 3.15399 L
s
.5 3.31272 m
.50375 3.31272 L
s
.5 .13811 m
.50375 .13811 L
s
.5 3.63018 m
.50375 3.63018 L
s
.25 Mabswid
.5 0 m
.5 3.76829 L
s
0 0 m
1 0 L
1 3.76829 L
0 3.76829 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.02381 .10099 m
.02424 .1047 L
.02555 .1158 L
.02771 .13415 L
.03071 .15952 L
.03453 .19162 L
.03915 .23007 L
.04454 .27441 L
.05065 .32414 L
.05745 .3787 L
.06489 .43748 L
.07292 .49985 L
.08149 .56516 L
.09052 .63275 L
.09998 .70196 L
.10978 .77215 L
.11986 .84271 L
.13016 .91304 L
.1406 .98262 L
.15111 1.05093 L
.16163 1.11755 L
.17207 1.18209 L
.18237 1.24423 L
.19245 1.30374 L
.20225 1.3604 L
.21171 1.41411 L
.22074 1.4648 L
.22931 1.51247 L
.23734 1.55717 L
.24478 1.59901 L
.25158 1.63815 L
.25769 1.67478 L
.26308 1.70914 L
.2677 1.7415 L
.27152 1.77214 L
.27452 1.80138 L
.27668 1.82957 L
.27799 1.85704 L
.27842 1.88402 L
s
.02381 3.6673 m
.02424 3.66359 L
.02555 3.65249 L
.02771 3.63414 L
.03071 3.60877 L
.03453 3.57667 L
.03915 3.53822 L
.04454 3.49388 L
.05065 3.44415 L
.05745 3.38959 L
.06489 3.33081 L
.07292 3.26844 L
.08149 3.20313 L
.09052 3.13554 L
.09998 3.06633 L
.10978 2.99614 L
.11986 2.92558 L
.13016 2.85524 L
.1406 2.78567 L
.15111 2.71736 L
.16163 2.65074 L
.17207 2.5862 L
.18237 2.52405 L
.19245 2.46455 L
.20225 2.40789 L
.21171 2.35418 L
.22074 2.30349 L
.22931 2.25582 L
.23734 2.21112 L
.24478 2.16928 L
.25158 2.13014 L
.25769 2.0935 L
.26308 2.05914 L
.2677 2.02679 L
.27152 1.99615 L
.27452 1.9669 L
.27668 1.93872 L
.27799 1.91125 L
.27842 1.88427 L
s
.46404 1.88409 m
.46417 1.87836 L
.46453 1.87261 L
.46514 1.86694 L
.46599 1.86137 L
.46707 1.85595 L
.46838 1.8507 L
.4699 1.84568 L
.47162 1.8409 L
.47355 1.83641 L
.47565 1.83223 L
.47791 1.82841 L
.48033 1.82495 L
.48289 1.8219 L
.48556 1.81928 L
.48832 1.8171 L
.49117 1.81538 L
.49408 1.81415 L
.49703 1.81341 L
.5 1.81316 L
.50297 1.81341 L
.50592 1.81415 L
.50883 1.81538 L
.51168 1.8171 L
.51444 1.81928 L
.51711 1.8219 L
.51967 1.82495 L
.52209 1.82841 L
.52435 1.83223 L
.52645 1.83641 L
.52838 1.8409 L
.5301 1.84568 L
.53162 1.8507 L
.53293 1.85595 L
.53401 1.86137 L
.53486 1.86694 L
.53547 1.87261 L
.53583 1.87836 L
.53596 1.88409 L
s
.46404 1.8842 m
.46417 1.88993 L
.46453 1.89568 L
.46514 1.90135 L
.46599 1.90692 L
.46707 1.91234 L
.46838 1.91758 L
.4699 1.92261 L
.47162 1.92739 L
.47355 1.93188 L
.47565 1.93605 L
.47791 1.93988 L
.48033 1.94334 L
.48289 1.94639 L
.48556 1.94901 L
.48832 1.95119 L
.49117 1.9529 L
.49408 1.95414 L
.49703 1.95488 L
.5 1.95513 L
.50297 1.95488 L
.50592 1.95414 L
.50883 1.9529 L
.51168 1.95119 L
.51444 1.94901 L
.51711 1.94639 L
.51967 1.94334 L
.52209 1.93988 L
.52435 1.93605 L
.52645 1.93188 L
.52838 1.92739 L
.5301 1.92261 L
.53162 1.91758 L
.53293 1.91234 L
.53401 1.90692 L
.53486 1.90135 L
.53547 1.89568 L
.53583 1.88993 L
.53596 1.8842 L
s
.72158 1.88402 m
.72201 1.85704 L
.72332 1.82957 L
.72548 1.80138 L
.72848 1.77214 L
.7323 1.7415 L
.73692 1.70914 L
.74231 1.67478 L
.74842 1.63815 L
.75522 1.59901 L
.76266 1.55717 L
.77069 1.51247 L
.77926 1.4648 L
.78829 1.41411 L
.79775 1.3604 L
.80755 1.30374 L
.81763 1.24423 L
.82793 1.18209 L
.83837 1.11755 L
.84889 1.05093 L
.8594 .98262 L
.86984 .91304 L
.88014 .84271 L
.89022 .77215 L
.90002 .70196 L
.90948 .63275 L
.91851 .56516 L
.92708 .49985 L
.93511 .43748 L
.94255 .3787 L
.94935 .32414 L
.95546 .27441 L
.96085 .23007 L
.96547 .19162 L
.96929 .15952 L
.97229 .13415 L
.97445 .1158 L
.97576 .1047 L
.97619 .10099 L
s
.72158 1.88427 m
.72201 1.91125 L
.72332 1.93872 L
.72548 1.9669 L
.72848 1.99615 L
.7323 2.02679 L
.73692 2.05914 L
.74231 2.0935 L
.74842 2.13014 L
.75522 2.16928 L
.76266 2.21112 L
.77069 2.25582 L
.77926 2.30349 L
.78829 2.35418 L
.79775 2.40789 L
.80755 2.46455 L
.81763 2.52405 L
.82793 2.5862 L
.83837 2.65074 L
.84889 2.71736 L
.8594 2.78567 L
.86984 2.85524 L
.88014 2.92558 L
.89022 2.99614 L
.90002 3.06633 L
.90948 3.13554 L
.91851 3.20313 L
.92708 3.26844 L
.93511 3.33081 L
.94255 3.38959 L
.94935 3.44415 L
.95546 3.49388 L
.96085 3.53822 L
.96547 3.57667 L
.96929 3.60877 L
.97229 3.63414 L
.97445 3.65249 L
.97576 3.66359 L
.97619 3.6673 L
s
.02381 .09817 m
.02426 .10197 L
.02559 .11333 L
.0278 .13211 L
.03088 .15807 L
.0348 .19092 L
.03954 .23024 L
.04507 .27558 L
.05133 .32641 L
.05831 .38213 L
.06594 .44214 L
.07417 .50577 L
.08295 .57235 L
.09222 .6412 L
.10191 .71163 L
.11196 .78298 L
.1223 .85461 L
.13286 .92593 L
.14357 .99636 L
.15435 1.06541 L
.16513 1.13261 L
.17583 1.19759 L
.18639 1.26001 L
.19673 1.31962 L
.20678 1.37622 L
.21648 1.4297 L
.22574 1.47998 L
.23452 1.52708 L
.24276 1.57105 L
.25039 1.61201 L
.25736 1.65012 L
.26363 1.68558 L
.26915 1.71865 L
.27389 1.7496 L
.27781 1.77874 L
.28089 1.8064 L
.2831 1.83295 L
.28444 1.85874 L
.28488 1.88403 L
s
.02381 3.67012 m
.02426 3.66632 L
.02559 3.65496 L
.0278 3.63618 L
.03088 3.61021 L
.0348 3.57737 L
.03954 3.53805 L
.04507 3.49271 L
.05133 3.44188 L
.05831 3.38615 L
.06594 3.32615 L
.07417 3.26252 L
.08295 3.19594 L
.09222 3.12709 L
.10191 3.05666 L
.11196 2.98531 L
.1223 2.91368 L
.13286 2.84236 L
.14357 2.77193 L
.15435 2.70288 L
.16513 2.63567 L
.17583 2.5707 L
.18639 2.50828 L
.19673 2.44867 L
.20678 2.39207 L
.21648 2.33859 L
.22574 2.28831 L
.23452 2.24121 L
.24276 2.19724 L
.25039 2.15628 L
.25736 2.11817 L
.26363 2.08271 L
.26915 2.04964 L
.27389 2.01869 L
.27781 1.98955 L
.28089 1.96188 L
.2831 1.93534 L
.28444 1.90955 L
.28488 1.88426 L
s
.43585 1.88408 m
.43607 1.87445 L
.43672 1.8648 L
.43781 1.85525 L
.43932 1.84584 L
.44125 1.83663 L
.44358 1.82767 L
.44629 1.81903 L
.44938 1.81075 L
.4528 1.8029 L
.45655 1.79555 L
.4606 1.78876 L
.46491 1.78259 L
.46947 1.77711 L
.47423 1.77236 L
.47917 1.7684 L
.48425 1.76527 L
.48944 1.76302 L
.4947 1.76165 L
.5 1.76119 L
.5053 1.76165 L
.51056 1.76302 L
.51575 1.76527 L
.52083 1.7684 L
.52577 1.77236 L
.53053 1.77711 L
.53509 1.78259 L
.5394 1.78876 L
.54345 1.79555 L
.5472 1.8029 L
.55062 1.81075 L
.55371 1.81903 L
.55642 1.82767 L
.55875 1.83663 L
.56068 1.84584 L
.56219 1.85525 L
.56328 1.8648 L
.56393 1.87445 L
.56415 1.88408 L
s
.43585 1.88421 m
.43607 1.89384 L
.43672 1.90349 L
.43781 1.91304 L
.43932 1.92245 L
.44125 1.93166 L
.44358 1.94061 L
.44629 1.94926 L
.44938 1.95754 L
.4528 1.96539 L
.45655 1.97274 L
.4606 1.97953 L
.46491 1.9857 L
.46947 1.99118 L
.47423 1.99593 L
.47917 1.99989 L
.48425 2.00301 L
.48944 2.00527 L
.4947 2.00664 L
.5 2.0071 L
.5053 2.00664 L
.51056 2.00527 L
.51575 2.00301 L
.52083 1.99989 L
.52577 1.99593 L
.53053 1.99118 L
.53509 1.9857 L
.5394 1.97953 L
.54345 1.97274 L
.5472 1.96539 L
.55062 1.95754 L
.55371 1.94926 L
.55642 1.94061 L
.55875 1.93166 L
.56068 1.92245 L
.56219 1.91304 L
.56328 1.90349 L
.56393 1.89384 L
.56415 1.88421 L
s
.71512 1.88403 m
.71556 1.85874 L
.7169 1.83295 L
.71911 1.8064 L
.72219 1.77874 L
.72611 1.7496 L
.73085 1.71865 L
.73637 1.68558 L
.74264 1.65012 L
.74961 1.61201 L
.75724 1.57105 L
.76548 1.52708 L
.77426 1.47998 L
.78352 1.4297 L
.79322 1.37622 L
.80327 1.31962 L
.81361 1.26001 L
.82417 1.19759 L
.83487 1.13261 L
.84565 1.06541 L
.85643 .99636 L
.86714 .92593 L
.8777 .85461 L
.88804 .78298 L
.89809 .71163 L
.90778 .6412 L
.91705 .57235 L
.92583 .50577 L
.93406 .44214 L
.94169 .38213 L
.94867 .32641 L
.95493 .27558 L
.96046 .23024 L
.9652 .19092 L
.96912 .15807 L
.9722 .13211 L
.97441 .11333 L
.97574 .10197 L
.97619 .09817 L
s
.71512 1.88426 m
.71556 1.90955 L
.7169 1.93534 L
.71911 1.96188 L
.72219 1.98955 L
.72611 2.01869 L
.73085 2.04964 L
.73637 2.08271 L
.74264 2.11817 L
.74961 2.15628 L
.75724 2.19724 L
.76548 2.24121 L
.77426 2.28831 L
.78352 2.33859 L
.79322 2.39207 L
.80327 2.44867 L
.81361 2.50828 L
.82417 2.5707 L
.83487 2.63567 L
.84565 2.70288 L
.85643 2.77193 L
.86714 2.84236 L
.8777 2.91368 L
.88804 2.98531 L
.89809 3.05666 L
.90778 3.12709 L
.91705 3.19594 L
.92583 3.26252 L
.93406 3.32615 L
.94169 3.38615 L
.94867 3.44188 L
.95493 3.49271 L
.96046 3.53805 L
.9652 3.57737 L
.96912 3.61021 L
.9722 3.63618 L
.97441 3.65496 L
.97574 3.66632 L
.97619 3.67012 L
s
.02381 .09535 m
.02427 .09925 L
.02564 .11093 L
.02792 .13023 L
.03109 .15691 L
.03513 .19065 L
.04001 .23103 L
.04569 .27757 L
.05215 .32971 L
.05933 .38685 L
.06718 .44834 L
.07566 .51349 L
.0847 .58159 L
.09424 .65194 L
.10422 .72383 L
.11457 .79657 L
.12522 .8695 L
.13609 .94199 L
.14711 1.01346 L
.15821 1.08338 L
.16931 1.15129 L
.18033 1.21679 L
.1912 1.27953 L
.20185 1.33927 L
.2122 1.39579 L
.22218 1.44898 L
.23172 1.49877 L
.24076 1.54517 L
.24924 1.58825 L
.25709 1.62813 L
.26427 1.66497 L
.27072 1.699 L
.27641 1.73047 L
.28129 1.75969 L
.28533 1.78697 L
.2885 1.81267 L
.29078 1.83717 L
.29215 1.86086 L
.29261 1.88404 L
s
.02381 3.67294 m
.02427 3.66903 L
.02564 3.65736 L
.02792 3.63806 L
.03109 3.61137 L
.03513 3.57764 L
.04001 3.53726 L
.04569 3.49072 L
.05215 3.43857 L
.05933 3.38144 L
.06718 3.31995 L
.07566 3.2548 L
.0847 3.1867 L
.09424 3.11635 L
.10422 3.04446 L
.11457 2.97171 L
.12522 2.89879 L
.13609 2.8263 L
.14711 2.75483 L
.15821 2.68491 L
.16931 2.617 L
.18033 2.5515 L
.1912 2.48876 L
.20185 2.42902 L
.2122 2.3725 L
.22218 2.31931 L
.23172 2.26952 L
.24076 2.22311 L
.24924 2.18004 L
.25709 2.14016 L
.26427 2.10332 L
.27072 2.06929 L
.27641 2.03782 L
.28129 2.0086 L
.28533 1.98132 L
.2885 1.95562 L
.29078 1.93112 L
.29215 1.90743 L
.29261 1.88425 L
s
.4141 1.88408 m
.41439 1.87221 L
.41527 1.8603 L
.41672 1.84846 L
.41875 1.83672 L
.42133 1.82515 L
.42445 1.81379 L
.42808 1.80271 L
.43221 1.79201 L
.4368 1.78175 L
.44182 1.77205 L
.44724 1.76301 L
.45301 1.75472 L
.45911 1.74728 L
.46549 1.74081 L
.47211 1.73538 L
.47891 1.73107 L
.48586 1.72794 L
.49291 1.72605 L
.5 1.72541 L
.50709 1.72605 L
.51414 1.72794 L
.52109 1.73107 L
.52789 1.73538 L
.53451 1.74081 L
.54089 1.74728 L
.54699 1.75472 L
.55276 1.76301 L
.55818 1.77205 L
.5632 1.78175 L
.56779 1.79201 L
.57192 1.80271 L
.57555 1.81379 L
.57867 1.82515 L
.58125 1.83672 L
.58328 1.84846 L
.58473 1.8603 L
.58561 1.87221 L
.5859 1.88408 L
s
.4141 1.88421 m
.41439 1.89608 L
.41527 1.90799 L
.41672 1.91983 L
.41875 1.93156 L
.42133 1.94314 L
.42445 1.9545 L
.42808 1.96557 L
.43221 1.97628 L
.4368 1.98654 L
.44182 1.99624 L
.44724 2.00528 L
.45301 2.01357 L
.45911 2.021 L
.46549 2.02748 L
.47211 2.03291 L
.47891 2.03722 L
.48586 2.04035 L
.49291 2.04224 L
.5 2.04287 L
.50709 2.04224 L
.51414 2.04035 L
.52109 2.03722 L
.52789 2.03291 L
.53451 2.02748 L
.54089 2.021 L
.54699 2.01357 L
.55276 2.00528 L
.55818 1.99624 L
.5632 1.98654 L
.56779 1.97628 L
.57192 1.96557 L
.57555 1.9545 L
.57867 1.94314 L
.58125 1.93156 L
.58328 1.91983 L
.58473 1.90799 L
.58561 1.89608 L
.5859 1.88421 L
s
.70739 1.88404 m
.70785 1.86086 L
.70922 1.83717 L
.7115 1.81267 L
.71467 1.78697 L
.71871 1.75969 L
.72359 1.73047 L
.72928 1.699 L
.73573 1.66497 L
.74291 1.62813 L
.75076 1.58825 L
.75924 1.54517 L
.76828 1.49877 L
.77782 1.44898 L
.7878 1.39579 L
.79815 1.33927 L
.8088 1.27953 L
.81967 1.21679 L
.83069 1.15129 L
.84179 1.08338 L
.85289 1.01346 L
.86391 .94199 L
.87478 .8695 L
.88543 .79657 L
.89578 .72383 L
.90576 .65194 L
.9153 .58159 L
.92434 .51349 L
.93282 .44834 L
.94067 .38685 L
.94785 .32971 L
.95431 .27757 L
.95999 .23103 L
.96487 .19065 L
.96891 .15691 L
.97208 .13023 L
.97436 .11093 L
.97573 .09925 L
.97619 .09535 L
s
.70739 1.88425 m
.70785 1.90743 L
.70922 1.93112 L
.7115 1.95562 L
.71467 1.98132 L
.71871 2.0086 L
.72359 2.03782 L
.72928 2.06929 L
.73573 2.10332 L
.74291 2.14016 L
.75076 2.18004 L
.75924 2.22311 L
.76828 2.26952 L
.77782 2.31931 L
.7878 2.3725 L
.79815 2.42902 L
.8088 2.48876 L
.81967 2.5515 L
.83069 2.617 L
.84179 2.68491 L
.85289 2.75483 L
.86391 2.8263 L
.87478 2.89879 L
.88543 2.97171 L
.89578 3.04446 L
.90576 3.11635 L
.9153 3.1867 L
.92434 3.2548 L
.93282 3.31995 L
.94067 3.38144 L
.94785 3.43857 L
.95431 3.49072 L
.95999 3.53726 L
.96487 3.57764 L
.96891 3.61137 L
.97208 3.63806 L
.97436 3.65736 L
.97573 3.66903 L
.97619 3.67294 L
s
.02381 .09253 m
.02429 .09658 L
.02571 .10867 L
.02807 .12864 L
.03136 .15625 L
.03555 .19115 L
.04061 .2329 L
.0465 .28099 L
.05319 .33484 L
.06064 .3938 L
.06878 .4572 L
.07757 .52431 L
.08695 .59438 L
.09684 .66668 L
.10719 .74046 L
.11792 .815 L
.12896 .8896 L
.14023 .9636 L
.15166 1.0364 L
.16317 1.10746 L
.17468 1.17628 L
.18611 1.24245 L
.19738 1.30561 L
.20842 1.36551 L
.21915 1.42193 L
.2295 1.47476 L
.23939 1.52392 L
.24876 1.56942 L
.25755 1.61135 L
.2657 1.64981 L
.27314 1.685 L
.27984 1.71713 L
.28573 1.74649 L
.29079 1.77339 L
.29498 1.79817 L
.29826 1.82122 L
.30063 1.84294 L
.30205 1.86377 L
.30253 1.88405 L
s
.02381 3.67576 m
.02429 3.67171 L
.02571 3.65962 L
.02807 3.63965 L
.03136 3.61204 L
.03555 3.57714 L
.04061 3.53539 L
.0465 3.4873 L
.05319 3.43345 L
.06064 3.37449 L
.06878 3.31109 L
.07757 3.24398 L
.08695 3.17391 L
.09684 3.10161 L
.10719 3.02783 L
.11792 2.95329 L
.12896 2.87869 L
.14023 2.80469 L
.15166 2.73188 L
.16317 2.66083 L
.17468 2.59201 L
.18611 2.52584 L
.19738 2.46268 L
.20842 2.40278 L
.21915 2.34636 L
.2295 2.29353 L
.23939 2.24437 L
.24876 2.19886 L
.25755 2.15694 L
.2657 2.11848 L
.27314 2.08329 L
.27984 2.05116 L
.28573 2.0218 L
.29079 1.9949 L
.29498 1.97012 L
.29826 1.94707 L
.30063 1.92535 L
.30205 1.90452 L
.30253 1.88424 L
s
.39325 1.88408 m
.39362 1.87108 L
.39471 1.85799 L
.39652 1.84488 L
.39904 1.83174 L
.40224 1.81859 L
.40612 1.8055 L
.41063 1.79254 L
.41576 1.77981 L
.42146 1.76744 L
.4277 1.75556 L
.43443 1.74434 L
.44161 1.73394 L
.44919 1.72453 L
.45712 1.71625 L
.46534 1.70927 L
.47379 1.70369 L
.48243 1.69963 L
.49118 1.69716 L
.5 1.69633 L
.50882 1.69716 L
.51757 1.69963 L
.52621 1.70369 L
.53466 1.70927 L
.54288 1.71625 L
.55081 1.72453 L
.55839 1.73394 L
.56557 1.74434 L
.5723 1.75556 L
.57854 1.76744 L
.58424 1.77981 L
.58937 1.79254 L
.59388 1.8055 L
.59776 1.81859 L
.60096 1.83174 L
.60348 1.84488 L
.60529 1.85799 L
.60638 1.87108 L
.60675 1.88408 L
s
.39325 1.88421 m
.39362 1.89721 L
.39471 1.9103 L
.39652 1.92341 L
.39904 1.93655 L
.40224 1.94969 L
.40612 1.96278 L
.41063 1.97575 L
.41576 1.98848 L
.42146 2.00085 L
.4277 2.01273 L
.43443 2.02395 L
.44161 2.03434 L
.44919 2.04376 L
.45712 2.05203 L
.46534 2.05902 L
.47379 2.0646 L
.48243 2.06866 L
.49118 2.07113 L
.5 2.07196 L
.50882 2.07113 L
.51757 2.06866 L
.52621 2.0646 L
.53466 2.05902 L
.54288 2.05203 L
.55081 2.04376 L
.55839 2.03434 L
.56557 2.02395 L
.5723 2.01273 L
.57854 2.00085 L
.58424 1.98848 L
.58937 1.97575 L
.59388 1.96278 L
.59776 1.94969 L
.60096 1.93655 L
.60348 1.92341 L
.60529 1.9103 L
.60638 1.89721 L
.60675 1.88421 L
s
.69747 1.88405 m
.69795 1.86377 L
.69937 1.84294 L
.70174 1.82122 L
.70502 1.79817 L
.70921 1.77339 L
.71427 1.74649 L
.72016 1.71713 L
.72686 1.685 L
.7343 1.64981 L
.74245 1.61135 L
.75124 1.56942 L
.76061 1.52392 L
.7705 1.47476 L
.78085 1.42193 L
.79158 1.36551 L
.80262 1.30561 L
.81389 1.24245 L
.82532 1.17628 L
.83683 1.10746 L
.84834 1.0364 L
.85977 .9636 L
.87104 .8896 L
.88208 .815 L
.89281 .74046 L
.90316 .66668 L
.91305 .59438 L
.92243 .52431 L
.93122 .4572 L
.93936 .3938 L
.94681 .33484 L
.9535 .28099 L
.95939 .2329 L
.96445 .19115 L
.96864 .15625 L
.97193 .12864 L
.97429 .10867 L
.97571 .09658 L
.97619 .09253 L
s
.69747 1.88424 m
.69795 1.90452 L
.69937 1.92535 L
.70174 1.94707 L
.70502 1.97012 L
.70921 1.9949 L
.71427 2.0218 L
.72016 2.05116 L
.72686 2.08329 L
.7343 2.11848 L
.74245 2.15694 L
.75124 2.19886 L
.76061 2.24437 L
.7705 2.29353 L
.78085 2.34636 L
.79158 2.40278 L
.80262 2.46268 L
.81389 2.52584 L
.82532 2.59201 L
.83683 2.66083 L
.84834 2.73188 L
.85977 2.80469 L
.87104 2.87869 L
.88208 2.95329 L
.89281 3.02783 L
.90316 3.10161 L
.91305 3.17391 L
.92243 3.24398 L
.93122 3.31109 L
.93936 3.37449 L
.94681 3.43345 L
.9535 3.4873 L
.95939 3.53539 L
.96445 3.57714 L
.96864 3.61204 L
.97193 3.63965 L
.97429 3.65962 L
.97571 3.67171 L
.97619 3.67576 L
s
.02381 .08972 m
.02431 .09398 L
.02581 .10672 L
.02831 .12775 L
.03178 .15681 L
.03619 .19353 L
.04153 .23743 L
.04775 .28795 L
.05481 .34448 L
.06267 .4063 L
.07126 .47269 L
.08054 .54287 L
.09043 .61603 L
.10087 .69138 L
.11179 .76812 L
.12311 .84546 L
.13475 .92267 L
.14665 .99905 L
.15871 1.07395 L
.17085 1.14678 L
.18299 1.21705 L
.19505 1.28429 L
.20695 1.34816 L
.2186 1.40836 L
.22992 1.46469 L
.24084 1.517 L
.25128 1.56525 L
.26117 1.60943 L
.27044 1.64962 L
.27903 1.68593 L
.28689 1.71856 L
.29395 1.74772 L
.30017 1.7737 L
.30551 1.79681 L
.30993 1.81745 L
.31339 1.83601 L
.31589 1.85297 L
.31739 1.86884 L
.31789 1.88408 L
s
.02381 3.67857 m
.02431 3.6743 L
.02581 3.66157 L
.02831 3.64054 L
.03178 3.61148 L
.03619 3.57476 L
.04153 3.53086 L
.04775 3.48033 L
.05481 3.42381 L
.06267 3.36199 L
.07126 3.2956 L
.08054 3.22542 L
.09043 3.15226 L
.10087 3.07691 L
.11179 3.00017 L
.12311 2.92283 L
.13475 2.84562 L
.14665 2.76924 L
.15871 2.69434 L
.17085 2.62151 L
.18299 2.55124 L
.19505 2.484 L
.20695 2.42013 L
.2186 2.35993 L
.22992 2.3036 L
.24084 2.25129 L
.25128 2.20304 L
.26117 2.15885 L
.27044 2.11867 L
.27903 2.08236 L
.28689 2.04973 L
.29395 2.02057 L
.30017 1.99459 L
.30551 1.97147 L
.30993 1.95084 L
.31339 1.93228 L
.31589 1.91532 L
.31739 1.89945 L
.31789 1.88421 L
s
.36875 1.88409 m
.36919 1.87191 L
.37054 1.85949 L
.37276 1.84674 L
.37586 1.83355 L
.3798 1.81988 L
.38456 1.80575 L
.39012 1.79126 L
.39642 1.77656 L
.40343 1.76186 L
.4111 1.7474 L
.41938 1.73345 L
.42821 1.7203 L
.43753 1.70822 L
.44728 1.69748 L
.45738 1.68832 L
.46778 1.68096 L
.4784 1.67557 L
.48916 1.67229 L
.5 1.67119 L
.51084 1.67229 L
.5216 1.67557 L
.53222 1.68096 L
.54262 1.68832 L
.55272 1.69748 L
.56247 1.70822 L
.57179 1.7203 L
.58062 1.73345 L
.5889 1.7474 L
.59657 1.76186 L
.60358 1.77656 L
.60988 1.79126 L
.61544 1.80575 L
.6202 1.81988 L
.62414 1.83355 L
.62724 1.84674 L
.62946 1.85949 L
.63081 1.87191 L
.63125 1.88409 L
s
.36875 1.8842 m
.36919 1.89638 L
.37054 1.9088 L
.37276 1.92154 L
.37586 1.93473 L
.3798 1.94841 L
.38456 1.96254 L
.39012 1.97703 L
.39642 1.99173 L
.40343 2.00643 L
.4111 2.02089 L
.41938 2.03483 L
.42821 2.04799 L
.43753 2.06007 L
.44728 2.07081 L
.45738 2.07997 L
.46778 2.08733 L
.4784 2.09272 L
.48916 2.096 L
.5 2.0971 L
.51084 2.096 L
.5216 2.09272 L
.53222 2.08733 L
.54262 2.07997 L
.55272 2.07081 L
.56247 2.06007 L
.57179 2.04799 L
.58062 2.03483 L
.5889 2.02089 L
.59657 2.00643 L
.60358 1.99173 L
.60988 1.97703 L
.61544 1.96254 L
.6202 1.94841 L
.62414 1.93473 L
.62724 1.92154 L
.62946 1.9088 L
.63081 1.89638 L
.63125 1.8842 L
s
.68211 1.88408 m
.68261 1.86884 L
.68411 1.85297 L
.68661 1.83601 L
.69007 1.81745 L
.69449 1.79681 L
.69983 1.7737 L
.70605 1.74772 L
.71311 1.71856 L
.72097 1.68593 L
.72956 1.64962 L
.73883 1.60943 L
.74872 1.56525 L
.75916 1.517 L
.77008 1.46469 L
.7814 1.40836 L
.79305 1.34816 L
.80495 1.28429 L
.81701 1.21705 L
.82915 1.14678 L
.84129 1.07395 L
.85335 .99905 L
.86525 .92267 L
.87689 .84546 L
.88821 .76812 L
.89913 .69138 L
.90957 .61603 L
.91946 .54287 L
.92874 .47269 L
.93733 .4063 L
.94519 .34448 L
.95225 .28795 L
.95847 .23743 L
.96381 .19353 L
.96822 .15681 L
.97169 .12775 L
.97419 .10672 L
.97569 .09398 L
.97619 .08972 L
s
.68211 1.88421 m
.68261 1.89945 L
.68411 1.91532 L
.68661 1.93228 L
.69007 1.95084 L
.69449 1.97147 L
.69983 1.99459 L
.70605 2.02057 L
.71311 2.04973 L
.72097 2.08236 L
.72956 2.11867 L
.73883 2.15885 L
.74872 2.20304 L
.75916 2.25129 L
.77008 2.3036 L
.7814 2.35993 L
.79305 2.42013 L
.80495 2.484 L
.81701 2.55124 L
.82915 2.62151 L
.84129 2.69434 L
.85335 2.76924 L
.86525 2.84562 L
.87689 2.92283 L
.88821 3.00017 L
.89913 3.07691 L
.90957 3.15226 L
.91946 3.22542 L
.92874 3.2956 L
.93733 3.36199 L
.94519 3.42381 L
.95225 3.48033 L
.95847 3.53086 L
.96381 3.57476 L
.96822 3.61148 L
.97169 3.64054 L
.97419 3.66157 L
.97569 3.6743 L
.97619 3.67857 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  ImageSize->{48.25, 182.25},
  ImageMargins->{{205.5, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001P0001K2000`400?l00000o`00003oH03oool0
0600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03o
ool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00
H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?oo
o`00H03oool00380oooo00<000000?ooo`3oool0:`3oool00380oooo00<000000?ooo`3oool0:`3o
ool00380oooo00<000000?ooo`3oool0:`3oool00380oooo00<000000?ooo`3oool0:`3oool00380
oooo00<000000?ooo`3oool0:`3oool00380oooo00<000000?ooo`3oool0:`3oool00380oooo00<0
00000?ooo`3oool0:`3oool00380oooo00<000000?ooo`3oool0:`3oool000`0oooo00<00?l00?oo
o`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`03003o003oool0oooo00@0oooo000<0?ooo`03
003o003oool0oooo02<0oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`040?ooo`00
303oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo00<00?l00?ooo`3oool0
103oool000`0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`03003o003o
ool0oooo00@0oooo000<0?ooo`03003o003oool0oooo02<0oooo0P00000T0?ooo`03003o003oool0
oooo00D0oooo000<0?ooo`03003o003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`00
o`00oooo0?ooo`050?ooo`00303oool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo02<0
oooo00<00?l00?ooo`3oool01@3oool000`0oooo0P00o`0T0?ooo`030000003oool0oooo02<0oooo
00<00?l00?ooo`3oool01@3oool000`0oooo0P00o`0T0?ooo`030000003oool0oooo02<0oooo00<0
0?l00?ooo`3oool01@3oool000`0oooo0P00o`0T0?ooo`030000003oool0oooo02<0oooo00<00?l0
0?ooo`3oool01@3oool000d0oooo00<00?l00?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?oo
o`03003o003oool0oooo00D0oooo000=0?ooo`03003o003oool0oooo0280oooo00<000000?ooo`3o
ool08`3oool00`00o`00oooo0?ooo`050?ooo`003@3oool00`00o`00oooo0?ooo`0<0?ooo`L00000
1P3oool4000000D0oooo00<000000?ooo`3oool08`3oool00`00o`00oooo0?ooo`050?ooo`003@3o
ool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo0P00o`070?ooo`003@3oool0
0`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo00<00?l00?ooo`3oool01P3oool0
00d0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`03003o003oool0oooo00H0oooo000=0?oo
o`03003o003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`000000903oool00`00o`00oooo0?ooo`060?ooo`003@3oool00`00
o`00oooo00000007000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo0?ooo`8000008`3oool00`00o`00oooo0?ooo`060?ooo`003@3oool2003o
0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000008`3oool2003o00P0oooo000>0?ooo`03003o003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000008`3oool2
003o00P0oooo000>0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000008`3oool2003o00P0oooo000>0?oo
o`03003o003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000008`3oool2003o00P0oooo000>0?ooo`03003o003oool0oooo
00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08@3oool00`00o`00oooo0?ooo`070?ooo`003P3oool2003o00/0
oooo0`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo00L0oooo000>0?ooo`800?l0
3P3oool2000000T0oooo100000050?ooo`030000003oool0oooo0240oooo00<00?l00?ooo`3oool0
1`3oool000h0oooo0P00o`0R0?ooo`030000003oool0oooo0240oooo00<00?l00?ooo`3oool01`3o
ool000h0oooo0P00o`0R0?ooo`030000003oool0oooo0240oooo00<00?l00?ooo`3oool01`3oool0
00h0oooo0P00o`0R0?ooo`030000003oool0oooo0200oooo0P00o`090?ooo`003`3oool00`00o`00
oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo0P00o`090?ooo`003`3oool00`00o`00oooo
0?ooo`0P0?ooo`8000008@3oool2003o00T0oooo000?0?ooo`03003o003oool0oooo0200oooo00<0
00000?ooo`3oool0803oool2003o00T0oooo000?0?ooo`03003o003oool0oooo0200oooo00<00000
0?ooo`3oool0803oool00`00o`00oooo0?ooo`080?ooo`003`3oool2003o0240oooo00<000000?oo
o`3oool0803oool00`00o`00oooo0?ooo`080?ooo`003`3oool2003o0240oooo00<000000?ooo`3o
ool0803oool00`00o`00oooo0?ooo`080?ooo`003`3oool2003o0240oooo00<000000?ooo`3oool0
7`3oool2003o00X0oooo000?0?ooo`800?l08@3oool00`000000oooo0?ooo`0O0?ooo`800?l02P3o
ool00100oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`800?l02P3oool0
0100oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`800?l02P3oool00100
oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo00T0
oooo000@0?ooo`800?l0803oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo00T0oooo
000@0?ooo`800?l0803oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo00T0oooo000@
0?ooo`800?l0803oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo00T0oooo000@0?oo
o`800?l0803oool2000001l0oooo0P00o`0;0?ooo`004@3oool00`00o`00oooo0?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo0P00o`0;0?ooo`004@3oool00`00o`00oooo0?ooo`0N0?ooo`030000
003oool0oooo01h0oooo0P00o`0;0?ooo`004@3oool00`00o`00oooo0?ooo`0N0?ooo`030000003o
ool0oooo01h0oooo0P00o`0;0?ooo`004@3oool00`00o`00oooo0?ooo`0N0?ooo`030000003oool0
oooo01h0oooo0P00o`0;0?ooo`004@3oool2003o01l0oooo00<000000?ooo`3oool07P3oool00`00
o`00oooo0?ooo`0:0?ooo`004@3oool2003o01l0oooo00<000000?ooo`3oool07@3oool2003o00`0
oooo000A0?ooo`800?l07`3oool00`000000oooo0?ooo`0M0?ooo`800?l0303oool00140oooo0P00
o`0O0?ooo`030000003oool0oooo01d0oooo0P00o`0<0?ooo`004P3oool00`00o`00oooo0?ooo`0M
0?ooo`030000003oool0oooo01d0oooo0P00o`0<0?ooo`004P3oool00`00o`00oooo0?ooo`0M0?oo
o`030000003oool0oooo01d0oooo0P00o`0<0?ooo`004P3oool2003o01h0oooo00<000000?ooo`3o
ool07@3oool00`00o`00oooo0?ooo`0;0?ooo`004P3oool2003o01h0oooo00<000000?ooo`3oool0
7@3oool00`00o`00oooo0?ooo`0;0?ooo`004P3oool2003o01h0oooo0P00000N0?ooo`03003o003o
ool0oooo00/0oooo000B0?ooo`800?l07P3oool00`000000oooo0?ooo`0L0?ooo`800?l03@3oool0
0180oooo0P00o`0N0?ooo`030000003oool0oooo01`0oooo0P00o`0=0?ooo`004P3oool2003o01h0
oooo00<000000?ooo`3oool0703oool2003o00d0oooo000C0?ooo`800?l07@3oool00`000000oooo
0?ooo`0L0?ooo`800?l03@3oool001<0oooo0P00o`0M0?ooo`030000003oool0oooo01`0oooo00<0
0?l00?ooo`3oool0303oool001<0oooo0P00o`0M0?ooo`030000003oool0oooo01`0oooo00<00?l0
0?ooo`3oool0303oool001<0oooo0P00o`0M0?ooo`030000003oool0oooo01/0oooo0P00o`0>0?oo
o`004`3oool2003o01d0oooo00<000000?ooo`3oool06`3oool2003o00h0oooo000C0?ooo`800?l0
7@3oool00`000000oooo0?ooo`0K0?ooo`800?l03P3oool001@0oooo0P00o`0L0?ooo`030000003o
ool0oooo01/0oooo0P00o`0>0?ooo`00503oool2003o01`0oooo00<000000?ooo`3oool06`3oool0
0`00o`00oooo0?ooo`0=0?ooo`00503oool2003o01`0oooo00<000000?ooo`3oool06`3oool00`00
o`00oooo0?ooo`0=0?ooo`00503oool2003o01`0oooo0P00000L0?ooo`03003o003oool0oooo00d0
oooo000D0?ooo`800?l0703oool00`000000oooo0?ooo`0K0?ooo`03003o003oool0oooo00d0oooo
000D0?ooo`800?l0703oool00`000000oooo0?ooo`0J0?ooo`800?l03`3oool001@0oooo0P00o`0L
0?ooo`030000003oool0oooo01X0oooo0P00o`0?0?ooo`005@3oool00`00o`00oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo0P00o`0?0?ooo`005@3oool2003o01/0oooo00<000000?ooo`3o
ool06P3oool2003o00l0oooo000E0?ooo`800?l06`3oool00`000000oooo0?ooo`0J0?ooo`03003o
003oool0oooo00h0oooo000E0?ooo`800?l06`3oool00`000000oooo0?ooo`0J0?ooo`03003o003o
ool0oooo00h0oooo000E0?ooo`800?l04P3oool4000000D0oooo00<000000?ooo`3oool06P3oool0
0`00o`00oooo0?ooo`0>0?ooo`005@3oool2003o0140oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo0P00o`0@0?ooo`005P3oool00`00o`00
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000K0?oo
o`800?l0403oool001H0oooo00<00?l00?ooo`3oool05@3oool01@000000oooo0?ooo`3oool00000
01/0oooo0P00o`0@0?ooo`005P3oool00`00o`00oooo0?ooo`0E0?ooo`050000003oool0oooo0?oo
o`0000006`3oool2003o0100oooo000F0?ooo`800?l00`3oool8000000/0oooo00@000000?ooo`3o
ool0oooo0P00000J0?ooo`03003o003oool0oooo00l0oooo000F0?ooo`800?l0403oool2000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`03003o003oool0oooo00l0
oooo000F0?ooo`800?l0403oool00`000000oooo00000002000000D0oooo00<000000?ooo`3oool0
603oool2003o0140oooo000G0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0H0?ooo`800?l04@3oool001L0oooo00<00?l00?ooo`3oool03P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo0P00o`0A0?ooo`005`3oool2003o
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`800?l04@3oool001L0
oooo0P00o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool2003o0140
oooo000G0?ooo`800?l03`3oool6000000@0oooo00<000000?ooo`3oool0603oool00`00o`00oooo
0?ooo`0@0?ooo`00603oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo0P00
o`0B0?ooo`00603oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo0P00o`0B
0?ooo`00603oool00`00o`00oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo0P00o`0B0?oo
o`00603oool2003o01P0oooo00<000000?ooo`3oool05`3oool2003o0180oooo000H0?ooo`800?l0
603oool00`000000oooo0?ooo`0G0?ooo`03003o003oool0oooo0140oooo000H0?ooo`800?l0603o
ool2000001L0oooo0P00o`0C0?ooo`00603oool2003o01P0oooo00<000000?ooo`3oool05P3oool2
003o01<0oooo000H0?ooo`800?l0603oool00`000000oooo0?ooo`0F0?ooo`800?l04`3oool001T0
oooo0P00o`0G0?ooo`030000003oool0oooo01H0oooo0P00o`0C0?ooo`006@3oool2003o01L0oooo
00<000000?ooo`3oool05P3oool00`00o`00oooo0?ooo`0B0?ooo`006@3oool2003o01L0oooo00<0
00000?ooo`3oool05P3oool00`00o`00oooo0?ooo`0B0?ooo`006@3oool2003o01L0oooo00<00000
0?ooo`3oool05@3oool2003o01@0oooo000I0?ooo`800?l05`3oool00`000000oooo0?ooo`0E0?oo
o`800?l0503oool001X0oooo0P00o`0F0?ooo`030000003oool0oooo01D0oooo0P00o`0D0?ooo`00
6P3oool2003o01H0oooo00<000000?ooo`3oool05@3oool2003o01@0oooo000J0?ooo`800?l05P3o
ool00`000000oooo0?ooo`0E0?ooo`03003o003oool0oooo01<0oooo000J0?ooo`800?l05P3oool0
0`000000oooo0?ooo`0D0?ooo`800?l05@3oool001X0oooo0P00o`0F0?ooo`030000003oool0oooo
01@0oooo0P00o`0E0?ooo`006`3oool00`00o`00oooo0?ooo`0D0?ooo`8000005@3oool2003o01D0
oooo000K0?ooo`03003o003oool0oooo01@0oooo00<000000?ooo`3oool0503oool2003o01D0oooo
000K0?ooo`800?l05@3oool00`000000oooo0?ooo`0D0?ooo`800?l05@3oool001/0oooo0P00o`0E
0?ooo`030000003oool0oooo01<0oooo0P00o`0F0?ooo`006`3oool2003o01D0oooo00<000000?oo
o`3oool04`3oool2003o01H0oooo000L0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3o
ool04`3oool2003o01H0oooo000L0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3oool0
4`3oool2003o01H0oooo000L0?ooo`03003o003oool0oooo01<0oooo00<000000?ooo`3oool04P3o
ool3003o01H0oooo000L0?ooo`800?l0503oool00`000000oooo0?ooo`0B0?ooo`800?l05`3oool0
01`0oooo0P00o`0D0?ooo`030000003oool0oooo0180oooo0P00o`0G0?ooo`00703oool2003o01@0
oooo00<000000?ooo`3oool04P3oool2003o01L0oooo000M0?ooo`03003o003oool0oooo0180oooo
00<000000?ooo`3oool04@3oool3003o01L0oooo000M0?ooo`800?l04`3oool00`000000oooo0?oo
o`0A0?ooo`<00?l05`3oool001d0oooo0P00o`0C0?ooo`8000004P3oool3003o01L0oooo000M0?oo
o`800?l04`3oool00`000000oooo0?ooo`0A0?ooo`800?l0603oool001d0oooo0`00o`0B0?ooo`03
0000003oool0oooo0140oooo0P00o`0H0?ooo`007@3oool3003o0180oooo00<000000?ooo`3oool0
4@3oool2003o01P0oooo000M0?ooo`<00?l04P3oool00`000000oooo0?ooo`0A0?ooo`800?l0603o
ool001h0oooo0P00o`0B0?ooo`030000003oool0oooo0100oooo0`00o`0H0?ooo`007P3oool3003o
0140oooo00<000000?ooo`3oool0403oool2003o01T0oooo000N0?ooo`<00?l04@3oool00`000000
oooo0?ooo`0@0?ooo`800?l06@3oool001l0oooo0P00o`0A0?ooo`03003o003oool0oooo0100oooo
0P00o`0I0?ooo`003`3oool5000000H0oooo1@000002003o00030000003oool0oooo00@0oooo1`00
0000103oool00?l0003o00000003003o00H0oooo1`0000001@3oool00?l0003o0000o`00oooo00P0
00001P3oool5000000D0oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`800?l000<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool00?l00080oooo00D00?l00?ooo`3oool0oooo003o00080?ooo`030000003oool0oooo
0080oooo0`00o`000`3oool000000?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`005@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`800?l02P3oool01@000000oooo003o0000o`00oooo00D00?l00P3oool0
0`00o`00oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`00o`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`03003o00T0oooo00D00000003o003oool0oooo003o00020?ooo`030000003oool0
oooo00800?l000<0oooo003o003oool01@3oool00`000000oooo0?ooo`020?ooo`<00?l00`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0040oooo000E0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`00o`000P00o`090?ooo`0400000000o`00oooo003o0080oooo1000o`00
1@3oool00?l00?ooo`3oool00?l000D0oooo00<000000?ooo`3oool00P3oool2003o00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`010?ooo`000P3oool8000000@0oooo20000005
0?ooo`@000000`00o`000`000000oooo0?ooo`060?ooo`03003o003oool00?l000<00?l000H0oooo
0000003oool0oooo003o003oool3003o00D0oooo00@000000?ooo`3oool0oooo0`00o`060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool001@0oooo00<000000?ooo`3oool0
203oool3003o00T0oooo0P00o`000`3oool00?l0003o00020?ooo`060000003oool0oooo0?ooo`00
o`00oooo0P00o`050?ooo`040000003oool0oooo0?ooo`<00?l01`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo000A0?ooo`<00000303oool2003o00P0oooo00D00?l00000
0000o`00oooo003o00020?ooo`@00?l00P3oool01000o`00oooo003o0000o`040?ooo`040000003o
ool0oooo0?ooo`<00?l0203oool00`000000oooo0?ooo`070?ooo`<000001@3oool001@0oooo00<0
00000?ooo`3oool02@3oool3003o00L0oooo0P00o`000`3oool00?l0003o0002003o00030?ooo`00
0000oooo00800?l000H0oooo003o003oool00?l00?ooo`00o`030?ooo`040000003oool0oooo0?oo
o`<00?l02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo000E0?ooo`03
0000003oool0oooo00P0oooo0`00o`060?ooo`07003o003oool00?l00?ooo`00o`00oooo003o0002
0?ooo`040000003oool0oooo003o0080oooo00@00?l00?ooo`00o`000?l00`3oool00`000000oooo
0?ooo`04003o00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00o`060?ooo`05003o003o
ool00?l0003o003oool00P00o`020?ooo`0;0000003oool0oooo0?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`000P3oool00`000000oooo0?ooo`04003o0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000>0?ooo`800000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo1000o`030?ooo`0800000000o`00
0000003o000000000?l00?ooo`00o`020?ooo`<00?l00P3oool3003o00070?ooo`00o`000000003o
00000000oooo000000020?ooo`<00?l0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo0P0000040?ooo`030000003oool0oooo0080oooo000@0?ooo`@00000203oool40000
00@00?l0103oool02000o`00oooo003o000000000?l00?ooo`00o`00oooo0P00o`000`000000oooo
003o00020?ooo`07003o003oool00?l0003o003oool00?l00?ooo`02000000030?ooo`00o`00oooo
00800?l01@3oool4000000T0oooo100000050?ooo`00803oool4003o00@0oooo00@00?l00?ooo`00
o`00oooo0P00o`020?ooo`04003o003oool000000?ooo`800?l000<0oooo003o003oool00P00o`00
0`3oool00?l00?ooo`030?ooo`@00?l06`3oool00200oooo1000o`040?ooo`06003o003oool00?l0
003o003oool00?l00P3oool00`00o`00oooo000000020?ooo`09003o003oool00?l00?ooo`00o`00
oooo003o003oool00?l000<0oooo1000o`0K0?ooo`00803oool4003o00@0oooo00P00?l00?ooo`00
o`000?l00?ooo`00o`00oooo003o0080oooo00`000000?ooo`3oool00?l00?ooo`00o`00oooo003o
003oool00?l00?ooo`00o`030?ooo`@00?l06`3oool00200oooo1000o`040?ooo`08003o003oool0
0?l0003o003oool00?l00?ooo`00o`020?ooo`0<0000003oool0oooo003o003oool00?l00?ooo`00
o`00oooo003o003oool00?l00`3oool4003o01/0oooo000:0?oooaH000001000o`0400000008003o
000000000?l0003o000000000?l000000000o`0500000009003o000000000?l000000000o`000000
003o000000000?l000<000001000o`0G000000@0oooo000P0?ooo`@00?l0103oool02000o`00oooo
003o0000o`00oooo003o003oool00?l00P3oool030000000oooo0?ooo`00o`00oooo003o003oool0
0?l00?ooo`00o`00oooo003o00<0oooo1000o`0K0?ooo`00803oool4003o00@0oooo00L00?l00?oo
o`00o`000?l00?ooo`00o`00oooo00800?l000d0oooo0000003oool0oooo003o003oool00?l00?oo
o`00o`00oooo003o003oool00?l000<0oooo1000o`0K0?ooo`00803oool4003o00@0oooo00H00?l0
0?ooo`00o`000?l00?ooo`00o`020?ooo`03003o003oool000000080oooo00T00?l00?ooo`00o`00
oooo003o003oool00?l00?ooo`00o`000`3oool4003o01/0oooo000P0?ooo`@00?l0103oool01000
o`00oooo003o003oool3003o00060?ooo`00o`00oooo0000003oool00?l00P3oool01P00o`00oooo
003o0000o`00oooo003o00@0oooo1000o`0K0?ooo`00803oool4003o00@0oooo00L00?l00?ooo`00
o`00oooo003o003oool00?l00080oooo1000o`020?ooo`@00?l000<0oooo003o003oool0103oool3
003o01/0oooo000P0?ooo`<00?l01P3oool01P00o`00oooo003o0000o`00oooo003o00<0oooo00/0
0?l00?ooo`3oool0oooo003o003oool00?l00?ooo`00o`00oooo003o00050?ooo`@00?l06P3oool0
0200oooo0`00o`060?ooo`07003o003oool00?l00?ooo`00o`00oooo003o00020?ooo`080000003o
ool0oooo0?ooo`00o`00oooo003o003oool2003o00H0oooo1000o`0J0?ooo`00803oool3003o00H0
oooo00H00?l00?ooo`00o`00oooo003o003oool2003o000;0?ooo`000000oooo0?ooo`00o`00oooo
003o003oool00?l00?ooo`00o`001P3oool4003o01X0oooo000P0?ooo`<00?l01`3oool01P00o`00
oooo003o003oool00?l00?ooo`800?l000<000000?ooo`00o`000P3oool01@00o`00oooo003o003o
ool00?l000L0oooo0`00o`0J0?ooo`007`3oool3003o00P0oooo00D00?l00?ooo`00o`00oooo003o
00020?ooo`<00?l00P3oool3003o00030?ooo`00o`00oooo00L0oooo0`00o`0J0?ooo`007`3oool3
003o00T0oooo00D00?l00?ooo`00o`00oooo003o00020?ooo`030000003oool0oooo00800?l000<0
oooo003o0000o`002@3oool3003o01X0oooo000O0?ooo`<00?l02P3oool01000o`00oooo003o003o
ool2003o000800000000o`000?l0003o003oool00?l00?ooo`00o`090?ooo`<00?l06P3oool001l0
oooo0`00o`0:0?ooo`04003o003oool00?l0003o0080oooo0P00o`020?ooo`03003o003oool00?l0
00/0oooo0`00o`0I0?ooo`007`3oool3003o00/0oooo00L00?l00?ooo`00o`000?l00?ooo`000000
oooo00800?l000<0oooo003o003oool02`3oool3003o01T0oooo000O0?ooo`800?l03@3oool00`00
o`00oooo0?ooo`04003o0080oooo00<00?l00?ooo`3oool02P3oool3003o01T0oooo000O0?ooo`80
0?l03P3oool2003o00040?ooo`000000oooo0?ooo`800?l03@3oool3003o01T0oooo000O0?ooo`80
0?l03`3oool5003o00l0oooo0`00o`0I0?ooo`007`3oool2003o0140oooo00<000000?ooo`3oool0
403oool2003o01T0oooo000N0?ooo`<00?l04@3oool00`000000oooo0?ooo`0@0?ooo`800?l06@3o
ool001h0oooo0`00o`0A0?ooo`030000003oool0oooo0100oooo0P00o`0I0?ooo`007P3oool2003o
0180oooo00<000000?ooo`3oool04@3oool2003o01P0oooo000M0?ooo`<00?l04P3oool00`000000
oooo0?ooo`0A0?ooo`800?l0603oool001d0oooo0`00o`0B0?ooo`030000003oool0oooo0140oooo
0P00o`0H0?ooo`007@3oool2003o01<0oooo00<000000?ooo`3oool04@3oool2003o01P0oooo000M
0?ooo`800?l04`3oool00`000000oooo0?ooo`0A0?ooo`<00?l05`3oool001d0oooo0P00o`0C0?oo
o`8000004P3oool3003o01L0oooo000M0?ooo`800?l04`3oool00`000000oooo0?ooo`0A0?ooo`<0
0?l05`3oool001`0oooo0P00o`0D0?ooo`030000003oool0oooo0140oooo0`00o`0G0?ooo`00703o
ool2003o01@0oooo00<000000?ooo`3oool04P3oool2003o01L0oooo000L0?ooo`800?l0503oool0
0`000000oooo0?ooo`0B0?ooo`800?l05`3oool001`0oooo0P00o`0D0?ooo`030000003oool0oooo
0180oooo0P00o`0G0?ooo`00703oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo0180
oooo0`00o`0F0?ooo`00703oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
0P00o`0F0?ooo`00703oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo0P00
o`0F0?ooo`006`3oool2003o01D0oooo00<000000?ooo`3oool04`3oool2003o01H0oooo000K0?oo
o`800?l05@3oool00`000000oooo0?ooo`0C0?ooo`800?l05P3oool001/0oooo00<00?l00?ooo`3o
ool0503oool00`000000oooo0?ooo`0D0?ooo`800?l05@3oool001/0oooo00<00?l00?ooo`3oool0
503oool2000001D0oooo0P00o`0E0?ooo`006P3oool2003o01H0oooo00<000000?ooo`3oool0503o
ool2003o01D0oooo000J0?ooo`800?l05P3oool00`000000oooo0?ooo`0D0?ooo`800?l05@3oool0
01X0oooo0P00o`0F0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool04`3oool001X0
oooo0P00o`0F0?ooo`030000003oool0oooo01D0oooo0P00o`0D0?ooo`006P3oool2003o01H0oooo
00<000000?ooo`3oool05@3oool2003o01@0oooo000J0?ooo`800?l05P3oool00`000000oooo0?oo
o`0E0?ooo`800?l0503oool001T0oooo0P00o`0G0?ooo`030000003oool0oooo01D0oooo0P00o`0D
0?ooo`006@3oool2003o01L0oooo00<000000?ooo`3oool05@3oool2003o01@0oooo000I0?ooo`80
0?l05`3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo0180oooo000I0?ooo`800?l0
5`3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo0180oooo000I0?ooo`800?l05`3o
ool00`000000oooo0?ooo`0F0?ooo`800?l04`3oool001P0oooo0P00o`0H0?ooo`030000003oool0
oooo01H0oooo0P00o`0C0?ooo`00603oool2003o01P0oooo0P00000G0?ooo`800?l04`3oool001P0
oooo0P00o`0H0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool04@3oool001P0oooo
0P00o`0H0?ooo`030000003oool0oooo01L0oooo00<00?l00?ooo`3oool04@3oool001P0oooo0P00
o`0H0?ooo`030000003oool0oooo01L0oooo0P00o`0B0?ooo`00603oool00`00o`00oooo0?ooo`0G
0?ooo`030000003oool0oooo01L0oooo0P00o`0B0?ooo`00603oool00`00o`00oooo0?ooo`0G0?oo
o`030000003oool0oooo01L0oooo0P00o`0B0?ooo`005`3oool2003o01T0oooo00<000000?ooo`3o
ool05`3oool2003o0180oooo000G0?ooo`800?l06@3oool00`000000oooo0?ooo`0H0?ooo`03003o
003oool0oooo0100oooo000G0?ooo`800?l0403oool4000000D0oooo00<000000?ooo`3oool0603o
ool2003o0140oooo000G0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo0P00o`0A0?ooo`005`3oool00`00
o`00oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000J
0?ooo`800?l04@3oool001H0oooo0P00o`0F0?ooo`050000003oool0oooo0?ooo`0000006P3oool2
003o0140oooo000F0?ooo`800?l05P3oool01@000000oooo0?ooo`3oool0000001X0oooo0P00o`0A
0?ooo`005P3oool2003o01H0oooo00@000000?ooo`3oool0oooo0P00000J0?ooo`03003o003oool0
oooo00l0oooo000F0?ooo`800?l0403oool2000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0I0?ooo`03003o003oool0oooo00l0oooo000F0?ooo`03003o003oool0oooo00l0
oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo01T0oooo0P00o`0@0?ooo`00
5P3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6@3oool2003o0100oooo000F0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0I0?ooo`800?l0403oool001D0oooo0P00o`0A0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06@3oool2003o0100oooo000E0?ooo`800?l04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<00?l00?ooo`3oool03P3oool001D0
oooo0P00o`0A0?ooo`H00000103oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo00h0
oooo000E0?ooo`800?l06`3oool00`000000oooo0?ooo`0J0?ooo`03003o003oool0oooo00h0oooo
000E0?ooo`800?l06`3oool00`000000oooo0?ooo`0J0?ooo`800?l03`3oool001D0oooo00<00?l0
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`800?l03`3oool001@0oooo0P00o`0L0?oo
o`030000003oool0oooo01X0oooo0P00o`0?0?ooo`00503oool2003o01`0oooo00<000000?ooo`3o
ool06P3oool2003o00l0oooo000D0?ooo`800?l0703oool2000001`0oooo00<00?l00?ooo`3oool0
3@3oool001@0oooo0P00o`0L0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`3oool03@3o
ool001@0oooo0P00o`0L0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`3oool03@3oool0
01@0oooo0P00o`0L0?ooo`030000003oool0oooo01/0oooo0P00o`0>0?ooo`00503oool00`00o`00
oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo0P00o`0>0?ooo`004`3oool2003o01d0oooo
00<000000?ooo`3oool06`3oool2003o00h0oooo000C0?ooo`800?l07@3oool00`000000oooo0?oo
o`0K0?ooo`800?l03P3oool001<0oooo0P00o`0M0?ooo`030000003oool0oooo01/0oooo0P00o`0>
0?ooo`004`3oool2003o01d0oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`0<0?oo
o`004`3oool2003o01d0oooo00<000000?ooo`3oool0703oool2003o00d0oooo000B0?ooo`<00?l0
7@3oool00`000000oooo0?ooo`0L0?ooo`800?l03@3oool00180oooo0P00o`0N0?ooo`030000003o
ool0oooo01`0oooo0P00o`0=0?ooo`004P3oool2003o01h0oooo00<000000?ooo`3oool0703oool2
003o00d0oooo000B0?ooo`800?l07P3oool2000001d0oooo0P00o`0=0?ooo`004P3oool2003o01h0
oooo00<000000?ooo`3oool07@3oool00`00o`00oooo0?ooo`0;0?ooo`004P3oool2003o01h0oooo
00<000000?ooo`3oool07@3oool00`00o`00oooo0?ooo`0;0?ooo`004P3oool2003o01h0oooo00<0
00000?ooo`3oool07@3oool2003o00`0oooo000B0?ooo`03003o003oool0oooo01d0oooo00<00000
0?ooo`3oool07@3oool2003o00`0oooo000B0?ooo`03003o003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool2003o00`0oooo000A0?ooo`800?l07`3oool00`000000oooo0?ooo`0M0?ooo`80
0?l0303oool00140oooo0P00o`0O0?ooo`030000003oool0oooo01d0oooo0P00o`0<0?ooo`004@3o
ool2003o01l0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0:0?ooo`004@3oool2
003o01l0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0:0?ooo`004@3oool00`00
o`00oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo0P00o`0;0?ooo`004@3oool00`00o`00
oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo0P00o`0;0?ooo`004@3oool00`00o`00oooo
0?ooo`0N0?ooo`030000003oool0oooo01h0oooo0P00o`0;0?ooo`00403oool2003o0200oooo0P00
000O0?ooo`800?l02`3oool00100oooo0P00o`0P0?ooo`030000003oool0oooo01l0oooo00<00?l0
0?ooo`3oool02@3oool00100oooo0P00o`0P0?ooo`030000003oool0oooo01l0oooo00<00?l00?oo
o`3oool02@3oool00100oooo0P00o`0P0?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3o
ool02@3oool00100oooo0P00o`0P0?ooo`030000003oool0oooo01l0oooo00<00?l00?ooo`3oool0
2@3oool00100oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`800?l02P3o
ool00100oooo00<00?l00?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`800?l02P3oool0
00l0oooo0P00o`0Q0?ooo`030000003oool0oooo01l0oooo0P00o`0:0?ooo`003`3oool2003o0240
oooo00<000000?ooo`3oool07`3oool2003o00X0oooo000?0?ooo`800?l08@3oool00`000000oooo
0?ooo`0O0?ooo`800?l02P3oool000l0oooo0P00o`0Q0?ooo`030000003oool0oooo0200oooo00<0
0?l00?ooo`3oool0203oool000l0oooo0P00o`0Q0?ooo`030000003oool0oooo0200oooo00<00?l0
0?ooo`3oool0203oool000l0oooo00<00?l00?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`800?l02@3oool000l0oooo00<00?l00?ooo`3oool0803oool200000240oooo0P00o`090?ooo`00
3`3oool00`00o`00oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo0P00o`090?ooo`003`3o
ool00`00o`00oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo0P00o`090?ooo`003P3oool2
003o0280oooo00<000000?ooo`3oool0803oool2003o00T0oooo000>0?ooo`800?l08P3oool00`00
0000oooo0?ooo`0Q0?ooo`03003o003oool0oooo00L0oooo000>0?ooo`800?l08P3oool00`000000
oooo0?ooo`0Q0?ooo`03003o003oool0oooo00L0oooo000>0?ooo`800?l08P3oool00`000000oooo
0?ooo`0Q0?ooo`03003o003oool0oooo00L0oooo000>0?ooo`03003o003oool0oooo0240oooo00<0
00000?ooo`3oool08@3oool00`00o`00oooo0?ooo`070?ooo`003P3oool00`00o`00oooo0?ooo`0;
0?ooo`L000001P3oool4000000D0oooo00<000000?ooo`3oool08@3oool2003o00P0oooo000>0?oo
o`03003o003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool2003o00P0oooo000>0?ooo`03
003o003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool2003o00P0oooo000>0?ooo`03003o
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000008`3oool2003o00P0oooo000=0?ooo`800?l0403oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`03
003o003oool0oooo00H0oooo000=0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000008`3oool00`00o`00
oooo0?ooo`060?ooo`003@3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002@0oooo00<00?l00?ooo`3o
ool01P3oool000d0oooo00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`03003o003oool0oooo00H0
oooo000=0?ooo`03003o003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`000000903oool00`00o`00oooo0?ooo`060?ooo`00
3@3oool00`00o`00oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000002D0oooo00<00?l00?ooo`3oool01@3oool000d0oooo
00<00?l00?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`03003o003oool0oooo00D0oooo
000=0?ooo`03003o003oool0oooo00/0oooo0`0000000`3oool000000?ooo`070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`03003o003o
ool0oooo00D0oooo000<0?ooo`800?l0403oool2000000T0oooo100000050?ooo`030000003oool0
oooo02<0oooo00<00?l00?ooo`3oool01@3oool000`0oooo0P00o`0T0?ooo`030000003oool0oooo
02<0oooo00<00?l00?ooo`3oool01@3oool000`0oooo0P00o`0T0?ooo`030000003oool0oooo02<0
oooo00<00?l00?ooo`3oool01@3oool000`0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo
0?ooo`0S0?ooo`03003o003oool0oooo00D0oooo000<0?ooo`03003o003oool0oooo02<0oooo00<0
00000?ooo`3oool08`3oool00`00o`00oooo0?ooo`050?ooo`00303oool00`00o`00oooo0?ooo`0S
0?ooo`030000003oool0oooo02<0oooo00<00?l00?ooo`3oool01@3oool000`0oooo00<00?l00?oo
o`3oool08`3oool2000002D0oooo00<00?l00?ooo`3oool0103oool000`0oooo00<00?l00?ooo`3o
ool08`3oool00`000000oooo0?ooo`0T0?ooo`03003o003oool0oooo00@0oooo000<0?ooo`03003o
003oool0oooo02<0oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`040?ooo`00303o
ool00`00o`00oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo00<00?l00?ooo`3oool0103o
ool000`0oooo00<00?l00?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`03003o003oool0
oooo00@0oooo000b0?ooo`030000003oool0oooo02/0oooo000b0?ooo`030000003oool0oooo02/0
oooo000b0?ooo`030000003oool0oooo02/0oooo000b0?ooo`030000003oool0oooo02/0oooo000b
0?ooo`030000003oool0oooo02/0oooo000b0?ooo`030000003oool0oooo02/0oooo000b0?ooo`03
0000003oool0oooo02/0oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo
001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600
oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00H03oool0
0600oooo001P0?ooo`00H03oool00600oooo001P0?ooo`00\
\>"],
  ImageRangeCache->{{{217.5, 255.063}, {203.5, 58.75}} -> {-46.9297, \
-2.69246, 0.158091, 0.158091}}],

Cell[BoxData[
    \(\(s3 = 
        ImplicitPlot[
          Table[y^2/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x \[Equal] 
              c, {c, 1.5, 5.5, 1}], {x, \(-3\), 3}, 
          PlotStyle \[Rule] {RGBColor[0, \ 0, \ 1]}];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.90157 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 1.95078 0.15873 [
[.02381 1.93828 -6 -9 ]
[.02381 1.93828 6 0 ]
[.18254 1.93828 -6 -9 ]
[.18254 1.93828 6 0 ]
[.34127 1.93828 -6 -9 ]
[.34127 1.93828 6 0 ]
[.65873 1.93828 -3 -9 ]
[.65873 1.93828 3 0 ]
[.81746 1.93828 -3 -9 ]
[.81746 1.93828 3 0 ]
[.97619 1.93828 -3 -9 ]
[.97619 1.93828 3 0 ]
[.4875 .36348 -18 -4.5 ]
[.4875 .36348 0 4.5 ]
[.4875 1.15713 -12 -4.5 ]
[.4875 1.15713 0 4.5 ]
[.4875 2.74443 -6 -4.5 ]
[.4875 2.74443 0 4.5 ]
[.4875 3.53808 -12 -4.5 ]
[.4875 3.53808 0 4.5 ]
[ 0 0 0 0 ]
[ 1 3.90157 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 1.95078 m
.02381 1.95703 L
s
[(-3)] .02381 1.93828 0 1 Mshowa
.18254 1.95078 m
.18254 1.95703 L
s
[(-2)] .18254 1.93828 0 1 Mshowa
.34127 1.95078 m
.34127 1.95703 L
s
[(-1)] .34127 1.93828 0 1 Mshowa
.65873 1.95078 m
.65873 1.95703 L
s
[(1)] .65873 1.93828 0 1 Mshowa
.81746 1.95078 m
.81746 1.95703 L
s
[(2)] .81746 1.93828 0 1 Mshowa
.97619 1.95078 m
.97619 1.95703 L
s
[(3)] .97619 1.93828 0 1 Mshowa
.125 Mabswid
.05556 1.95078 m
.05556 1.95453 L
s
.0873 1.95078 m
.0873 1.95453 L
s
.11905 1.95078 m
.11905 1.95453 L
s
.15079 1.95078 m
.15079 1.95453 L
s
.21429 1.95078 m
.21429 1.95453 L
s
.24603 1.95078 m
.24603 1.95453 L
s
.27778 1.95078 m
.27778 1.95453 L
s
.30952 1.95078 m
.30952 1.95453 L
s
.37302 1.95078 m
.37302 1.95453 L
s
.40476 1.95078 m
.40476 1.95453 L
s
.43651 1.95078 m
.43651 1.95453 L
s
.46825 1.95078 m
.46825 1.95453 L
s
.53175 1.95078 m
.53175 1.95453 L
s
.56349 1.95078 m
.56349 1.95453 L
s
.59524 1.95078 m
.59524 1.95453 L
s
.62698 1.95078 m
.62698 1.95453 L
s
.69048 1.95078 m
.69048 1.95453 L
s
.72222 1.95078 m
.72222 1.95453 L
s
.75397 1.95078 m
.75397 1.95453 L
s
.78571 1.95078 m
.78571 1.95453 L
s
.84921 1.95078 m
.84921 1.95453 L
s
.88095 1.95078 m
.88095 1.95453 L
s
.9127 1.95078 m
.9127 1.95453 L
s
.94444 1.95078 m
.94444 1.95453 L
s
.25 Mabswid
0 1.95078 m
1 1.95078 L
s
.5 .36348 m
.50625 .36348 L
s
[(-10)] .4875 .36348 1 0 Mshowa
.5 1.15713 m
.50625 1.15713 L
s
[(-5)] .4875 1.15713 1 0 Mshowa
.5 2.74443 m
.50625 2.74443 L
s
[(5)] .4875 2.74443 1 0 Mshowa
.5 3.53808 m
.50625 3.53808 L
s
[(10)] .4875 3.53808 1 0 Mshowa
.125 Mabswid
.5 .52221 m
.50375 .52221 L
s
.5 .68094 m
.50375 .68094 L
s
.5 .83967 m
.50375 .83967 L
s
.5 .9984 m
.50375 .9984 L
s
.5 1.31586 m
.50375 1.31586 L
s
.5 1.47459 m
.50375 1.47459 L
s
.5 1.63332 m
.50375 1.63332 L
s
.5 1.79205 m
.50375 1.79205 L
s
.5 2.10951 m
.50375 2.10951 L
s
.5 2.26824 m
.50375 2.26824 L
s
.5 2.42697 m
.50375 2.42697 L
s
.5 2.5857 m
.50375 2.5857 L
s
.5 2.90316 m
.50375 2.90316 L
s
.5 3.06189 m
.50375 3.06189 L
s
.5 3.22062 m
.50375 3.22062 L
s
.5 3.37935 m
.50375 3.37935 L
s
.5 .20475 m
.50375 .20475 L
s
.5 .04602 m
.50375 .04602 L
s
.5 3.69682 m
.50375 3.69682 L
s
.5 3.85555 m
.50375 3.85555 L
s
.25 Mabswid
.5 0 m
.5 3.90157 L
s
0 0 m
1 0 L
1 3.90157 L
0 3.90157 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .14796 m
.02544 .16168 L
.0303 .20247 L
.03838 .2692 L
.04961 .36002 L
.06392 .47241 L
.0812 .60323 L
.10135 .74881 L
.12422 .90501 L
.14966 1.06732 L
.17748 1.23081 L
.20752 1.39015 L
.23955 1.53906 L
.27336 1.66871 L
.30872 1.76237 L
.34538 1.79164 L
.3831 1.76171 L
.42162 1.71839 L
.46068 1.68698 L
.5 1.67585 L
.53932 1.68698 L
.57838 1.71839 L
.6169 1.76171 L
.65462 1.79164 L
.69128 1.76237 L
.72664 1.66871 L
.76045 1.53906 L
.79248 1.39015 L
.82252 1.23081 L
.85034 1.06732 L
.87578 .90501 L
.89865 .74881 L
.9188 .60323 L
.93608 .47241 L
.95039 .36002 L
.96162 .2692 L
.9697 .20247 L
.97456 .16168 L
.97619 .14796 L
s
.02381 3.75361 m
.02544 3.73989 L
.0303 3.6991 L
.03838 3.63237 L
.04961 3.54155 L
.06392 3.42916 L
.0812 3.29834 L
.10135 3.15276 L
.12422 2.99655 L
.14966 2.83425 L
.17748 2.67076 L
.20752 2.51142 L
.23955 2.36251 L
.27336 2.23286 L
.30872 2.1392 L
.34538 2.10993 L
.3831 2.13986 L
.42162 2.18318 L
.46068 2.21458 L
.5 2.22571 L
.53932 2.21458 L
.57838 2.18318 L
.6169 2.13986 L
.65462 2.10993 L
.69128 2.1392 L
.72664 2.23286 L
.76045 2.36251 L
.79248 2.51142 L
.82252 2.67076 L
.85034 2.83425 L
.87578 2.99655 L
.89865 3.15276 L
.9188 3.29834 L
.93608 3.42916 L
.95039 3.54155 L
.96162 3.63237 L
.9697 3.6991 L
.97456 3.73989 L
.97619 3.75361 L
s
.02381 .13403 m
.02544 .14765 L
.0303 .18812 L
.03838 .25428 L
.04961 .34426 L
.06392 .45546 L
.0812 .58466 L
.10135 .72803 L
.12422 .88119 L
.14966 1.03924 L
.17748 1.19663 L
.20752 1.34688 L
.23955 1.48184 L
.27336 1.59029 L
.30872 1.65771 L
.34538 1.67562 L
.3831 1.65729 L
.42162 1.62767 L
.46068 1.6044 L
.5 1.59585 L
.53932 1.6044 L
.57838 1.62767 L
.6169 1.65729 L
.65462 1.67562 L
.69128 1.65771 L
.72664 1.59029 L
.76045 1.48184 L
.79248 1.34688 L
.82252 1.19663 L
.85034 1.03924 L
.87578 .88119 L
.89865 .72803 L
.9188 .58466 L
.93608 .45546 L
.95039 .34426 L
.96162 .25428 L
.9697 .18812 L
.97456 .14765 L
.97619 .13403 L
s
.02381 3.76753 m
.02544 3.75392 L
.0303 3.71345 L
.03838 3.64729 L
.04961 3.55731 L
.06392 3.44611 L
.0812 3.31691 L
.10135 3.17354 L
.12422 3.02037 L
.14966 2.86232 L
.17748 2.70494 L
.20752 2.55469 L
.23955 2.41973 L
.27336 2.31128 L
.30872 2.24386 L
.34538 2.22595 L
.3831 2.24428 L
.42162 2.27389 L
.46068 2.29717 L
.5 2.30571 L
.53932 2.29717 L
.57838 2.27389 L
.6169 2.24428 L
.65462 2.22595 L
.69128 2.24386 L
.72664 2.31128 L
.76045 2.41973 L
.79248 2.55469 L
.82252 2.70494 L
.85034 2.86232 L
.87578 3.02037 L
.89865 3.17354 L
.9188 3.31691 L
.93608 3.44611 L
.95039 3.55731 L
.96162 3.64729 L
.9697 3.71345 L
.97456 3.75392 L
.97619 3.76753 L
s
.02381 .12022 m
.02544 .13373 L
.0303 .17388 L
.03838 .23949 L
.04961 .32865 L
.06392 .4387 L
.0812 .56634 L
.10135 .70759 L
.12422 .85789 L
.14966 1.01201 L
.17748 1.16393 L
.20752 1.30651 L
.23955 1.43088 L
.27336 1.52611 L
.30872 1.58162 L
.34538 1.59567 L
.3831 1.58128 L
.42162 1.55735 L
.46068 1.53802 L
.5 1.53082 L
.53932 1.53802 L
.57838 1.55735 L
.6169 1.58128 L
.65462 1.59567 L
.69128 1.58162 L
.72664 1.52611 L
.76045 1.43088 L
.79248 1.30651 L
.82252 1.16393 L
.85034 1.01201 L
.87578 .85789 L
.89865 .70759 L
.9188 .56634 L
.93608 .4387 L
.95039 .32865 L
.96162 .23949 L
.9697 .17388 L
.97456 .13373 L
.97619 .12022 L
s
.02381 3.78135 m
.02544 3.76783 L
.0303 3.72769 L
.03838 3.66207 L
.04961 3.57292 L
.06392 3.46286 L
.0812 3.33523 L
.10135 3.19397 L
.12422 3.04368 L
.14966 2.88956 L
.17748 2.73764 L
.20752 2.59506 L
.23955 2.47069 L
.27336 2.37545 L
.30872 2.31995 L
.34538 2.3059 L
.3831 2.32028 L
.42162 2.34422 L
.46068 2.36354 L
.5 2.37074 L
.53932 2.36354 L
.57838 2.34422 L
.6169 2.32028 L
.65462 2.3059 L
.69128 2.31995 L
.72664 2.37545 L
.76045 2.47069 L
.79248 2.59506 L
.82252 2.73764 L
.85034 2.88956 L
.87578 3.04368 L
.89865 3.19397 L
.9188 3.33523 L
.93608 3.46286 L
.95039 3.57292 L
.96162 3.66207 L
.9697 3.72769 L
.97456 3.76783 L
.97619 3.78135 L
s
.02381 .10651 m
.02544 .11992 L
.0303 .15976 L
.03838 .22483 L
.04961 .31319 L
.06392 .42213 L
.0812 .54826 L
.10135 .68749 L
.12422 .83508 L
.14966 .98554 L
.17748 1.13253 L
.20752 1.26852 L
.23955 1.38449 L
.27336 1.47043 L
.30872 1.51873 L
.34538 1.53067 L
.3831 1.51844 L
.42162 1.49781 L
.46068 1.48093 L
.5 1.47459 L
.53932 1.48093 L
.57838 1.49781 L
.6169 1.51844 L
.65462 1.53067 L
.69128 1.51873 L
.72664 1.47043 L
.76045 1.38449 L
.79248 1.26852 L
.82252 1.13253 L
.85034 .98554 L
.87578 .83508 L
.89865 .68749 L
.9188 .54826 L
.93608 .42213 L
.95039 .31319 L
.96162 .22483 L
.9697 .15976 L
.97456 .11992 L
.97619 .10651 L
s
.02381 3.79506 m
.02544 3.78165 L
.0303 3.74181 L
.03838 3.67673 L
.04961 3.58837 L
.06392 3.47943 L
.0812 3.35331 L
.10135 3.21408 L
.12422 3.06649 L
.14966 2.91602 L
.17748 2.76903 L
.20752 2.63305 L
.23955 2.51708 L
.27336 2.43113 L
.30872 2.38284 L
.34538 2.3709 L
.3831 2.38313 L
.42162 2.40375 L
.46068 2.42064 L
.5 2.42697 L
.53932 2.42064 L
.57838 2.40375 L
.6169 2.38313 L
.65462 2.3709 L
.69128 2.38284 L
.72664 2.43113 L
.76045 2.51708 L
.79248 2.63305 L
.82252 2.76903 L
.85034 2.91602 L
.87578 3.06649 L
.89865 3.21408 L
.9188 3.35331 L
.93608 3.47943 L
.95039 3.58837 L
.96162 3.67673 L
.9697 3.74181 L
.97456 3.78165 L
.97619 3.79506 L
s
.02381 .09289 m
.02544 .10621 L
.0303 .14574 L
.03838 .2103 L
.04961 .29788 L
.06392 .40574 L
.0812 .53041 L
.10135 .6677 L
.12422 .81272 L
.14966 .95978 L
.17748 1.1023 L
.20752 1.23254 L
.23955 1.34162 L
.27336 1.42057 L
.30872 1.46389 L
.34538 1.47445 L
.3831 1.46364 L
.42162 1.44524 L
.46068 1.43006 L
.5 1.42433 L
.53932 1.43006 L
.57838 1.44524 L
.6169 1.46364 L
.65462 1.47445 L
.69128 1.46389 L
.72664 1.42057 L
.76045 1.34162 L
.79248 1.23254 L
.82252 1.1023 L
.85034 .95978 L
.87578 .81272 L
.89865 .6677 L
.9188 .53041 L
.93608 .40574 L
.95039 .29788 L
.96162 .2103 L
.9697 .14574 L
.97456 .10621 L
.97619 .09289 L
s
.02381 3.80867 m
.02544 3.79536 L
.0303 3.75582 L
.03838 3.69127 L
.04961 3.60369 L
.06392 3.49583 L
.0812 3.37116 L
.10135 3.23387 L
.12422 3.08885 L
.14966 2.94178 L
.17748 2.79927 L
.20752 2.66903 L
.23955 2.55995 L
.27336 2.481 L
.30872 2.43767 L
.34538 2.42711 L
.3831 2.43793 L
.42162 2.45632 L
.46068 2.47151 L
.5 2.47723 L
.53932 2.47151 L
.57838 2.45632 L
.6169 2.43793 L
.65462 2.42711 L
.69128 2.43767 L
.72664 2.481 L
.76045 2.55995 L
.79248 2.66903 L
.82252 2.79927 L
.85034 2.94178 L
.87578 3.08885 L
.89865 3.23387 L
.9188 3.37116 L
.93608 3.49583 L
.95039 3.60369 L
.96162 3.69127 L
.9697 3.75582 L
.97456 3.79536 L
.97619 3.80867 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  ImageSize->{47.0625, 184.25},
  ImageMargins->{{52.5, 0}, {0, 14.5}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001N0001L2000`400?l00000o`00003oGP3oool0
05h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3o
ool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00
GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?oo
o`00GP3oool005h0oooo001N0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`00
0000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo
0?ooo`0Z0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo0?ooo`0Z
0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`00303oool00`000?l0oooo0?ooo`0R0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`3oool0103oool000`0oooo00<0003o0?ooo`3oool0
8P3oool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool000`0oooo00<0003o0?ooo`3oool08P3o
ool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool000`0oooo00<0003o0?ooo`3oool08P3oool0
0`000000oooo0?ooo`0R0?ooo`80003o1P3oool000`0oooo00<0003o0?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo000<0?ooo`030000o`3oool0oooo0280
oooo00<000000?ooo`3oool08P3oool20000o`H0oooo000<0?ooo`030000o`3oool0oooo0280oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`050?ooo`00303oool20000ob<0oooo00<0
00000?ooo`3oool08@3oool20000o`L0oooo000<0?ooo`80003o8`3oool00`000000oooo0?ooo`0Q
0?ooo`80003o1`3oool000`0oooo0P000?lS0?ooo`030000003oool0oooo0240oooo0P000?l70?oo
o`00303oool20000ob<0oooo00<000000?ooo`3oool08@3oool20000o`L0oooo000<0?ooo`80003o
8`3oool00`000000oooo0?ooo`0Q0?ooo`80003o1`3oool000d0oooo00<0003o0?ooo`3oool08@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o8P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o8P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o8P3oool00`000000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o8P3oool00`000000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o303oool7000000H0oooo1000
00050?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool000h0oooo00<0003o
0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000>0?oo
o`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0803oool20000o`P0oooo000>0?ooo`03
0000o`3oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000008P3oool20000o`P0oooo000>0?ooo`80003o3P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000R0?oo
o`80003o203oool000h0oooo0P000?l6000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000008@3oool20000o`P0oooo000>0?ooo`80
003o3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000Q0?ooo`<0003o203oool000h0oooo0P000?l>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000240oooo0P000?l90?oo
o`003P3oool20000o`h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000008@3oool20000o`T0oooo000?0?ooo`030000o`3oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000008@3oool20000o`T0oooo000?0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool07`3oool20000o`T0oooo000?0?ooo`030000o`3oool0oooo00P0oooo0`0000000`3oool00000
0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0O0?ooo`030000o`3oool0oooo00P0oooo000?0?ooo`030000o`3oool0oooo00/0oooo0P00
00090?ooo`@000001@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00P0oooo000?
0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool07P3oool20000o`X0oooo000?0?oo
o`80003o803oool00`000000oooo0?ooo`0N0?ooo`80003o2P3oool000l0oooo0P000?lP0?ooo`03
0000003oool0oooo01h0oooo0P000?l:0?ooo`003`3oool20000ob00oooo00<000000?ooo`3oool0
7P3oool20000o`X0oooo000?0?ooo`80003o803oool00`000000oooo0?ooo`0N0?ooo`80003o2P3o
ool000l0oooo0P000?lP0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool02@3oool0
0100oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo
00T0oooo000@0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000?l0
oooo0?ooo`090?ooo`00403oool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo
0?ooo`090?ooo`00403oool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`090?ooo`00403oool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`09
0?ooo`00403oool20000oal0oooo00<000000?ooo`3oool07@3oool20000o`/0oooo000@0?ooo`80
003o7`3oool00`000000oooo0?ooo`0M0?ooo`80003o2`3oool00100oooo0P000?lO0?ooo`030000
003oool0oooo01d0oooo0P000?l;0?ooo`004@3oool20000oah0oooo00<000000?ooo`3oool07@3o
ool20000o`/0oooo000A0?ooo`80003o7P3oool00`000000oooo0?ooo`0M0?ooo`80003o2`3oool0
0140oooo0P000?lN0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool02P3oool00140
oooo0P000?lN0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool02P3oool00140oooo
0P000?lN0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool02P3oool00140oooo0P00
0?lN0?ooo`030000003oool0oooo01`0oooo0P000?l<0?ooo`004P3oool00`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo01`0oooo0P000?l<0?ooo`004P3oool00`000?l0oooo0?ooo`0L0?oo
o`030000003oool0oooo01`0oooo0P000?l<0?ooo`004P3oool20000oad0oooo00<000000?ooo`3o
ool0703oool20000o``0oooo000B0?ooo`80003o7@3oool00`000000oooo0?ooo`0L0?ooo`80003o
303oool00180oooo0P000?lM0?ooo`030000003oool0oooo01`0oooo0P000?l<0?ooo`004P3oool2
0000oad0oooo00<000000?ooo`3oool06`3oool20000o`d0oooo000B0?ooo`80003o7@3oool00`00
0000oooo0?ooo`0K0?ooo`80003o3@3oool00180oooo0P000?lM0?ooo`030000003oool0oooo01/0
oooo0P000?l=0?ooo`004P3oool20000oad0oooo00<000000?ooo`3oool06`3oool20000o`d0oooo
000C0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool06`3oool20000o`d0oooo000C
0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool06P3oool30000o`d0oooo000C0?oo
o`80003o703oool00`000000oooo0?ooo`0J0?ooo`80003o3P3oool001<0oooo0P000?lL0?ooo`03
0000003oool0oooo01X0oooo0P000?l>0?ooo`004`3oool20000oa`0oooo00<000000?ooo`3oool0
6P3oool20000o`h0oooo000C0?ooo`80003o703oool00`000000oooo0?ooo`0J0?ooo`80003o3P3o
ool001<0oooo0P000?lL0?ooo`030000003oool0oooo01X0oooo0P000?l>0?ooo`004`3oool20000
oa`0oooo00<000000?ooo`3oool06@3oool30000o`h0oooo000C0?ooo`<0003o6`3oool00`000000
oooo0?ooo`0I0?ooo`<0003o3P3oool001@0oooo0P000?lK0?ooo`030000003oool0oooo01T0oooo
0P000?l?0?ooo`00503oool20000oa/0oooo00<000000?ooo`3oool06@3oool20000o`l0oooo000D
0?ooo`80003o6`3oool00`000000oooo0?ooo`0I0?ooo`80003o3`3oool001@0oooo0`000?lJ0?oo
o`030000003oool0oooo01T0oooo0P000?l?0?ooo`00503oool30000oaX0oooo00<000000?ooo`3o
ool0603oool30000o`l0oooo000D0?ooo`<0003o6P3oool00`000000oooo0?ooo`0H0?ooo`<0003o
3`3oool001D0oooo0P000?lJ0?ooo`030000003oool0oooo01P0oooo0P000?l@0?ooo`005@3oool3
0000oaT0oooo00<000000?ooo`3oool0603oool20000oa00oooo000E0?ooo`<0003o6@3oool00`00
0000oooo0?ooo`0H0?ooo`80003o403oool001D0oooo0`000?lI0?ooo`030000003oool0oooo01P0
oooo0P000?l@0?ooo`005@3oool30000oaT0oooo00<000000?ooo`3oool05`3oool30000oa00oooo
000E0?ooo`@0003o3`3oool4000000D0oooo00<000000?ooo`3oool05`3oool30000oa00oooo000F
0?ooo`<0003o3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05`3oool30000oa00oooo000F0?ooo`<0003o3@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000006@3oool20000oa40oooo000F0?ooo`<0003o503oool01@00
0000oooo0?ooo`3oool0000001P0oooo0`000?lA0?ooo`005P3oool40000oa<0oooo00D000000?oo
o`3oool0oooo0000000H0?ooo`<0003o4@3oool001L0oooo0`000?l8000000/0oooo00@000000?oo
o`3oool0oooo0P00000G0?ooo`<0003o4@3oool001L0oooo0`000?l=0?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo10000?lA0?ooo`005`3oool30000o`d0
oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo01D0oooo10000?lA0?ooo`00
5`3oool30000o`d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`<0003o
4P3oool001P0oooo0`000?l<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3o
ool30000oa80oooo000H0?ooo`<0003o303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01@0oooo10000?lB0?ooo`00603oool30000o``0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0D0?ooo`@0003o4P3oool001P0oooo0`000?l<0?ooo`H00000103oool00`000000
oooo0?ooo`0D0?ooo`@0003o4P3oool001P0oooo10000?lE0?ooo`030000003oool0oooo01@0oooo
10000?lB0?ooo`00603oool40000oaD0oooo00<000000?ooo`3oool04`3oool40000oa<0oooo000I
0?ooo`<0003o5@3oool00`000000oooo0?ooo`0C0?ooo`@0003o4`3oool001T0oooo10000?lD0?oo
o`030000003oool0oooo01<0oooo10000?lC0?ooo`006@3oool40000oa@0oooo00<000000?ooo`3o
ool04`3oool40000oa<0oooo000I0?ooo`@0003o503oool00`000000oooo0?ooo`0B0?ooo`@0003o
503oool001T0oooo1@000?lC0?ooo`030000003oool0oooo0180oooo10000?lD0?ooo`006@3oool5
0000oa<0oooo00<000000?ooo`3oool04P3oool40000oa@0oooo000J0?ooo`@0003o4`3oool00`00
0000oooo0?ooo`0A0?ooo`D0003o503oool001X0oooo0P000?l00`3oool0003o0000o`0B0?ooo`03
0000003oool0oooo0140oooo10000?lE0?ooo`006P3oool50000oa80oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0000o`020000oaD0oooo000J0?ooo`D0003o4P3oool00`000000oooo0?oo
o`0@0?ooo`030000o`3oool0003o0080003o5@3oool001X0oooo0`000?l00`3oool0003o0000o`0A
0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`000?l00`000?lE0?ooo`006`3oool50000
oa00oooo0`000?l@0?ooo`030000o`3oool0003o00<0003o5@3oool001/0oooo10000?l00`3oool0
003o0?ooo`0;0?ooo`<0003o00<0oooo0000003oool00`000?l<0?ooo`040000o`3oool0003o0?oo
o`80003o5P3oool001/0oooo10000?l20?ooo`030000o`3oool0oooo00H0oooo0`000?l40?ooo`03
0000003oool0oooo0080oooo0`000?l80?ooo`050000o`3oool0oooo0000o`3oool00P000?lF0?oo
o`006`3oool20000o`030?ooo`000?l0003o0080oooo0P000?l30?ooo`<0003o1`3oool00`000000
oooo0?ooo`050?ooo`<0003o0`3oool20000o`80oooo00<0003o0?ooo`000?l00P000?lF0?ooo`00
703oool40000o`@0oooo0`000?l90?ooo`<0003o2@3oool30000o`@0oooo00<0003o0?ooo`000?l0
0P000?lF0?ooo`00703oool30000o`030?ooo`000?l0oooo00/0oooo0`000?l00`3oool000000?oo
o`030000o``0oooo00@0003o0?ooo`000?l0oooo0P000?lF0?ooo`00703oool30000o`030?ooo`00
0?l0oooo00T0oooo0P000?l40?ooo`030000003oool0oooo0080oooo0P000?l90?ooo`050000o`3o
ool0oooo0000o`3oool00P000?lF0?ooo`00703oool20000o`040?ooo`000?l0oooo0000o`L0oooo
0P000?l60?ooo`030000003oool0oooo00@0oooo0P000?l70?ooo`040000o`3oool0003o0?ooo`80
003o5`3oool001d0oooo0`000?l20?ooo`80003o0`3oool20000o`P0oooo00<000000?ooo`3oool0
1P3oool20000o`<0oooo0P000?l20?ooo`040000o`3oool0003o0000oaL0oooo000M0?ooo`80003o
00<0oooo0000o`3oool00P3oool30000o`L0oooo1`000?l70?ooo`<0003o0`3oool01@000?l0oooo
0000o`3oool0003o01L0oooo000M0?ooo`80003o00<0oooo0000o`3oool02P3oool20000o`<0oooo
00@000000?ooo`3oool0oooo0P000?l;0?ooo`050000o`3oool0003o0?ooo`000?l05`3oool001d0
oooo0P000?l20?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P000?lH0?ooo`00
7P3oool20000o`030?ooo`000?l0oooo00H0oooo0P000?l60?ooo`030000003oool0oooo00@0oooo
0P000?l70?ooo`050000o`3oool0003o0?ooo`000?l0603oool001h0oooo0P000?l20?ooo`80003o
0`3oool20000o`P0oooo00<000000?ooo`3oool01P3oool20000o`<0oooo0P000?l20?ooo`030000
o`3oool0003o01P0oooo000N0?ooo`80003o103oool30000o`L0oooo1`000?l70?ooo`<0003o0`3o
ool00`000?l0oooo0000o`0I0?ooo`007P3oool00`000?l0oooo0000o`0;0?ooo`80003o0`3oool0
10000000oooo0?ooo`3oool20000o`/0oooo00<0003o0?ooo`000?l06@3oool001h0oooo00<0003o
0?ooo`000?l02P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0003o
0?ooo`3oool01`3oool010000?l0oooo0?ooo`000?lI0?ooo`007`3oool00`000?l0oooo0000o`08
0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`06
0?ooo`040000o`3oool0oooo0000oaT0oooo000O0?ooo`030000o`3oool0003o00L0oooo00<0003o
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00@0003o
0?ooo`3oool0003o6P3oool001l0oooo00<0003o0?ooo`3oool00P000?l30?ooo`80003o203oool0
0`000000oooo0?ooo`060?ooo`80003o0`3oool20000o`80oooo00<0003o0?ooo`3oool0603oool0
01l0oooo00<0003o0?ooo`3oool00P3oool30000o`T0oooo0`000?l90?ooo`<0003o103oool00`00
0?l0oooo0?ooo`0H0?ooo`00803oool00`000?l0oooo0?ooo`0;0?ooo`80003o00<0oooo0000003o
ool00P000?l=0?ooo`030000o`3oool0oooo01T0oooo000P0?ooo`030000o`3oool0oooo00T0oooo
0P000?l30?ooo`040000003oool0oooo0?ooo`80003o2`3oool00`000?l0oooo0?ooo`0I0?ooo`00
803oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01X0oooo000Q0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool06P3oool000l0oooo1@0000060?ooo`L0000000<0003o
0?ooo`3oool0103oool00`000000003o0000000400000080oooo00<000000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`06000000030000o`3oool0oooo0080oooo200000060?ooo`D000001@3oool0
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000000o`3oool01@3oool00`000?l0oooo000000050?ooo`030000003oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0000o`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`040000o`3oool0oooo000000D0oooo00<000000?ooo`3oool01P3oool01`00
0?l0oooo0?ooo`3oool000000?ooo`000?l01P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0040oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2
0000o`030?ooo`000?l0003o00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`80003o00<0oooo0000o`000?l0203oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0040oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0?l000000?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00@3oool00080
oooo200000040?ooo`P000001@3oool8000000P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`010?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`004@3oool3000000`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`<000001@3oool001@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0040oooo000>0?ooo`800000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool3000000030?oo
o`000000oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`00403oool4000000P0oooo1000000:0?ooo`8000001@3o
ool00`000000oooo0?ooo`090?ooo`8000002@3oool4000000T0oooo100000050?ooo`00<@3oool0
0`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`00<@3oool00`000000
oooo0?ooo`0Z0?ooo`00<@3oool00`000000oooo0?ooo`0Z0?ooo`002P3ooom@000000@0oooo000a
0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo02X0oooo000a0?ooo`03
0000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003o
ool0oooo02X0oooo000a0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo
02X0oooo000a0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo02X0oooo
000a0?ooo`030000003oool0oooo02X0oooo000a0?ooo`030000003oool0oooo02X0oooo000U0?oo
o`030000o`3oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0N0?oo
o`00903oool00`000?l0oooo0000o`0:0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`00
0?l07`3oool002<0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030000003oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0000o`0N0?ooo`008P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01/0oooo000R0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
6`3oool00240oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0J0?ooo`008@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01X0oooo000P0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool06@3oool00200oooo00<0003o0?ooo`3oool02P3oool01@000?l0
oooo0?ooo`3oool0000000<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0I0?oo
o`007`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo1`000?l80?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0603oool001l0oooo00@0003o0?ooo`3oool0
oooo0P000?l00`3oool0003o0000o`090?ooo`030000003oool0oooo00L0oooo0P000?l00`3oool0
003o0000o`030?ooo`030000o`3oool0oooo01P0oooo000O0?ooo`040000o`3oool0oooo0000o`D0
oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0
oooo00@0003o0?ooo`3oool0003o6P3oool001l0oooo00<0003o0?ooo`000?l01`3oool20000o`H0
oooo00<000000?ooo`3oool0103oool20000o`L0oooo00@0003o0?ooo`3oool0003o6@3oool001h0
oooo00@0003o0?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`000?lI0?ooo`007P3oool00`00
0?l0oooo0000o`0;0?ooo`80003o0`3oool010000000oooo0?ooo`3oool20000o`/0oooo00<0003o
0?ooo`000?l06@3oool001h0oooo00<0003o0?ooo`000?l03@3oool20000o`030?ooo`000000oooo
0080003o3@3oool00`000?l0oooo0000o`0I0?ooo`007P3oool20000o`@0oooo0`000?l90?ooo`<0
003o2@3oool30000o`@0oooo00<0003o0?ooo`000?l0603oool001h0oooo0P000?l20?ooo`80003o
0`3oool20000o`P0oooo00<000000?ooo`3oool01P3oool20000o`<0oooo0P000?l20?ooo`030000
o`3oool0003o01P0oooo000M0?ooo`050000o`3oool0003o0?ooo`000?l01`3oool20000o`H0oooo
00<000000?ooo`3oool0103oool20000o`L0oooo00<0003o0?ooo`3oool00P000?lH0?ooo`007@3o
ool20000o`030?ooo`000?l0oooo00T0oooo0P000?l40?ooo`030000003oool0oooo0080oooo0P00
0?l90?ooo`060000o`3oool0oooo0000o`3oool0003o5`3oool001d0oooo0P000?l00`3oool0003o
0?ooo`0;0?ooo`<0003o00<0oooo0000003oool00`000?l<0?ooo`050000o`3oool0003o0?ooo`00
0?l05`3oool001d0oooo0`000?l40?ooo`<0003o2@3oool30000o`T0oooo0`000?l40?ooo`040000
o`3oool0003o0000oaL0oooo000L0?ooo`040000o`3oool0003o0000o`80oooo0P000?l30?ooo`<0
003o1`3oool00`000000oooo0?ooo`050?ooo`<0003o0`3oool20000o`80oooo00@0003o0?ooo`00
0?l0003o5`3oool001`0oooo0`000?l20?ooo`030000o`3oool0oooo00H0oooo0P000?l50?ooo`03
0000003oool0oooo00<0oooo0P000?l80?ooo`030000o`3oool0oooo00<0003o5`3oool001`0oooo
0`000?l00`3oool0003o0?ooo`0:0?ooo`80003o0`3oool010000000oooo0?ooo`3oool20000o`X0
oooo00D0003o0?ooo`3oool0003o0?ooo`020000oaH0oooo000L0?ooo`<0003o00<0oooo0000o`3o
ool00P3oool30000o`L0oooo1`000?l70?ooo`<0003o0`3oool010000?l0oooo0000o`3oool20000
oaH0oooo000K0?ooo`030000o`3oool0003o0080003o0P3oool20000o`<0oooo0P000?l80?ooo`03
0000003oool0oooo00H0oooo0P000?l30?ooo`80003o0P3oool00`000?l0oooo0000o`020000oaH0
oooo000K0?ooo`<0003o00@0oooo0000o`3oool0003o1`3oool20000o`H0oooo00<000000?ooo`3o
ool0103oool20000o`L0oooo00@0003o0?ooo`000?l0oooo0`000?lF0?ooo`006`3oool40000o`03
0?ooo`000?l0oooo00T0oooo0P000?l40?ooo`030000003oool0oooo0080oooo0P000?l90?ooo`05
0000o`3oool0oooo0000o`3oool00P000?lF0?ooo`006`3oool40000o`030?ooo`000?l0oooo00/0
oooo2@000?l<0?ooo`040000o`3oool0003o0?ooo`80003o5P3oool001X0oooo0P000?l0103oool0
003o0000o`000?lA0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`000?l00`000?lE0?oo
o`006P3oool40000o`030?ooo`000?l0oooo0100oooo00<000000?ooo`3oool03`3oool00`000?l0
oooo0000o`030000oaD0oooo000J0?ooo`D0003o4P3oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oool0003o0080003o5@3oool001X0oooo1@000?lB0?ooo`030000003oool0oooo0100oooo00<0
003o0?ooo`000?l00P000?lE0?ooo`006P3oool30000o`030?ooo`000?l0oooo0140oooo00<00000
0?ooo`3oool04@3oool40000oaD0oooo000J0?ooo`@0003o4`3oool00`000000oooo0?ooo`0A0?oo
o`030000o`3oool0003o0080003o503oool001T0oooo1@000?lC0?ooo`030000003oool0oooo0180
oooo10000?lD0?ooo`006@3oool30000o`030?ooo`000?l0oooo0180oooo00<000000?ooo`3oool0
4P3oool40000oa@0oooo000I0?ooo`@0003o503oool00`000000oooo0?ooo`0B0?ooo`@0003o503o
ool001T0oooo10000?lD0?ooo`030000003oool0oooo01<0oooo10000?lC0?ooo`006@3oool30000
oaD0oooo00<000000?ooo`3oool04`3oool40000oa<0oooo000I0?ooo`<0003o5@3oool00`000000
oooo0?ooo`0C0?ooo`@0003o4`3oool001P0oooo10000?lE0?ooo`030000003oool0oooo01<0oooo
10000?lC0?ooo`00603oool30000oaH0oooo00<000000?ooo`3oool0503oool40000oa80oooo000H
0?ooo`<0003o5P3oool00`000000oooo0?ooo`0D0?ooo`@0003o4P3oool001P0oooo0`000?l=0?oo
o`@000001@3oool00`000000oooo0?ooo`0D0?ooo`@0003o4P3oool001P0oooo0`000?l<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`<0
003o4P3oool001L0oooo0`000?l<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000G0?ooo`<0003o4P3oool001L0oooo0`000?lC0?ooo`050000003oool0oooo0?ooo`00
00005`3oool30000oa80oooo000G0?ooo`<0003o4`3oool01@000000oooo0?ooo`3oool0000001L0
oooo10000?lA0?ooo`005`3oool30000oa<0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`<0
003o4@3oool001H0oooo10000?l=0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo0`000?lA0?ooo`005P3oool40000o`d0oooo00<000000?ooo`0000000P00
00050?ooo`030000003oool0oooo01H0oooo0`000?lA0?ooo`005P3oool30000o`h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`<0003o4@3oool001H0oooo0`000?l>0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool20000oa40oooo000E0?ooo`@0
003o3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo0`000?l@0?ooo`00
5@3oool40000o`h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`<0003o
403oool001D0oooo0`000?l?0?ooo`H00000103oool00`000000oooo0?ooo`0G0?ooo`<0003o403o
ool001D0oooo0`000?lI0?ooo`030000003oool0oooo01P0oooo0P000?l@0?ooo`005@3oool30000
oaT0oooo00<000000?ooo`3oool0603oool20000oa00oooo000E0?ooo`<0003o6@3oool00`000000
oooo0?ooo`0H0?ooo`80003o403oool001@0oooo0`000?lJ0?ooo`030000003oool0oooo01P0oooo
0`000?l?0?ooo`00503oool30000oaX0oooo00<000000?ooo`3oool0603oool30000o`l0oooo000D
0?ooo`<0003o6P3oool00`000000oooo0?ooo`0H0?ooo`<0003o3`3oool001@0oooo0`000?lJ0?oo
o`030000003oool0oooo01T0oooo0P000?l?0?ooo`00503oool20000oa/0oooo00<000000?ooo`3o
ool06@3oool20000o`l0oooo000D0?ooo`80003o6`3oool00`000000oooo0?ooo`0I0?ooo`80003o
3`3oool001<0oooo0`000?lK0?ooo`030000003oool0oooo01T0oooo0`000?l>0?ooo`004`3oool3
0000oa/0oooo00<000000?ooo`3oool06@3oool30000o`h0oooo000C0?ooo`80003o703oool00`00
0000oooo0?ooo`0I0?ooo`<0003o3P3oool001<0oooo0P000?lL0?ooo`030000003oool0oooo01X0
oooo0P000?l>0?ooo`004`3oool20000oa`0oooo00<000000?ooo`3oool06P3oool20000o`h0oooo
000C0?ooo`80003o703oool00`000000oooo0?ooo`0J0?ooo`80003o3P3oool001<0oooo0P000?lL
0?ooo`030000003oool0oooo01X0oooo0P000?l>0?ooo`004`3oool20000oa`0oooo00<000000?oo
o`3oool06P3oool30000o`d0oooo000C0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3o
ool06P3oool30000o`d0oooo000C0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0
6`3oool20000o`d0oooo000B0?ooo`80003o7@3oool00`000000oooo0?ooo`0K0?ooo`80003o3@3o
ool00180oooo0P000?lM0?ooo`030000003oool0oooo01/0oooo0P000?l=0?ooo`004P3oool20000
oad0oooo00<000000?ooo`3oool06`3oool20000o`d0oooo000B0?ooo`80003o7@3oool00`000000
oooo0?ooo`0K0?ooo`<0003o303oool00180oooo0P000?lM0?ooo`030000003oool0oooo01`0oooo
0P000?l<0?ooo`004P3oool20000oad0oooo00<000000?ooo`3oool0703oool20000o``0oooo000B
0?ooo`80003o7@3oool00`000000oooo0?ooo`0L0?ooo`80003o303oool00180oooo00<0003o0?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`80003o303oool00180oooo00<0003o0?ooo`3o
ool0703oool00`000000oooo0?ooo`0L0?ooo`80003o303oool00140oooo0P000?lN0?ooo`030000
003oool0oooo01`0oooo0P000?l<0?ooo`004@3oool20000oah0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0:0?ooo`004@3oool20000oah0oooo00<000000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`0:0?ooo`004@3oool20000oah0oooo00<000000?ooo`3oool07@3oool20000
o`/0oooo000A0?ooo`80003o7P3oool00`000000oooo0?ooo`0M0?ooo`80003o2`3oool00140oooo
0P000?lN0?ooo`030000003oool0oooo01d0oooo0P000?l;0?ooo`00403oool20000oal0oooo00<0
00000?ooo`3oool07@3oool20000o`/0oooo000@0?ooo`80003o7`3oool00`000000oooo0?ooo`0M
0?ooo`80003o2`3oool00100oooo0P000?lO0?ooo`030000003oool0oooo01d0oooo0P000?l;0?oo
o`00403oool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`090?ooo`00
403oool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`090?ooo`00403o
ool20000oal0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`090?ooo`00403oool0
0`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool02@3oool0
00l0oooo0P000?lP0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool02@3oool000l0
oooo0P000?lP0?ooo`030000003oool0oooo01h0oooo0P000?l:0?ooo`003`3oool20000ob00oooo
00<000000?ooo`3oool07P3oool20000o`X0oooo000?0?ooo`80003o803oool00`000000oooo0?oo
o`0N0?ooo`80003o2P3oool000l0oooo0P000?lP0?ooo`030000003oool0oooo01h0oooo0P000?l:
0?ooo`003`3oool20000ob00oooo00<000000?ooo`3oool07P3oool20000o`X0oooo000?0?ooo`03
0000o`3oool0oooo01l0oooo00<000000?ooo`3oool07P3oool20000o`X0oooo000?0?ooo`030000
o`3oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`080?ooo`003`3o
ool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo0P000?l90?ooo`003`3oool0
0`000?l0oooo0?ooo`090?ooo`L000001P3oool4000000D0oooo00<000000?ooo`3oool07`3oool2
0000o`T0oooo000>0?ooo`80003o3P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`80003o2@3oool000h0
oooo0P000?l>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo0P000?l90?ooo`003P3oool20000o`h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00008@3oool30000o`P0oooo000>0?ooo`80003o3P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`<0003o203oool000h0oooo
0P000?l>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3oool200000240oooo0P000?l80?ooo`003P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000280
oooo0P000?l80?ooo`003P3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000280oooo0P000?l80?ooo`00
3P3oool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000280oooo0P000?l80?ooo`003@3oool20000o`l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00008`3oool00`000?l0oooo0?ooo`060?ooo`003@3oool20000o`l0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`060?ooo`003@3oool20000o`/0oooo0`0000000`3oool000000?oo
o`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo00H0oooo000=0?ooo`80003o3P3oool2000000T0oooo10000005
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool000d0oooo0P000?lR0?oo
o`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool000d0oooo00<0003o0?ooo`3o
ool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000<0?ooo`80003o
8`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo000<0?ooo`80003o8`3o
ool00`000000oooo0?ooo`0Q0?ooo`80003o1`3oool000`0oooo0P000?lS0?ooo`030000003oool0
oooo0240oooo0P000?l70?ooo`00303oool20000ob<0oooo00<000000?ooo`3oool08@3oool20000
o`L0oooo000<0?ooo`80003o8`3oool00`000000oooo0?ooo`0Q0?ooo`80003o1`3oool000`0oooo
00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo
000<0?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`050?ooo`00303oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo0P000?l6
0?ooo`00303oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo0P000?l60?oo
o`00303oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo0P000?l60?ooo`00
303oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo0P000?l60?ooo`00303o
ool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0103o
ool00340oooo00<000000?ooo`3oool0:P3oool00340oooo00<000000?ooo`3oool0:P3oool00340
oooo00<000000?ooo`3oool0:P3oool00340oooo00<000000?ooo`3oool0:P3oool00340oooo00<0
00000?ooo`3oool0:P3oool00340oooo00<000000?ooo`3oool0:P3oool00340oooo00<000000?oo
o`3oool0:P3oool00340oooo00<000000?ooo`3oool0:P3oool005h0oooo001N0?ooo`00GP3oool0
05h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3o
ool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00
GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?ooo`00GP3oool005h0oooo001N0?oo
o`00\
\>"],
  ImageRangeCache->{{{95.125, 131.75}, {417.313, 270.938}} -> {-23.3758, \
40.3233, 0.163128, 0.163128}}],

Cell[TextData[{
  "For different values of  the energy E the curves have different shape.\n\
There is a special value of energy, corresponding to ",
  StyleBox["energy curves passing through critical unstable points",
    Background->RGBColor[1, 1, 0]],
  ". The critical points are the solutions of f(x)=0, and y=0."
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(Solve[f[x] \[Equal] 0, x]\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \({{x \[Rule] \(-1\)}, {x \[Rule] 0}, {x \[Rule] 1}}\)], "Output",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The unstable points are (-1,0) and (1,0). The ",
  StyleBox["energy",
    Background->RGBColor[1, 1, 0]],
  " for this points is:"
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\((y^2/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x)\) /. {x -> 1, 
        y \[Rule] 0}\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(1\)], "Output",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "We draw the trajectory corresponding to E=1, which it is called the ",
  StyleBox["separatrice.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(s2 = \ 
        ImplicitPlot[
          y^2/2 - \[Integral]\_0\%x f[x] \[DifferentialD]x \[Equal] 
            1, {x, \(-3\), 3}, 
          PlotStyle \[Rule] {RGBColor[1, \ 0, \ 0], 
              Thickness[0.03]}];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.77124 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 1.88562 0.15873 [
[.02381 1.87312 -6 -9 ]
[.02381 1.87312 6 0 ]
[.18254 1.87312 -6 -9 ]
[.18254 1.87312 6 0 ]
[.34127 1.87312 -6 -9 ]
[.34127 1.87312 6 0 ]
[.65873 1.87312 -3 -9 ]
[.65873 1.87312 3 0 ]
[.81746 1.87312 -3 -9 ]
[.81746 1.87312 3 0 ]
[.97619 1.87312 -3 -9 ]
[.97619 1.87312 3 0 ]
[.4875 .29832 -18 -4.5 ]
[.4875 .29832 0 4.5 ]
[.4875 1.09197 -12 -4.5 ]
[.4875 1.09197 0 4.5 ]
[.4875 2.67927 -6 -4.5 ]
[.4875 2.67927 0 4.5 ]
[.4875 3.47292 -12 -4.5 ]
[.4875 3.47292 0 4.5 ]
[ 0 0 0 0 ]
[ 1 3.77124 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 1.88562 m
.02381 1.89187 L
s
[(-3)] .02381 1.87312 0 1 Mshowa
.18254 1.88562 m
.18254 1.89187 L
s
[(-2)] .18254 1.87312 0 1 Mshowa
.34127 1.88562 m
.34127 1.89187 L
s
[(-1)] .34127 1.87312 0 1 Mshowa
.65873 1.88562 m
.65873 1.89187 L
s
[(1)] .65873 1.87312 0 1 Mshowa
.81746 1.88562 m
.81746 1.89187 L
s
[(2)] .81746 1.87312 0 1 Mshowa
.97619 1.88562 m
.97619 1.89187 L
s
[(3)] .97619 1.87312 0 1 Mshowa
.125 Mabswid
.05556 1.88562 m
.05556 1.88937 L
s
.0873 1.88562 m
.0873 1.88937 L
s
.11905 1.88562 m
.11905 1.88937 L
s
.15079 1.88562 m
.15079 1.88937 L
s
.21429 1.88562 m
.21429 1.88937 L
s
.24603 1.88562 m
.24603 1.88937 L
s
.27778 1.88562 m
.27778 1.88937 L
s
.30952 1.88562 m
.30952 1.88937 L
s
.37302 1.88562 m
.37302 1.88937 L
s
.40476 1.88562 m
.40476 1.88937 L
s
.43651 1.88562 m
.43651 1.88937 L
s
.46825 1.88562 m
.46825 1.88937 L
s
.53175 1.88562 m
.53175 1.88937 L
s
.56349 1.88562 m
.56349 1.88937 L
s
.59524 1.88562 m
.59524 1.88937 L
s
.62698 1.88562 m
.62698 1.88937 L
s
.69048 1.88562 m
.69048 1.88937 L
s
.72222 1.88562 m
.72222 1.88937 L
s
.75397 1.88562 m
.75397 1.88937 L
s
.78571 1.88562 m
.78571 1.88937 L
s
.84921 1.88562 m
.84921 1.88937 L
s
.88095 1.88562 m
.88095 1.88937 L
s
.9127 1.88562 m
.9127 1.88937 L
s
.94444 1.88562 m
.94444 1.88937 L
s
.25 Mabswid
0 1.88562 m
1 1.88562 L
s
.5 .29832 m
.50625 .29832 L
s
[(-10)] .4875 .29832 1 0 Mshowa
.5 1.09197 m
.50625 1.09197 L
s
[(-5)] .4875 1.09197 1 0 Mshowa
.5 2.67927 m
.50625 2.67927 L
s
[(5)] .4875 2.67927 1 0 Mshowa
.5 3.47292 m
.50625 3.47292 L
s
[(10)] .4875 3.47292 1 0 Mshowa
.125 Mabswid
.5 .45705 m
.50375 .45705 L
s
.5 .61578 m
.50375 .61578 L
s
.5 .77451 m
.50375 .77451 L
s
.5 .93324 m
.50375 .93324 L
s
.5 1.2507 m
.50375 1.2507 L
s
.5 1.40943 m
.50375 1.40943 L
s
.5 1.56816 m
.50375 1.56816 L
s
.5 1.72689 m
.50375 1.72689 L
s
.5 2.04435 m
.50375 2.04435 L
s
.5 2.20308 m
.50375 2.20308 L
s
.5 2.36181 m
.50375 2.36181 L
s
.5 2.52054 m
.50375 2.52054 L
s
.5 2.838 m
.50375 2.838 L
s
.5 2.99673 m
.50375 2.99673 L
s
.5 3.15546 m
.50375 3.15546 L
s
.5 3.31419 m
.50375 3.31419 L
s
.5 .13959 m
.50375 .13959 L
s
.5 3.63165 m
.50375 3.63165 L
s
.25 Mabswid
.5 0 m
.5 3.77124 L
s
0 0 m
1 0 L
1 3.77124 L
0 3.77124 L
closepath
clip
newpath
1 0 0 r
.03 w
.02381 .08979 m
.02435 .09439 L
.02597 .10812 L
.02867 .1308 L
.03241 .16211 L
.03718 .20164 L
.04294 .24886 L
.04966 .30315 L
.05728 .36381 L
.06576 .43006 L
.07503 .50107 L
.08505 .57599 L
.09572 .65392 L
.10699 .73397 L
.11878 .81527 L
.131 .89696 L
.14357 .97823 L
.15641 1.05831 L
.16943 1.1365 L
.18254 1.21218 L
.19565 1.2848 L
.20867 1.35389 L
.22151 1.41908 L
.23408 1.48007 L
.2463 1.53665 L
.25809 1.58869 L
.26936 1.63614 L
.28003 1.67901 L
.29004 1.71735 L
.29932 1.75129 L
.3078 1.78097 L
.31542 1.80656 L
.32214 1.82825 L
.3279 1.84621 L
.33267 1.86063 L
.33641 1.87167 L
.3391 1.87945 L
.34073 1.88408 L
.34127 1.88562 L
s
.02381 3.68144 m
.02435 3.67685 L
.02597 3.66312 L
.02867 3.64044 L
.03241 3.60913 L
.03718 3.56959 L
.04294 3.52237 L
.04966 3.46808 L
.05728 3.40743 L
.06576 3.34118 L
.07503 3.27016 L
.08505 3.19525 L
.09572 3.11732 L
.10699 3.03726 L
.11878 2.95596 L
.131 2.87427 L
.14357 2.79301 L
.15641 2.71293 L
.16943 2.63473 L
.18254 2.55905 L
.19565 2.48643 L
.20867 2.41734 L
.22151 2.35216 L
.23408 2.29117 L
.2463 2.23459 L
.25809 2.18254 L
.26936 2.13509 L
.28003 2.09223 L
.29004 2.05388 L
.29932 2.01994 L
.3078 1.99027 L
.31542 1.96468 L
.32214 1.94299 L
.3279 1.92502 L
.33267 1.9106 L
.33641 1.89957 L
.3391 1.89178 L
.34073 1.88715 L
.34127 1.88562 L
s
.34127 1.88562 m
.34181 1.88409 L
.34343 1.87954 L
.34613 1.87209 L
.34987 1.86195 L
.35464 1.8494 L
.3604 1.83477 L
.36712 1.81846 L
.37474 1.80093 L
.38322 1.78265 L
.39249 1.76411 L
.40251 1.74583 L
.41318 1.72829 L
.42445 1.71199 L
.43624 1.69736 L
.44846 1.68481 L
.46103 1.67467 L
.47387 1.66722 L
.48689 1.66267 L
.5 1.66114 L
.51311 1.66267 L
.52613 1.66722 L
.53897 1.67467 L
.55154 1.68481 L
.56376 1.69736 L
.57555 1.71199 L
.58682 1.72829 L
.59749 1.74583 L
.60751 1.76411 L
.61678 1.78265 L
.62526 1.80093 L
.63288 1.81846 L
.6396 1.83477 L
.64536 1.8494 L
.65013 1.86195 L
.65387 1.87209 L
.65657 1.87954 L
.65819 1.88409 L
.65873 1.88562 L
s
.34127 1.88562 m
.34181 1.88715 L
.34343 1.8917 L
.34613 1.89915 L
.34987 1.90928 L
.35464 1.92184 L
.3604 1.93647 L
.36712 1.95277 L
.37474 1.9703 L
.38322 1.98859 L
.39249 2.00713 L
.40251 2.02541 L
.41318 2.04294 L
.42445 2.05925 L
.43624 2.07387 L
.44846 2.08643 L
.46103 2.09657 L
.47387 2.10401 L
.48689 2.10857 L
.5 2.1101 L
.51311 2.10857 L
.52613 2.10401 L
.53897 2.09657 L
.55154 2.08643 L
.56376 2.07387 L
.57555 2.05925 L
.58682 2.04294 L
.59749 2.02541 L
.60751 2.00713 L
.61678 1.98859 L
.62526 1.9703 L
.63288 1.95277 L
.6396 1.93647 L
.64536 1.92184 L
.65013 1.90928 L
.65387 1.89915 L
.65657 1.8917 L
.65819 1.88715 L
.65873 1.88562 L
s
.65873 1.88562 m
.65927 1.88408 L
.6609 1.87945 L
.66359 1.87167 L
.66733 1.86063 L
.6721 1.84621 L
.67786 1.82825 L
.68458 1.80656 L
.6922 1.78097 L
.70068 1.75129 L
.70996 1.71735 L
.71997 1.67901 L
.73064 1.63614 L
.74191 1.58869 L
.7537 1.53665 L
.76592 1.48007 L
.77849 1.41908 L
.79133 1.35389 L
.80435 1.2848 L
.81746 1.21218 L
.83057 1.1365 L
.84359 1.05831 L
.85643 .97823 L
.869 .89696 L
.88122 .81527 L
.89301 .73397 L
.90428 .65392 L
.91495 .57599 L
.92497 .50107 L
.93424 .43006 L
.94272 .36381 L
.95034 .30315 L
.95706 .24886 L
.96282 .20164 L
.96759 .16211 L
.97133 .1308 L
.97403 .10812 L
.97565 .09439 L
.97619 .08979 L
s
.65873 1.88562 m
.65927 1.88715 L
.6609 1.89178 L
.66359 1.89957 L
.66733 1.9106 L
.6721 1.92502 L
.67786 1.94299 L
.68458 1.96468 L
.6922 1.99027 L
.70068 2.01994 L
.70996 2.05388 L
.71997 2.09223 L
.73064 2.13509 L
.74191 2.18254 L
.7537 2.23459 L
.76592 2.29117 L
.77849 2.35216 L
.79133 2.41734 L
.80435 2.48643 L
.81746 2.55905 L
.83057 2.63473 L
.84359 2.71293 L
.85643 2.79301 L
.869 2.87427 L
.88122 2.95596 L
.89301 3.03726 L
.90428 3.11732 L
.91495 3.19525 L
.92497 3.27016 L
.93424 3.34118 L
.94272 3.40743 L
.95034 3.46808 L
.95706 3.52237 L
.96282 3.56959 L
.96759 3.60913 L
.97133 3.64044 L
.97403 3.66312 L
.97565 3.67685 L
.97619 3.68144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  ImageSize->{46.4375, 175.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001L0001GR000`400?l00000o`00003oG03oool0
05`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03o
ool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00
G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?oo
o`00G03oool00300oooo00<000000?ooo`3oool0:@3oool00300oooo00<000000?ooo`3oool0:@3o
ool00300oooo00<000000?ooo`3oool0:@3oool00300oooo00<000000?ooo`3oool0:@3oool00300
oooo00<000000?ooo`3oool0:@3oool00300oooo00<000000?ooo`3oool0:@3oool00300oooo00<0
00000?ooo`3oool0:@3oool000/0oooo0P3o000S0?ooo`030000003oool0oooo0240oooo0P3o0006
0?ooo`002`3oool20?l002<0oooo00<000000?ooo`3oool08@3oool20?l000H0oooo000;0?ooo`80
o`008`3oool00`000000oooo0?ooo`0Q0?ooo`80o`001P3oool000/0oooo0P3o000S0?ooo`030000
003oool0oooo0240oooo0P3o00060?ooo`002`3oool20?l002<0oooo0P00000R0?ooo`80o`001P3o
ool000/0oooo0P3o000S0?ooo`030000003oool0oooo0240oooo0P3o00060?ooo`002`3oool30?l0
0280oooo00<000000?ooo`3oool08@3oool20?l000H0oooo000<0?ooo`80o`008P3oool00`000000
oooo0?ooo`0Q0?ooo`80o`001P3oool000`0oooo0P3o000R0?ooo`030000003oool0oooo0240oooo
0P3o00060?ooo`00303oool20?l00280oooo00<000000?ooo`3oool0803oool30?l000H0oooo000<
0?ooo`80o`008P3oool00`000000oooo0?ooo`0P0?ooo`80o`001`3oool000`0oooo0P3o000R0?oo
o`030000003oool0oooo0200oooo0P3o00070?ooo`00303oool20?l000`0oooo1`0000060?ooo`@0
00001@3oool00`000000oooo0?ooo`0P0?ooo`80o`001`3oool000`0oooo0`3o000>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0200oooo0P3o00070?ooo`003@3oool20?l000h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool20?l000L0oooo000=0?ooo`80o`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`80o`001`3oool000d0oooo0P3o000>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000280oooo0P3o00070?ooo`003@3oool20?l000H00000203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000P0?ooo`<0o`001`3o
ool000d0oooo0P3o000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool000000240oooo0P3o00080?ooo`003@3oool20?l000h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000008@3o
ool20?l000P0oooo000=0?ooo`80o`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000Q0?ooo`80o`00203oool000d0oooo0P3o000>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000240oooo0P3o00080?ooo`003@3oool20?l000h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07`3oool2
0?l000P0oooo000>0?ooo`80o`002@3oool3000000030?ooo`000000oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo0P3o00080?oo
o`003P3oool20?l000`0oooo0P0000090?ooo`@000001@3oool00`000000oooo0?ooo`0O0?ooo`80
o`00203oool000h0oooo0P3o000P0?ooo`030000003oool0oooo01l0oooo0P3o00080?ooo`003P3o
ool20?l00200oooo00<000000?ooo`3oool07`3oool20?l000P0oooo000>0?ooo`80o`00803oool0
0`000000oooo0?ooo`0N0?ooo`80o`002@3oool000h0oooo0P3o000P0?ooo`030000003oool0oooo
01h0oooo0P3o00090?ooo`003P3oool20?l00200oooo0P00000O0?ooo`80o`002@3oool000h0oooo
0P3o000P0?ooo`030000003oool0oooo01h0oooo0P3o00090?ooo`003P3oool20?l00200oooo00<0
00000?ooo`3oool07P3oool20?l000T0oooo000>0?ooo`80o`00803oool00`000000oooo0?ooo`0M
0?ooo`80o`002P3oool000l0oooo0P3o000O0?ooo`030000003oool0oooo01d0oooo0P3o000:0?oo
o`003`3oool20?l001l0oooo00<000000?ooo`3oool07@3oool20?l000X0oooo000?0?ooo`80o`00
7`3oool00`000000oooo0?ooo`0M0?ooo`80o`002P3oool000l0oooo0P3o000O0?ooo`030000003o
ool0oooo01d0oooo0P3o000:0?ooo`003`3oool20?l001l0oooo00<000000?ooo`3oool07@3oool2
0?l000X0oooo000?0?ooo`80o`007`3oool00`000000oooo0?ooo`0M0?ooo`80o`002P3oool00100
oooo0P3o000N0?ooo`030000003oool0oooo01d0oooo0P3o000:0?ooo`00403oool20?l001h0oooo
00<000000?ooo`3oool07@3oool20?l000X0oooo000@0?ooo`80o`007P3oool2000001h0oooo0P3o
000:0?ooo`00403oool20?l001h0oooo00<000000?ooo`3oool07@3oool20?l000X0oooo000@0?oo
o`80o`007P3oool00`000000oooo0?ooo`0M0?ooo`80o`002P3oool00100oooo0P3o000N0?ooo`03
0000003oool0oooo01`0oooo0P3o000;0?ooo`004@3oool20?l001d0oooo00<000000?ooo`3oool0
703oool20?l000/0oooo000A0?ooo`80o`007@3oool00`000000oooo0?ooo`0L0?ooo`80o`002`3o
ool00140oooo0P3o000M0?ooo`030000003oool0oooo01`0oooo0P3o000;0?ooo`004@3oool20?l0
01d0oooo00<000000?ooo`3oool0703oool20?l000/0oooo000A0?ooo`80o`007@3oool00`000000
oooo0?ooo`0L0?ooo`80o`002`3oool00140oooo0P3o000M0?ooo`030000003oool0oooo01/0oooo
0P3o000<0?ooo`004P3oool20?l001`0oooo00<000000?ooo`3oool06`3oool20?l000`0oooo000B
0?ooo`80o`00703oool00`000000oooo0?ooo`0K0?ooo`80o`00303oool00180oooo0P3o000L0?oo
o`030000003oool0oooo01/0oooo0P3o000<0?ooo`004P3oool20?l001`0oooo0P00000L0?ooo`80
o`00303oool00180oooo0P3o000L0?ooo`030000003oool0oooo01/0oooo0P3o000<0?ooo`004P3o
ool20?l001`0oooo00<000000?ooo`3oool06`3oool20?l000`0oooo000B0?ooo`80o`00703oool0
0`000000oooo0?ooo`0J0?ooo`80o`003@3oool001<0oooo0P3o000K0?ooo`030000003oool0oooo
01X0oooo0P3o000=0?ooo`004`3oool20?l001/0oooo00<000000?ooo`3oool06P3oool20?l000d0
oooo000C0?ooo`80o`006`3oool00`000000oooo0?ooo`0J0?ooo`80o`003@3oool001<0oooo0P3o
000K0?ooo`030000003oool0oooo01X0oooo0P3o000=0?ooo`004`3oool20?l001/0oooo00<00000
0?ooo`3oool06P3oool20?l000d0oooo000C0?ooo`80o`006`3oool00`000000oooo0?ooo`0I0?oo
o`80o`003P3oool001@0oooo0P3o000J0?ooo`030000003oool0oooo01T0oooo0P3o000>0?ooo`00
503oool20?l001X0oooo00<000000?ooo`3oool06@3oool20?l000h0oooo000D0?ooo`80o`006P3o
ool2000001X0oooo0P3o000>0?ooo`00503oool20?l001X0oooo00<000000?ooo`3oool06@3oool2
0?l000h0oooo000D0?ooo`80o`006P3oool00`000000oooo0?ooo`0I0?ooo`80o`003P3oool001@0
oooo0P3o000J0?ooo`030000003oool0oooo01P0oooo0P3o000?0?ooo`005@3oool20?l001T0oooo
00<000000?ooo`3oool0603oool20?l000l0oooo000E0?ooo`80o`006@3oool00`000000oooo0?oo
o`0H0?ooo`80o`003`3oool001D0oooo0P3o000I0?ooo`030000003oool0oooo01P0oooo0P3o000?
0?ooo`005@3oool20?l00100oooo100000050?ooo`030000003oool0oooo01P0oooo0P3o000?0?oo
o`005@3oool20?l000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo0P3o000?0?ooo`005@3oool20?l000h0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000001X0oooo0P3o000?0?ooo`005@3oool20?l001D0oooo
00D000000?ooo`3oool0oooo0000000I0?ooo`80o`00403oool001H0oooo0P3o000D0?ooo`050000
003oool0oooo0?ooo`0000006@3oool20?l00100oooo000F0?ooo`80o`0000<0oooo000000000000
1P00000;0?ooo`040000003oool0oooo0?ooo`800000603oool20?l00100oooo000F0?ooo`80o`00
3P3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`80o`00
403oool001H0oooo0P3o000>0?ooo`030000003oool00000008000001@3oool00`000000oooo0?oo
o`0G0?ooo`80o`00403oool001H0oooo0P3o000>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool05`3oool20?l00100oooo000F0?ooo`80o`003P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01H0oooo0P3o000A0?ooo`005`3oool20?l000d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0F0?ooo`80o`004@3oool001L0oooo0P3o000=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool20?l00140oooo000G0?ooo`80o`003@3o
ool6000000@0oooo00<000000?ooo`3oool05P3oool20?l00140oooo000G0?ooo`80o`005`3oool0
0`000000oooo0?ooo`0F0?ooo`80o`004@3oool001L0oooo0P3o000G0?ooo`030000003oool0oooo
01H0oooo0P3o000A0?ooo`005`3oool20?l001L0oooo00<000000?ooo`3oool05@3oool20?l00180
oooo000H0?ooo`80o`005P3oool00`000000oooo0?ooo`0E0?ooo`80o`004P3oool001P0oooo0P3o
000F0?ooo`8000005P3oool20?l00180oooo000H0?ooo`80o`005P3oool00`000000oooo0?ooo`0E
0?ooo`80o`004P3oool001P0oooo0P3o000F0?ooo`030000003oool0oooo01D0oooo0P3o000B0?oo
o`00603oool20?l001H0oooo00<000000?ooo`3oool0503oool20?l001<0oooo000I0?ooo`80o`00
5@3oool00`000000oooo0?ooo`0D0?ooo`80o`004`3oool001T0oooo0P3o000E0?ooo`030000003o
ool0oooo01@0oooo0P3o000C0?ooo`006@3oool20?l001D0oooo00<000000?ooo`3oool0503oool2
0?l001<0oooo000I0?ooo`80o`005@3oool00`000000oooo0?ooo`0D0?ooo`80o`004`3oool001T0
oooo0P3o000E0?ooo`030000003oool0oooo01@0oooo0P3o000C0?ooo`006@3oool20?l001D0oooo
00<000000?ooo`3oool04`3oool20?l001@0oooo000J0?ooo`80o`00503oool00`000000oooo0?oo
o`0C0?ooo`80o`00503oool001X0oooo0P3o000D0?ooo`030000003oool0oooo01<0oooo0P3o000D
0?ooo`006P3oool20?l001@0oooo00<000000?ooo`3oool04`3oool20?l001@0oooo000J0?ooo`80
o`00503oool2000001@0oooo0P3o000D0?ooo`006P3oool30?l001<0oooo00<000000?ooo`3oool0
4P3oool20?l001D0oooo000K0?ooo`80o`004`3oool00`000000oooo0?ooo`0B0?ooo`80o`005@3o
ool001/0oooo0P3o000C0?ooo`030000003oool0oooo0180oooo0P3o000E0?ooo`006`3oool20?l0
01<0oooo00<000000?ooo`3oool04P3oool20?l001D0oooo000K0?ooo`80o`004`3oool00`000000
oooo0?ooo`0A0?ooo`<0o`005@3oool001`0oooo0P3o000B0?ooo`030000003oool0oooo0140oooo
0P3o000F0?ooo`00703oool20?l00180oooo00<000000?ooo`3oool04@3oool20?l001H0oooo000L
0?ooo`80o`004P3oool00`000000oooo0?ooo`0A0?ooo`80o`005P3oool001`0oooo0P3o000B0?oo
o`030000003oool0oooo0140oooo0P3o000F0?ooo`00703oool30?l00140oooo00<000000?ooo`3o
ool0403oool20?l001L0oooo000M0?ooo`80o`004@3oool00`000000oooo0?ooo`0@0?ooo`80o`00
5`3oool001d0oooo0P3o000A0?ooo`8000004@3oool20?l001L0oooo000M0?ooo`80o`004@3oool0
0`000000oooo0?ooo`0@0?ooo`80o`005`3oool001d0oooo0`3o000@0?ooo`030000003oool0oooo
00l0oooo0`3o000G0?ooo`007P3oool20?l00100oooo00<000000?ooo`3oool03`3oool20?l001P0
oooo000N0?ooo`80o`00403oool00`000000oooo0?ooo`0?0?ooo`80o`00603oool001h0oooo0P3o
000@0?ooo`030000003oool0oooo00h0oooo0`3o000H0?ooo`007P3oool20?l00100oooo00<00000
0?ooo`3oool03P3oool20?l001T0oooo000N0?ooo`80o`003P3oool50?l000h0oooo0P3o000I0?oo
o`003`3oool5000000H0oooo100000020?l0008000001@3oool5000000T0o`001@3oool700000080
o`000P3oool8000000D0oooo1@0000050?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`3o00000`000000oooo0?ooo`060?ooo`03
0000003o0000o`000080o`0000<0oooo0000003oool0103o00070?ooo`040000003oool0oooo0?oo
o`80o`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`005@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo0?ooo`80o`002@3oool30?l000<0oooo00@000000?ooo`3oool0oooo0`3o0006
0?ooo`040000003oool0oooo0?ooo`80o`000`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0040oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o0009
0?ooo`80o`00103oool00`000000oooo0?ooo`020?ooo`80o`001P3oool010000000oooo0?ooo`3o
ool20?l000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`010?ooo`005@3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo0?l000T0oooo0P3o00040?ooo`800000103o
ool20?l000D0oooo00D000000?ooo`3oool0oooo0?l000060?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00@3oool00080oooo200000040?ooo`P00000103oool600000080o`001`3o
ool20?l000D0oooo00<000000?ooo`3oool0103oool20?l000@0oooo00<000000?ooo`3oool00P3o
00070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool001@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?l000060?ooo`<0o`001@3oool00`000000oooo0?ooo`04
0?ooo`<0o`000`3oool010000000oooo0?ooo`3o00090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00140oooo0`00000<0?ooo`030000003o0000o`0000D0oooo0P3o0000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P3o00030?ooo`040000003oool0
o`000?l000X0oooo00<000000?ooo`3oool01P3oool3000000D0oooo000D0?ooo`030000003oool0
oooo00X0oooo0P3o00040?ooo`80o`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`05
0?ooo`80o`000`3oool010000000oooo0?l0003o000;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool001D0oooo00<000000?ooo`3oool02@3oool20?l000@0oooo00@0o`00
0?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`<0o`000P3oool010000000o`000?l0
003o000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00@3oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`80o`000`3oool20?l00080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`80o`000P3oool00`000000o`000?l0
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`010?ooo`003P3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`040000003o0000o`000?l00080oooo0P3o00000`000000oooo000000050?ooo`030000003o
ool0oooo00H0oooo00D000000?l0003o0000oooo000000020?l000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`00403o
ool4000000P0oooo100000020?ooo`80o`000P3oool00`3o0000oooo0?ooo`02000000D0oooo00<0
00000?ooo`3oool0203oool00`3o000000000?l000020?l000L0oooo100000080?ooo`@000001@3o
ool00280oooo0P3o00000`3oool0o`000?l000090?ooo`030000003oool0oooo00L0oooo1@3o000M
0?ooo`008P3oool50?l000T0oooo00<000000?ooo`3oool0203oool40?l001d0oooo000R0?ooo`@0
o`002P3oool00`000000oooo0?ooo`080?ooo`@0o`007@3oool002<0oooo0`3o000:0?ooo`030000
003oool0oooo00P0oooo0`3o000N0?ooo`002P3ooolI000000<0o`005@0000040?l001T00000103o
ool002<0oooo0`3o000:0?ooo`030000003oool0oooo00P0oooo0`3o000N0?ooo`008P3oool40?l0
00X0oooo00<000000?ooo`3oool0203oool40?l001d0oooo000R0?ooo`D0o`002@3oool00`000000
oooo0?ooo`080?ooo`@0o`007@3oool00280oooo0P3o00000`3oool0o`000?l000090?ooo`030000
003oool0oooo00L0oooo0`3o00000`3oool0o`000?ooo`0L0?ooo`008P3oool20?l000040?ooo`3o
0000o`000?l000P0oooo00<000000?ooo`3oool01`3oool20?l00080oooo0P3o000L0?ooo`008P3o
ool0103o0000oooo0?ooo`3oool20?l000P0oooo00<000000?ooo`3oool01`3oool20?l000<0oooo
00<0o`000?ooo`3oool06P3oool00240oooo0P3o00030?ooo`80o`00203oool00`000000oooo0?oo
o`060?ooo`80o`000`3oool20?l001`0oooo000Q0?ooo`80o`000`3oool30?l000L0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01X0oooo000Q0?oo
o`80o`00103oool20?l000L0oooo00<000000?ooo`3oool01@3oool20?l000D0oooo0P3o000K0?oo
o`008@3oool00`3o0000oooo0?ooo`040?ooo`80o`001P3oool00`000000oooo0?ooo`050?ooo`80
o`001P3oool00`3o0000oooo0?ooo`0I0?ooo`00803oool20?l000L0oooo0P3o00050?ooo`030000
003oool0oooo00@0oooo0P3o00070?ooo`80o`006P3oool00200oooo0P3o00070?ooo`<0o`00103o
ool2000000@0oooo0`3o00070?ooo`80o`006P3oool001l0oooo0`3o00080?ooo`80o`00103oool0
0`000000oooo0?ooo`020?ooo`<0o`00203oool30?l001T0oooo000O0?ooo`80o`002@3oool30?l0
00<0oooo00@000000?ooo`3oool0oooo0`3o000:0?ooo`80o`006@3oool001l0oooo0P3o000:0?oo
o`<0o`000P3oool00`000000oooo0?ooo`030?l000/0oooo0P3o000I0?ooo`007P3oool30?l000/0
oooo0`3o00000`3oool000000?ooo`030?l000`0oooo0P3o000I0?ooo`007P3oool20?l000d0oooo
1`3o000=0?ooo`80o`006@3oool001h0oooo0P3o000>0?ooo`D0o`003P3oool20?l001T0oooo000N
0?ooo`80o`00403oool00`000000oooo0?ooo`0>0?ooo`<0o`00603oool001h0oooo0P3o000@0?oo
o`030000003oool0oooo00l0oooo0P3o000H0?ooo`007P3oool20?l00100oooo00<000000?ooo`3o
ool03`3oool20?l001P0oooo000N0?ooo`80o`00403oool00`000000oooo0?ooo`0?0?ooo`80o`00
603oool001d0oooo0`3o000@0?ooo`030000003oool0oooo00l0oooo0`3o000G0?ooo`007@3oool2
0?l00140oooo0P00000A0?ooo`80o`005`3oool001d0oooo0P3o000A0?ooo`030000003oool0oooo
0100oooo0P3o000G0?ooo`007@3oool20?l00140oooo00<000000?ooo`3oool0403oool20?l001L0
oooo000L0?ooo`<0o`004@3oool00`000000oooo0?ooo`0@0?ooo`<0o`005P3oool001`0oooo0P3o
000B0?ooo`030000003oool0oooo0140oooo0P3o000F0?ooo`00703oool20?l00180oooo00<00000
0?ooo`3oool04@3oool20?l001H0oooo000L0?ooo`80o`004P3oool00`000000oooo0?ooo`0A0?oo
o`80o`005P3oool001/0oooo0`3o000B0?ooo`030000003oool0oooo0140oooo0P3o000F0?ooo`00
6`3oool20?l001<0oooo00<000000?ooo`3oool04P3oool20?l001D0oooo000K0?ooo`80o`004`3o
ool00`000000oooo0?ooo`0B0?ooo`80o`005@3oool001/0oooo0P3o000C0?ooo`030000003oool0
oooo0180oooo0P3o000E0?ooo`006`3oool20?l001<0oooo00<000000?ooo`3oool04P3oool20?l0
01D0oooo000J0?ooo`80o`00503oool00`000000oooo0?ooo`0B0?ooo`80o`005@3oool001X0oooo
0P3o000D0?ooo`800000503oool20?l001@0oooo000J0?ooo`80o`00503oool00`000000oooo0?oo
o`0C0?ooo`80o`00503oool001X0oooo0P3o000D0?ooo`030000003oool0oooo01<0oooo0P3o000D
0?ooo`006P3oool20?l001@0oooo00<000000?ooo`3oool04`3oool20?l001@0oooo000I0?ooo`80
o`005@3oool00`000000oooo0?ooo`0C0?ooo`80o`00503oool001T0oooo0P3o000E0?ooo`030000
003oool0oooo01@0oooo0P3o000C0?ooo`006@3oool20?l001D0oooo00<000000?ooo`3oool0503o
ool20?l001<0oooo000I0?ooo`80o`005@3oool00`000000oooo0?ooo`0D0?ooo`80o`004`3oool0
01T0oooo0P3o000E0?ooo`030000003oool0oooo01@0oooo0P3o000C0?ooo`00603oool20?l001H0
oooo00<000000?ooo`3oool0503oool20?l001<0oooo000H0?ooo`80o`005P3oool00`000000oooo
0?ooo`0E0?ooo`80o`004P3oool001P0oooo0P3o000F0?ooo`030000003oool0oooo01D0oooo0P3o
000B0?ooo`00603oool20?l001H0oooo0P00000F0?ooo`80o`004P3oool001P0oooo0P3o000F0?oo
o`030000003oool0oooo01D0oooo0P3o000B0?ooo`00603oool20?l001H0oooo00<000000?ooo`3o
ool05@3oool20?l00180oooo000G0?ooo`80o`005`3oool00`000000oooo0?ooo`0E0?ooo`80o`00
4P3oool001L0oooo0P3o000G0?ooo`030000003oool0oooo01H0oooo0P3o000A0?ooo`005`3oool2
0?l001L0oooo00<000000?ooo`3oool05P3oool20?l00140oooo000G0?ooo`80o`005`3oool00`00
0000oooo0?ooo`0F0?ooo`80o`004@3oool001L0oooo0P3o000>0?ooo`@000001@3oool00`000000
oooo0?ooo`0F0?ooo`80o`004@3oool001L0oooo0P3o000=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`80o`004@3oool001H0oooo0P3o
000=0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`80o`00
4@3oool001H0oooo0P3o000D0?ooo`050000003oool0oooo0?ooo`0000006@3oool20?l00100oooo
000F0?ooo`80o`00503oool01@000000oooo0?ooo`3oool0000001T0oooo0P3o000@0?ooo`005P3o
ool20?l001@0oooo00@000000?ooo`3oool0oooo0P00000H0?ooo`80o`00403oool001H0oooo0P3o
000>0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo0P3o
000@0?ooo`005P3oool20?l000h0oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0
oooo01L0oooo0P3o000@0?ooo`005@3oool20?l000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0G0?ooo`80o`00403oool001D0oooo0P3o000?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0603oool20?l000l0oooo000E0?ooo`80o`003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01P0oooo0P3o000?0?ooo`005@3oool20?l000l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`80o`003`3oool001D0oooo0P3o000?
0?ooo`H00000103oool00`000000oooo0?ooo`0H0?ooo`80o`003`3oool001D0oooo0P3o000I0?oo
o`030000003oool0oooo01P0oooo0P3o000?0?ooo`00503oool20?l001X0oooo00<000000?ooo`3o
ool0603oool20?l000l0oooo000D0?ooo`80o`006P3oool00`000000oooo0?ooo`0I0?ooo`80o`00
3P3oool001@0oooo0P3o000J0?ooo`030000003oool0oooo01T0oooo0P3o000>0?ooo`00503oool2
0?l001X0oooo00<000000?ooo`3oool06@3oool20?l000h0oooo000D0?ooo`80o`006P3oool20000
01X0oooo0P3o000>0?ooo`00503oool20?l001X0oooo00<000000?ooo`3oool06@3oool20?l000h0
oooo000C0?ooo`80o`006`3oool00`000000oooo0?ooo`0I0?ooo`80o`003P3oool001<0oooo0P3o
000K0?ooo`030000003oool0oooo01X0oooo0P3o000=0?ooo`004`3oool20?l001/0oooo00<00000
0?ooo`3oool06P3oool20?l000d0oooo000C0?ooo`80o`006`3oool00`000000oooo0?ooo`0J0?oo
o`80o`003@3oool001<0oooo0P3o000K0?ooo`030000003oool0oooo01X0oooo0P3o000=0?ooo`00
4`3oool20?l001/0oooo00<000000?ooo`3oool06P3oool20?l000d0oooo000C0?ooo`80o`006`3o
ool00`000000oooo0?ooo`0J0?ooo`80o`003@3oool00180oooo0P3o000L0?ooo`030000003oool0
oooo01X0oooo0P3o000=0?ooo`004P3oool20?l001`0oooo00<000000?ooo`3oool06`3oool20?l0
00`0oooo000B0?ooo`80o`00703oool00`000000oooo0?ooo`0K0?ooo`80o`00303oool00180oooo
0P3o000L0?ooo`800000703oool20?l000`0oooo000B0?ooo`80o`00703oool00`000000oooo0?oo
o`0K0?ooo`80o`00303oool00180oooo0P3o000L0?ooo`030000003oool0oooo01/0oooo0P3o000<
0?ooo`004@3oool20?l001d0oooo00<000000?ooo`3oool06`3oool20?l000`0oooo000A0?ooo`80
o`007@3oool00`000000oooo0?ooo`0L0?ooo`80o`002`3oool00140oooo0P3o000M0?ooo`030000
003oool0oooo01`0oooo0P3o000;0?ooo`004@3oool20?l001d0oooo00<000000?ooo`3oool0703o
ool20?l000/0oooo000A0?ooo`80o`007@3oool00`000000oooo0?ooo`0L0?ooo`80o`002`3oool0
0140oooo0P3o000M0?ooo`030000003oool0oooo01`0oooo0P3o000;0?ooo`00403oool20?l001h0
oooo00<000000?ooo`3oool0703oool20?l000/0oooo000@0?ooo`80o`007P3oool00`000000oooo
0?ooo`0M0?ooo`80o`002P3oool00100oooo0P3o000N0?ooo`030000003oool0oooo01d0oooo0P3o
000:0?ooo`00403oool20?l001h0oooo0P00000N0?ooo`80o`002P3oool00100oooo0P3o000N0?oo
o`030000003oool0oooo01d0oooo0P3o000:0?ooo`00403oool20?l001h0oooo00<000000?ooo`3o
ool07@3oool20?l000X0oooo000?0?ooo`80o`007`3oool00`000000oooo0?ooo`0M0?ooo`80o`00
2P3oool000l0oooo0P3o000O0?ooo`030000003oool0oooo01d0oooo0P3o000:0?ooo`003`3oool2
0?l001l0oooo00<000000?ooo`3oool07@3oool20?l000X0oooo000?0?ooo`80o`007`3oool00`00
0000oooo0?ooo`0M0?ooo`80o`002P3oool000l0oooo0P3o000O0?ooo`030000003oool0oooo01d0
oooo0P3o000:0?ooo`003`3oool20?l001l0oooo00<000000?ooo`3oool07@3oool20?l000X0oooo
000>0?ooo`80o`00803oool00`000000oooo0?ooo`0M0?ooo`80o`002P3oool000h0oooo0P3o000P
0?ooo`030000003oool0oooo01h0oooo0P3o00090?ooo`003P3oool20?l00200oooo00<000000?oo
o`3oool07P3oool20?l000T0oooo000>0?ooo`80o`00803oool00`000000oooo0?ooo`0N0?ooo`80
o`002@3oool000h0oooo0P3o000P0?ooo`8000007`3oool20?l000T0oooo000>0?ooo`80o`00803o
ool00`000000oooo0?ooo`0N0?ooo`80o`002@3oool000h0oooo0P3o000P0?ooo`030000003oool0
oooo01h0oooo0P3o00090?ooo`003P3oool20?l00200oooo00<000000?ooo`3oool07`3oool20?l0
00P0oooo000>0?ooo`80o`00803oool00`000000oooo0?ooo`0O0?ooo`80o`00203oool000h0oooo
0P3o000P0?ooo`030000003oool0oooo01l0oooo0P3o00080?ooo`003P3oool20?l00200oooo00<0
00000?ooo`3oool07`3oool20?l000P0oooo000=0?ooo`80o`002`3oool7000000H0oooo10000005
0?ooo`030000003oool0oooo01l0oooo0P3o00080?ooo`003@3oool20?l000h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool07`3oool20?l000P0oooo000=0?ooo`80o`003P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`80
o`00203oool000d0oooo0P3o000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool000000240oooo0P3o00080?ooo`003@3oool20?l000h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00008@3oool20?l000P0oooo000=0?ooo`80o`003P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000Q0?ooo`80o`001`3oool000d0oooo
0P3o000>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool000000280oooo0P3o00070?ooo`003@3oool20?l000h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000008P3oool20?l000L0
oooo000=0?ooo`80o`003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo0000000R0?ooo`80o`001`3oool000`0oooo0P3o000?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000280
oooo0P3o00070?ooo`00303oool20?l000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803oool20?l000L0oooo
000<0?ooo`80o`002`3oool3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo0P3o00070?ooo`00303oool2
0?l000h0oooo0P0000090?ooo`@000001@3oool00`000000oooo0?ooo`0P0?ooo`<0o`001P3oool0
00`0oooo0P3o000R0?ooo`030000003oool0oooo0240oooo0P3o00060?ooo`00303oool20?l00280
oooo00<000000?ooo`3oool08@3oool20?l000H0oooo000;0?ooo`<0o`008P3oool00`000000oooo
0?ooo`0Q0?ooo`80o`001P3oool000/0oooo0P3o000S0?ooo`030000003oool0oooo0240oooo0P3o
00060?ooo`002`3oool20?l002<0oooo0P00000R0?ooo`80o`001P3oool000/0oooo0P3o000S0?oo
o`030000003oool0oooo0240oooo0P3o00060?ooo`002`3oool20?l002<0oooo00<000000?ooo`3o
ool08@3oool20?l000H0oooo000;0?ooo`80o`008`3oool00`000000oooo0?ooo`0Q0?ooo`80o`00
1P3oool000/0oooo0P3o000S0?ooo`030000003oool0oooo0240oooo0P3o00060?ooo`002`3oool2
0?l002<0oooo00<000000?ooo`3oool08@3oool20?l000H0oooo000`0?ooo`030000003oool0oooo
02T0oooo000`0?ooo`030000003oool0oooo02T0oooo000`0?ooo`030000003oool0oooo02T0oooo
000`0?ooo`030000003oool0oooo02T0oooo000`0?ooo`030000003oool0oooo02T0oooo000`0?oo
o`030000003oool0oooo02T0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0
oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool0
05`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00G03o
ool005`0oooo001L0?ooo`00G03oool005`0oooo001L0?ooo`00\
\>"],
  ImageRangeCache->{{{87.5, 123.625}, {196.375, 57.1875}} -> {-22.1463, \
-2.57349, 0.165948, 0.165948}}],

Cell["Now together", "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(Show[s1, s2, s3];\)\)], "Input",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.90157 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 1.95078 0.15873 [
[.02381 1.93828 -6 -9 ]
[.02381 1.93828 6 0 ]
[.18254 1.93828 -6 -9 ]
[.18254 1.93828 6 0 ]
[.34127 1.93828 -6 -9 ]
[.34127 1.93828 6 0 ]
[.65873 1.93828 -3 -9 ]
[.65873 1.93828 3 0 ]
[.81746 1.93828 -3 -9 ]
[.81746 1.93828 3 0 ]
[.97619 1.93828 -3 -9 ]
[.97619 1.93828 3 0 ]
[.4875 .36348 -18 -4.5 ]
[.4875 .36348 0 4.5 ]
[.4875 1.15713 -12 -4.5 ]
[.4875 1.15713 0 4.5 ]
[.4875 2.74443 -6 -4.5 ]
[.4875 2.74443 0 4.5 ]
[.4875 3.53808 -12 -4.5 ]
[.4875 3.53808 0 4.5 ]
[ 0 0 0 0 ]
[ 1 3.90157 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 1.95078 m
.02381 1.95703 L
s
[(-3)] .02381 1.93828 0 1 Mshowa
.18254 1.95078 m
.18254 1.95703 L
s
[(-2)] .18254 1.93828 0 1 Mshowa
.34127 1.95078 m
.34127 1.95703 L
s
[(-1)] .34127 1.93828 0 1 Mshowa
.65873 1.95078 m
.65873 1.95703 L
s
[(1)] .65873 1.93828 0 1 Mshowa
.81746 1.95078 m
.81746 1.95703 L
s
[(2)] .81746 1.93828 0 1 Mshowa
.97619 1.95078 m
.97619 1.95703 L
s
[(3)] .97619 1.93828 0 1 Mshowa
.125 Mabswid
.05556 1.95078 m
.05556 1.95453 L
s
.0873 1.95078 m
.0873 1.95453 L
s
.11905 1.95078 m
.11905 1.95453 L
s
.15079 1.95078 m
.15079 1.95453 L
s
.21429 1.95078 m
.21429 1.95453 L
s
.24603 1.95078 m
.24603 1.95453 L
s
.27778 1.95078 m
.27778 1.95453 L
s
.30952 1.95078 m
.30952 1.95453 L
s
.37302 1.95078 m
.37302 1.95453 L
s
.40476 1.95078 m
.40476 1.95453 L
s
.43651 1.95078 m
.43651 1.95453 L
s
.46825 1.95078 m
.46825 1.95453 L
s
.53175 1.95078 m
.53175 1.95453 L
s
.56349 1.95078 m
.56349 1.95453 L
s
.59524 1.95078 m
.59524 1.95453 L
s
.62698 1.95078 m
.62698 1.95453 L
s
.69048 1.95078 m
.69048 1.95453 L
s
.72222 1.95078 m
.72222 1.95453 L
s
.75397 1.95078 m
.75397 1.95453 L
s
.78571 1.95078 m
.78571 1.95453 L
s
.84921 1.95078 m
.84921 1.95453 L
s
.88095 1.95078 m
.88095 1.95453 L
s
.9127 1.95078 m
.9127 1.95453 L
s
.94444 1.95078 m
.94444 1.95453 L
s
.25 Mabswid
0 1.95078 m
1 1.95078 L
s
.5 .36348 m
.50625 .36348 L
s
[(-10)] .4875 .36348 1 0 Mshowa
.5 1.15713 m
.50625 1.15713 L
s
[(-5)] .4875 1.15713 1 0 Mshowa
.5 2.74443 m
.50625 2.74443 L
s
[(5)] .4875 2.74443 1 0 Mshowa
.5 3.53808 m
.50625 3.53808 L
s
[(10)] .4875 3.53808 1 0 Mshowa
.125 Mabswid
.5 .52221 m
.50375 .52221 L
s
.5 .68094 m
.50375 .68094 L
s
.5 .83967 m
.50375 .83967 L
s
.5 .9984 m
.50375 .9984 L
s
.5 1.31586 m
.50375 1.31586 L
s
.5 1.47459 m
.50375 1.47459 L
s
.5 1.63332 m
.50375 1.63332 L
s
.5 1.79205 m
.50375 1.79205 L
s
.5 2.10951 m
.50375 2.10951 L
s
.5 2.26824 m
.50375 2.26824 L
s
.5 2.42697 m
.50375 2.42697 L
s
.5 2.5857 m
.50375 2.5857 L
s
.5 2.90316 m
.50375 2.90316 L
s
.5 3.06189 m
.50375 3.06189 L
s
.5 3.22062 m
.50375 3.22062 L
s
.5 3.37935 m
.50375 3.37935 L
s
.5 .20475 m
.50375 .20475 L
s
.5 .04602 m
.50375 .04602 L
s
.5 3.69682 m
.50375 3.69682 L
s
.5 3.85555 m
.50375 3.85555 L
s
.25 Mabswid
.5 0 m
.5 3.90157 L
s
0 0 m
1 0 L
1 3.90157 L
0 3.90157 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.02381 .16763 m
.02424 .17134 L
.02555 .18244 L
.02771 .20079 L
.03071 .22616 L
.03453 .25826 L
.03915 .29671 L
.04454 .34105 L
.05065 .39078 L
.05745 .44534 L
.06489 .50412 L
.07292 .56649 L
.08149 .6318 L
.09052 .69939 L
.09998 .7686 L
.10978 .83879 L
.11986 .90935 L
.13016 .97968 L
.1406 1.04925 L
.15111 1.11757 L
.16163 1.18419 L
.17207 1.24873 L
.18237 1.31087 L
.19245 1.37037 L
.20225 1.42704 L
.21171 1.48075 L
.22074 1.53144 L
.22931 1.57911 L
.23734 1.62381 L
.24478 1.66565 L
.25158 1.70479 L
.25769 1.74142 L
.26308 1.77578 L
.2677 1.80814 L
.27152 1.83878 L
.27452 1.86802 L
.27668 1.89621 L
.27799 1.92367 L
.27842 1.95066 L
s
.02381 3.73394 m
.02424 3.73022 L
.02555 3.71913 L
.02771 3.70078 L
.03071 3.67541 L
.03453 3.64331 L
.03915 3.60486 L
.04454 3.56052 L
.05065 3.51079 L
.05745 3.45623 L
.06489 3.39745 L
.07292 3.33508 L
.08149 3.26977 L
.09052 3.20218 L
.09998 3.13297 L
.10978 3.06278 L
.11986 2.99222 L
.13016 2.92188 L
.1406 2.85231 L
.15111 2.784 L
.16163 2.71738 L
.17207 2.65284 L
.18237 2.59069 L
.19245 2.53119 L
.20225 2.47453 L
.21171 2.42082 L
.22074 2.37013 L
.22931 2.32246 L
.23734 2.27776 L
.24478 2.23591 L
.25158 2.19678 L
.25769 2.16014 L
.26308 2.12578 L
.2677 2.09343 L
.27152 2.06279 L
.27452 2.03354 L
.27668 2.00536 L
.27799 1.97789 L
.27842 1.95091 L
s
.46404 1.95073 m
.46417 1.945 L
.46453 1.93925 L
.46514 1.93357 L
.46599 1.92801 L
.46707 1.92259 L
.46838 1.91734 L
.4699 1.91232 L
.47162 1.90754 L
.47355 1.90305 L
.47565 1.89887 L
.47791 1.89504 L
.48033 1.89159 L
.48289 1.88854 L
.48556 1.88591 L
.48832 1.88374 L
.49117 1.88202 L
.49408 1.88079 L
.49703 1.88005 L
.5 1.8798 L
.50297 1.88005 L
.50592 1.88079 L
.50883 1.88202 L
.51168 1.88374 L
.51444 1.88591 L
.51711 1.88854 L
.51967 1.89159 L
.52209 1.89504 L
.52435 1.89887 L
.52645 1.90305 L
.52838 1.90754 L
.5301 1.91232 L
.53162 1.91734 L
.53293 1.92259 L
.53401 1.92801 L
.53486 1.93357 L
.53547 1.93925 L
.53583 1.945 L
.53596 1.95073 L
s
.46404 1.95083 m
.46417 1.95657 L
.46453 1.96232 L
.46514 1.96799 L
.46599 1.97356 L
.46707 1.97898 L
.46838 1.98422 L
.4699 1.98925 L
.47162 1.99402 L
.47355 1.99852 L
.47565 2.00269 L
.47791 2.00652 L
.48033 2.00998 L
.48289 2.01303 L
.48556 2.01565 L
.48832 2.01783 L
.49117 2.01954 L
.49408 2.02078 L
.49703 2.02152 L
.5 2.02177 L
.50297 2.02152 L
.50592 2.02078 L
.50883 2.01954 L
.51168 2.01783 L
.51444 2.01565 L
.51711 2.01303 L
.51967 2.00998 L
.52209 2.00652 L
.52435 2.00269 L
.52645 1.99852 L
.52838 1.99402 L
.5301 1.98925 L
.53162 1.98422 L
.53293 1.97898 L
.53401 1.97356 L
.53486 1.96799 L
.53547 1.96232 L
.53583 1.95657 L
.53596 1.95083 L
s
.72158 1.95066 m
.72201 1.92367 L
.72332 1.89621 L
.72548 1.86802 L
.72848 1.83878 L
.7323 1.80814 L
.73692 1.77578 L
.74231 1.74142 L
.74842 1.70479 L
.75522 1.66565 L
.76266 1.62381 L
.77069 1.57911 L
.77926 1.53144 L
.78829 1.48075 L
.79775 1.42704 L
.80755 1.37037 L
.81763 1.31087 L
.82793 1.24873 L
.83837 1.18419 L
.84889 1.11757 L
.8594 1.04925 L
.86984 .97968 L
.88014 .90935 L
.89022 .83879 L
.90002 .7686 L
.90948 .69939 L
.91851 .6318 L
.92708 .56649 L
.93511 .50412 L
.94255 .44534 L
.94935 .39078 L
.95546 .34105 L
.96085 .29671 L
.96547 .25826 L
.96929 .22616 L
.97229 .20079 L
.97445 .18244 L
.97576 .17134 L
.97619 .16763 L
s
.72158 1.95091 m
.72201 1.97789 L
.72332 2.00536 L
.72548 2.03354 L
.72848 2.06279 L
.7323 2.09343 L
.73692 2.12578 L
.74231 2.16014 L
.74842 2.19678 L
.75522 2.23591 L
.76266 2.27776 L
.77069 2.32246 L
.77926 2.37013 L
.78829 2.42082 L
.79775 2.47453 L
.80755 2.53119 L
.81763 2.59069 L
.82793 2.65284 L
.83837 2.71738 L
.84889 2.784 L
.8594 2.85231 L
.86984 2.92188 L
.88014 2.99222 L
.89022 3.06278 L
.90002 3.13297 L
.90948 3.20218 L
.91851 3.26977 L
.92708 3.33508 L
.93511 3.39745 L
.94255 3.45623 L
.94935 3.51079 L
.95546 3.56052 L
.96085 3.60486 L
.96547 3.64331 L
.96929 3.67541 L
.97229 3.70078 L
.97445 3.71913 L
.97576 3.73022 L
.97619 3.73394 L
s
.02381 .1648 m
.02426 .16861 L
.02559 .17997 L
.0278 .19875 L
.03088 .22471 L
.0348 .25756 L
.03954 .29688 L
.04507 .34222 L
.05133 .39304 L
.05831 .44877 L
.06594 .50878 L
.07417 .57241 L
.08295 .63899 L
.09222 .70784 L
.10191 .77826 L
.11196 .84962 L
.1223 .92125 L
.13286 .99257 L
.14357 1.063 L
.15435 1.13205 L
.16513 1.19925 L
.17583 1.26423 L
.18639 1.32665 L
.19673 1.38626 L
.20678 1.44286 L
.21648 1.49634 L
.22574 1.54662 L
.23452 1.59372 L
.24276 1.63769 L
.25039 1.67865 L
.25736 1.71676 L
.26363 1.75222 L
.26915 1.78529 L
.27389 1.81624 L
.27781 1.84538 L
.28089 1.87304 L
.2831 1.89959 L
.28444 1.92538 L
.28488 1.95067 L
s
.02381 3.73676 m
.02426 3.73296 L
.02559 3.7216 L
.0278 3.70282 L
.03088 3.67685 L
.0348 3.64401 L
.03954 3.60469 L
.04507 3.55935 L
.05133 3.50852 L
.05831 3.45279 L
.06594 3.39279 L
.07417 3.32915 L
.08295 3.26258 L
.09222 3.19373 L
.10191 3.1233 L
.11196 3.05195 L
.1223 2.98032 L
.13286 2.909 L
.14357 2.83857 L
.15435 2.76952 L
.16513 2.70231 L
.17583 2.63734 L
.18639 2.57492 L
.19673 2.51531 L
.20678 2.4587 L
.21648 2.40523 L
.22574 2.35494 L
.23452 2.30785 L
.24276 2.26388 L
.25039 2.22292 L
.25736 2.18481 L
.26363 2.14935 L
.26915 2.11628 L
.27389 2.08533 L
.27781 2.05619 L
.28089 2.02852 L
.2831 2.00198 L
.28444 1.97619 L
.28488 1.9509 L
s
.43585 1.95072 m
.43607 1.94109 L
.43672 1.93144 L
.43781 1.92189 L
.43932 1.91248 L
.44125 1.90327 L
.44358 1.89431 L
.44629 1.88566 L
.44938 1.87739 L
.4528 1.86954 L
.45655 1.86219 L
.4606 1.8554 L
.46491 1.84923 L
.46947 1.84375 L
.47423 1.839 L
.47917 1.83504 L
.48425 1.83191 L
.48944 1.82965 L
.4947 1.82829 L
.5 1.82783 L
.5053 1.82829 L
.51056 1.82965 L
.51575 1.83191 L
.52083 1.83504 L
.52577 1.839 L
.53053 1.84375 L
.53509 1.84923 L
.5394 1.8554 L
.54345 1.86219 L
.5472 1.86954 L
.55062 1.87739 L
.55371 1.88566 L
.55642 1.89431 L
.55875 1.90327 L
.56068 1.91248 L
.56219 1.92189 L
.56328 1.93144 L
.56393 1.94109 L
.56415 1.95072 L
s
.43585 1.95085 m
.43607 1.96048 L
.43672 1.97013 L
.43781 1.97968 L
.43932 1.98908 L
.44125 1.9983 L
.44358 2.00725 L
.44629 2.0159 L
.44938 2.02418 L
.4528 2.03203 L
.45655 2.03938 L
.4606 2.04617 L
.46491 2.05234 L
.46947 2.05782 L
.47423 2.06257 L
.47917 2.06653 L
.48425 2.06965 L
.48944 2.07191 L
.4947 2.07328 L
.5 2.07374 L
.5053 2.07328 L
.51056 2.07191 L
.51575 2.06965 L
.52083 2.06653 L
.52577 2.06257 L
.53053 2.05782 L
.53509 2.05234 L
.5394 2.04617 L
.54345 2.03938 L
.5472 2.03203 L
.55062 2.02418 L
.55371 2.0159 L
.55642 2.00725 L
.55875 1.9983 L
.56068 1.98908 L
.56219 1.97968 L
.56328 1.97013 L
.56393 1.96048 L
.56415 1.95085 L
s
.71512 1.95067 m
.71556 1.92538 L
.7169 1.89959 L
.71911 1.87304 L
.72219 1.84538 L
.72611 1.81624 L
.73085 1.78529 L
.73637 1.75222 L
.74264 1.71676 L
.74961 1.67865 L
.75724 1.63769 L
.76548 1.59372 L
.77426 1.54662 L
.78352 1.49634 L
.79322 1.44286 L
.80327 1.38626 L
.81361 1.32665 L
.82417 1.26423 L
.83487 1.19925 L
.84565 1.13205 L
.85643 1.063 L
.86714 .99257 L
.8777 .92125 L
.88804 .84962 L
.89809 .77826 L
.90778 .70784 L
.91705 .63899 L
.92583 .57241 L
.93406 .50878 L
.94169 .44877 L
.94867 .39304 L
.95493 .34222 L
.96046 .29688 L
.9652 .25756 L
.96912 .22471 L
.9722 .19875 L
.97441 .17997 L
.97574 .16861 L
.97619 .1648 L
s
.71512 1.9509 m
.71556 1.97619 L
.7169 2.00198 L
.71911 2.02852 L
.72219 2.05619 L
.72611 2.08533 L
.73085 2.11628 L
.73637 2.14935 L
.74264 2.18481 L
.74961 2.22292 L
.75724 2.26388 L
.76548 2.30785 L
.77426 2.35494 L
.78352 2.40523 L
.79322 2.4587 L
.80327 2.51531 L
.81361 2.57492 L
.82417 2.63734 L
.83487 2.70231 L
.84565 2.76952 L
.85643 2.83857 L
.86714 2.909 L
.8777 2.98032 L
.88804 3.05195 L
.89809 3.1233 L
.90778 3.19373 L
.91705 3.26258 L
.92583 3.32915 L
.93406 3.39279 L
.94169 3.45279 L
.94867 3.50852 L
.95493 3.55935 L
.96046 3.60469 L
.9652 3.64401 L
.96912 3.67685 L
.9722 3.70282 L
.97441 3.7216 L
.97574 3.73296 L
.97619 3.73676 L
s
.02381 .16199 m
.02427 .16589 L
.02564 .17757 L
.02792 .19687 L
.03109 .22355 L
.03513 .25729 L
.04001 .29767 L
.04569 .34421 L
.05215 .39635 L
.05933 .45349 L
.06718 .51498 L
.07566 .58012 L
.0847 .64823 L
.09424 .71858 L
.10422 .79047 L
.11457 .86321 L
.12522 .93614 L
.13609 1.00863 L
.14711 1.0801 L
.15821 1.15002 L
.16931 1.21793 L
.18033 1.28343 L
.1912 1.34617 L
.20185 1.4059 L
.2122 1.46243 L
.22218 1.51562 L
.23172 1.56541 L
.24076 1.61181 L
.24924 1.65489 L
.25709 1.69477 L
.26427 1.73161 L
.27072 1.76564 L
.27641 1.79711 L
.28129 1.82633 L
.28533 1.85361 L
.2885 1.87931 L
.29078 1.90381 L
.29215 1.9275 L
.29261 1.95068 L
s
.02381 3.73958 m
.02427 3.73567 L
.02564 3.724 L
.02792 3.7047 L
.03109 3.67801 L
.03513 3.64428 L
.04001 3.60389 L
.04569 3.55736 L
.05215 3.50521 L
.05933 3.44807 L
.06718 3.38659 L
.07566 3.32144 L
.0847 3.25334 L
.09424 3.18299 L
.10422 3.11109 L
.11457 3.03835 L
.12522 2.96543 L
.13609 2.89294 L
.14711 2.82147 L
.15821 2.75155 L
.16931 2.68364 L
.18033 2.61814 L
.1912 2.55539 L
.20185 2.49566 L
.2122 2.43914 L
.22218 2.38595 L
.23172 2.33616 L
.24076 2.28975 L
.24924 2.24667 L
.25709 2.2068 L
.26427 2.16996 L
.27072 2.13593 L
.27641 2.10446 L
.28129 2.07524 L
.28533 2.04796 L
.2885 2.02226 L
.29078 1.99775 L
.29215 1.97406 L
.29261 1.95089 L
s
.4141 1.95072 m
.41439 1.93884 L
.41527 1.92694 L
.41672 1.9151 L
.41875 1.90336 L
.42133 1.89179 L
.42445 1.88043 L
.42808 1.86935 L
.43221 1.85864 L
.4368 1.84839 L
.44182 1.83869 L
.44724 1.82964 L
.45301 1.82135 L
.45911 1.81392 L
.46549 1.80745 L
.47211 1.80202 L
.47891 1.79771 L
.48586 1.79458 L
.49291 1.79269 L
.5 1.79205 L
.50709 1.79269 L
.51414 1.79458 L
.52109 1.79771 L
.52789 1.80202 L
.53451 1.80745 L
.54089 1.81392 L
.54699 1.82135 L
.55276 1.82964 L
.55818 1.83869 L
.5632 1.84839 L
.56779 1.85864 L
.57192 1.86935 L
.57555 1.88043 L
.57867 1.89179 L
.58125 1.90336 L
.58328 1.9151 L
.58473 1.92694 L
.58561 1.93884 L
.5859 1.95072 L
s
.4141 1.95085 m
.41439 1.96272 L
.41527 1.97463 L
.41672 1.98647 L
.41875 1.9982 L
.42133 2.00978 L
.42445 2.02114 L
.42808 2.03221 L
.43221 2.04292 L
.4368 2.05317 L
.44182 2.06288 L
.44724 2.07192 L
.45301 2.08021 L
.45911 2.08764 L
.46549 2.09412 L
.47211 2.09955 L
.47891 2.10386 L
.48586 2.10698 L
.49291 2.10888 L
.5 2.10951 L
.50709 2.10888 L
.51414 2.10698 L
.52109 2.10386 L
.52789 2.09955 L
.53451 2.09412 L
.54089 2.08764 L
.54699 2.08021 L
.55276 2.07192 L
.55818 2.06288 L
.5632 2.05317 L
.56779 2.04292 L
.57192 2.03221 L
.57555 2.02114 L
.57867 2.00978 L
.58125 1.9982 L
.58328 1.98647 L
.58473 1.97463 L
.58561 1.96272 L
.5859 1.95085 L
s
.70739 1.95068 m
.70785 1.9275 L
.70922 1.90381 L
.7115 1.87931 L
.71467 1.85361 L
.71871 1.82633 L
.72359 1.79711 L
.72928 1.76564 L
.73573 1.73161 L
.74291 1.69477 L
.75076 1.65489 L
.75924 1.61181 L
.76828 1.56541 L
.77782 1.51562 L
.7878 1.46243 L
.79815 1.4059 L
.8088 1.34617 L
.81967 1.28343 L
.83069 1.21793 L
.84179 1.15002 L
.85289 1.0801 L
.86391 1.00863 L
.87478 .93614 L
.88543 .86321 L
.89578 .79047 L
.90576 .71858 L
.9153 .64823 L
.92434 .58012 L
.93282 .51498 L
.94067 .45349 L
.94785 .39635 L
.95431 .34421 L
.95999 .29767 L
.96487 .25729 L
.96891 .22355 L
.97208 .19687 L
.97436 .17757 L
.97573 .16589 L
.97619 .16199 L
s
.70739 1.95089 m
.70785 1.97406 L
.70922 1.99775 L
.7115 2.02226 L
.71467 2.04796 L
.71871 2.07524 L
.72359 2.10446 L
.72928 2.13593 L
.73573 2.16996 L
.74291 2.2068 L
.75076 2.24667 L
.75924 2.28975 L
.76828 2.33616 L
.77782 2.38595 L
.7878 2.43914 L
.79815 2.49566 L
.8088 2.55539 L
.81967 2.61814 L
.83069 2.68364 L
.84179 2.75155 L
.85289 2.82147 L
.86391 2.89294 L
.87478 2.96543 L
.88543 3.03835 L
.89578 3.11109 L
.90576 3.18299 L
.9153 3.25334 L
.92434 3.32144 L
.93282 3.38659 L
.94067 3.44807 L
.94785 3.50521 L
.95431 3.55736 L
.95999 3.60389 L
.96487 3.64428 L
.96891 3.67801 L
.97208 3.7047 L
.97436 3.724 L
.97573 3.73567 L
.97619 3.73958 L
s
.02381 .15917 m
.02429 .16322 L
.02571 .1753 L
.02807 .19528 L
.03136 .22289 L
.03555 .25779 L
.04061 .29954 L
.0465 .34763 L
.05319 .40148 L
.06064 .46044 L
.06878 .52384 L
.07757 .59095 L
.08695 .66102 L
.09684 .73332 L
.10719 .8071 L
.11792 .88164 L
.12896 .95624 L
.14023 1.03024 L
.15166 1.10304 L
.16317 1.1741 L
.17468 1.24292 L
.18611 1.30908 L
.19738 1.37225 L
.20842 1.43215 L
.21915 1.48857 L
.2295 1.54139 L
.23939 1.59056 L
.24876 1.63606 L
.25755 1.67799 L
.2657 1.71645 L
.27314 1.75164 L
.27984 1.78377 L
.28573 1.81313 L
.29079 1.84003 L
.29498 1.86481 L
.29826 1.88786 L
.30063 1.90958 L
.30205 1.93041 L
.30253 1.95069 L
s
.02381 3.7424 m
.02429 3.73835 L
.02571 3.72626 L
.02807 3.70629 L
.03136 3.67868 L
.03555 3.64378 L
.04061 3.60203 L
.0465 3.55394 L
.05319 3.50009 L
.06064 3.44112 L
.06878 3.37773 L
.07757 3.31062 L
.08695 3.24054 L
.09684 3.16824 L
.10719 3.09446 L
.11792 3.01993 L
.12896 2.94533 L
.14023 2.87133 L
.15166 2.79852 L
.16317 2.72747 L
.17468 2.65865 L
.18611 2.59248 L
.19738 2.52931 L
.20842 2.46942 L
.21915 2.41299 L
.2295 2.36017 L
.23939 2.31101 L
.24876 2.2655 L
.25755 2.22358 L
.2657 2.18512 L
.27314 2.14993 L
.27984 2.1178 L
.28573 2.08844 L
.29079 2.06154 L
.29498 2.03676 L
.29826 2.01371 L
.30063 1.99199 L
.30205 1.97116 L
.30253 1.95087 L
s
.39325 1.95072 m
.39362 1.93772 L
.39471 1.92463 L
.39652 1.91152 L
.39904 1.89837 L
.40224 1.88523 L
.40612 1.87214 L
.41063 1.85918 L
.41576 1.84645 L
.42146 1.83407 L
.4277 1.8222 L
.43443 1.81098 L
.44161 1.80058 L
.44919 1.79117 L
.45712 1.78289 L
.46534 1.77591 L
.47379 1.77033 L
.48243 1.76627 L
.49118 1.7638 L
.5 1.76297 L
.50882 1.7638 L
.51757 1.76627 L
.52621 1.77033 L
.53466 1.77591 L
.54288 1.78289 L
.55081 1.79117 L
.55839 1.80058 L
.56557 1.81098 L
.5723 1.8222 L
.57854 1.83407 L
.58424 1.84645 L
.58937 1.85918 L
.59388 1.87214 L
.59776 1.88523 L
.60096 1.89837 L
.60348 1.91152 L
.60529 1.92463 L
.60638 1.93772 L
.60675 1.95072 L
s
.39325 1.95085 m
.39362 1.96385 L
.39471 1.97694 L
.39652 1.99005 L
.39904 2.00319 L
.40224 2.01633 L
.40612 2.02942 L
.41063 2.04239 L
.41576 2.05512 L
.42146 2.06749 L
.4277 2.07937 L
.43443 2.09059 L
.44161 2.10098 L
.44919 2.1104 L
.45712 2.11867 L
.46534 2.12566 L
.47379 2.13124 L
.48243 2.1353 L
.49118 2.13777 L
.5 2.1386 L
.50882 2.13777 L
.51757 2.1353 L
.52621 2.13124 L
.53466 2.12566 L
.54288 2.11867 L
.55081 2.1104 L
.55839 2.10098 L
.56557 2.09059 L
.5723 2.07937 L
.57854 2.06749 L
.58424 2.05512 L
.58937 2.04239 L
.59388 2.02942 L
.59776 2.01633 L
.60096 2.00319 L
.60348 1.99005 L
.60529 1.97694 L
.60638 1.96385 L
.60675 1.95085 L
s
.69747 1.95069 m
.69795 1.93041 L
.69937 1.90958 L
.70174 1.88786 L
.70502 1.86481 L
.70921 1.84003 L
.71427 1.81313 L
.72016 1.78377 L
.72686 1.75164 L
.7343 1.71645 L
.74245 1.67799 L
.75124 1.63606 L
.76061 1.59056 L
.7705 1.54139 L
.78085 1.48857 L
.79158 1.43215 L
.80262 1.37225 L
.81389 1.30908 L
.82532 1.24292 L
.83683 1.1741 L
.84834 1.10304 L
.85977 1.03024 L
.87104 .95624 L
.88208 .88164 L
.89281 .8071 L
.90316 .73332 L
.91305 .66102 L
.92243 .59095 L
.93122 .52384 L
.93936 .46044 L
.94681 .40148 L
.9535 .34763 L
.95939 .29954 L
.96445 .25779 L
.96864 .22289 L
.97193 .19528 L
.97429 .1753 L
.97571 .16322 L
.97619 .15917 L
s
.69747 1.95087 m
.69795 1.97116 L
.69937 1.99199 L
.70174 2.01371 L
.70502 2.03676 L
.70921 2.06154 L
.71427 2.08844 L
.72016 2.1178 L
.72686 2.14993 L
.7343 2.18512 L
.74245 2.22358 L
.75124 2.2655 L
.76061 2.31101 L
.7705 2.36017 L
.78085 2.41299 L
.79158 2.46942 L
.80262 2.52931 L
.81389 2.59248 L
.82532 2.65865 L
.83683 2.72747 L
.84834 2.79852 L
.85977 2.87133 L
.87104 2.94533 L
.88208 3.01993 L
.89281 3.09446 L
.90316 3.16824 L
.91305 3.24054 L
.92243 3.31062 L
.93122 3.37773 L
.93936 3.44112 L
.94681 3.50009 L
.9535 3.55394 L
.95939 3.60203 L
.96445 3.64378 L
.96864 3.67868 L
.97193 3.70629 L
.97429 3.72626 L
.97571 3.73835 L
.97619 3.7424 L
s
.02381 .15636 m
.02431 .16062 L
.02581 .17335 L
.02831 .19439 L
.03178 .22345 L
.03619 .26017 L
.04153 .30407 L
.04775 .35459 L
.05481 .41112 L
.06267 .47294 L
.07126 .53933 L
.08054 .60951 L
.09043 .68267 L
.10087 .75802 L
.11179 .83475 L
.12311 .9121 L
.13475 .98931 L
.14665 1.06569 L
.15871 1.14059 L
.17085 1.21342 L
.18299 1.28368 L
.19505 1.35093 L
.20695 1.4148 L
.2186 1.475 L
.22992 1.53132 L
.24084 1.58364 L
.25128 1.63189 L
.26117 1.67607 L
.27044 1.71626 L
.27903 1.75257 L
.28689 1.7852 L
.29395 1.81436 L
.30017 1.84033 L
.30551 1.86345 L
.30993 1.88408 L
.31339 1.90265 L
.31589 1.91961 L
.31739 1.93547 L
.31789 1.95072 L
s
.02381 3.74521 m
.02431 3.74094 L
.02581 3.72821 L
.02831 3.70718 L
.03178 3.67811 L
.03619 3.6414 L
.04153 3.5975 L
.04775 3.54697 L
.05481 3.49045 L
.06267 3.42862 L
.07126 3.36223 L
.08054 3.29206 L
.09043 3.21889 L
.10087 3.14355 L
.11179 3.06681 L
.12311 2.98947 L
.13475 2.91226 L
.14665 2.83588 L
.15871 2.76098 L
.17085 2.68814 L
.18299 2.61788 L
.19505 2.55064 L
.20695 2.48677 L
.2186 2.42657 L
.22992 2.37024 L
.24084 2.31792 L
.25128 2.26968 L
.26117 2.22549 L
.27044 2.18531 L
.27903 2.14899 L
.28689 2.11637 L
.29395 2.08721 L
.30017 2.06123 L
.30551 2.03811 L
.30993 2.01748 L
.31339 1.99892 L
.31589 1.98196 L
.31739 1.96609 L
.31789 1.95085 L
s
.36875 1.95073 m
.36919 1.93855 L
.37054 1.92613 L
.37276 1.91338 L
.37586 1.90019 L
.3798 1.88652 L
.38456 1.87239 L
.39012 1.8579 L
.39642 1.8432 L
.40343 1.8285 L
.4111 1.81404 L
.41938 1.80009 L
.42821 1.78694 L
.43753 1.77486 L
.44728 1.76411 L
.45738 1.75496 L
.46778 1.7476 L
.4784 1.74221 L
.48916 1.73893 L
.5 1.73782 L
.51084 1.73893 L
.5216 1.74221 L
.53222 1.7476 L
.54262 1.75496 L
.55272 1.76411 L
.56247 1.77486 L
.57179 1.78694 L
.58062 1.80009 L
.5889 1.81404 L
.59657 1.8285 L
.60358 1.8432 L
.60988 1.8579 L
.61544 1.87239 L
.6202 1.88652 L
.62414 1.90019 L
.62724 1.91338 L
.62946 1.92613 L
.63081 1.93855 L
.63125 1.95073 L
s
.36875 1.95084 m
.36919 1.96302 L
.37054 1.97543 L
.37276 1.98818 L
.37586 2.00137 L
.3798 2.01505 L
.38456 2.02918 L
.39012 2.04367 L
.39642 2.05837 L
.40343 2.07307 L
.4111 2.08753 L
.41938 2.10147 L
.42821 2.11463 L
.43753 2.12671 L
.44728 2.13745 L
.45738 2.14661 L
.46778 2.15397 L
.4784 2.15935 L
.48916 2.16264 L
.5 2.16374 L
.51084 2.16264 L
.5216 2.15935 L
.53222 2.15397 L
.54262 2.14661 L
.55272 2.13745 L
.56247 2.12671 L
.57179 2.11463 L
.58062 2.10147 L
.5889 2.08753 L
.59657 2.07307 L
.60358 2.05837 L
.60988 2.04367 L
.61544 2.02918 L
.6202 2.01505 L
.62414 2.00137 L
.62724 1.98818 L
.62946 1.97543 L
.63081 1.96302 L
.63125 1.95084 L
s
.68211 1.95072 m
.68261 1.93547 L
.68411 1.91961 L
.68661 1.90265 L
.69007 1.88408 L
.69449 1.86345 L
.69983 1.84033 L
.70605 1.81436 L
.71311 1.7852 L
.72097 1.75257 L
.72956 1.71626 L
.73883 1.67607 L
.74872 1.63189 L
.75916 1.58364 L
.77008 1.53132 L
.7814 1.475 L
.79305 1.4148 L
.80495 1.35093 L
.81701 1.28368 L
.82915 1.21342 L
.84129 1.14059 L
.85335 1.06569 L
.86525 .98931 L
.87689 .9121 L
.88821 .83475 L
.89913 .75802 L
.90957 .68267 L
.91946 .60951 L
.92874 .53933 L
.93733 .47294 L
.94519 .41112 L
.95225 .35459 L
.95847 .30407 L
.96381 .26017 L
.96822 .22345 L
.97169 .19439 L
.97419 .17335 L
.97569 .16062 L
.97619 .15636 L
s
.68211 1.95085 m
.68261 1.96609 L
.68411 1.98196 L
.68661 1.99892 L
.69007 2.01748 L
.69449 2.03811 L
.69983 2.06123 L
.70605 2.08721 L
.71311 2.11637 L
.72097 2.14899 L
.72956 2.18531 L
.73883 2.22549 L
.74872 2.26968 L
.75916 2.31792 L
.77008 2.37024 L
.7814 2.42657 L
.79305 2.48677 L
.80495 2.55064 L
.81701 2.61788 L
.82915 2.68814 L
.84129 2.76098 L
.85335 2.83588 L
.86525 2.91226 L
.87689 2.98947 L
.88821 3.06681 L
.89913 3.14355 L
.90957 3.21889 L
.91946 3.29206 L
.92874 3.36223 L
.93733 3.42862 L
.94519 3.49045 L
.95225 3.54697 L
.95847 3.5975 L
.96381 3.6414 L
.96822 3.67811 L
.97169 3.70718 L
.97419 3.72821 L
.97569 3.74094 L
.97619 3.74521 L
s
1 0 0 r
.03 w
.02381 .15496 m
.02435 .15955 L
.02597 .17328 L
.02867 .19596 L
.03241 .22727 L
.03718 .26681 L
.04294 .31403 L
.04966 .36832 L
.05728 .42898 L
.06576 .49522 L
.07503 .56624 L
.08505 .64115 L
.09572 .71908 L
.10699 .79914 L
.11878 .88044 L
.131 .96213 L
.14357 1.0434 L
.15641 1.12348 L
.16943 1.20167 L
.18254 1.27735 L
.19565 1.34997 L
.20867 1.41906 L
.22151 1.48425 L
.23408 1.54523 L
.2463 1.60181 L
.25809 1.65386 L
.26936 1.70131 L
.28003 1.74417 L
.29004 1.78252 L
.29932 1.81646 L
.3078 1.84614 L
.31542 1.87173 L
.32214 1.89341 L
.3279 1.91138 L
.33267 1.9258 L
.33641 1.93684 L
.3391 1.94462 L
.34073 1.94925 L
.34127 1.95078 L
s
.02381 3.74661 m
.02435 3.74201 L
.02597 3.72828 L
.02867 3.70561 L
.03241 3.67429 L
.03718 3.63476 L
.04294 3.58754 L
.04966 3.53325 L
.05728 3.47259 L
.06576 3.40634 L
.07503 3.33533 L
.08505 3.26041 L
.09572 3.18248 L
.10699 3.10243 L
.11878 3.02113 L
.131 2.93944 L
.14357 2.85817 L
.15641 2.77809 L
.16943 2.6999 L
.18254 2.62422 L
.19565 2.5516 L
.20867 2.48251 L
.22151 2.41732 L
.23408 2.35633 L
.2463 2.29975 L
.25809 2.24771 L
.26936 2.20026 L
.28003 2.15739 L
.29004 2.11905 L
.29932 2.08511 L
.3078 2.05543 L
.31542 2.02984 L
.32214 2.00816 L
.3279 1.99019 L
.33267 1.97577 L
.33641 1.96473 L
.3391 1.95695 L
.34073 1.95232 L
.34127 1.95078 L
s
.34127 1.95078 m
.34181 1.94925 L
.34343 1.9447 L
.34613 1.93726 L
.34987 1.92712 L
.35464 1.91456 L
.3604 1.89993 L
.36712 1.88363 L
.37474 1.8661 L
.38322 1.84781 L
.39249 1.82928 L
.40251 1.81099 L
.41318 1.79346 L
.42445 1.77716 L
.43624 1.76253 L
.44846 1.74997 L
.46103 1.73983 L
.47387 1.73239 L
.48689 1.72784 L
.5 1.7263 L
.51311 1.72784 L
.52613 1.73239 L
.53897 1.73983 L
.55154 1.74997 L
.56376 1.76253 L
.57555 1.77716 L
.58682 1.79346 L
.59749 1.81099 L
.60751 1.82928 L
.61678 1.84781 L
.62526 1.8661 L
.63288 1.88363 L
.6396 1.89993 L
.64536 1.91456 L
.65013 1.92712 L
.65387 1.93726 L
.65657 1.9447 L
.65819 1.94925 L
.65873 1.95078 L
s
.34127 1.95078 m
.34181 1.95231 L
.34343 1.95686 L
.34613 1.96431 L
.34987 1.97445 L
.35464 1.987 L
.3604 2.00163 L
.36712 2.01794 L
.37474 2.03547 L
.38322 2.05375 L
.39249 2.07229 L
.40251 2.09058 L
.41318 2.10811 L
.42445 2.12441 L
.43624 2.13904 L
.44846 2.15159 L
.46103 2.16173 L
.47387 2.16918 L
.48689 2.17373 L
.5 2.17526 L
.51311 2.17373 L
.52613 2.16918 L
.53897 2.16173 L
.55154 2.15159 L
.56376 2.13904 L
.57555 2.12441 L
.58682 2.10811 L
.59749 2.09058 L
.60751 2.07229 L
.61678 2.05375 L
.62526 2.03547 L
.63288 2.01794 L
.6396 2.00163 L
.64536 1.987 L
.65013 1.97445 L
.65387 1.96431 L
.65657 1.95686 L
.65819 1.95231 L
.65873 1.95078 L
s
.65873 1.95078 m
.65927 1.94925 L
.6609 1.94462 L
.66359 1.93684 L
.66733 1.9258 L
.6721 1.91138 L
.67786 1.89341 L
.68458 1.87173 L
.6922 1.84614 L
.70068 1.81646 L
.70996 1.78252 L
.71997 1.74417 L
.73064 1.70131 L
.74191 1.65386 L
.7537 1.60181 L
.76592 1.54523 L
.77849 1.48425 L
.79133 1.41906 L
.80435 1.34997 L
.81746 1.27735 L
.83057 1.20167 L
.84359 1.12348 L
.85643 1.0434 L
.869 .96213 L
.88122 .88044 L
.89301 .79914 L
.90428 .71908 L
.91495 .64115 L
.92497 .56624 L
.93424 .49522 L
.94272 .42898 L
.95034 .36832 L
.95706 .31403 L
.96282 .26681 L
.96759 .22727 L
.97133 .19596 L
.97403 .17328 L
.97565 .15955 L
.97619 .15496 L
s
.65873 1.95078 m
.65927 1.95232 L
.6609 1.95695 L
.66359 1.96473 L
.66733 1.97577 L
.6721 1.99019 L
.67786 2.00816 L
.68458 2.02984 L
.6922 2.05543 L
.70068 2.08511 L
.70996 2.11905 L
.71997 2.15739 L
.73064 2.20026 L
.74191 2.24771 L
.7537 2.29975 L
.76592 2.35633 L
.77849 2.41732 L
.79133 2.48251 L
.80435 2.5516 L
.81746 2.62422 L
.83057 2.6999 L
.84359 2.77809 L
.85643 2.85817 L
.869 2.93944 L
.88122 3.02113 L
.89301 3.10243 L
.90428 3.18248 L
.91495 3.26041 L
.92497 3.33533 L
.93424 3.40634 L
.94272 3.47259 L
.95034 3.53325 L
.95706 3.58754 L
.96282 3.63476 L
.96759 3.67429 L
.97133 3.70561 L
.97403 3.72828 L
.97565 3.74201 L
.97619 3.74661 L
s
0 0 1 r
.5 Mabswid
.02381 .14796 m
.02544 .16168 L
.0303 .20247 L
.03838 .2692 L
.04961 .36002 L
.06392 .47241 L
.0812 .60323 L
.10135 .74881 L
.12422 .90501 L
.14966 1.06732 L
.17748 1.23081 L
.20752 1.39015 L
.23955 1.53906 L
.27336 1.66871 L
.30872 1.76237 L
.34538 1.79164 L
.3831 1.76171 L
.42162 1.71839 L
.46068 1.68698 L
.5 1.67585 L
.53932 1.68698 L
.57838 1.71839 L
.6169 1.76171 L
.65462 1.79164 L
.69128 1.76237 L
.72664 1.66871 L
.76045 1.53906 L
.79248 1.39015 L
.82252 1.23081 L
.85034 1.06732 L
.87578 .90501 L
.89865 .74881 L
.9188 .60323 L
.93608 .47241 L
.95039 .36002 L
.96162 .2692 L
.9697 .20247 L
.97456 .16168 L
.97619 .14796 L
s
.02381 3.75361 m
.02544 3.73989 L
.0303 3.6991 L
.03838 3.63237 L
.04961 3.54155 L
.06392 3.42916 L
.0812 3.29834 L
.10135 3.15276 L
.12422 2.99655 L
.14966 2.83425 L
.17748 2.67076 L
.20752 2.51142 L
.23955 2.36251 L
.27336 2.23286 L
.30872 2.1392 L
.34538 2.10993 L
.3831 2.13986 L
.42162 2.18318 L
.46068 2.21458 L
.5 2.22571 L
.53932 2.21458 L
.57838 2.18318 L
.6169 2.13986 L
.65462 2.10993 L
.69128 2.1392 L
.72664 2.23286 L
.76045 2.36251 L
.79248 2.51142 L
.82252 2.67076 L
.85034 2.83425 L
.87578 2.99655 L
.89865 3.15276 L
.9188 3.29834 L
.93608 3.42916 L
.95039 3.54155 L
.96162 3.63237 L
.9697 3.6991 L
.97456 3.73989 L
.97619 3.75361 L
s
.02381 .13403 m
.02544 .14765 L
.0303 .18812 L
.03838 .25428 L
.04961 .34426 L
.06392 .45546 L
.0812 .58466 L
.10135 .72803 L
.12422 .88119 L
.14966 1.03924 L
.17748 1.19663 L
.20752 1.34688 L
.23955 1.48184 L
.27336 1.59029 L
.30872 1.65771 L
.34538 1.67562 L
.3831 1.65729 L
.42162 1.62767 L
.46068 1.6044 L
.5 1.59585 L
.53932 1.6044 L
.57838 1.62767 L
.6169 1.65729 L
.65462 1.67562 L
.69128 1.65771 L
.72664 1.59029 L
.76045 1.48184 L
.79248 1.34688 L
.82252 1.19663 L
.85034 1.03924 L
.87578 .88119 L
.89865 .72803 L
.9188 .58466 L
.93608 .45546 L
.95039 .34426 L
.96162 .25428 L
.9697 .18812 L
.97456 .14765 L
.97619 .13403 L
s
.02381 3.76753 m
.02544 3.75392 L
.0303 3.71345 L
.03838 3.64729 L
.04961 3.55731 L
.06392 3.44611 L
.0812 3.31691 L
.10135 3.17354 L
.12422 3.02037 L
.14966 2.86232 L
.17748 2.70494 L
.20752 2.55469 L
.23955 2.41973 L
.27336 2.31128 L
.30872 2.24386 L
.34538 2.22595 L
.3831 2.24428 L
.42162 2.27389 L
.46068 2.29717 L
.5 2.30571 L
.53932 2.29717 L
.57838 2.27389 L
.6169 2.24428 L
.65462 2.22595 L
.69128 2.24386 L
.72664 2.31128 L
.76045 2.41973 L
.79248 2.55469 L
.82252 2.70494 L
.85034 2.86232 L
.87578 3.02037 L
.89865 3.17354 L
.9188 3.31691 L
.93608 3.44611 L
.95039 3.55731 L
.96162 3.64729 L
.9697 3.71345 L
.97456 3.75392 L
.97619 3.76753 L
s
.02381 .12022 m
.02544 .13373 L
.0303 .17388 L
.03838 .23949 L
.04961 .32865 L
.06392 .4387 L
.0812 .56634 L
.10135 .70759 L
.12422 .85789 L
.14966 1.01201 L
.17748 1.16393 L
.20752 1.30651 L
.23955 1.43088 L
.27336 1.52611 L
.30872 1.58162 L
.34538 1.59567 L
.3831 1.58128 L
.42162 1.55735 L
.46068 1.53802 L
.5 1.53082 L
.53932 1.53802 L
.57838 1.55735 L
.6169 1.58128 L
.65462 1.59567 L
.69128 1.58162 L
.72664 1.52611 L
.76045 1.43088 L
.79248 1.30651 L
.82252 1.16393 L
.85034 1.01201 L
.87578 .85789 L
.89865 .70759 L
.9188 .56634 L
.93608 .4387 L
.95039 .32865 L
.96162 .23949 L
.9697 .17388 L
.97456 .13373 L
.97619 .12022 L
s
.02381 3.78135 m
.02544 3.76783 L
.0303 3.72769 L
.03838 3.66207 L
.04961 3.57292 L
.06392 3.46286 L
.0812 3.33523 L
.10135 3.19397 L
.12422 3.04368 L
.14966 2.88956 L
.17748 2.73764 L
.20752 2.59506 L
.23955 2.47069 L
.27336 2.37545 L
.30872 2.31995 L
.34538 2.3059 L
.3831 2.32028 L
.42162 2.34422 L
.46068 2.36354 L
.5 2.37074 L
.53932 2.36354 L
.57838 2.34422 L
.6169 2.32028 L
.65462 2.3059 L
.69128 2.31995 L
.72664 2.37545 L
.76045 2.47069 L
.79248 2.59506 L
.82252 2.73764 L
.85034 2.88956 L
.87578 3.04368 L
.89865 3.19397 L
.9188 3.33523 L
.93608 3.46286 L
.95039 3.57292 L
.96162 3.66207 L
.9697 3.72769 L
.97456 3.76783 L
.97619 3.78135 L
s
.02381 .10651 m
.02544 .11992 L
.0303 .15976 L
.03838 .22483 L
.04961 .31319 L
.06392 .42213 L
.0812 .54826 L
.10135 .68749 L
.12422 .83508 L
.14966 .98554 L
.17748 1.13253 L
.20752 1.26852 L
.23955 1.38449 L
.27336 1.47043 L
.30872 1.51873 L
.34538 1.53067 L
.3831 1.51844 L
.42162 1.49781 L
.46068 1.48093 L
.5 1.47459 L
.53932 1.48093 L
.57838 1.49781 L
.6169 1.51844 L
.65462 1.53067 L
.69128 1.51873 L
.72664 1.47043 L
.76045 1.38449 L
.79248 1.26852 L
.82252 1.13253 L
.85034 .98554 L
.87578 .83508 L
.89865 .68749 L
.9188 .54826 L
.93608 .42213 L
.95039 .31319 L
.96162 .22483 L
.9697 .15976 L
.97456 .11992 L
.97619 .10651 L
s
.02381 3.79506 m
.02544 3.78165 L
.0303 3.74181 L
.03838 3.67673 L
.04961 3.58837 L
.06392 3.47943 L
.0812 3.35331 L
.10135 3.21408 L
.12422 3.06649 L
.14966 2.91602 L
.17748 2.76903 L
.20752 2.63305 L
.23955 2.51708 L
.27336 2.43113 L
.30872 2.38284 L
.34538 2.3709 L
.3831 2.38313 L
.42162 2.40375 L
.46068 2.42064 L
.5 2.42697 L
.53932 2.42064 L
.57838 2.40375 L
.6169 2.38313 L
.65462 2.3709 L
.69128 2.38284 L
.72664 2.43113 L
.76045 2.51708 L
.79248 2.63305 L
.82252 2.76903 L
.85034 2.91602 L
.87578 3.06649 L
.89865 3.21408 L
.9188 3.35331 L
.93608 3.47943 L
.95039 3.58837 L
.96162 3.67673 L
.9697 3.74181 L
.97456 3.78165 L
.97619 3.79506 L
s
.02381 .09289 m
.02544 .10621 L
.0303 .14574 L
.03838 .2103 L
.04961 .29788 L
.06392 .40574 L
.0812 .53041 L
.10135 .6677 L
.12422 .81272 L
.14966 .95978 L
.17748 1.1023 L
.20752 1.23254 L
.23955 1.34162 L
.27336 1.42057 L
.30872 1.46389 L
.34538 1.47445 L
.3831 1.46364 L
.42162 1.44524 L
.46068 1.43006 L
.5 1.42433 L
.53932 1.43006 L
.57838 1.44524 L
.6169 1.46364 L
.65462 1.47445 L
.69128 1.46389 L
.72664 1.42057 L
.76045 1.34162 L
.79248 1.23254 L
.82252 1.1023 L
.85034 .95978 L
.87578 .81272 L
.89865 .6677 L
.9188 .53041 L
.93608 .40574 L
.95039 .29788 L
.96162 .2103 L
.9697 .14574 L
.97456 .10621 L
.97619 .09289 L
s
.02381 3.80867 m
.02544 3.79536 L
.0303 3.75582 L
.03838 3.69127 L
.04961 3.60369 L
.06392 3.49583 L
.0812 3.37116 L
.10135 3.23387 L
.12422 3.08885 L
.14966 2.94178 L
.17748 2.79927 L
.20752 2.66903 L
.23955 2.55995 L
.27336 2.481 L
.30872 2.43767 L
.34538 2.42711 L
.3831 2.43793 L
.42162 2.45632 L
.46068 2.47151 L
.5 2.47723 L
.53932 2.47151 L
.57838 2.45632 L
.6169 2.43793 L
.65462 2.42711 L
.69128 2.43767 L
.72664 2.481 L
.76045 2.55995 L
.79248 2.66903 L
.82252 2.79927 L
.85034 2.94178 L
.87578 3.08885 L
.89865 3.23387 L
.9188 3.37116 L
.93608 3.49583 L
.95039 3.60369 L
.96162 3.69127 L
.9697 3.75582 L
.97456 3.79536 L
.97619 3.80867 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}},
  ImageSize->{57.125, 223.125},
  ImageMargins->{{66.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001b0001_R000`400?l00000o`00003oLP3oool0
0780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3o
ool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00
LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?oo
o`00LP3oool003/0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool0=03o
ool003/0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool0=03oool003/0
oooo0P00000e0?ooo`00>`3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?oo
o`0d0?ooo`00>`3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0d0?oo
o`00303oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0103oool000`0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo00@0oooo000<0?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`040?ooo`00303oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0
oooo02`0oooo0P000?l60?ooo`00303oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo
02`0oooo0P000?l60?ooo`002`3oool00`3o0000003o0?l0000]0?ooo`030000003oool0oooo02`0
oooo0P000?l00`3o0000oooo0?ooo`030?ooo`002`3oool00`3o0000003o0?l0000]0?ooo`030000
003oool0oooo02`0oooo0P000?l00`3o0000oooo0?ooo`030?ooo`002`3oool00`3o0000003o0?l0
000]0?ooo`030000003oool0oooo02`0oooo0P000?l00`3o0000oooo0?ooo`030?ooo`002`3oool0
0`3o0000003o0?l0000]0?ooo`030000003oool0oooo02`0oooo0P000?l00`3o0000oooo0?ooo`03
0?ooo`002`3oool00`3o0000003o0000o`0]0?ooo`030000003oool0oooo02/0oooo0P000?l20?l0
00D0oooo000;0?ooo`030?l000000?l0003o02d0oooo00<000000?ooo`3oool0:`3oool20000o`03
0?l0003oool0oooo00@0oooo000;0?ooo`030?l000000?l0003o02d0oooo0P00000/0?ooo`80003o
00<0o`000?ooo`3oool0103oool000/0oooo00<0o`000000o`000?l0;@3oool00`000000oooo0?oo
o`0[0?ooo`80003o00<0o`000?ooo`3oool0103oool000/0oooo00<0o`000000o`000?l0;@3oool0
0`000000oooo0?ooo`0[0?ooo`80003o00<0o`000?ooo`3oool0103oool000/0oooo00<0o`000000
o`000?l0;@3oool00`000000oooo0?ooo`0[0?ooo`80003o00<0o`000?ooo`3oool0103oool000/0
oooo0P3o00000`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00@0o`000000o`3o
0000o`001P3oool000/0oooo0P3o00000`000?l0o`000?ooo`0[0?ooo`030000003oool0oooo02X0
oooo00<0o`000000o`3o00001`3oool000`0oooo00<0o`000000o`000?l0;03oool00`000000oooo
0?ooo`0Z0?ooo`80003o00<0o`000?ooo`3oool01@3oool000`0oooo00<0o`000000o`000?l0;03o
ool00`000000oooo0?ooo`0Z0?ooo`80003o00<0o`000?ooo`3oool01@3oool000`0oooo00<0o`00
0000o`000?l0;03oool00`000000oooo0?ooo`0Z0?ooo`80003o00<0o`000?ooo`3oool01@3oool0
00`0oooo00<0o`000000o`000?l0;03oool00`000000oooo0?ooo`0Z0?ooo`80003o00<0o`000?oo
o`3oool01@3oool000`0oooo00<0o`000000o`000?l0;03oool00`000000oooo0?ooo`0Z0?ooo`80
003o00<0o`000?ooo`3oool01@3oool000`0oooo00<0o`000000o`000?l05P3oool7000000H0oooo
100000050?ooo`030000003oool0oooo02X0oooo0P000?l00`3o0000oooo0?ooo`050?ooo`00303o
ool20?l000030000o`3oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool00`000?l0o`000?l0
00070?ooo`00303oool20?l00080003o603oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3o0000
o`0000L0oooo000<0?ooo`80o`000P000?lH0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo00<0o`000000o`3o0000203oool0
00d0oooo00<0o`000000o`000?l0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`80003o00<0o`000?ooo`3oool01P3oool0
00d0oooo00<0o`000000o`000?l0203oool8000000P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000:P3oool20000o`030?l0003oool0
oooo00H0oooo000=0?ooo`030?l000000?l0003o01P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000:`3oool20000o`030?l0003oool0
oooo00H0oooo000=0?ooo`040?l000000?l0003o0000oaL0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000:`3oool20000o`030?l0003o
ool0oooo00H0oooo000=0?ooo`80o`000P000?lG0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo0P000?l00`3o0000oooo0?oo
o`060?ooo`003@3oool20?l00080003o5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000Z0?ooo`030?l000000?l0003o00T0oooo000>
0?ooo`030?l000000?l0003o01L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`3o0000003o0000o`09
0?ooo`003P3oool00`3o0000003o0000o`0C0?ooo`<0000000<0oooo0000003oool01`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`3o
0000003o0?l000090?ooo`003P3oool00`3o0000003o0000o`0F0?ooo`8000002@3oool4000000D0
oooo00<000000?ooo`3oool0:03oool00`3o0000003o0?l000090?ooo`003P3oool00`3o0000003o
0000o`0Z0?ooo`030000003oool0oooo02P0oooo0P000?l00`3o0000oooo0?ooo`070?ooo`003P3o
ool20?l000030000o`3oool0oooo02P0oooo00<000000?ooo`3oool0:03oool20000o`030?l0003o
ool0oooo00L0oooo000>0?ooo`80o`0000<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0X
0?ooo`80003o00<0o`000?ooo`3oool01`3oool000l0oooo00<0o`000000o`000?l0:@3oool00`00
0000oooo0?ooo`0X0?ooo`80003o00<0o`000?ooo`3oool01`3oool000l0oooo00<0o`000000o`00
0?l0:@3oool00`000000oooo0?ooo`0X0?ooo`80003o00<0o`000?ooo`3oool01`3oool000l0oooo
00<0o`000000o`000?l0:@3oool00`000000oooo0?ooo`0X0?ooo`80003o00<0o`000?ooo`3oool0
1`3oool000l0oooo00<0o`000000o`000?l0:@3oool00`000000oooo0?ooo`0W0?ooo`<0003o00<0
o`000?ooo`3oool01`3oool000l0oooo00<0o`000000o`000?l0:@3oool00`000000oooo0?ooo`0W
0?ooo`80003o0P3o00090?ooo`003`3oool00`3o0000003o0000o`0Y0?ooo`800000:03oool20000
o`80o`002@3oool00100oooo0P000?l00`3o0000oooo0?ooo`0V0?ooo`030000003oool0oooo02L0
oooo0P000?l00`3o0000oooo0?ooo`080?ooo`00403oool00`3o0000003o0?l0000X0?ooo`030000
003oool0oooo02L0oooo0P000?l00`3o0000oooo0?ooo`080?ooo`00403oool00`3o0000003o0?l0
000X0?ooo`030000003oool0oooo02L0oooo0P000?l00`3o0000oooo0?ooo`080?ooo`00403oool0
0`3o0000003o0?l0000X0?ooo`030000003oool0oooo02L0oooo0P000?l00`3o0000oooo0?ooo`08
0?ooo`00403oool00`3o0000003o0000o`0X0?ooo`030000003oool0oooo02H0oooo0P000?l20?l0
00X0oooo000@0?ooo`030?l000000?l0003o02P0oooo00<000000?ooo`3oool09P3oool20000o`80
o`002P3oool00100oooo00<0o`000000o`000?l0:03oool00`000000oooo0?ooo`0V0?ooo`80003o
0P3o000:0?ooo`00403oool00`3o0000003o0000o`0X0?ooo`030000003oool0oooo02H0oooo0P00
0?l00`3o0000oooo0?ooo`090?ooo`004@3oool20000o`030?l0003oool0oooo02D0oooo00<00000
0?ooo`3oool09P3oool20000o`030?l0003oool0oooo00T0oooo000A0?ooo`80003o00<0o`000?oo
o`3oool09@3oool00`000000oooo0?ooo`0V0?ooo`80003o00<0o`000?ooo`3oool02@3oool00140
oooo0P000?l00`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo0P000?l00`3o0000
oooo0?ooo`090?ooo`004@3oool00`3o0000003o0000o`0W0?ooo`030000003oool0oooo02D0oooo
0P000?l20?l000/0oooo000A0?ooo`030?l000000?l0003o02L0oooo00<000000?ooo`3oool09@3o
ool20000o`80o`002`3oool00140oooo00<0o`000000o`000?l09`3oool00`000000oooo0?ooo`0U
0?ooo`80003o0P3o000;0?ooo`004@3oool00`3o0000003o0000o`0W0?ooo`030000003oool0oooo
02D0oooo0P000?l20?l000/0oooo000A0?ooo`030?l000000?l0003o02L0oooo0P00000V0?ooo`80
003o00<0o`000?ooo`3oool02P3oool00180oooo0P000?l00`3o0000oooo0?ooo`0T0?ooo`030000
003oool0oooo02D0oooo0P000?l00`3o0000oooo0?ooo`0:0?ooo`004P3oool30000obH0oooo00<0
00000?ooo`3oool09@3oool20000o`030?l0003oool0oooo00X0oooo000B0?ooo`<0003o9P3oool0
0`000000oooo0?ooo`0T0?ooo`<0003o00<0o`000?ooo`3oool02P3oool00180oooo00<0o`000000
o`000?l09P3oool00`000000oooo0?ooo`0T0?ooo`80003o0P3o000<0?ooo`004P3oool00`3o0000
003o0000o`0V0?ooo`030000003oool0oooo02@0oooo0P000?l20?l000`0oooo000B0?ooo`030?l0
00000?l0003o02H0oooo00<000000?ooo`3oool0903oool20000o`80o`00303oool00180oooo00@0
o`000000o`000?l0003o9@3oool00`000000oooo0?ooo`0T0?ooo`80003o00<0o`000?ooo`3oool0
2`3oool00180oooo00@0o`000000o`000?l0003o9@3oool00`000000oooo0?ooo`0T0?ooo`80003o
00<0o`000?ooo`3oool02`3oool001<0oooo0`000?lU0?ooo`030000003oool0oooo02@0oooo0P00
0?l00`3o0000oooo0?ooo`0;0?ooo`004`3oool00`3o0000003o0000o`0U0?ooo`030000003oool0
oooo02<0oooo0`000?l00`3o0000oooo0?ooo`0;0?ooo`004`3oool0103o0000003o0000o`000?lT
0?ooo`030000003oool0oooo02<0oooo0P000?l00`3o0000oooo0?ooo`0<0?ooo`004`3oool0103o
0000003o0000o`000?lT0?ooo`030000003oool0oooo02<0oooo0P000?l00`3o0000oooo0?ooo`0<
0?ooo`004`3oool0103o0000003o0000o`000?lT0?ooo`030000003oool0oooo02<0oooo0P000?l0
0`3o0000oooo0?ooo`0<0?ooo`004`3oool0103o0000003o0000o`000?lT0?ooo`030000003oool0
oooo02<0oooo0P000?l00`3o0000oooo0?ooo`0<0?ooo`004`3oool20?l00080003o903oool00`00
0000oooo0?ooo`0S0?ooo`80003o00<0o`000?ooo`3oool0303oool001<0oooo0P3o00020000ob@0
oooo0P00000S0?ooo`<0003o3`3oool001@0oooo00@0o`000000o`000?l0003o8`3oool00`000000
oooo0?ooo`0R0?ooo`<0003o3`3oool001@0oooo00@0o`000000o`000?l0003o8`3oool00`000000
oooo0?ooo`0R0?ooo`<0003o3`3oool001@0oooo00@0o`000000o`000?l0003o8`3oool00`000000
oooo0?ooo`0R0?ooo`80003o00<0o`000?ooo`3oool03@3oool001@0oooo0P3o00020000ob<0oooo
00<000000?ooo`3oool08P3oool20000o`030?l0003oool0oooo00d0oooo000D0?ooo`80o`000P00
0?lS0?ooo`030000003oool0oooo0240oooo0`000?l00`3o0000oooo0?ooo`0=0?ooo`00503oool2
0?l00080003o8`3oool00`000000oooo0?ooo`0Q0?ooo`<0003o00<0o`000?ooo`3oool03@3oool0
01@0oooo0P3o00020000ob<0oooo00<000000?ooo`3oool08@3oool30000o`030?l0003oool0oooo
00d0oooo000D0?ooo`80o`000P000?lS0?ooo`030000003oool0oooo0240oooo0`000?l@0?ooo`00
5@3oool0103o0000003o0000o`000?lR0?ooo`030000003oool0oooo0240oooo0P000?l00`3o0000
oooo0?ooo`0>0?ooo`005@3oool0103o0000003o0000o`000?lR0?ooo`030000003oool0oooo0200
oooo0`000?l00`3o0000oooo0?ooo`0>0?ooo`005@3oool20?l00080003o8P3oool00`000000oooo
0?ooo`0P0?ooo`<0003o00<0o`000?ooo`3oool03P3oool001D0oooo0P3o00020000ob80oooo00<0
00000?ooo`3oool0803oool30000o`030?l0003oool0oooo00h0oooo000E0?ooo`80o`000P000?lR
0?ooo`030000003oool0oooo0200oooo0`000?l00`3o0000oooo0?ooo`0>0?ooo`005@3oool20?l0
0080003o8P3oool00`000000oooo0?ooo`0P0?ooo`<0003o00<0o`000?ooo`3oool03P3oool001D0
oooo0P3o00030000ob40oooo00<000000?ooo`3oool07`3oool30000o`80o`00403oool001D0oooo
0P3o00030000ob40oooo0P00000P0?ooo`<0003o00<0o`000?ooo`3oool03`3oool001H0oooo00@0
o`000000o`000?l0003o8@3oool00`000000oooo0?ooo`0O0?ooo`<0003o00<0o`000?ooo`3oool0
3`3oool001H0oooo00@0o`000000o`000?l0003o8@3oool00`000000oooo0?ooo`0O0?ooo`<0003o
00<0o`000?ooo`3oool03`3oool001H0oooo0P3o00020000ob40oooo00<000000?ooo`3oool07P3o
ool40000o`030?l0003oool0oooo00l0oooo000F0?ooo`80o`000`000?lP0?ooo`030000003oool0
oooo01h0oooo10000?l00`3o0000oooo0?ooo`0?0?ooo`005P3oool20?l000<0003o803oool00`00
0000oooo0?ooo`0N0?ooo`<0003o0P3o000A0?ooo`005P3oool20?l000<0003o803oool00`000000
oooo0?ooo`0N0?ooo`<0003o0P3o000A0?ooo`005`3oool0103o0000003o0000o`000?lP0?ooo`03
0000003oool0oooo01h0oooo0`000?l00`3o0000oooo0?ooo`0@0?ooo`005`3oool00`3o0000003o
0000o`020000oal0oooo00<000000?ooo`3oool07@3oool40000o`030?l0003oool0oooo0100oooo
000G0?ooo`030?l000000?l0003o0080003o7`3oool00`000000oooo0?ooo`0M0?ooo`@0003o00<0
o`000?ooo`3oool0403oool001L0oooo0P3o00030000oaH0oooo100000050?ooo`030000003oool0
oooo01d0oooo0`000?l20?l00180oooo000H0?ooo`040?l000000?l0003o0000oaD0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo0`000?l0
0`3o0000oooo0?ooo`0A0?ooo`00603oool0103o0000003o0000o`000?lD0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`<0003o00<0o`000?ooo`3oool04@3o
ool001P0oooo00<0o`000000o`000?l00P000?lJ0?ooo`050000003oool0oooo0?ooo`0000007P3o
ool40000o`030?l0003oool0oooo0140oooo000H0?ooo`030?l000000?l0003o0080003o6P3oool0
1@000000oooo0?ooo`3oool0000001h0oooo10000?l00`3o0000oooo0?ooo`0A0?ooo`00603oool0
0`3o0000003o0000o`020000o`L0oooo2000000;0?ooo`040000003oool0oooo0?ooo`8000007@3o
ool30000o`80o`004`3oool001P0oooo0P3o00030000oa@0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool30000o`030?l00000o`00oooo0180oooo000I0?oo
o`030?l000000?l0003o0080003o4`3oool00`000000oooo00000002000000D0oooo00<000000?oo
o`3oool06`3oool40000o`030?l0003oool0oooo0180oooo000I0?ooo`030?l000000?l0003o0080
003o4`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo10000?l00`3o0000
oooo0?ooo`0B0?ooo`006@3oool00`3o0000003o0000o`020000oa<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0K0?ooo`@0003o00<0o`000?ooo`3oool04P3oool001T0oooo00<0
o`000000o`000?l00P000?lC0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3o
ool40000o`030?l0003oool0oooo0180oooo000I0?ooo`80o`0010000?lB0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06P3oool40000o`80o`00503oool001T0oooo0P3o00040000
oa80oooo1P0000040?ooo`030000003oool0oooo01X0oooo10000?l20?l001@0oooo000I0?ooo`80
o`0010000?lL0?ooo`030000003oool0oooo01X0oooo10000?l20?l001@0oooo000I0?ooo`80o`00
10000?lL0?ooo`030000003oool0oooo01X0oooo10000?l00`3o0000oooo0?ooo`0C0?ooo`006P3o
ool00`3o0000003o0000o`030000oa/0oooo00<000000?ooo`3oool06@3oool50000o`030?l0003o
ool0oooo01<0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0oooo01T0oooo10000?l2
0?l001D0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0oooo01T0oooo10000?l20?l0
01D0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0oooo01T0oooo10000?l20?l001D0
oooo000J0?ooo`80o`001@000?lJ0?ooo`030000003oool0oooo01P0oooo1@000?l20?l001D0oooo
000J0?ooo`80o`001@000?lJ0?ooo`030000003oool0oooo01P0oooo1@000?l20?l001D0oooo000K
0?ooo`030?l000000?l0003o00<0003o6P3oool2000001T0oooo10000?l30?l001D0oooo000K0?oo
o`80o`0010000?lJ0?ooo`030000003oool0oooo01P0oooo10000?l20?l001H0oooo000K0?ooo`80
o`001@000?lI0?ooo`030000003oool0oooo01L0oooo1@000?l20?l001H0oooo000K0?ooo`03003o
003o0000003o00@0003o6@3oool00`000000oooo0?ooo`0G0?ooo`D0003o0P3o000F0?ooo`00703o
ool00`3o0000003o0000o`030000oaT0oooo00<000000?ooo`3oool05`3oool50000o`80o`005P3o
ool001`0oooo00<0o`000000o`000?l00P000?l00`3oool0003o0?ooo`0G0?ooo`030000003oool0
oooo01H0oooo00<0003o0?ooo`000?l00`000?l20?l001H0oooo000L0?ooo`80o`001@000?lH0?oo
o`030000003oool0oooo01H0oooo1@000?l30?l001H0oooo000L0?ooo`80o`001@000?lH0?ooo`03
0000003oool0oooo01D0oooo00<0003o0?ooo`000?l00`000?l20?l001L0oooo000L0?ooo`03003o
003o0000003o00<0003o00<0oooo0000o`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
o`3oool0003o00<0003o0P3o000G0?ooo`007@3oool01@3o0000003o0000o`000?l0oooo0080003o
5`3oool00`000000oooo0?ooo`0E0?ooo`80003o00@0oooo0000o`000?l0003o0P3o000G0?ooo`00
7@3oool0103o0000003o0000o`3oool20000o`030?ooo`000?l0oooo01D0oooo00<000000?ooo`3o
ool0503oool00`000?l0oooo0000o`020000o`030?l000000?l0o`0001P0oooo000M0?ooo`80o`00
10000?l00`3oool0003o0?ooo`0D0?ooo`<0003o5@3oool00`000?l0oooo0000o`030000o`80o`00
603oool001d0oooo0P3o00030000o`040?ooo`000?l0oooo0000oa00oooo10000?l00`3oool00000
0?ooo`040000oa00oooo00@0003o0?ooo`000?l0oooo0`000?l20?l001P0oooo000M0?ooo`80o`00
0`000?l01@3oool0003o0?ooo`3oool0003o00`0oooo0`000?l50?ooo`030000003oool0oooo00<0
oooo0`000?l<0?ooo`050000o`3oool0oooo0000o`3oool00`000?l20?l001P0oooo000M0?ooo`80
o`000P000?l00`3oool0003o0000o`030?ooo`030000o`3oool0oooo00L0oooo0P000?l80?ooo`03
0000003oool0oooo00H0oooo0P000?l90?ooo`040000o`3oool0oooo0?ooo`80003o00@0oooo0000
o`000?l0o`006@3oool001h0oooo00<0o`000000o`3o00000P000?l00`3oool0003o0?ooo`020?oo
o`80003o103oool30000o`X0oooo00<000000?ooo`3oool0203oool30000o`@0oooo0P000?l30?oo
o`070000o`3oool0003o0000o`3o0000003o0?l0000I0?ooo`007P3oool20?l000<0003o00<0oooo
0000o`3oool0103oool40000o``0oooo0`000?l<0?ooo`@0003o1@3oool00`000?l0oooo0000o`02
0000o`80o`006@3oool001h0oooo0P3o00020000o`040?ooo`000?l0oooo0000oa40oooo0`000?l0
0`3oool000000?ooo`030000oa40oooo00@0003o0?ooo`000?l0oooo0P000?l20?l001T0oooo000N
0?ooo`80o`000P000?l01@3oool0003o0?ooo`3oool0003o00h0oooo0P000?l40?ooo`030000003o
ool0oooo0080oooo0P000?l>0?ooo`050000o`3oool0oooo0000o`3oool00P000?l20?l001T0oooo
000N0?ooo`80o`0000@0003o0?l000000?l0003o0P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o
1P3oool00`000000oooo0?ooo`040?ooo`80003o303oool00`000?l0oooo0?ooo`020000o`040?oo
o`000?l0o`000?l001T0oooo000O0?ooo`060?l000000?l0o`000000o`3oool0003o0P3oool00`00
0?l0oooo0?ooo`070?ooo`80003o203oool00`000000oooo0?ooo`060?ooo`80003o2@3oool02@00
0?l0oooo0?ooo`000?l0oooo0000o`3o0000003o0?l0000J0?ooo`007`3oool20?l00080003o00<0
oooo0000o`3oool00P3oool20000o`@0oooo0`000?l:0?ooo`030000003oool0oooo00P0oooo0`00
0?l40?ooo`80003o0`3oool010000?l0oooo0000o`000?l20?l001X0oooo000O0?ooo`80o`000P00
0?l20?ooo`030000o`3oool0oooo0080oooo10000?l<0?ooo`<0003o303oool40000o`@0oooo00<0
003o0?ooo`3oool00P000?l20?l001X0oooo000O0?ooo`07003o003o0000003o0?l000000?l0oooo
0000o`0A0?ooo`<0003o00<0oooo0000003oool00`000?lA0?ooo`050000o`3oool0003o0?ooo`00
0?l00P3o000J0?ooo`007`3oool01@00o`00o`000000o`3o0000003o0080oooo00<0003o0?ooo`3o
ool0303oool20000o`@0oooo00<000000?ooo`3oool00P3oool20000o`h0oooo00H0003o0?ooo`3o
ool0003o0?l000000?l20?l001X0oooo000P0?ooo`040?l000000?l0o`000000o`<0oooo00<0003o
0?ooo`3oool02@3oool20000o`H0oooo00<000000?ooo`3oool0103oool20000o`/0oooo00T0003o
0?ooo`3oool0oooo0000o`3o0000003o0?l00000o`006P3oool00200oooo0P3o00020000o`<0oooo
00<0003o0?ooo`3oool01`3oool20000o`P0oooo00<000000?ooo`3oool01P3oool20000o`T0oooo
00@0003o0?ooo`3oool0oooo0P000?l20?l001/0oooo000P0?ooo`05003o003o0000003o0?l00000
0?l00`3oool20000o`@0oooo0`000?l:0?ooo`030000003oool0oooo00P0oooo0`000?l40?ooo`80
003o0`3oool00`000?l0o`000000o`020?l001/0oooo000P0?ooo`05003o003o0000003o0?l00000
0?l01@3oool40000o``0oooo0`000?l<0?ooo`@0003o1@3oool01@000?l0o`000000o`3o00000?l0
01/0oooo000P0?ooo`06003o003o0000003o0?l0003oool0003o4@3oool30000o`030?ooo`000000
oooo00<0003o4@3oool01P000?l0oooo0?l000000?l0o`00003o01/0oooo000Q0?ooo`80o`0000<0
003o0?ooo`000?l0403oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0000o`020?l00003003o003oool0oooo01T0oooo000Q
0?ooo`80o`0000@0003o0?ooo`3oool0003o3@3oool20000o`D0oooo00<000000?ooo`3oool00`3o
ool20000o`d0oooo00@0003o0?ooo`3oool0003o0P3o000L0?ooo`008@3oool01P00o`00o`000000
o`3o0000oooo0000o``0oooo00<0003o0?ooo`3oool01@3oool2000000H0oooo00<0003o0?ooo`3o
ool02P3oool01P000?l0oooo0?l000000?l0o`00003o01`0oooo000Q0?ooo`04003o003o0000003o
0?l00080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool01`000?l0oooo0?ooo`3o0000003o0?l00000o`00
703oool00240oooo00@00?l00?l0003o0000003o0P3oool00`000?l0oooo0?ooo`060?ooo`80003o
2@3oool00`000000oooo0?ooo`070?ooo`80003o203oool010000?l0oooo0?ooo`000?l20?l00003
003o003oool0oooo01X0oooo000Q0?ooo`04003o003o0000o`000000o`<0oooo0P000?l40?ooo`80
003o2`3oool00`000000oooo0?ooo`090?ooo`80003o103oool20000o`<0oooo00@0003o0?l0003o
00000?l0703oool00280oooo0P3o00000`000?l0oooo0?ooo`030?ooo`@0003o303oool30000o``0
oooo10000?l50?ooo`040000o`3o0000o`00003o01`0oooo000R0?ooo`04003o003o0000003o0?l0
0140oooo0`000?l00`3oool000000?ooo`030000oa40oooo00@0o`000000o`3o00000?l07@3oool0
0280oooo00@00?l00?l0003o0000003o403oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<0003o0?ooo`3oool03P3oool010000?l0o`000?l00000o`0M0?ooo`008P3oool0
1000o`00o`000?l000000?l?0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0=0?ooo`040000o`3o0000o`00003o01d0oooo000R0?ooo`05003o003o
0000o`000?l000000?l03@3oool00`000?l0oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo
0?ooo`0;0?ooo`050000o`3o0000o`000?l00000o`007@3oool00280oooo00D00?l00?l0003o0000
o`000000o`0<0?ooo`030000o`3oool0oooo0080oooo1`3o00040?ooo`030000o`3oool0oooo00X0
oooo00@0003o0?l0003o0000o`007P3oool002<0oooo00D00?l00?l0003o0000o`000000o`0:0?oo
o`040000o`3oool0oooo0?ooo`X0o`00103oool00`000?l0oooo0?ooo`080?ooo`050000o`3o0000
o`000?l00000o`007P3oool002<0oooo00D00?l00?l0003o0000o`000000o`090?ooo`040000o`3o
ool0oooo0?ooo`d0o`000`3oool00`000?l0oooo0?ooo`070?ooo`050000o`3o0000o`000?l00000
o`007P3oool002<0oooo00H00?l00?l0003o0000o`000?ooo`000?l70?ooo`040000o`3oool0oooo
0?ooo`D0o`000P3oool00`000000oooo0?ooo`060?l00080oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?l000020?l00003003o003oool0oooo01`0oooo000S0?ooo`03003o003o0000o`00
0080o`0000<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`<0o`000P3oool5003o
00030?ooo`3o0000o`0000<0o`000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000o`00
0080o`0000<00?l00?ooo`3oool0703oool002<0oooo0P00o`030?l000030?ooo`000?l0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool40?l000050?ooo`00o`000?l00?ooo`0000000P3oool2003o
00030?ooo`3o0000o`000080o`000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`00
0080o`000P00o`0N0?ooo`003`3oool5000000T0oooo1P000002003o00<0o`000P3oool20000o`03
0?ooo`000?l00000008000001@3o00000`3oool00?l00?ooo`020?ooo`050000003oool0oooo0?oo
o`00o`000P3oool30?l000<0oooo00D000000000o`000?l000000000o`02000000<0o`000P00o`03
0?ooo`P000002@3oool5000000D0oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`800?l00`3o00040?ooo`030000o`3oool0oooo
0080oooo1@3o00001000o`00oooo0?ooo`3oool4003o0080oooo00<00?l00?ooo`3o00000`3o0005
0?ooo`030000o`3oool0oooo00@0o`0000<00?l00?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00?l00?l0
003o00000P3o00070?ooo`@0o`0000@0oooo003o003oool0oooo0P00o`000`3oool000000?ooo`02
003o0080oooo00<00?l00?ooo`3o00000`3o00040?ooo`030000003oool0oooo00<0o`000P00o`05
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00@3oool001D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`800?l00`3o00070?ooo`<0o`000P3oool01000
o`00oooo003o0000o`020?ooo`050000003oool0oooo0?ooo`00o`000P3oool00`00o`00oooo0?l0
00020?l000@0oooo00<000000?ooo`3oool00`3o0002003o00H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`010?ooo`005@3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo0?ooo`800?l00`3o00060?ooo`@0o`0000@0oooo003o003oool00?l0103oool00`000000oooo
0?ooo`020?ooo`04003o003oool00?l00?ooo`@0o`000`3oool00`000000oooo0?l000030?l00080
0?l01`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0040oooo00020?ooo`P00000
1`3oool8000000P0oooo0`000002003o00@0o`001@3oool30?l000050?ooo`00o`00oooo0?ooo`00
o`000P3oool5003o0080oooo00D00?l00?ooo`3oool00?l00?ooo`030?l000<0oooo00<000000?oo
o`3o00000P3o0003003o00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`010?oo
o`00503oool00`000000oooo0?ooo`0;0?ooo`030000003oool00?l000800?l00`3o00040?ooo`@0
o`0000@0oooo003o003oool00?l00P3oool2003o00050?ooo`000000oooo0?ooo`00o`000P3oool0
1000o`00oooo0?ooo`00o`040?l00080oooo00<000000?ooo`3o00000P3o0003003o00T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`004@3oool3000000l0oooo00@00000
003o0000o`000?l00`3o00040?ooo`<0o`0000H00000003o003oool0oooo003o003oool2003o0080
oooo00L000000?ooo`3oool0oooo003o003oool00?l00080oooo0P00o`030?l00080oooo00<00000
0?ooo`3o00000P3o0003003o00X0oooo00<000000?ooo`3oool02P3oool3000000D0oooo000D0?oo
o`030000003oool0oooo00d0oooo00<00000003o0000o`00103o00030?ooo`<0o`0000@00000003o
003oool00?l00P3oool01@00o`00oooo0?ooo`3oool0000000<0oooo00L00?l00?ooo`3oool00?l0
0?ooo`00o`00oooo00@0o`0000<0oooo0000003oool00`3o0003003o00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`040000
0000o`000?l0003o00<0o`000P3oool40?l0000600000000o`00oooo003o003oool00?l0103oool0
0`000000oooo0?ooo`020?ooo`03003o003oool00?l00080oooo00<00?l00?ooo`3o00000P3o0000
0`3oool000000?ooo`030?l000<00?l02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0040oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01000
00000?l0003o0000o`030?l00080oooo0`3o00001`3oool00?l00?ooo`3oool00?l00?ooo`00o`00
0`3oool4003o0080oooo00L00?l00?ooo`3oool00?l00?ooo`00o`00oooo00<0o`0000<0oooo0000
003o00000`3o0002003o00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0040oooo000>0?ooo`800000103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`00o`000P00o`030?l000030?ooo`3o0000o`000080
o`0000H0oooo003o003oool00?l00?ooo`00o`030?ooo`05003o003oool000000?ooo`00o`000`3o
ool01P00o`00oooo003o003oool00?l00?ooo`@0o`0000@000000?l0003o0000o`000`00o`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?oo
o`3oool00P3oool00100oooo1000000;0?ooo`@000000P3oool3003o00L0o`0000L00?l000000000
o`00oooo003o003oool00?l00080oooo0P00o`001@3oool000000?ooo`3oool00?l00080oooo00D0
0?l00?ooo`00o`00oooo003o00020?ooo`L0o`000`00o`070?ooo`@00000303oool4000000D0oooo
000U0?ooo`@00?l01P3o00020?ooo`05003o003oool00?l00?ooo`00o`000P3oool01000o`00oooo
0?ooo`0000020?ooo`08003o003oool0oooo003o003oool00?l00?ooo`00o`020?ooo`H0o`001000
o`0P0?ooo`009@3oool3003o00030?ooo`3o0000o`0000@0o`000P3oool01@00o`00oooo003o003o
ool00?l00080oooo00@00?l00?ooo`3oool000000P3oool01000o`00oooo0?ooo`00o`020?ooo`05
003o003oool00?l00?ooo`00o`001@3o0004003o0200oooo000U0?ooo`<00?l000<0oooo0?l0003o
00000`3o00000`00o`00oooo003o00020?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3o
ool000000`3oool00`00o`00oooo003o00020?ooo`05003o003oool00?l00?ooo`00o`00103o0000
0`00o`00oooo003o0002003o0200oooo000U0?ooo`<00?l000<0oooo003o003o00000`3o00000`00
o`00oooo003o00020?ooo`03003o003oool00?l00080oooo00@00?l00?ooo`3oool000000`3oool0
2P00o`00oooo0?ooo`00o`00oooo003o003oool00?l00?ooo`00o`040?l00003003o003oool00?l0
00800?l0803oool000T0oooo70000003003o00030000003o0000o`0000<0o`0000<00?l000000000
o`000P0000000`00o`000000003o000200000003003o00000000000000@0000000/00?l000000000
00000?l000000000o`000000003o000000000?l0000000030?l00003003o000000000?l000800?l0
700000040?ooo`009@3oool3003o00030?ooo`3o0000o`0000<0o`0000<00?l00?ooo`00o`000P3o
ool00`00o`00oooo003o00020?ooo`04003o003oool0oooo000000<0oooo00X00?l00?ooo`3oool0
0?l00?ooo`00o`00oooo003o003oool00?l0103o00000`00o`00oooo003o0002003o0200oooo000U
0?ooo`<00?l000<0oooo0?l0003o00000`3o00002000o`00oooo0?ooo`00o`00oooo003o003oool0
0?l00P3oool01000o`00oooo0?ooo`0000030?ooo`03003o003oool00?l00080oooo00D00?l00?oo
o`00o`00oooo003o00050?l000040?ooo`00o`000?l0003o0200oooo000U0?ooo`<00?l000<0oooo
0?l0003o0000103o00020?ooo`05003o003oool00?l00?ooo`00o`000P3oool01000o`00oooo0?oo
o`0000020?ooo`08003o003oool0oooo003o003oool00?l00?ooo`00o`020?ooo`03003o003o0000
o`0000<0o`001000o`0P0?ooo`009@3oool4003o00H0o`000P3oool01@00o`00oooo003o003oool0
0?l00080oooo00@00?l00?ooo`3oool000000P3oool02000o`00oooo0?ooo`00o`00oooo003o003o
ool00?l00P3oool60?l000@00?l0803oool002D0oooo0`00o`070?l00007003o003oool00?l00?oo
o`00o`00oooo003o00020?ooo`800?l000<0oooo0000003oool00P00o`020?ooo`05003o003oool0
0?l00?ooo`00o`000P3oool70?l000<00?l0803oool002D0oooo0`00o`030?l000030?ooo`3o0000
o`000080o`0000D0oooo003o003oool00?l00?ooo`02003o0080oooo0P00o`000`000000oooo003o
00020?ooo`800?l000D0oooo003o003oool00?l00?ooo`040?l000040?ooo`3o0000o`000?l000<0
0?l0803oool002D0oooo0`00o`030?l00080oooo0`3o00001`3oool00?l00?ooo`3oool00?l00?oo
o`00o`000`3oool3003o00<0oooo00L00?l00?ooo`3oool00?l00?ooo`00o`00oooo00<0o`000P3o
ool40?l000<00?l07`3oool002D0oooo0`00o`030?l00080oooo103o00001P3oool00?l00?ooo`00
o`00oooo003o00@0oooo00<000000?ooo`3oool00P3oool00`00o`00oooo003o00020?ooo`03003o
003oool0o`000080o`000`3oool30?l000<00?l07`3oool002D0oooo0P00o`040?l000<0oooo0`3o
0000103oool00?l00?ooo`00o`020?ooo`05003o003oool0oooo0?ooo`0000000`3oool01`00o`00
oooo0?ooo`00o`00oooo003o003oool0103o00030?ooo`<0o`000`00o`0O0?ooo`00903oool3003o
00<0o`00103oool30?l00080oooo00<00?l00?ooo`00o`000P3oool01000o`00oooo0?ooo`000003
0?ooo`03003o003oool00?l00080oooo0P00o`030?l000@0oooo0`3o0003003o01l0oooo000T0?oo
o`800?l0103o00040?ooo`@0o`0000@0oooo003o003oool00?l00P3oool2003o00030?ooo`000000
oooo00800?l00P3oool01000o`00oooo003o003oool40?l000@0oooo0`3o0003003o01l0oooo000T
0?ooo`800?l00`3o00060?ooo`<0o`0000D0oooo003o003oool0oooo003o00030?ooo`@00?l00P3o
ool01@00o`00oooo0?ooo`00o`00oooo00<0o`001@3oool40?l000800?l07`3oool002@0oooo0P00
o`030?l000H0oooo103o0000103oool00?l00?ooo`00o`040?ooo`030000003oool0oooo0080oooo
00@00?l00?ooo`00o`00oooo103o00060?ooo`<0o`000P00o`0O0?ooo`00903oool2003o00<0o`00
1`3oool30?l00080oooo00@00?l00?ooo`00o`000?l00P3oool01@000000oooo0?ooo`3oool00?l0
0080oooo00<00?l00?ooo`3o00000P3o00070?ooo`<0o`000P00o`0O0?ooo`00903oool00`00o`00
o`000?l000020?l000L0oooo103o0000103oool00?l00?ooo`3oool3003o00040000003oool00?l0
003o0080oooo00<00?l00?ooo`3o00000`3o00070?ooo`@0o`0000<00?l00?ooo`3oool07@3oool0
02<0oooo0P00o`030?l000@0oooo00<0003o0?ooo`3oool00P3oool50?l00004003o003oool0oooo
0?ooo`<00?l00`3oool00`00o`00oooo0?l000030?l000D0oooo00@0003o0?ooo`3oool0oooo0`3o
0002003o01h0oooo000S0?ooo`800?l00`3o00030?ooo`030000o`3oool0003o00<0oooo1@3o0000
0`3oool00?l0003o00020?ooo`070000003oool0oooo0?ooo`00o`00oooo003o00030?l000D0oooo
00<0003o0?ooo`000?l00P3oool30?l000800?l07P3oool002<0oooo0P00o`030?l000030?ooo`00
0?l0003o00<0oooo00<0003o0?ooo`3oool00P3oool40?l00080oooo00@00?l00?ooo`000000oooo
0P00o`000`3oool00?l00?l000030?l000<0oooo0P000?l30?ooo`030000o`3oool0o`000080o`00
0P00o`0N0?ooo`008`3oool00`00o`00o`000?l000020?l000030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool30?l00003003o003oool0oooo00<00?l00P3oool50?l000<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0o`000?l000020?l00003003o003oool0oooo01`0oooo000S
0?ooo`06003o003o0000o`000?l0003oool0003o1`3oool010000?l0oooo0?ooo`3oool50?l00080
oooo00<000000?ooo`3oool01P3o00020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
00000P3o00000`00o`00oooo0?ooo`0L0?ooo`008`3oool01@00o`00o`000?l0003o0000003o00T0
oooo00@0003o0?ooo`3oool0oooo3@3o00030?ooo`030000o`3oool0oooo00L0oooo00D0003o0?l0
003o0000o`00003o000N0?ooo`008`3oool01@00o`00o`000?l0003o0000003o00X0oooo00@0003o
0?ooo`3oool0oooo2P3o00040?ooo`030000o`3oool0oooo00P0oooo00D0003o0?l0003o0000o`00
003o000N0?ooo`008P3oool01@00o`00o`000?l0003o0000003o00`0oooo00<0003o0?ooo`3oool0
0P3oool70?l000@0oooo00<0003o0?ooo`3oool02P3oool01@000?l0o`000?l0003o00000?l001d0
oooo000R0?ooo`05003o003o0000o`000?l000000?l03@3oool00`000?l0oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool01@000?l0o`000?l0003o00000?l0
01d0oooo000R0?ooo`04003o003o0000o`000000o`l0oooo0P000?l40?ooo`030000003oool0oooo
0080oooo0P000?l?0?ooo`040000o`3o0000o`00003o01d0oooo000R0?ooo`04003o003o0000o`00
0000oa40oooo0P000?l20?ooo`030000003oool0oooo0080003o4@3oool010000?l0o`000?l00000
o`0M0?ooo`008P3oool01000o`00o`000000o`3o00060?ooo`030000o`3oool0oooo00X0oooo1@00
0?l=0?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`3o00000P00o`0L0?ooo`008P3oool2
0?l000030000o`3oool0oooo00<0oooo0P000?l00`3oool0003o0000o`0<0?ooo`030000003oool0
oooo00/0oooo0P000?l00`3oool0003o0000o`040?ooo`040000o`3o0000o`00003o01`0oooo000Q
0?ooo`04003o003o0000o`000000o`<0oooo0P000?l50?ooo`030000o`3oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool20000o`D0oooo00D0003o0?ooo`3oool0oooo0000o`020?l00003003o
003oool0oooo01X0oooo000Q0?ooo`04003o003o0000o`000000o`80oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1P3oool010000?l0oooo0?ooo`000?l20?l00003003o003oool0oooo01X0oooo000Q0?ooo`04003o
003o0000003o0?l00080oooo00<0003o0?ooo`3oool01`3oool20000o`P0oooo00<000000?ooo`3o
ool01P3oool20000o`T0oooo00L0003o0?ooo`3oool0o`000000o`3o00000?l001`0oooo000Q0?oo
o`06003o003o0000003o0?l0003oool0003o303oool00`000?l0oooo0?ooo`050?ooo`8000001P3o
ool00`000?l0oooo0?ooo`0:0?ooo`060000o`3oool0o`000000o`3o00000?l0703oool00240oooo
0P3o000010000?l0oooo0?ooo`000?l=0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000o`80o`00703oool00240
oooo0P3o00000`000?l0oooo0000o`0?0?ooo`80003o103oool00`000000oooo0?ooo`020?ooo`80
003o3`3oool00`000?l0oooo0000o`020?l00003003o003oool0oooo01T0oooo000P0?ooo`06003o
003o0000003o0?l0003oool0003o1P3oool00`000?l0oooo0?ooo`080?ooo`T0003o2`3oool00`00
0?l0oooo0?ooo`030?ooo`060000o`3oool0o`000000o`3o00000?l06`3oool00200oooo00D00?l0
0?l000000?l0o`000000o`050?ooo`80003o00<0oooo0000o`000?l0303oool00`000000oooo0?oo
o`0;0?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0o`000000o`020?l001/0oooo000P
0?ooo`05003o003o0000003o0?l000000?l00`3oool20000o`D0oooo00<0003o0?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`80003o1@3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00
0?l00P3o000K0?ooo`00803oool20?l00080003o0`3oool00`000?l0oooo0?ooo`060?ooo`80003o
2@3oool00`000000oooo0?ooo`070?ooo`80003o203oool010000?l0oooo0?ooo`3oool20000o`80
o`006`3oool00200oooo00@0o`000000o`3o0000003o0P3oool00`000?l0oooo0?ooo`090?ooo`80
003o1`3oool00`000000oooo0?ooo`050?ooo`80003o2`3oool01P000?l0oooo0?ooo`000?l0o`00
0000o`80o`006P3oool001l0oooo00D00?l00?l000000?l0o`000000o`020?ooo`030000o`3oool0
oooo00/0oooo0P000?l50?ooo`030000003oool0oooo00<0oooo0P000?l=0?ooo`060000o`3oool0
oooo0000o`3oool0003o0P3o000J0?ooo`007`3oool01`00o`00o`000000o`3o0000003o0?ooo`00
0?l0403oool30000o`80oooo00<000000?ooo`3oool00`000?l@0?ooo`050000o`3oool0003o0?oo
o`000?l00P3o000J0?ooo`007`3oool20?l00080003o00<0oooo0000o`3oool01@3oool30000o`/0
oooo1@000?l<0?ooo`<0003o1@3oool010000?l0oooo0000o`000?l20?l001X0oooo000O0?ooo`80
o`000P000?l00`3oool0003o0?ooo`020?ooo`<0003o0`3oool20000o`/0oooo00<000000?ooo`3o
ool02@3oool30000o`<0oooo0P000?l30?ooo`040000o`3oool0003o0000o`80o`006P3oool001l0
oooo00<0o`000000o`3o00000P000?l30?ooo`030000o`3oool0oooo00H0oooo0P000?l90?ooo`03
0000003oool0oooo00L0oooo0P000?l80?ooo`040000o`3oool0oooo0?ooo`80003o00@0oooo0000
o`3o0000o`006@3oool001h0oooo0P3o000010000?l0o`000000o`000?l20?ooo`030000o`3oool0
oooo00T0oooo0P000?l70?ooo`030000003oool0oooo00D0oooo0P000?l;0?ooo`030000o`3oool0
oooo0080003o00@0oooo0000o`3o0000o`006@3oool001h0oooo0P3o00020000o`050?ooo`000?l0
oooo0?ooo`000?l03@3oool20000o`D0oooo00<000000?ooo`3oool00`3oool20000o`d0oooo00D0
003o0?ooo`3oool0003o0?ooo`020000o`80o`006@3oool001h0oooo0P3o00030000o`80oooo00<0
003o0?ooo`3oool03P3oool;0000oa00oooo00@0003o0?ooo`000?l0oooo0P000?l20?l001T0oooo
000N0?ooo`80o`000`000?l00`3oool0003o0?ooo`050?ooo`<0003o3@3oool00`000000oooo0?oo
o`0<0?ooo`<0003o1@3oool00`000?l0oooo0000o`020000o`80o`006@3oool001h0oooo00<0o`00
0000o`3o00000P000?l00`3oool0003o0?ooo`020?ooo`<0003o0`3oool30000o`X0oooo00<00000
0?ooo`3oool0203oool40000o`<0oooo0P000?l30?ooo`070000o`3oool0003o0000o`3o0000003o
0?l0000I0?ooo`007@3oool20?l00080003o00<0oooo0000o`000?l00`3oool00`000?l0oooo0?oo
o`070?ooo`<0003o1`3oool00`000000oooo0?ooo`050?ooo`<0003o2@3oool010000?l0oooo0?oo
o`3oool20000o`050?ooo`000?l0003o0?l00000o`00603oool001d0oooo0P3o00030000o`050?oo
o`000?l0oooo0?ooo`000?l03@3oool20000o`D0oooo00<000000?ooo`3oool00`3oool20000o`d0
oooo00D0003o0?ooo`3oool0003o0?ooo`030000o`80o`00603oool001d0oooo0P3o00030000o`04
0?ooo`000?l0oooo0000oa00oooo0`000?l20?ooo`030000003oool0oooo00<0003o403oool01000
0?l0oooo0000o`3oool30000o`80o`00603oool001d0oooo0P3o00040000o`030?ooo`000?l0oooo
01<0oooo1@000?lD0?ooo`030000o`3oool0003o00<0003o0P3o000H0?ooo`007@3oool0203o0000
003o0000o`000?l0oooo0000o`3oool0003o5P3oool00`000000oooo0?ooo`0D0?ooo`050000o`3o
ool0003o0000o`3oool00P000?l00`3o0000oooo0?ooo`0F0?ooo`00703oool00`00o`00o`000000
o`020000o`030?ooo`000?l0003o01L0oooo00<000000?ooo`3oool05@3oool20000o`040?ooo`00
0?l0003o0000o`80o`005`3oool001`0oooo00<00?l00?l000000?l00`000?l00`3oool0003o0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`000?l00`000?l20?l001L0oooo000L
0?ooo`80o`001@000?lH0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`000?l00`000?l2
0?l001L0oooo000L0?ooo`80o`000P000?l00`3oool0003o0000o`0H0?ooo`030000003oool0oooo
01H0oooo0`000?l00`3oool0003o0?l000020?l001H0oooo000L0?ooo`030?l000000?l0003o0080
003o00<0oooo0000o`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0003o00<0
003o0P3o000F0?ooo`00703oool00`3o0000003o0000o`030000oaT0oooo00<000000?ooo`3oool0
5`3oool50000o`80o`005P3oool001/0oooo00<00?l00?l000000?l010000?lI0?ooo`030000003o
ool0oooo01L0oooo1@000?l20?l001H0oooo000K0?ooo`80o`000P000?l00`3oool0003o0000o`0I
0?ooo`030000003oool0oooo01L0oooo1@000?l20?l001H0oooo000K0?ooo`80o`0010000?lJ0?oo
o`8000006@3oool40000o`80o`005P3oool001/0oooo00<0o`000000o`000?l00`000?lJ0?ooo`03
0000003oool0oooo01P0oooo10000?l30?l001D0oooo000J0?ooo`80o`001@000?lJ0?ooo`030000
003oool0oooo01P0oooo1@000?l20?l001D0oooo000J0?ooo`80o`001@000?lJ0?ooo`030000003o
ool0oooo01P0oooo1@000?l20?l001D0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0
oooo01T0oooo10000?l20?l001D0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0oooo
01T0oooo10000?l20?l001D0oooo000J0?ooo`80o`0010000?lK0?ooo`030000003oool0oooo01T0
oooo10000?l20?l001D0oooo000J0?ooo`030?l000000?l0003o00<0003o6`3oool00`000000oooo
0?ooo`0I0?ooo`D0003o00<0o`000?ooo`3oool04`3oool001T0oooo0P3o00040000oa`0oooo00<0
00000?ooo`3oool06P3oool40000o`030?l0003oool0oooo01<0oooo000I0?ooo`80o`0010000?lL
0?ooo`030000003oool0oooo01X0oooo10000?l20?l001@0oooo000I0?ooo`80o`0010000?lL0?oo
o`030000003oool0oooo01X0oooo10000?l20?l001@0oooo000I0?ooo`80o`0010000?lC0?ooo`@0
00001@3oool00`000000oooo0?ooo`0J0?ooo`@0003o0P3o000D0?ooo`006@3oool00`3o0000003o
0000o`020000oa<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01/0oooo10000?l00`3o0000oooo0?ooo`0B0?ooo`006@3oool00`3o0000003o0000
o`020000oa80oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000001d0oooo
10000?l00`3o0000oooo0?ooo`0B0?ooo`006@3oool00`3o0000003o0000o`020000oaT0oooo00D0
00000?ooo`3oool0oooo0000000M0?ooo`@0003o00<0o`000?ooo`3oool04P3oool001T0oooo00<0
o`000000o`000?l00P000?lI0?ooo`050000003oool0oooo0?ooo`0000007@3oool40000o`030?l0
003oool0oooo0180oooo000H0?ooo`80o`000`000?lJ0?ooo`040000003oool0oooo0?ooo`800000
7@3oool30000o`030?l00000o`00oooo0180oooo000H0?ooo`030?l000000?l0003o0080003o503o
ool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`<0003o0P3o
000C0?ooo`00603oool00`3o0000003o0000o`020000oa@0oooo00<000000?ooo`0000000P000005
0?ooo`030000003oool0oooo01`0oooo10000?l00`3o0000oooo0?ooo`0A0?ooo`00603oool00`3o
0000003o0000o`020000oa@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?oo
o`@0003o00<0o`000?ooo`3oool04@3oool001P0oooo00@0o`000000o`000?l0003o5@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo0`000?l00`3o0000oooo0?ooo`0A0?oo
o`00603oool0103o0000003o0000o`000?lE0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07@3oool30000o`030?l0003oool0oooo0140oooo000G0?ooo`80o`000`000?lE0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool30000o`80o`004P3oool001L0oooo
00<0o`000000o`000?l00P000?lE0?ooo`H00000103oool00`000000oooo0?ooo`0M0?ooo`@0003o
00<0o`000?ooo`3oool0403oool001L0oooo00<0o`000000o`000?l00P000?lO0?ooo`030000003o
ool0oooo01d0oooo10000?l00`3o0000oooo0?ooo`0@0?ooo`005`3oool0103o0000003o0000o`00
0?lP0?ooo`030000003oool0oooo01h0oooo0`000?l00`3o0000oooo0?ooo`0@0?ooo`005P3oool2
0?l000<0003o803oool00`000000oooo0?ooo`0N0?ooo`<0003o0P3o000A0?ooo`005P3oool20?l0
00<0003o803oool00`000000oooo0?ooo`0N0?ooo`<0003o0P3o000A0?ooo`005P3oool20?l000<0
003o803oool00`000000oooo0?ooo`0N0?ooo`@0003o00<0o`000?ooo`3oool03`3oool001H0oooo
00@0o`000000o`000?l0003o8@3oool00`000000oooo0?ooo`0N0?ooo`@0003o00<0o`000?ooo`3o
ool03`3oool001H0oooo00@0o`000000o`000?l0003o8@3oool00`000000oooo0?ooo`0O0?ooo`<0
003o00<0o`000?ooo`3oool03`3oool001H0oooo00@0o`000000o`000?l0003o8@3oool00`000000
oooo0?ooo`0O0?ooo`<0003o00<0o`000?ooo`3oool03`3oool001D0oooo0P3o00030000ob40oooo
0P00000P0?ooo`<0003o00<0o`000?ooo`3oool03`3oool001D0oooo0P3o00030000ob40oooo00<0
00000?ooo`3oool07`3oool30000o`80o`00403oool001D0oooo0P3o00020000ob80oooo00<00000
0?ooo`3oool0803oool30000o`030?l0003oool0oooo00h0oooo000E0?ooo`80o`000P000?lR0?oo
o`030000003oool0oooo0200oooo0`000?l00`3o0000oooo0?ooo`0>0?ooo`005@3oool20?l00080
003o8P3oool00`000000oooo0?ooo`0P0?ooo`<0003o00<0o`000?ooo`3oool03P3oool001D0oooo
00@0o`000000o`000?l0003o8P3oool00`000000oooo0?ooo`0P0?ooo`<0003o00<0o`000?ooo`3o
ool03P3oool001D0oooo00@0o`000000o`000?l0003o8P3oool00`000000oooo0?ooo`0P0?ooo`<0
003o00<0o`000?ooo`3oool03P3oool001D0oooo00@0o`000000o`000?l0003o8P3oool00`000000
oooo0?ooo`0Q0?ooo`<0003o403oool001@0oooo0P3o00020000ob<0oooo00<000000?ooo`3oool0
8@3oool30000oa00oooo000D0?ooo`80o`000P000?lS0?ooo`030000003oool0oooo0240oooo0`00
0?l00`3o0000oooo0?ooo`0=0?ooo`00503oool20?l00080003o8`3oool00`000000oooo0?ooo`0Q
0?ooo`<0003o00<0o`000?ooo`3oool03@3oool001@0oooo0P3o00020000ob<0oooo00<000000?oo
o`3oool08@3oool30000o`030?l0003oool0oooo00d0oooo000D0?ooo`040?l000000?l0003o0000
ob<0oooo00<000000?ooo`3oool08P3oool20000o`030?l0003oool0oooo00d0oooo000D0?ooo`04
0?l000000?l0003o0000ob<0oooo00<000000?ooo`3oool08P3oool20000o`030?l0003oool0oooo
00d0oooo000D0?ooo`040?l000000?l0003o0000ob<0oooo00<000000?ooo`3oool08P3oool30000
o`l0oooo000D0?ooo`040?l000000?l0003o0000ob<0oooo00<000000?ooo`3oool08P3oool30000
o`l0oooo000C0?ooo`80o`000P000?lT0?ooo`8000008`3oool30000o`l0oooo000C0?ooo`040?l0
00000?l0003o0000ob@0oooo00<000000?ooo`3oool08`3oool20000o`030?l0003oool0oooo00`0
oooo000C0?ooo`040?l000000?l0003o0000ob@0oooo00<000000?ooo`3oool08`3oool20000o`03
0?l0003oool0oooo00`0oooo000C0?ooo`040?l000000?l0003o0000ob@0oooo00<000000?ooo`3o
ool08`3oool20000o`030?l0003oool0oooo00`0oooo000C0?ooo`040?l000000?l0003o0000ob@0
oooo00<000000?ooo`3oool08`3oool20000o`030?l0003oool0oooo00`0oooo000C0?ooo`040?l0
00000?l0003o0000ob@0oooo00<000000?ooo`3oool08`3oool20000o`030?l0003oool0oooo00`0
oooo000C0?ooo`030?l000000?l0003o02D0oooo00<000000?ooo`3oool08`3oool30000o`030?l0
003oool0oooo00/0oooo000C0?ooo`<0003o9@3oool00`000000oooo0?ooo`0T0?ooo`80003o00<0
o`000?ooo`3oool02`3oool00180oooo00@0o`000000o`000?l0003o9@3oool00`000000oooo0?oo
o`0T0?ooo`80003o00<0o`000?ooo`3oool02`3oool00180oooo00@0o`000000o`000?l0003o9@3o
ool00`000000oooo0?ooo`0T0?ooo`80003o00<0o`000?ooo`3oool02`3oool00180oooo00<0o`00
0000o`000?l09P3oool00`000000oooo0?ooo`0T0?ooo`80003o0P3o000<0?ooo`004P3oool00`3o
0000003o0000o`0V0?ooo`030000003oool0oooo02@0oooo0P000?l20?l000`0oooo000B0?ooo`03
0?l000000?l0003o02H0oooo00<000000?ooo`3oool0903oool20000o`80o`00303oool00180oooo
0`000?lV0?ooo`030000003oool0oooo02@0oooo0`000?l00`3o0000oooo0?ooo`0:0?ooo`004P3o
ool30000obH0oooo00<000000?ooo`3oool09@3oool20000o`030?l0003oool0oooo00X0oooo000B
0?ooo`80003o00<0o`000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`80003o00<0o`00
0?ooo`3oool02P3oool00140oooo00<0o`000000o`000?l09`3oool2000002H0oooo0P000?l00`3o
0000oooo0?ooo`0:0?ooo`004@3oool00`3o0000003o0000o`0W0?ooo`030000003oool0oooo02D0
oooo0P000?l20?l000/0oooo000A0?ooo`030?l000000?l0003o02L0oooo00<000000?ooo`3oool0
9@3oool20000o`80o`002`3oool00140oooo00<0o`000000o`000?l09`3oool00`000000oooo0?oo
o`0U0?ooo`80003o0P3o000;0?ooo`004@3oool00`3o0000003o0000o`0W0?ooo`030000003oool0
oooo02D0oooo0P000?l20?l000/0oooo000A0?ooo`80003o00<0o`000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0V0?ooo`80003o00<0o`000?ooo`3oool02@3oool00140oooo0P000?l00`3o0000
oooo0?ooo`0U0?ooo`030000003oool0oooo02H0oooo0P000?l00`3o0000oooo0?ooo`090?ooo`00
4@3oool20000o`030?l0003oool0oooo02D0oooo00<000000?ooo`3oool09P3oool20000o`030?l0
003oool0oooo00T0oooo000@0?ooo`030?l000000?l0003o02P0oooo00<000000?ooo`3oool09P3o
ool20000o`80o`002P3oool00100oooo00<0o`000000o`000?l0:03oool00`000000oooo0?ooo`0V
0?ooo`80003o0P3o000:0?ooo`00403oool00`3o0000003o0000o`0X0?ooo`030000003oool0oooo
02H0oooo0P000?l20?l000X0oooo000@0?ooo`030?l000000?l0003o02P0oooo00<000000?ooo`3o
ool09P3oool20000o`80o`002P3oool00100oooo00<0o`000000o`3o0000:03oool00`000000oooo
0?ooo`0W0?ooo`80003o00<0o`000?ooo`3oool0203oool00100oooo00<0o`000000o`3o0000:03o
ool00`000000oooo0?ooo`0W0?ooo`80003o00<0o`000?ooo`3oool0203oool00100oooo00<0o`00
0000o`3o0000:03oool00`000000oooo0?ooo`0W0?ooo`80003o00<0o`000?ooo`3oool0203oool0
00l0oooo00<0o`000000o`000?l0:@3oool00`000000oooo0?ooo`0W0?ooo`80003o0P3o00090?oo
o`003`3oool00`3o0000003o0000o`0Y0?ooo`800000:03oool20000o`80o`002@3oool000l0oooo
00<0o`000000o`000?l0:@3oool00`000000oooo0?ooo`0W0?ooo`80003o0P3o00090?ooo`003`3o
ool00`3o0000003o0000o`0Y0?ooo`030000003oool0oooo02L0oooo0`000?l00`3o0000oooo0?oo
o`070?ooo`003`3oool00`3o0000003o0000o`0Y0?ooo`030000003oool0oooo02P0oooo0P000?l0
0`3o0000oooo0?ooo`070?ooo`003`3oool00`3o0000003o0000o`0Y0?ooo`030000003oool0oooo
02P0oooo0P000?l00`3o0000oooo0?ooo`070?ooo`003`3oool00`3o0000003o0?l0000Y0?ooo`03
0000003oool0oooo02P0oooo0P000?l00`3o0000oooo0?ooo`070?ooo`003P3oool20?l000030000
o`3oool0oooo02P0oooo00<000000?ooo`3oool0:03oool20000o`030?l0003oool0oooo00L0oooo
000>0?ooo`80o`0000<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`80003o00<0
o`000?ooo`3oool01`3oool000h0oooo00<0o`000000o`000?l0:P3oool00`000000oooo0?ooo`0X
0?ooo`80003o00<0o`000?ooo`3oool01`3oool000h0oooo00<0o`000000o`000?l0:P3oool00`00
0000oooo0?ooo`0X0?ooo`030?l000000?l0o`0000T0oooo000>0?ooo`030?l000000?l0003o02X0
oooo00<000000?ooo`3oool0:03oool00`3o0000003o0?l000090?ooo`003P3oool00`3o0000003o
0000o`0D0?ooo`L000001P3oool4000000D0oooo00<000000?ooo`3oool0:03oool00`3o0000003o
0000o`090?ooo`003@3oool20?l00080003o5`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`030?l00000
0?l0003o00T0oooo000=0?ooo`80o`000P000?lG0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo0P000?l0
0`3o0000oooo0?ooo`060?ooo`003@3oool00`3o0000003o0000o`0H0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo0P000?l0
0`3o0000oooo0?ooo`060?ooo`003@3oool00`3o0000003o0000o`0H0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo0P000?l0
0`3o0000oooo0?ooo`060?ooo`003@3oool00`3o0000003o0000o`0H0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000002X0oooo0P000?l0
0`3o0000oooo0?ooo`060?ooo`003@3oool00`3o0000003o0000o`0H0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000002/0oooo00<0o`00
0000o`3o0000203oool000`0oooo0P3o00020000oaP0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000:`3oool00`3o0000003o0?l00008
0?ooo`00303oool20?l00080003o603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000o`3o0000o`0000L0oooo000<0?oo
o`80o`0000<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000o`3o0000o`0000L0oooo000<0?oo
o`030?l000000?l0003o01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0:P3oool20000o`030?l0003oool0oooo
00D0oooo000<0?ooo`030?l000000?l0003o01D0oooo0`0000000`3oool000000?ooo`070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`80
003o00<0o`000?ooo`3oool01@3oool000`0oooo00<0o`000000o`000?l0603oool2000000T0oooo
100000050?ooo`030000003oool0oooo02X0oooo0P000?l00`3o0000oooo0?ooo`050?ooo`00303o
ool00`3o0000003o0000o`0/0?ooo`030000003oool0oooo02X0oooo0P000?l00`3o0000oooo0?oo
o`050?ooo`00303oool00`3o0000003o0000o`0/0?ooo`030000003oool0oooo02X0oooo0P000?l0
0`3o0000oooo0?ooo`050?ooo`00303oool00`3o0000003o0000o`0/0?ooo`030000003oool0oooo
02X0oooo0P000?l00`3o0000oooo0?ooo`050?ooo`002`3oool20?l000030000o`3o0000oooo02/0
oooo00<000000?ooo`3oool0:P3oool0103o0000003o0?l0003o00060?ooo`002`3oool20?l00003
0000o`3oool0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000?l0o`000?l000060?ooo`00
2`3oool00`3o0000003o0000o`0]0?ooo`030000003oool0oooo02/0oooo0P000?l00`3o0000oooo
0?ooo`040?ooo`002`3oool00`3o0000003o0000o`0]0?ooo`030000003oool0oooo02/0oooo0P00
0?l00`3o0000oooo0?ooo`040?ooo`002`3oool00`3o0000003o0000o`0]0?ooo`800000;03oool2
0000o`030?l0003oool0oooo00@0oooo000;0?ooo`030?l000000?l0003o02d0oooo00<000000?oo
o`3oool0:`3oool20000o`030?l0003oool0oooo00@0oooo000;0?ooo`030?l000000?l0003o02d0
oooo00<000000?ooo`3oool0:`3oool20000o`030?l0003oool0oooo00@0oooo000;0?ooo`030?l0
00000?l0o`0002d0oooo00<000000?ooo`3oool0:`3oool20000o`80o`001@3oool000/0oooo00<0
o`000000o`3o0000;@3oool00`000000oooo0?ooo`0/0?ooo`80003o00<0o`000?ooo`3oool00`3o
ool000/0oooo00<0o`000000o`3o0000;@3oool00`000000oooo0?ooo`0/0?ooo`80003o00<0o`00
0?ooo`3oool00`3oool000/0oooo00<0o`000000o`3o0000;@3oool00`000000oooo0?ooo`0/0?oo
o`80003o00<0o`000?ooo`3oool00`3oool000`0oooo00<0003o0?ooo`3oool0;03oool00`000000
oooo0?ooo`0/0?ooo`80003o1P3oool000`0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo
0?ooo`0/0?ooo`80003o1P3oool000`0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo00@0oooo000<0?ooo`030000o`3oool0oooo02`0oooo00<00000
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`040?ooo`00303oool00`000?l0oooo0?ooo`0/0?oo
o`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0103oool000`0oooo00<0003o0?ooo`3o
ool0;03oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00@0oooo000k0?ooo`030000
003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0
oooo03@0oooo000k0?ooo`800000=@3oool003/0oooo00<000000?ooo`3oool0=03oool003/0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool0=03oool003/0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool0=03oool00780oooo001b0?ooo`00LP3o
ool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00
LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?oo
o`00LP3oool00780oooo001b0?ooo`00LP3oool00780oooo001b0?ooo`00LP3oool00001\
\>"],
  ImageRangeCache->{{{106.125, 150.813}, {429.688, 252.188}} -> {-20.7541, \
26.159, 0.128044, 0.128044}}],

Cell[TextData[{
  "The ",
  "separatrice",
  StyleBox[", ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["red energy",
    FontColor->RGBColor[1, 0, 0]],
  ", separates the trajectories corresponding to less values of energy, green \
curves and the curves with more values of energy, blue curves. "
}], "Text",
  CellMargins->{{18.5, Inherited}, {Inherited, Inherited}}]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{1013, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->2
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 203, 5, 209, "Title"],
Cell[1960, 58, 183, 4, 130, "Subsection"],
Cell[2146, 64, 622, 16, 134, "Text"],
Cell[2771, 82, 181, 3, 158, "Title"],
Cell[2955, 87, 844, 25, 160, "Text"],
Cell[3802, 114, 118, 2, 55, "Input"],
Cell[3923, 118, 242, 6, 94, "Text"],
Cell[4168, 126, 331, 10, 61, "Text"],
Cell[4502, 138, 170, 5, 61, "Text"],
Cell[4675, 145, 107, 2, 55, "Input"],
Cell[4785, 149, 121, 2, 57, "Input"],
Cell[4909, 153, 155, 3, 61, "Text"],
Cell[5067, 158, 233, 4, 124, "Input"],
Cell[5303, 164, 69404, 1463, 433, 11302, 740, "GraphicsData", "PostScript", \
"Graphics"],
Cell[74710, 1629, 151, 2, 61, "Text"],
Cell[74864, 1633, 173, 4, 61, "Text"],
Cell[75040, 1639, 121, 2, 57, "Input"],
Cell[75164, 1643, 177, 4, 61, "Text"],
Cell[75344, 1649, 256, 5, 132, "Input"],
Cell[75603, 1656, 104285, 1837, 506, 9778, 666, "GraphicsData", "PostScript", \
"Graphics"],
Cell[179891, 3495, 308, 6, 124, "Input"],
Cell[180202, 3503, 51617, 1799, 385, 22775, 1437, "GraphicsData", \
"PostScript", "Graphics"],
Cell[231822, 5304, 306, 6, 124, "Input"],
Cell[232131, 5312, 38915, 1009, 414, 9788, 643, "GraphicsData", "PostScript", \
"Graphics"],
Cell[271049, 6323, 389, 7, 127, "Text"],
Cell[271441, 6332, 118, 2, 55, "Input"],
Cell[271562, 6336, 144, 2, 55, "Output"],
Cell[271709, 6340, 221, 6, 61, "Text"],
Cell[271933, 6348, 181, 3, 83, "Input"],
Cell[272117, 6353, 95, 2, 55, "Output"],
Cell[272215, 6357, 222, 5, 61, "Text"],
Cell[272440, 6364, 313, 7, 124, "Input"],
Cell[272756, 6373, 30969, 775, 367, 7192, 477, "GraphicsData", "PostScript", \
"Graphics"],
Cell[303728, 7150, 88, 1, 61, "Text"],
Cell[303819, 7153, 114, 2, 55, "Input"],
Cell[303936, 7157, 81608, 2688, 463, 33264, 2087, "GraphicsData", \
"PostScript", "Graphics"],
Cell[385547, 9847, 371, 10, 94, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

